//
//                           VELOXCHEM 1.0-RC
//      ---------------------------------------------------
//                     An Electronic Structure Code
//
//  Copyright © 2018-2020 by VeloxChem developers. All rights reserved.
//  Contact: https://veloxchem.org/contact

#include "ElectronRepulsionRecFuncForDX.hpp"

namespace erirecfunc { // erirecfunc namespace

    void
    compElectronRepulsionForSDSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_x_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx); 

                auto tg_x_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 1); 

                auto tg_x_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 2); 

                auto tg_x_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 3); 

                auto tg_x_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 4); 

                auto tg_x_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 5); 

                auto tg_y_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 6); 

                auto tg_y_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 7); 

                auto tg_y_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 8); 

                auto tg_y_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 9); 

                auto tg_y_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 10); 

                auto tg_y_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 11); 

                auto tg_z_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 12); 

                auto tg_z_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 13); 

                auto tg_z_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 14); 

                auto tg_z_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 15); 

                auto tg_z_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 16); 

                auto tg_z_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 17); 

                auto tg_x_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx); 

                auto tg_x_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 1); 

                auto tg_x_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 2); 

                auto tg_x_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 3); 

                auto tg_x_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 4); 

                auto tg_x_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 5); 

                auto tg_y_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 6); 

                auto tg_y_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 7); 

                auto tg_y_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 8); 

                auto tg_y_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 9); 

                auto tg_y_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 10); 

                auto tg_y_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 11); 

                auto tg_z_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 12); 

                auto tg_z_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 13); 

                auto tg_z_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 14); 

                auto tg_z_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 15); 

                auto tg_z_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 16); 

                auto tg_z_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 17); 

                auto tg_0_xx_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx); 

                auto tg_0_xy_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx + 1); 

                auto tg_0_xz_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx + 2); 

                auto tg_0_yy_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx + 3); 

                auto tg_0_yz_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx + 4); 

                auto tg_0_zz_0 = primBuffer[pidx_g_0_2_m0].data(6 * idx + 5); 

                auto tg_0_xx_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx); 

                auto tg_0_xy_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx + 1); 

                auto tg_0_xz_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx + 2); 

                auto tg_0_yy_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx + 3); 

                auto tg_0_yz_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx + 4); 

                auto tg_0_zz_1 = primBuffer[pidx_g_0_2_m1].data(6 * idx + 5); 

                auto tg_x_x_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx); 

                auto tg_x_y_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 1); 

                auto tg_x_z_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 2); 

                auto tg_y_x_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 3); 

                auto tg_y_y_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 4); 

                auto tg_y_z_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 5); 

                auto tg_z_x_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 6); 

                auto tg_z_y_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 7); 

                auto tg_z_z_1 = primBuffer[pidx_g_1_1_m1].data(9 * idx + 8); 

                // set up pointers to integrals

                auto tg_xx_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx); 

                auto tg_xx_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 1); 

                auto tg_xx_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 2); 

                auto tg_xx_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 3); 

                auto tg_xx_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 4); 

                auto tg_xx_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 5); 

                auto tg_xy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 6); 

                auto tg_xy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 7); 

                auto tg_xy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 8); 

                auto tg_xy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 9); 

                auto tg_xy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 10); 

                auto tg_xy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 11); 

                auto tg_xz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 12); 

                auto tg_xz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 13); 

                auto tg_xz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 14); 

                auto tg_xz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 15); 

                auto tg_xz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 16); 

                auto tg_xz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 17); 

                auto tg_yy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 18); 

                auto tg_yy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 19); 

                auto tg_yy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 20); 

                auto tg_yy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 21); 

                auto tg_yy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 22); 

                auto tg_yy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 23); 

                auto tg_yz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 24); 

                auto tg_yz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 25); 

                auto tg_yz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 26); 

                auto tg_yz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 27); 

                auto tg_yz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 28); 

                auto tg_yz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 29); 

                auto tg_zz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 30); 

                auto tg_zz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 31); 

                auto tg_zz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 32); 

                auto tg_zz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 33); 

                auto tg_zz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 34); 

                auto tg_zz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 35); 

                #pragma omp simd aligned(fxn, fza, tg_0_xx_0, tg_0_xx_1, tg_0_xy_0, tg_0_xy_1, tg_0_xz_0, tg_0_xz_1, \
                                         tg_0_yy_0, tg_0_yy_1, tg_0_yz_0, tg_0_yz_1, tg_0_zz_0, tg_0_zz_1, tg_x_x_1, \
                                         tg_x_xx_0, tg_x_xx_1, tg_x_xy_0, tg_x_xy_1, tg_x_xz_0, tg_x_xz_1, tg_x_y_1, \
                                         tg_x_yy_0, tg_x_yy_1, tg_x_yz_0, tg_x_yz_1, tg_x_z_1, tg_x_zz_0, tg_x_zz_1, \
                                         tg_xx_xx_0, tg_xx_xy_0, tg_xx_xz_0, tg_xx_yy_0, tg_xx_yz_0, tg_xx_zz_0, tg_xy_xx_0, \
                                         tg_xy_xy_0, tg_xy_xz_0, tg_xy_yy_0, tg_xy_yz_0, tg_xy_zz_0, tg_xz_xx_0, tg_xz_xy_0, \
                                         tg_xz_xz_0, tg_xz_yy_0, tg_xz_yz_0, tg_xz_zz_0, tg_y_x_1, tg_y_xx_0, tg_y_xx_1, \
                                         tg_y_xy_0, tg_y_xy_1, tg_y_xz_0, tg_y_xz_1, tg_y_y_1, tg_y_yy_0, tg_y_yy_1, \
                                         tg_y_yz_0, tg_y_yz_1, tg_y_z_1, tg_y_zz_0, tg_y_zz_1, tg_yy_xx_0, tg_yy_xy_0, \
                                         tg_yy_xz_0, tg_yy_yy_0, tg_yy_yz_0, tg_yy_zz_0, tg_yz_xx_0, tg_yz_xy_0, tg_yz_xz_0, \
                                         tg_yz_yy_0, tg_yz_yz_0, tg_yz_zz_0, tg_z_x_1, tg_z_xx_0, tg_z_xx_1, tg_z_xy_0, \
                                         tg_z_xy_1, tg_z_xz_0, tg_z_xz_1, tg_z_y_1, tg_z_yy_0, tg_z_yy_1, tg_z_yz_0, \
                                         tg_z_yz_1, tg_z_z_1, tg_z_zz_0, tg_z_zz_1, tg_zz_xx_0, tg_zz_xy_0, tg_zz_xz_0, \
                                         tg_zz_yy_0, tg_zz_yz_0, tg_zz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xx_0[j] = pb_x * tg_x_xx_0[j] + fr * tg_x_xx_1[j] + 0.5 * fl1_fx * (tg_0_xx_0[j] - tg_0_xx_1[j] * fl1_fza) + fl1_fxn * tg_x_x_1[j];

                    tg_xx_xy_0[j] = pb_x * tg_x_xy_0[j] + fr * tg_x_xy_1[j] + 0.5 * fl1_fx * (tg_0_xy_0[j] - tg_0_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_y_1[j];

                    tg_xx_xz_0[j] = pb_x * tg_x_xz_0[j] + fr * tg_x_xz_1[j] + 0.5 * fl1_fx * (tg_0_xz_0[j] - tg_0_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_z_1[j];

                    tg_xx_yy_0[j] = pb_x * tg_x_yy_0[j] + fr * tg_x_yy_1[j] + 0.5 * fl1_fx * (tg_0_yy_0[j] - tg_0_yy_1[j] * fl1_fza);

                    tg_xx_yz_0[j] = pb_x * tg_x_yz_0[j] + fr * tg_x_yz_1[j] + 0.5 * fl1_fx * (tg_0_yz_0[j] - tg_0_yz_1[j] * fl1_fza);

                    tg_xx_zz_0[j] = pb_x * tg_x_zz_0[j] + fr * tg_x_zz_1[j] + 0.5 * fl1_fx * (tg_0_zz_0[j] - tg_0_zz_1[j] * fl1_fza);

                    tg_xy_xx_0[j] = pb_x * tg_y_xx_0[j] + fr * tg_y_xx_1[j] + fl1_fxn * tg_y_x_1[j];

                    tg_xy_xy_0[j] = pb_x * tg_y_xy_0[j] + fr * tg_y_xy_1[j] + 0.5 * fl1_fxn * tg_y_y_1[j];

                    tg_xy_xz_0[j] = pb_x * tg_y_xz_0[j] + fr * tg_y_xz_1[j] + 0.5 * fl1_fxn * tg_y_z_1[j];

                    tg_xy_yy_0[j] = pb_x * tg_y_yy_0[j] + fr * tg_y_yy_1[j];

                    tg_xy_yz_0[j] = pb_x * tg_y_yz_0[j] + fr * tg_y_yz_1[j];

                    tg_xy_zz_0[j] = pb_x * tg_y_zz_0[j] + fr * tg_y_zz_1[j];

                    tg_xz_xx_0[j] = pb_x * tg_z_xx_0[j] + fr * tg_z_xx_1[j] + fl1_fxn * tg_z_x_1[j];

                    tg_xz_xy_0[j] = pb_x * tg_z_xy_0[j] + fr * tg_z_xy_1[j] + 0.5 * fl1_fxn * tg_z_y_1[j];

                    tg_xz_xz_0[j] = pb_x * tg_z_xz_0[j] + fr * tg_z_xz_1[j] + 0.5 * fl1_fxn * tg_z_z_1[j];

                    tg_xz_yy_0[j] = pb_x * tg_z_yy_0[j] + fr * tg_z_yy_1[j];

                    tg_xz_yz_0[j] = pb_x * tg_z_yz_0[j] + fr * tg_z_yz_1[j];

                    tg_xz_zz_0[j] = pb_x * tg_z_zz_0[j] + fr * tg_z_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yy_xx_0[j] = pb_y * tg_y_xx_0[j] + fr * tg_y_xx_1[j] + 0.5 * fl1_fx * (tg_0_xx_0[j] - tg_0_xx_1[j] * fl1_fza);

                    tg_yy_xy_0[j] = pb_y * tg_y_xy_0[j] + fr * tg_y_xy_1[j] + 0.5 * fl1_fx * (tg_0_xy_0[j] - tg_0_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_x_1[j];

                    tg_yy_xz_0[j] = pb_y * tg_y_xz_0[j] + fr * tg_y_xz_1[j] + 0.5 * fl1_fx * (tg_0_xz_0[j] - tg_0_xz_1[j] * fl1_fza);

                    tg_yy_yy_0[j] = pb_y * tg_y_yy_0[j] + fr * tg_y_yy_1[j] + 0.5 * fl1_fx * (tg_0_yy_0[j] - tg_0_yy_1[j] * fl1_fza) + fl1_fxn * tg_y_y_1[j];

                    tg_yy_yz_0[j] = pb_y * tg_y_yz_0[j] + fr * tg_y_yz_1[j] + 0.5 * fl1_fx * (tg_0_yz_0[j] - tg_0_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_z_1[j];

                    tg_yy_zz_0[j] = pb_y * tg_y_zz_0[j] + fr * tg_y_zz_1[j] + 0.5 * fl1_fx * (tg_0_zz_0[j] - tg_0_zz_1[j] * fl1_fza);

                    tg_yz_xx_0[j] = pb_y * tg_z_xx_0[j] + fr * tg_z_xx_1[j];

                    tg_yz_xy_0[j] = pb_y * tg_z_xy_0[j] + fr * tg_z_xy_1[j] + 0.5 * fl1_fxn * tg_z_x_1[j];

                    tg_yz_xz_0[j] = pb_y * tg_z_xz_0[j] + fr * tg_z_xz_1[j];

                    tg_yz_yy_0[j] = pb_y * tg_z_yy_0[j] + fr * tg_z_yy_1[j] + fl1_fxn * tg_z_y_1[j];

                    tg_yz_yz_0[j] = pb_y * tg_z_yz_0[j] + fr * tg_z_yz_1[j] + 0.5 * fl1_fxn * tg_z_z_1[j];

                    tg_yz_zz_0[j] = pb_y * tg_z_zz_0[j] + fr * tg_z_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xx_0[j] = pb_z * tg_z_xx_0[j] + fr * tg_z_xx_1[j] + 0.5 * fl1_fx * (tg_0_xx_0[j] - tg_0_xx_1[j] * fl1_fza);

                    tg_zz_xy_0[j] = pb_z * tg_z_xy_0[j] + fr * tg_z_xy_1[j] + 0.5 * fl1_fx * (tg_0_xy_0[j] - tg_0_xy_1[j] * fl1_fza);

                    tg_zz_xz_0[j] = pb_z * tg_z_xz_0[j] + fr * tg_z_xz_1[j] + 0.5 * fl1_fx * (tg_0_xz_0[j] - tg_0_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_x_1[j];

                    tg_zz_yy_0[j] = pb_z * tg_z_yy_0[j] + fr * tg_z_yy_1[j] + 0.5 * fl1_fx * (tg_0_yy_0[j] - tg_0_yy_1[j] * fl1_fza);

                    tg_zz_yz_0[j] = pb_z * tg_z_yz_0[j] + fr * tg_z_yz_1[j] + 0.5 * fl1_fx * (tg_0_yz_0[j] - tg_0_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_y_1[j];

                    tg_zz_zz_0[j] = pb_z * tg_z_zz_0[j] + fr * tg_z_zz_1[j] + 0.5 * fl1_fx * (tg_0_zz_0[j] - tg_0_zz_1[j] * fl1_fza) + fl1_fxn * tg_z_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSF(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {3, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_3_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_3_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_3_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_3_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_3_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_3_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_x_xxx_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx); 

                auto tg_x_xxy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 1); 

                auto tg_x_xxz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 2); 

                auto tg_x_xyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 3); 

                auto tg_x_xyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 4); 

                auto tg_x_xzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 5); 

                auto tg_x_yyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 6); 

                auto tg_x_yyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 7); 

                auto tg_x_yzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 8); 

                auto tg_x_zzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 9); 

                auto tg_y_xxx_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 10); 

                auto tg_y_xxy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 11); 

                auto tg_y_xxz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 12); 

                auto tg_y_xyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 13); 

                auto tg_y_xyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 14); 

                auto tg_y_xzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 15); 

                auto tg_y_yyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 16); 

                auto tg_y_yyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 17); 

                auto tg_y_yzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 18); 

                auto tg_y_zzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 19); 

                auto tg_z_xxx_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 20); 

                auto tg_z_xxy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 21); 

                auto tg_z_xxz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 22); 

                auto tg_z_xyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 23); 

                auto tg_z_xyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 24); 

                auto tg_z_xzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 25); 

                auto tg_z_yyy_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 26); 

                auto tg_z_yyz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 27); 

                auto tg_z_yzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 28); 

                auto tg_z_zzz_0 = primBuffer[pidx_g_1_3_m0].data(30 * idx + 29); 

                auto tg_x_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx); 

                auto tg_x_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 1); 

                auto tg_x_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 2); 

                auto tg_x_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 3); 

                auto tg_x_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 4); 

                auto tg_x_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 5); 

                auto tg_x_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 6); 

                auto tg_x_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 7); 

                auto tg_x_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 8); 

                auto tg_x_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 9); 

                auto tg_y_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 10); 

                auto tg_y_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 11); 

                auto tg_y_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 12); 

                auto tg_y_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 13); 

                auto tg_y_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 14); 

                auto tg_y_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 15); 

                auto tg_y_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 16); 

                auto tg_y_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 17); 

                auto tg_y_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 18); 

                auto tg_y_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 19); 

                auto tg_z_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 20); 

                auto tg_z_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 21); 

                auto tg_z_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 22); 

                auto tg_z_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 23); 

                auto tg_z_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 24); 

                auto tg_z_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 25); 

                auto tg_z_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 26); 

                auto tg_z_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 27); 

                auto tg_z_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 28); 

                auto tg_z_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 29); 

                auto tg_0_xxx_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx); 

                auto tg_0_xxy_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 1); 

                auto tg_0_xxz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 2); 

                auto tg_0_xyy_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 3); 

                auto tg_0_xyz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 4); 

                auto tg_0_xzz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 5); 

                auto tg_0_yyy_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 6); 

                auto tg_0_yyz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 7); 

                auto tg_0_yzz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 8); 

                auto tg_0_zzz_0 = primBuffer[pidx_g_0_3_m0].data(10 * idx + 9); 

                auto tg_0_xxx_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx); 

                auto tg_0_xxy_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 1); 

                auto tg_0_xxz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 2); 

                auto tg_0_xyy_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 3); 

                auto tg_0_xyz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 4); 

                auto tg_0_xzz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 5); 

                auto tg_0_yyy_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 6); 

                auto tg_0_yyz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 7); 

                auto tg_0_yzz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 8); 

                auto tg_0_zzz_1 = primBuffer[pidx_g_0_3_m1].data(10 * idx + 9); 

                auto tg_x_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx); 

                auto tg_x_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 1); 

                auto tg_x_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 2); 

                auto tg_x_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 3); 

                auto tg_x_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 4); 

                auto tg_x_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 5); 

                auto tg_y_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 6); 

                auto tg_y_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 7); 

                auto tg_y_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 8); 

                auto tg_y_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 9); 

                auto tg_y_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 10); 

                auto tg_y_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 11); 

                auto tg_z_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 12); 

                auto tg_z_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 13); 

                auto tg_z_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 14); 

                auto tg_z_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 15); 

                auto tg_z_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 16); 

                auto tg_z_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 17); 

                // set up pointers to integrals

                auto tg_xx_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx); 

                auto tg_xx_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 1); 

                auto tg_xx_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 2); 

                auto tg_xx_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 3); 

                auto tg_xx_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 4); 

                auto tg_xx_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 5); 

                auto tg_xx_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 6); 

                auto tg_xx_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 7); 

                auto tg_xx_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 8); 

                auto tg_xx_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 9); 

                auto tg_xy_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 10); 

                auto tg_xy_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 11); 

                auto tg_xy_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 12); 

                auto tg_xy_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 13); 

                auto tg_xy_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 14); 

                auto tg_xy_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 15); 

                auto tg_xy_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 16); 

                auto tg_xy_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 17); 

                auto tg_xy_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 18); 

                auto tg_xy_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 19); 

                auto tg_xz_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 20); 

                auto tg_xz_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 21); 

                auto tg_xz_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 22); 

                auto tg_xz_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 23); 

                auto tg_xz_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 24); 

                auto tg_xz_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 25); 

                auto tg_xz_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 26); 

                auto tg_xz_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 27); 

                auto tg_xz_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 28); 

                auto tg_xz_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 29); 

                auto tg_yy_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 30); 

                auto tg_yy_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 31); 

                auto tg_yy_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 32); 

                auto tg_yy_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 33); 

                auto tg_yy_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 34); 

                auto tg_yy_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 35); 

                auto tg_yy_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 36); 

                auto tg_yy_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 37); 

                auto tg_yy_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 38); 

                auto tg_yy_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 39); 

                auto tg_yz_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 40); 

                auto tg_yz_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 41); 

                auto tg_yz_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 42); 

                auto tg_yz_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 43); 

                auto tg_yz_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 44); 

                auto tg_yz_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 45); 

                auto tg_yz_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 46); 

                auto tg_yz_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 47); 

                auto tg_yz_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 48); 

                auto tg_yz_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 49); 

                auto tg_zz_xxx_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 50); 

                auto tg_zz_xxy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 51); 

                auto tg_zz_xxz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 52); 

                auto tg_zz_xyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 53); 

                auto tg_zz_xyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 54); 

                auto tg_zz_xzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 55); 

                auto tg_zz_yyy_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 56); 

                auto tg_zz_yyz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 57); 

                auto tg_zz_yzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 58); 

                auto tg_zz_zzz_0 = primBuffer[pidx_g_2_3_m0].data(60 * idx + 59); 

                #pragma omp simd aligned(fxn, fza, tg_0_xxx_0, tg_0_xxx_1, tg_0_xxy_0, tg_0_xxy_1, tg_0_xxz_0, \
                                         tg_0_xxz_1, tg_0_xyy_0, tg_0_xyy_1, tg_0_xyz_0, tg_0_xyz_1, tg_0_xzz_0, tg_0_xzz_1, \
                                         tg_0_yyy_0, tg_0_yyy_1, tg_0_yyz_0, tg_0_yyz_1, tg_0_yzz_0, tg_0_yzz_1, tg_0_zzz_0, \
                                         tg_0_zzz_1, tg_x_xx_1, tg_x_xxx_0, tg_x_xxx_1, tg_x_xxy_0, tg_x_xxy_1, tg_x_xxz_0, \
                                         tg_x_xxz_1, tg_x_xy_1, tg_x_xyy_0, tg_x_xyy_1, tg_x_xyz_0, tg_x_xyz_1, tg_x_xz_1, \
                                         tg_x_xzz_0, tg_x_xzz_1, tg_x_yy_1, tg_x_yyy_0, tg_x_yyy_1, tg_x_yyz_0, tg_x_yyz_1, \
                                         tg_x_yz_1, tg_x_yzz_0, tg_x_yzz_1, tg_x_zz_1, tg_x_zzz_0, tg_x_zzz_1, tg_xx_xxx_0, \
                                         tg_xx_xxy_0, tg_xx_xxz_0, tg_xx_xyy_0, tg_xx_xyz_0, tg_xx_xzz_0, tg_xx_yyy_0, \
                                         tg_xx_yyz_0, tg_xx_yzz_0, tg_xx_zzz_0, tg_xy_xxx_0, tg_xy_xxy_0, tg_xy_xxz_0, \
                                         tg_xy_xyy_0, tg_xy_xyz_0, tg_xy_xzz_0, tg_xy_yyy_0, tg_xy_yyz_0, tg_xy_yzz_0, \
                                         tg_xy_zzz_0, tg_xz_xxx_0, tg_xz_xxy_0, tg_xz_xxz_0, tg_xz_xyy_0, tg_xz_xyz_0, \
                                         tg_xz_xzz_0, tg_xz_yyy_0, tg_xz_yyz_0, tg_xz_yzz_0, tg_xz_zzz_0, tg_y_xx_1, \
                                         tg_y_xxx_0, tg_y_xxx_1, tg_y_xxy_0, tg_y_xxy_1, tg_y_xxz_0, tg_y_xxz_1, tg_y_xy_1, \
                                         tg_y_xyy_0, tg_y_xyy_1, tg_y_xyz_0, tg_y_xyz_1, tg_y_xz_1, tg_y_xzz_0, tg_y_xzz_1, \
                                         tg_y_yy_1, tg_y_yyy_0, tg_y_yyy_1, tg_y_yyz_0, tg_y_yyz_1, tg_y_yz_1, tg_y_yzz_0, \
                                         tg_y_yzz_1, tg_y_zz_1, tg_y_zzz_0, tg_y_zzz_1, tg_yy_xxx_0, tg_yy_xxy_0, \
                                         tg_yy_xxz_0, tg_yy_xyy_0, tg_yy_xyz_0, tg_yy_xzz_0, tg_yy_yyy_0, tg_yy_yyz_0, \
                                         tg_yy_yzz_0, tg_yy_zzz_0, tg_yz_xxx_0, tg_yz_xxy_0, tg_yz_xxz_0, tg_yz_xyy_0, \
                                         tg_yz_xyz_0, tg_yz_xzz_0, tg_yz_yyy_0, tg_yz_yyz_0, tg_yz_yzz_0, tg_yz_zzz_0, \
                                         tg_z_xx_1, tg_z_xxx_0, tg_z_xxx_1, tg_z_xxy_0, tg_z_xxy_1, tg_z_xxz_0, tg_z_xxz_1, \
                                         tg_z_xy_1, tg_z_xyy_0, tg_z_xyy_1, tg_z_xyz_0, tg_z_xyz_1, tg_z_xz_1, tg_z_xzz_0, \
                                         tg_z_xzz_1, tg_z_yy_1, tg_z_yyy_0, tg_z_yyy_1, tg_z_yyz_0, tg_z_yyz_1, tg_z_yz_1, \
                                         tg_z_yzz_0, tg_z_yzz_1, tg_z_zz_1, tg_z_zzz_0, tg_z_zzz_1, tg_zz_xxx_0, \
                                         tg_zz_xxy_0, tg_zz_xxz_0, tg_zz_xyy_0, tg_zz_xyz_0, tg_zz_xzz_0, tg_zz_yyy_0, \
                                         tg_zz_yyz_0, tg_zz_yzz_0, tg_zz_zzz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxx_0[j] = pb_x * tg_x_xxx_0[j] + fr * tg_x_xxx_1[j] + 0.5 * fl1_fx * (tg_0_xxx_0[j] - tg_0_xxx_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xx_1[j];

                    tg_xx_xxy_0[j] = pb_x * tg_x_xxy_0[j] + fr * tg_x_xxy_1[j] + 0.5 * fl1_fx * (tg_0_xxy_0[j] - tg_0_xxy_1[j] * fl1_fza) + fl1_fxn * tg_x_xy_1[j];

                    tg_xx_xxz_0[j] = pb_x * tg_x_xxz_0[j] + fr * tg_x_xxz_1[j] + 0.5 * fl1_fx * (tg_0_xxz_0[j] - tg_0_xxz_1[j] * fl1_fza) + fl1_fxn * tg_x_xz_1[j];

                    tg_xx_xyy_0[j] = pb_x * tg_x_xyy_0[j] + fr * tg_x_xyy_1[j] + 0.5 * fl1_fx * (tg_0_xyy_0[j] - tg_0_xyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yy_1[j];

                    tg_xx_xyz_0[j] = pb_x * tg_x_xyz_0[j] + fr * tg_x_xyz_1[j] + 0.5 * fl1_fx * (tg_0_xyz_0[j] - tg_0_xyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yz_1[j];

                    tg_xx_xzz_0[j] = pb_x * tg_x_xzz_0[j] + fr * tg_x_xzz_1[j] + 0.5 * fl1_fx * (tg_0_xzz_0[j] - tg_0_xzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zz_1[j];

                    tg_xx_yyy_0[j] = pb_x * tg_x_yyy_0[j] + fr * tg_x_yyy_1[j] + 0.5 * fl1_fx * (tg_0_yyy_0[j] - tg_0_yyy_1[j] * fl1_fza);

                    tg_xx_yyz_0[j] = pb_x * tg_x_yyz_0[j] + fr * tg_x_yyz_1[j] + 0.5 * fl1_fx * (tg_0_yyz_0[j] - tg_0_yyz_1[j] * fl1_fza);

                    tg_xx_yzz_0[j] = pb_x * tg_x_yzz_0[j] + fr * tg_x_yzz_1[j] + 0.5 * fl1_fx * (tg_0_yzz_0[j] - tg_0_yzz_1[j] * fl1_fza);

                    tg_xx_zzz_0[j] = pb_x * tg_x_zzz_0[j] + fr * tg_x_zzz_1[j] + 0.5 * fl1_fx * (tg_0_zzz_0[j] - tg_0_zzz_1[j] * fl1_fza);

                    tg_xy_xxx_0[j] = pb_x * tg_y_xxx_0[j] + fr * tg_y_xxx_1[j] + 1.5 * fl1_fxn * tg_y_xx_1[j];

                    tg_xy_xxy_0[j] = pb_x * tg_y_xxy_0[j] + fr * tg_y_xxy_1[j] + fl1_fxn * tg_y_xy_1[j];

                    tg_xy_xxz_0[j] = pb_x * tg_y_xxz_0[j] + fr * tg_y_xxz_1[j] + fl1_fxn * tg_y_xz_1[j];

                    tg_xy_xyy_0[j] = pb_x * tg_y_xyy_0[j] + fr * tg_y_xyy_1[j] + 0.5 * fl1_fxn * tg_y_yy_1[j];

                    tg_xy_xyz_0[j] = pb_x * tg_y_xyz_0[j] + fr * tg_y_xyz_1[j] + 0.5 * fl1_fxn * tg_y_yz_1[j];

                    tg_xy_xzz_0[j] = pb_x * tg_y_xzz_0[j] + fr * tg_y_xzz_1[j] + 0.5 * fl1_fxn * tg_y_zz_1[j];

                    tg_xy_yyy_0[j] = pb_x * tg_y_yyy_0[j] + fr * tg_y_yyy_1[j];

                    tg_xy_yyz_0[j] = pb_x * tg_y_yyz_0[j] + fr * tg_y_yyz_1[j];

                    tg_xy_yzz_0[j] = pb_x * tg_y_yzz_0[j] + fr * tg_y_yzz_1[j];

                    tg_xy_zzz_0[j] = pb_x * tg_y_zzz_0[j] + fr * tg_y_zzz_1[j];

                    tg_xz_xxx_0[j] = pb_x * tg_z_xxx_0[j] + fr * tg_z_xxx_1[j] + 1.5 * fl1_fxn * tg_z_xx_1[j];

                    tg_xz_xxy_0[j] = pb_x * tg_z_xxy_0[j] + fr * tg_z_xxy_1[j] + fl1_fxn * tg_z_xy_1[j];

                    tg_xz_xxz_0[j] = pb_x * tg_z_xxz_0[j] + fr * tg_z_xxz_1[j] + fl1_fxn * tg_z_xz_1[j];

                    tg_xz_xyy_0[j] = pb_x * tg_z_xyy_0[j] + fr * tg_z_xyy_1[j] + 0.5 * fl1_fxn * tg_z_yy_1[j];

                    tg_xz_xyz_0[j] = pb_x * tg_z_xyz_0[j] + fr * tg_z_xyz_1[j] + 0.5 * fl1_fxn * tg_z_yz_1[j];

                    tg_xz_xzz_0[j] = pb_x * tg_z_xzz_0[j] + fr * tg_z_xzz_1[j] + 0.5 * fl1_fxn * tg_z_zz_1[j];

                    tg_xz_yyy_0[j] = pb_x * tg_z_yyy_0[j] + fr * tg_z_yyy_1[j];

                    tg_xz_yyz_0[j] = pb_x * tg_z_yyz_0[j] + fr * tg_z_yyz_1[j];

                    tg_xz_yzz_0[j] = pb_x * tg_z_yzz_0[j] + fr * tg_z_yzz_1[j];

                    tg_xz_zzz_0[j] = pb_x * tg_z_zzz_0[j] + fr * tg_z_zzz_1[j];

                    fr = wp_y[j]; 

                    tg_yy_xxx_0[j] = pb_y * tg_y_xxx_0[j] + fr * tg_y_xxx_1[j] + 0.5 * fl1_fx * (tg_0_xxx_0[j] - tg_0_xxx_1[j] * fl1_fza);

                    tg_yy_xxy_0[j] = pb_y * tg_y_xxy_0[j] + fr * tg_y_xxy_1[j] + 0.5 * fl1_fx * (tg_0_xxy_0[j] - tg_0_xxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xx_1[j];

                    tg_yy_xxz_0[j] = pb_y * tg_y_xxz_0[j] + fr * tg_y_xxz_1[j] + 0.5 * fl1_fx * (tg_0_xxz_0[j] - tg_0_xxz_1[j] * fl1_fza);

                    tg_yy_xyy_0[j] = pb_y * tg_y_xyy_0[j] + fr * tg_y_xyy_1[j] + 0.5 * fl1_fx * (tg_0_xyy_0[j] - tg_0_xyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xy_1[j];

                    tg_yy_xyz_0[j] = pb_y * tg_y_xyz_0[j] + fr * tg_y_xyz_1[j] + 0.5 * fl1_fx * (tg_0_xyz_0[j] - tg_0_xyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xz_1[j];

                    tg_yy_xzz_0[j] = pb_y * tg_y_xzz_0[j] + fr * tg_y_xzz_1[j] + 0.5 * fl1_fx * (tg_0_xzz_0[j] - tg_0_xzz_1[j] * fl1_fza);

                    tg_yy_yyy_0[j] = pb_y * tg_y_yyy_0[j] + fr * tg_y_yyy_1[j] + 0.5 * fl1_fx * (tg_0_yyy_0[j] - tg_0_yyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yy_1[j];

                    tg_yy_yyz_0[j] = pb_y * tg_y_yyz_0[j] + fr * tg_y_yyz_1[j] + 0.5 * fl1_fx * (tg_0_yyz_0[j] - tg_0_yyz_1[j] * fl1_fza) + fl1_fxn * tg_y_yz_1[j];

                    tg_yy_yzz_0[j] = pb_y * tg_y_yzz_0[j] + fr * tg_y_yzz_1[j] + 0.5 * fl1_fx * (tg_0_yzz_0[j] - tg_0_yzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zz_1[j];

                    tg_yy_zzz_0[j] = pb_y * tg_y_zzz_0[j] + fr * tg_y_zzz_1[j] + 0.5 * fl1_fx * (tg_0_zzz_0[j] - tg_0_zzz_1[j] * fl1_fza);

                    tg_yz_xxx_0[j] = pb_y * tg_z_xxx_0[j] + fr * tg_z_xxx_1[j];

                    tg_yz_xxy_0[j] = pb_y * tg_z_xxy_0[j] + fr * tg_z_xxy_1[j] + 0.5 * fl1_fxn * tg_z_xx_1[j];

                    tg_yz_xxz_0[j] = pb_y * tg_z_xxz_0[j] + fr * tg_z_xxz_1[j];

                    tg_yz_xyy_0[j] = pb_y * tg_z_xyy_0[j] + fr * tg_z_xyy_1[j] + fl1_fxn * tg_z_xy_1[j];

                    tg_yz_xyz_0[j] = pb_y * tg_z_xyz_0[j] + fr * tg_z_xyz_1[j] + 0.5 * fl1_fxn * tg_z_xz_1[j];

                    tg_yz_xzz_0[j] = pb_y * tg_z_xzz_0[j] + fr * tg_z_xzz_1[j];

                    tg_yz_yyy_0[j] = pb_y * tg_z_yyy_0[j] + fr * tg_z_yyy_1[j] + 1.5 * fl1_fxn * tg_z_yy_1[j];

                    tg_yz_yyz_0[j] = pb_y * tg_z_yyz_0[j] + fr * tg_z_yyz_1[j] + fl1_fxn * tg_z_yz_1[j];

                    tg_yz_yzz_0[j] = pb_y * tg_z_yzz_0[j] + fr * tg_z_yzz_1[j] + 0.5 * fl1_fxn * tg_z_zz_1[j];

                    tg_yz_zzz_0[j] = pb_y * tg_z_zzz_0[j] + fr * tg_z_zzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxx_0[j] = pb_z * tg_z_xxx_0[j] + fr * tg_z_xxx_1[j] + 0.5 * fl1_fx * (tg_0_xxx_0[j] - tg_0_xxx_1[j] * fl1_fza);

                    tg_zz_xxy_0[j] = pb_z * tg_z_xxy_0[j] + fr * tg_z_xxy_1[j] + 0.5 * fl1_fx * (tg_0_xxy_0[j] - tg_0_xxy_1[j] * fl1_fza);

                    tg_zz_xxz_0[j] = pb_z * tg_z_xxz_0[j] + fr * tg_z_xxz_1[j] + 0.5 * fl1_fx * (tg_0_xxz_0[j] - tg_0_xxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xx_1[j];

                    tg_zz_xyy_0[j] = pb_z * tg_z_xyy_0[j] + fr * tg_z_xyy_1[j] + 0.5 * fl1_fx * (tg_0_xyy_0[j] - tg_0_xyy_1[j] * fl1_fza);

                    tg_zz_xyz_0[j] = pb_z * tg_z_xyz_0[j] + fr * tg_z_xyz_1[j] + 0.5 * fl1_fx * (tg_0_xyz_0[j] - tg_0_xyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xy_1[j];

                    tg_zz_xzz_0[j] = pb_z * tg_z_xzz_0[j] + fr * tg_z_xzz_1[j] + 0.5 * fl1_fx * (tg_0_xzz_0[j] - tg_0_xzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xz_1[j];

                    tg_zz_yyy_0[j] = pb_z * tg_z_yyy_0[j] + fr * tg_z_yyy_1[j] + 0.5 * fl1_fx * (tg_0_yyy_0[j] - tg_0_yyy_1[j] * fl1_fza);

                    tg_zz_yyz_0[j] = pb_z * tg_z_yyz_0[j] + fr * tg_z_yyz_1[j] + 0.5 * fl1_fx * (tg_0_yyz_0[j] - tg_0_yyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yy_1[j];

                    tg_zz_yzz_0[j] = pb_z * tg_z_yzz_0[j] + fr * tg_z_yzz_1[j] + 0.5 * fl1_fx * (tg_0_yzz_0[j] - tg_0_yzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yz_1[j];

                    tg_zz_zzz_0[j] = pb_z * tg_z_zzz_0[j] + fr * tg_z_zzz_1[j] + 0.5 * fl1_fx * (tg_0_zzz_0[j] - tg_0_zzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_zz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSFSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {3, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_3_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_3_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_2_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_2_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_2_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_xx_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx); 

                auto tg_xx_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 1); 

                auto tg_xx_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 2); 

                auto tg_xx_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 3); 

                auto tg_xx_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 4); 

                auto tg_xx_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 5); 

                auto tg_xy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 6); 

                auto tg_xy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 7); 

                auto tg_xy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 8); 

                auto tg_xy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 9); 

                auto tg_xy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 10); 

                auto tg_xy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 11); 

                auto tg_xz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 12); 

                auto tg_xz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 13); 

                auto tg_xz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 14); 

                auto tg_xz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 15); 

                auto tg_xz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 16); 

                auto tg_xz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 17); 

                auto tg_yy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 18); 

                auto tg_yy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 19); 

                auto tg_yy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 20); 

                auto tg_yy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 21); 

                auto tg_yy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 22); 

                auto tg_yy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 23); 

                auto tg_yz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 24); 

                auto tg_yz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 25); 

                auto tg_yz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 26); 

                auto tg_yz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 27); 

                auto tg_yz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 28); 

                auto tg_yz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 29); 

                auto tg_zz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 30); 

                auto tg_zz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 31); 

                auto tg_zz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 32); 

                auto tg_zz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 33); 

                auto tg_zz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 34); 

                auto tg_zz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 35); 

                auto tg_xx_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx); 

                auto tg_xx_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 1); 

                auto tg_xx_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 2); 

                auto tg_xx_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 3); 

                auto tg_xx_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 4); 

                auto tg_xx_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 5); 

                auto tg_xy_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 6); 

                auto tg_xy_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 7); 

                auto tg_xy_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 8); 

                auto tg_xy_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 9); 

                auto tg_xy_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 10); 

                auto tg_xy_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 11); 

                auto tg_xz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 12); 

                auto tg_xz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 13); 

                auto tg_xz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 14); 

                auto tg_xz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 15); 

                auto tg_xz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 16); 

                auto tg_xz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 17); 

                auto tg_yy_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 18); 

                auto tg_yy_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 19); 

                auto tg_yy_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 20); 

                auto tg_yy_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 21); 

                auto tg_yy_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 22); 

                auto tg_yy_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 23); 

                auto tg_yz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 24); 

                auto tg_yz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 25); 

                auto tg_yz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 26); 

                auto tg_yz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 27); 

                auto tg_yz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 28); 

                auto tg_yz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 29); 

                auto tg_zz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 30); 

                auto tg_zz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 31); 

                auto tg_zz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 32); 

                auto tg_zz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 33); 

                auto tg_zz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 34); 

                auto tg_zz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 35); 

                auto tg_x_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx); 

                auto tg_x_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 1); 

                auto tg_x_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 2); 

                auto tg_x_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 3); 

                auto tg_x_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 4); 

                auto tg_x_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 5); 

                auto tg_y_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 6); 

                auto tg_y_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 7); 

                auto tg_y_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 8); 

                auto tg_y_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 9); 

                auto tg_y_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 10); 

                auto tg_y_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 11); 

                auto tg_z_xx_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 12); 

                auto tg_z_xy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 13); 

                auto tg_z_xz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 14); 

                auto tg_z_yy_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 15); 

                auto tg_z_yz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 16); 

                auto tg_z_zz_0 = primBuffer[pidx_g_1_2_m0].data(18 * idx + 17); 

                auto tg_x_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx); 

                auto tg_x_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 1); 

                auto tg_x_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 2); 

                auto tg_x_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 3); 

                auto tg_x_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 4); 

                auto tg_x_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 5); 

                auto tg_y_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 6); 

                auto tg_y_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 7); 

                auto tg_y_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 8); 

                auto tg_y_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 9); 

                auto tg_y_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 10); 

                auto tg_y_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 11); 

                auto tg_z_xx_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 12); 

                auto tg_z_xy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 13); 

                auto tg_z_xz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 14); 

                auto tg_z_yy_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 15); 

                auto tg_z_yz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 16); 

                auto tg_z_zz_1 = primBuffer[pidx_g_1_2_m1].data(18 * idx + 17); 

                auto tg_xx_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx); 

                auto tg_xx_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 1); 

                auto tg_xx_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 2); 

                auto tg_xy_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 3); 

                auto tg_xy_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 4); 

                auto tg_xy_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 5); 

                auto tg_xz_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 6); 

                auto tg_xz_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 7); 

                auto tg_xz_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 8); 

                auto tg_yy_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 9); 

                auto tg_yy_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 10); 

                auto tg_yy_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 11); 

                auto tg_yz_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 12); 

                auto tg_yz_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 13); 

                auto tg_yz_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 14); 

                auto tg_zz_x_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 15); 

                auto tg_zz_y_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 16); 

                auto tg_zz_z_1 = primBuffer[pidx_g_2_1_m1].data(18 * idx + 17); 

                // set up pointers to integrals

                auto tg_xxx_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx); 

                auto tg_xxx_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 1); 

                auto tg_xxx_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 2); 

                auto tg_xxx_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 3); 

                auto tg_xxx_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 4); 

                auto tg_xxx_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 5); 

                auto tg_xxy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 6); 

                auto tg_xxy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 7); 

                auto tg_xxy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 8); 

                auto tg_xxy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 9); 

                auto tg_xxy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 10); 

                auto tg_xxy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 11); 

                auto tg_xxz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 12); 

                auto tg_xxz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 13); 

                auto tg_xxz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 14); 

                auto tg_xxz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 15); 

                auto tg_xxz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 16); 

                auto tg_xxz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 17); 

                auto tg_xyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 18); 

                auto tg_xyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 19); 

                auto tg_xyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 20); 

                auto tg_xyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 21); 

                auto tg_xyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 22); 

                auto tg_xyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 23); 

                auto tg_xyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 24); 

                auto tg_xyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 25); 

                auto tg_xyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 26); 

                auto tg_xyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 27); 

                auto tg_xyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 28); 

                auto tg_xyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 29); 

                auto tg_xzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 30); 

                auto tg_xzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 31); 

                auto tg_xzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 32); 

                auto tg_xzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 33); 

                auto tg_xzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 34); 

                auto tg_xzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 35); 

                auto tg_yyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 36); 

                auto tg_yyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 37); 

                auto tg_yyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 38); 

                auto tg_yyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 39); 

                auto tg_yyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 40); 

                auto tg_yyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 41); 

                auto tg_yyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 42); 

                auto tg_yyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 43); 

                auto tg_yyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 44); 

                auto tg_yyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 45); 

                auto tg_yyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 46); 

                auto tg_yyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 47); 

                auto tg_yzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 48); 

                auto tg_yzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 49); 

                auto tg_yzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 50); 

                auto tg_yzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 51); 

                auto tg_yzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 52); 

                auto tg_yzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 53); 

                auto tg_zzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 54); 

                auto tg_zzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 55); 

                auto tg_zzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 56); 

                auto tg_zzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 57); 

                auto tg_zzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 58); 

                auto tg_zzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 59); 

                #pragma omp simd aligned(fxn, fza, tg_x_xx_0, tg_x_xx_1, tg_x_xy_0, tg_x_xy_1, tg_x_xz_0, tg_x_xz_1, \
                                         tg_x_yy_0, tg_x_yy_1, tg_x_yz_0, tg_x_yz_1, tg_x_zz_0, tg_x_zz_1, tg_xx_x_1, \
                                         tg_xx_xx_0, tg_xx_xx_1, tg_xx_xy_0, tg_xx_xy_1, tg_xx_xz_0, tg_xx_xz_1, tg_xx_y_1, \
                                         tg_xx_yy_0, tg_xx_yy_1, tg_xx_yz_0, tg_xx_yz_1, tg_xx_z_1, tg_xx_zz_0, tg_xx_zz_1, \
                                         tg_xxx_xx_0, tg_xxx_xy_0, tg_xxx_xz_0, tg_xxx_yy_0, tg_xxx_yz_0, tg_xxx_zz_0, \
                                         tg_xxy_xx_0, tg_xxy_xy_0, tg_xxy_xz_0, tg_xxy_yy_0, tg_xxy_yz_0, tg_xxy_zz_0, \
                                         tg_xxz_xx_0, tg_xxz_xy_0, tg_xxz_xz_0, tg_xxz_yy_0, tg_xxz_yz_0, tg_xxz_zz_0, \
                                         tg_xy_x_1, tg_xy_xx_0, tg_xy_xx_1, tg_xy_xy_0, tg_xy_xy_1, tg_xy_xz_0, tg_xy_xz_1, \
                                         tg_xy_y_1, tg_xy_yy_0, tg_xy_yy_1, tg_xy_yz_0, tg_xy_yz_1, tg_xy_z_1, tg_xy_zz_0, \
                                         tg_xy_zz_1, tg_xyy_xx_0, tg_xyy_xy_0, tg_xyy_xz_0, tg_xyy_yy_0, tg_xyy_yz_0, \
                                         tg_xyy_zz_0, tg_xyz_xx_0, tg_xyz_xy_0, tg_xyz_xz_0, tg_xyz_yy_0, tg_xyz_yz_0, \
                                         tg_xyz_zz_0, tg_xz_x_1, tg_xz_xx_0, tg_xz_xx_1, tg_xz_xy_0, tg_xz_xy_1, tg_xz_xz_0, \
                                         tg_xz_xz_1, tg_xz_y_1, tg_xz_yy_0, tg_xz_yy_1, tg_xz_yz_0, tg_xz_yz_1, tg_xz_z_1, \
                                         tg_xz_zz_0, tg_xz_zz_1, tg_xzz_xx_0, tg_xzz_xy_0, tg_xzz_xz_0, tg_xzz_yy_0, \
                                         tg_xzz_yz_0, tg_xzz_zz_0, tg_y_xx_0, tg_y_xx_1, tg_y_xy_0, tg_y_xy_1, tg_y_xz_0, \
                                         tg_y_xz_1, tg_y_yy_0, tg_y_yy_1, tg_y_yz_0, tg_y_yz_1, tg_y_zz_0, tg_y_zz_1, \
                                         tg_yy_x_1, tg_yy_xx_0, tg_yy_xx_1, tg_yy_xy_0, tg_yy_xy_1, tg_yy_xz_0, tg_yy_xz_1, \
                                         tg_yy_y_1, tg_yy_yy_0, tg_yy_yy_1, tg_yy_yz_0, tg_yy_yz_1, tg_yy_z_1, tg_yy_zz_0, \
                                         tg_yy_zz_1, tg_yyy_xx_0, tg_yyy_xy_0, tg_yyy_xz_0, tg_yyy_yy_0, tg_yyy_yz_0, \
                                         tg_yyy_zz_0, tg_yyz_xx_0, tg_yyz_xy_0, tg_yyz_xz_0, tg_yyz_yy_0, tg_yyz_yz_0, \
                                         tg_yyz_zz_0, tg_yz_x_1, tg_yz_xx_0, tg_yz_xx_1, tg_yz_xy_0, tg_yz_xy_1, tg_yz_xz_0, \
                                         tg_yz_xz_1, tg_yz_y_1, tg_yz_yy_0, tg_yz_yy_1, tg_yz_yz_0, tg_yz_yz_1, tg_yz_z_1, \
                                         tg_yz_zz_0, tg_yz_zz_1, tg_yzz_xx_0, tg_yzz_xy_0, tg_yzz_xz_0, tg_yzz_yy_0, \
                                         tg_yzz_yz_0, tg_yzz_zz_0, tg_z_xx_0, tg_z_xx_1, tg_z_xy_0, tg_z_xy_1, tg_z_xz_0, \
                                         tg_z_xz_1, tg_z_yy_0, tg_z_yy_1, tg_z_yz_0, tg_z_yz_1, tg_z_zz_0, tg_z_zz_1, \
                                         tg_zz_x_1, tg_zz_xx_0, tg_zz_xx_1, tg_zz_xy_0, tg_zz_xy_1, tg_zz_xz_0, tg_zz_xz_1, \
                                         tg_zz_y_1, tg_zz_yy_0, tg_zz_yy_1, tg_zz_yz_0, tg_zz_yz_1, tg_zz_z_1, tg_zz_zz_0, \
                                         tg_zz_zz_1, tg_zzz_xx_0, tg_zzz_xy_0, tg_zzz_xz_0, tg_zzz_yy_0, tg_zzz_yz_0, \
                                         tg_zzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxx_xx_0[j] = pb_x * tg_xx_xx_0[j] + fr * tg_xx_xx_1[j] + fl1_fx * (tg_x_xx_0[j] - tg_x_xx_1[j] * fl1_fza) + fl1_fxn * tg_xx_x_1[j];

                    tg_xxx_xy_0[j] = pb_x * tg_xx_xy_0[j] + fr * tg_xx_xy_1[j] + fl1_fx * (tg_x_xy_0[j] - tg_x_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xx_y_1[j];

                    tg_xxx_xz_0[j] = pb_x * tg_xx_xz_0[j] + fr * tg_xx_xz_1[j] + fl1_fx * (tg_x_xz_0[j] - tg_x_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xx_z_1[j];

                    tg_xxx_yy_0[j] = pb_x * tg_xx_yy_0[j] + fr * tg_xx_yy_1[j] + fl1_fx * (tg_x_yy_0[j] - tg_x_yy_1[j] * fl1_fza);

                    tg_xxx_yz_0[j] = pb_x * tg_xx_yz_0[j] + fr * tg_xx_yz_1[j] + fl1_fx * (tg_x_yz_0[j] - tg_x_yz_1[j] * fl1_fza);

                    tg_xxx_zz_0[j] = pb_x * tg_xx_zz_0[j] + fr * tg_xx_zz_1[j] + fl1_fx * (tg_x_zz_0[j] - tg_x_zz_1[j] * fl1_fza);

                    tg_xxy_xx_0[j] = pb_x * tg_xy_xx_0[j] + fr * tg_xy_xx_1[j] + 0.5 * fl1_fx * (tg_y_xx_0[j] - tg_y_xx_1[j] * fl1_fza) + fl1_fxn * tg_xy_x_1[j];

                    tg_xxy_xy_0[j] = pb_x * tg_xy_xy_0[j] + fr * tg_xy_xy_1[j] + 0.5 * fl1_fx * (tg_y_xy_0[j] - tg_y_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xy_y_1[j];

                    tg_xxy_xz_0[j] = pb_x * tg_xy_xz_0[j] + fr * tg_xy_xz_1[j] + 0.5 * fl1_fx * (tg_y_xz_0[j] - tg_y_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xy_z_1[j];

                    tg_xxy_yy_0[j] = pb_x * tg_xy_yy_0[j] + fr * tg_xy_yy_1[j] + 0.5 * fl1_fx * (tg_y_yy_0[j] - tg_y_yy_1[j] * fl1_fza);

                    tg_xxy_yz_0[j] = pb_x * tg_xy_yz_0[j] + fr * tg_xy_yz_1[j] + 0.5 * fl1_fx * (tg_y_yz_0[j] - tg_y_yz_1[j] * fl1_fza);

                    tg_xxy_zz_0[j] = pb_x * tg_xy_zz_0[j] + fr * tg_xy_zz_1[j] + 0.5 * fl1_fx * (tg_y_zz_0[j] - tg_y_zz_1[j] * fl1_fza);

                    tg_xxz_xx_0[j] = pb_x * tg_xz_xx_0[j] + fr * tg_xz_xx_1[j] + 0.5 * fl1_fx * (tg_z_xx_0[j] - tg_z_xx_1[j] * fl1_fza) + fl1_fxn * tg_xz_x_1[j];

                    tg_xxz_xy_0[j] = pb_x * tg_xz_xy_0[j] + fr * tg_xz_xy_1[j] + 0.5 * fl1_fx * (tg_z_xy_0[j] - tg_z_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xz_y_1[j];

                    tg_xxz_xz_0[j] = pb_x * tg_xz_xz_0[j] + fr * tg_xz_xz_1[j] + 0.5 * fl1_fx * (tg_z_xz_0[j] - tg_z_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xz_z_1[j];

                    tg_xxz_yy_0[j] = pb_x * tg_xz_yy_0[j] + fr * tg_xz_yy_1[j] + 0.5 * fl1_fx * (tg_z_yy_0[j] - tg_z_yy_1[j] * fl1_fza);

                    tg_xxz_yz_0[j] = pb_x * tg_xz_yz_0[j] + fr * tg_xz_yz_1[j] + 0.5 * fl1_fx * (tg_z_yz_0[j] - tg_z_yz_1[j] * fl1_fza);

                    tg_xxz_zz_0[j] = pb_x * tg_xz_zz_0[j] + fr * tg_xz_zz_1[j] + 0.5 * fl1_fx * (tg_z_zz_0[j] - tg_z_zz_1[j] * fl1_fza);

                    tg_xyy_xx_0[j] = pb_x * tg_yy_xx_0[j] + fr * tg_yy_xx_1[j] + fl1_fxn * tg_yy_x_1[j];

                    tg_xyy_xy_0[j] = pb_x * tg_yy_xy_0[j] + fr * tg_yy_xy_1[j] + 0.5 * fl1_fxn * tg_yy_y_1[j];

                    tg_xyy_xz_0[j] = pb_x * tg_yy_xz_0[j] + fr * tg_yy_xz_1[j] + 0.5 * fl1_fxn * tg_yy_z_1[j];

                    tg_xyy_yy_0[j] = pb_x * tg_yy_yy_0[j] + fr * tg_yy_yy_1[j];

                    tg_xyy_yz_0[j] = pb_x * tg_yy_yz_0[j] + fr * tg_yy_yz_1[j];

                    tg_xyy_zz_0[j] = pb_x * tg_yy_zz_0[j] + fr * tg_yy_zz_1[j];

                    tg_xyz_xx_0[j] = pb_x * tg_yz_xx_0[j] + fr * tg_yz_xx_1[j] + fl1_fxn * tg_yz_x_1[j];

                    tg_xyz_xy_0[j] = pb_x * tg_yz_xy_0[j] + fr * tg_yz_xy_1[j] + 0.5 * fl1_fxn * tg_yz_y_1[j];

                    tg_xyz_xz_0[j] = pb_x * tg_yz_xz_0[j] + fr * tg_yz_xz_1[j] + 0.5 * fl1_fxn * tg_yz_z_1[j];

                    tg_xyz_yy_0[j] = pb_x * tg_yz_yy_0[j] + fr * tg_yz_yy_1[j];

                    tg_xyz_yz_0[j] = pb_x * tg_yz_yz_0[j] + fr * tg_yz_yz_1[j];

                    tg_xyz_zz_0[j] = pb_x * tg_yz_zz_0[j] + fr * tg_yz_zz_1[j];

                    tg_xzz_xx_0[j] = pb_x * tg_zz_xx_0[j] + fr * tg_zz_xx_1[j] + fl1_fxn * tg_zz_x_1[j];

                    tg_xzz_xy_0[j] = pb_x * tg_zz_xy_0[j] + fr * tg_zz_xy_1[j] + 0.5 * fl1_fxn * tg_zz_y_1[j];

                    tg_xzz_xz_0[j] = pb_x * tg_zz_xz_0[j] + fr * tg_zz_xz_1[j] + 0.5 * fl1_fxn * tg_zz_z_1[j];

                    tg_xzz_yy_0[j] = pb_x * tg_zz_yy_0[j] + fr * tg_zz_yy_1[j];

                    tg_xzz_yz_0[j] = pb_x * tg_zz_yz_0[j] + fr * tg_zz_yz_1[j];

                    tg_xzz_zz_0[j] = pb_x * tg_zz_zz_0[j] + fr * tg_zz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyy_xx_0[j] = pb_y * tg_yy_xx_0[j] + fr * tg_yy_xx_1[j] + fl1_fx * (tg_y_xx_0[j] - tg_y_xx_1[j] * fl1_fza);

                    tg_yyy_xy_0[j] = pb_y * tg_yy_xy_0[j] + fr * tg_yy_xy_1[j] + fl1_fx * (tg_y_xy_0[j] - tg_y_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yy_x_1[j];

                    tg_yyy_xz_0[j] = pb_y * tg_yy_xz_0[j] + fr * tg_yy_xz_1[j] + fl1_fx * (tg_y_xz_0[j] - tg_y_xz_1[j] * fl1_fza);

                    tg_yyy_yy_0[j] = pb_y * tg_yy_yy_0[j] + fr * tg_yy_yy_1[j] + fl1_fx * (tg_y_yy_0[j] - tg_y_yy_1[j] * fl1_fza) + fl1_fxn * tg_yy_y_1[j];

                    tg_yyy_yz_0[j] = pb_y * tg_yy_yz_0[j] + fr * tg_yy_yz_1[j] + fl1_fx * (tg_y_yz_0[j] - tg_y_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yy_z_1[j];

                    tg_yyy_zz_0[j] = pb_y * tg_yy_zz_0[j] + fr * tg_yy_zz_1[j] + fl1_fx * (tg_y_zz_0[j] - tg_y_zz_1[j] * fl1_fza);

                    tg_yyz_xx_0[j] = pb_y * tg_yz_xx_0[j] + fr * tg_yz_xx_1[j] + 0.5 * fl1_fx * (tg_z_xx_0[j] - tg_z_xx_1[j] * fl1_fza);

                    tg_yyz_xy_0[j] = pb_y * tg_yz_xy_0[j] + fr * tg_yz_xy_1[j] + 0.5 * fl1_fx * (tg_z_xy_0[j] - tg_z_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yz_x_1[j];

                    tg_yyz_xz_0[j] = pb_y * tg_yz_xz_0[j] + fr * tg_yz_xz_1[j] + 0.5 * fl1_fx * (tg_z_xz_0[j] - tg_z_xz_1[j] * fl1_fza);

                    tg_yyz_yy_0[j] = pb_y * tg_yz_yy_0[j] + fr * tg_yz_yy_1[j] + 0.5 * fl1_fx * (tg_z_yy_0[j] - tg_z_yy_1[j] * fl1_fza) + fl1_fxn * tg_yz_y_1[j];

                    tg_yyz_yz_0[j] = pb_y * tg_yz_yz_0[j] + fr * tg_yz_yz_1[j] + 0.5 * fl1_fx * (tg_z_yz_0[j] - tg_z_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yz_z_1[j];

                    tg_yyz_zz_0[j] = pb_y * tg_yz_zz_0[j] + fr * tg_yz_zz_1[j] + 0.5 * fl1_fx * (tg_z_zz_0[j] - tg_z_zz_1[j] * fl1_fza);

                    tg_yzz_xx_0[j] = pb_y * tg_zz_xx_0[j] + fr * tg_zz_xx_1[j];

                    tg_yzz_xy_0[j] = pb_y * tg_zz_xy_0[j] + fr * tg_zz_xy_1[j] + 0.5 * fl1_fxn * tg_zz_x_1[j];

                    tg_yzz_xz_0[j] = pb_y * tg_zz_xz_0[j] + fr * tg_zz_xz_1[j];

                    tg_yzz_yy_0[j] = pb_y * tg_zz_yy_0[j] + fr * tg_zz_yy_1[j] + fl1_fxn * tg_zz_y_1[j];

                    tg_yzz_yz_0[j] = pb_y * tg_zz_yz_0[j] + fr * tg_zz_yz_1[j] + 0.5 * fl1_fxn * tg_zz_z_1[j];

                    tg_yzz_zz_0[j] = pb_y * tg_zz_zz_0[j] + fr * tg_zz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzz_xx_0[j] = pb_z * tg_zz_xx_0[j] + fr * tg_zz_xx_1[j] + fl1_fx * (tg_z_xx_0[j] - tg_z_xx_1[j] * fl1_fza);

                    tg_zzz_xy_0[j] = pb_z * tg_zz_xy_0[j] + fr * tg_zz_xy_1[j] + fl1_fx * (tg_z_xy_0[j] - tg_z_xy_1[j] * fl1_fza);

                    tg_zzz_xz_0[j] = pb_z * tg_zz_xz_0[j] + fr * tg_zz_xz_1[j] + fl1_fx * (tg_z_xz_0[j] - tg_z_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zz_x_1[j];

                    tg_zzz_yy_0[j] = pb_z * tg_zz_yy_0[j] + fr * tg_zz_yy_1[j] + fl1_fx * (tg_z_yy_0[j] - tg_z_yy_1[j] * fl1_fza);

                    tg_zzz_yz_0[j] = pb_z * tg_zz_yz_0[j] + fr * tg_zz_yz_1[j] + fl1_fx * (tg_z_yz_0[j] - tg_z_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zz_y_1[j];

                    tg_zzz_zz_0[j] = pb_z * tg_zz_zz_0[j] + fr * tg_zz_zz_1[j] + fl1_fx * (tg_z_zz_0[j] - tg_z_zz_1[j] * fl1_fza) + fl1_fxn * tg_zz_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSG(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {4, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_4_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_4_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_4_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_4_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_4_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_4_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_3_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {3, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_x_xxxx_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx); 

                auto tg_x_xxxy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 1); 

                auto tg_x_xxxz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 2); 

                auto tg_x_xxyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 3); 

                auto tg_x_xxyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 4); 

                auto tg_x_xxzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 5); 

                auto tg_x_xyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 6); 

                auto tg_x_xyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 7); 

                auto tg_x_xyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 8); 

                auto tg_x_xzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 9); 

                auto tg_x_yyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 10); 

                auto tg_x_yyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 11); 

                auto tg_x_yyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 12); 

                auto tg_x_yzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 13); 

                auto tg_x_zzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 14); 

                auto tg_y_xxxx_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 15); 

                auto tg_y_xxxy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 16); 

                auto tg_y_xxxz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 17); 

                auto tg_y_xxyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 18); 

                auto tg_y_xxyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 19); 

                auto tg_y_xxzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 20); 

                auto tg_y_xyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 21); 

                auto tg_y_xyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 22); 

                auto tg_y_xyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 23); 

                auto tg_y_xzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 24); 

                auto tg_y_yyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 25); 

                auto tg_y_yyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 26); 

                auto tg_y_yyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 27); 

                auto tg_y_yzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 28); 

                auto tg_y_zzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 29); 

                auto tg_z_xxxx_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 30); 

                auto tg_z_xxxy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 31); 

                auto tg_z_xxxz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 32); 

                auto tg_z_xxyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 33); 

                auto tg_z_xxyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 34); 

                auto tg_z_xxzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 35); 

                auto tg_z_xyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 36); 

                auto tg_z_xyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 37); 

                auto tg_z_xyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 38); 

                auto tg_z_xzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 39); 

                auto tg_z_yyyy_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 40); 

                auto tg_z_yyyz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 41); 

                auto tg_z_yyzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 42); 

                auto tg_z_yzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 43); 

                auto tg_z_zzzz_0 = primBuffer[pidx_g_1_4_m0].data(45 * idx + 44); 

                auto tg_x_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx); 

                auto tg_x_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 1); 

                auto tg_x_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 2); 

                auto tg_x_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 3); 

                auto tg_x_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 4); 

                auto tg_x_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 5); 

                auto tg_x_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 6); 

                auto tg_x_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 7); 

                auto tg_x_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 8); 

                auto tg_x_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 9); 

                auto tg_x_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 10); 

                auto tg_x_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 11); 

                auto tg_x_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 12); 

                auto tg_x_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 13); 

                auto tg_x_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 14); 

                auto tg_y_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 15); 

                auto tg_y_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 16); 

                auto tg_y_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 17); 

                auto tg_y_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 18); 

                auto tg_y_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 19); 

                auto tg_y_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 20); 

                auto tg_y_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 21); 

                auto tg_y_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 22); 

                auto tg_y_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 23); 

                auto tg_y_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 24); 

                auto tg_y_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 25); 

                auto tg_y_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 26); 

                auto tg_y_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 27); 

                auto tg_y_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 28); 

                auto tg_y_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 29); 

                auto tg_z_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 30); 

                auto tg_z_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 31); 

                auto tg_z_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 32); 

                auto tg_z_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 33); 

                auto tg_z_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 34); 

                auto tg_z_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 35); 

                auto tg_z_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 36); 

                auto tg_z_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 37); 

                auto tg_z_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 38); 

                auto tg_z_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 39); 

                auto tg_z_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 40); 

                auto tg_z_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 41); 

                auto tg_z_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 42); 

                auto tg_z_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 43); 

                auto tg_z_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 44); 

                auto tg_0_xxxx_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx); 

                auto tg_0_xxxy_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 1); 

                auto tg_0_xxxz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 2); 

                auto tg_0_xxyy_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 3); 

                auto tg_0_xxyz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 4); 

                auto tg_0_xxzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 5); 

                auto tg_0_xyyy_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 6); 

                auto tg_0_xyyz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 7); 

                auto tg_0_xyzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 8); 

                auto tg_0_xzzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 9); 

                auto tg_0_yyyy_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 10); 

                auto tg_0_yyyz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 11); 

                auto tg_0_yyzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 12); 

                auto tg_0_yzzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 13); 

                auto tg_0_zzzz_0 = primBuffer[pidx_g_0_4_m0].data(15 * idx + 14); 

                auto tg_0_xxxx_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx); 

                auto tg_0_xxxy_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 1); 

                auto tg_0_xxxz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 2); 

                auto tg_0_xxyy_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 3); 

                auto tg_0_xxyz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 4); 

                auto tg_0_xxzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 5); 

                auto tg_0_xyyy_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 6); 

                auto tg_0_xyyz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 7); 

                auto tg_0_xyzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 8); 

                auto tg_0_xzzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 9); 

                auto tg_0_yyyy_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 10); 

                auto tg_0_yyyz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 11); 

                auto tg_0_yyzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 12); 

                auto tg_0_yzzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 13); 

                auto tg_0_zzzz_1 = primBuffer[pidx_g_0_4_m1].data(15 * idx + 14); 

                auto tg_x_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx); 

                auto tg_x_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 1); 

                auto tg_x_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 2); 

                auto tg_x_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 3); 

                auto tg_x_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 4); 

                auto tg_x_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 5); 

                auto tg_x_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 6); 

                auto tg_x_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 7); 

                auto tg_x_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 8); 

                auto tg_x_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 9); 

                auto tg_y_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 10); 

                auto tg_y_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 11); 

                auto tg_y_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 12); 

                auto tg_y_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 13); 

                auto tg_y_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 14); 

                auto tg_y_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 15); 

                auto tg_y_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 16); 

                auto tg_y_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 17); 

                auto tg_y_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 18); 

                auto tg_y_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 19); 

                auto tg_z_xxx_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 20); 

                auto tg_z_xxy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 21); 

                auto tg_z_xxz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 22); 

                auto tg_z_xyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 23); 

                auto tg_z_xyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 24); 

                auto tg_z_xzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 25); 

                auto tg_z_yyy_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 26); 

                auto tg_z_yyz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 27); 

                auto tg_z_yzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 28); 

                auto tg_z_zzz_1 = primBuffer[pidx_g_1_3_m1].data(30 * idx + 29); 

                // set up pointers to integrals

                auto tg_xx_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx); 

                auto tg_xx_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 1); 

                auto tg_xx_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 2); 

                auto tg_xx_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 3); 

                auto tg_xx_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 4); 

                auto tg_xx_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 5); 

                auto tg_xx_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 6); 

                auto tg_xx_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 7); 

                auto tg_xx_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 8); 

                auto tg_xx_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 9); 

                auto tg_xx_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 10); 

                auto tg_xx_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 11); 

                auto tg_xx_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 12); 

                auto tg_xx_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 13); 

                auto tg_xx_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 14); 

                auto tg_xy_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 15); 

                auto tg_xy_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 16); 

                auto tg_xy_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 17); 

                auto tg_xy_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 18); 

                auto tg_xy_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 19); 

                auto tg_xy_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 20); 

                auto tg_xy_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 21); 

                auto tg_xy_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 22); 

                auto tg_xy_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 23); 

                auto tg_xy_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 24); 

                auto tg_xy_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 25); 

                auto tg_xy_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 26); 

                auto tg_xy_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 27); 

                auto tg_xy_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 28); 

                auto tg_xy_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 29); 

                auto tg_xz_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 30); 

                auto tg_xz_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 31); 

                auto tg_xz_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 32); 

                auto tg_xz_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 33); 

                auto tg_xz_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 34); 

                auto tg_xz_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 35); 

                auto tg_xz_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 36); 

                auto tg_xz_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 37); 

                auto tg_xz_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 38); 

                auto tg_xz_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 39); 

                auto tg_xz_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 40); 

                auto tg_xz_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 41); 

                auto tg_xz_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 42); 

                auto tg_xz_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 43); 

                auto tg_xz_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 44); 

                auto tg_yy_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 45); 

                auto tg_yy_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 46); 

                auto tg_yy_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 47); 

                auto tg_yy_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 48); 

                auto tg_yy_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 49); 

                auto tg_yy_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 50); 

                auto tg_yy_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 51); 

                auto tg_yy_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 52); 

                auto tg_yy_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 53); 

                auto tg_yy_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 54); 

                auto tg_yy_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 55); 

                auto tg_yy_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 56); 

                auto tg_yy_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 57); 

                auto tg_yy_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 58); 

                auto tg_yy_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 59); 

                auto tg_yz_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 60); 

                auto tg_yz_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 61); 

                auto tg_yz_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 62); 

                auto tg_yz_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 63); 

                auto tg_yz_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 64); 

                auto tg_yz_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 65); 

                auto tg_yz_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 66); 

                auto tg_yz_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 67); 

                auto tg_yz_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 68); 

                auto tg_yz_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 69); 

                auto tg_yz_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 70); 

                auto tg_yz_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 71); 

                auto tg_yz_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 72); 

                auto tg_yz_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 73); 

                auto tg_yz_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 74); 

                auto tg_zz_xxxx_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 75); 

                auto tg_zz_xxxy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 76); 

                auto tg_zz_xxxz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 77); 

                auto tg_zz_xxyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 78); 

                auto tg_zz_xxyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 79); 

                auto tg_zz_xxzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 80); 

                auto tg_zz_xyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 81); 

                auto tg_zz_xyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 82); 

                auto tg_zz_xyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 83); 

                auto tg_zz_xzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 84); 

                auto tg_zz_yyyy_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 85); 

                auto tg_zz_yyyz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 86); 

                auto tg_zz_yyzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 87); 

                auto tg_zz_yzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 88); 

                auto tg_zz_zzzz_0 = primBuffer[pidx_g_2_4_m0].data(90 * idx + 89); 

                #pragma omp simd aligned(fxn, fza, tg_0_xxxx_0, tg_0_xxxx_1, tg_0_xxxy_0, tg_0_xxxy_1, \
                                         tg_0_xxxz_0, tg_0_xxxz_1, tg_0_xxyy_0, tg_0_xxyy_1, tg_0_xxyz_0, tg_0_xxyz_1, \
                                         tg_0_xxzz_0, tg_0_xxzz_1, tg_0_xyyy_0, tg_0_xyyy_1, tg_0_xyyz_0, tg_0_xyyz_1, \
                                         tg_0_xyzz_0, tg_0_xyzz_1, tg_0_xzzz_0, tg_0_xzzz_1, tg_0_yyyy_0, tg_0_yyyy_1, \
                                         tg_0_yyyz_0, tg_0_yyyz_1, tg_0_yyzz_0, tg_0_yyzz_1, tg_0_yzzz_0, tg_0_yzzz_1, \
                                         tg_0_zzzz_0, tg_0_zzzz_1, tg_x_xxx_1, tg_x_xxxx_0, tg_x_xxxx_1, tg_x_xxxy_0, \
                                         tg_x_xxxy_1, tg_x_xxxz_0, tg_x_xxxz_1, tg_x_xxy_1, tg_x_xxyy_0, tg_x_xxyy_1, \
                                         tg_x_xxyz_0, tg_x_xxyz_1, tg_x_xxz_1, tg_x_xxzz_0, tg_x_xxzz_1, tg_x_xyy_1, \
                                         tg_x_xyyy_0, tg_x_xyyy_1, tg_x_xyyz_0, tg_x_xyyz_1, tg_x_xyz_1, tg_x_xyzz_0, \
                                         tg_x_xyzz_1, tg_x_xzz_1, tg_x_xzzz_0, tg_x_xzzz_1, tg_x_yyy_1, tg_x_yyyy_0, \
                                         tg_x_yyyy_1, tg_x_yyyz_0, tg_x_yyyz_1, tg_x_yyz_1, tg_x_yyzz_0, tg_x_yyzz_1, \
                                         tg_x_yzz_1, tg_x_yzzz_0, tg_x_yzzz_1, tg_x_zzz_1, tg_x_zzzz_0, tg_x_zzzz_1, \
                                         tg_xx_xxxx_0, tg_xx_xxxy_0, tg_xx_xxxz_0, tg_xx_xxyy_0, tg_xx_xxyz_0, tg_xx_xxzz_0, \
                                         tg_xx_xyyy_0, tg_xx_xyyz_0, tg_xx_xyzz_0, tg_xx_xzzz_0, tg_xx_yyyy_0, tg_xx_yyyz_0, \
                                         tg_xx_yyzz_0, tg_xx_yzzz_0, tg_xx_zzzz_0, tg_xy_xxxx_0, tg_xy_xxxy_0, tg_xy_xxxz_0, \
                                         tg_xy_xxyy_0, tg_xy_xxyz_0, tg_xy_xxzz_0, tg_xy_xyyy_0, tg_xy_xyyz_0, tg_xy_xyzz_0, \
                                         tg_xy_xzzz_0, tg_xy_yyyy_0, tg_xy_yyyz_0, tg_xy_yyzz_0, tg_xy_yzzz_0, tg_xy_zzzz_0, \
                                         tg_xz_xxxx_0, tg_xz_xxxy_0, tg_xz_xxxz_0, tg_xz_xxyy_0, tg_xz_xxyz_0, tg_xz_xxzz_0, \
                                         tg_xz_xyyy_0, tg_xz_xyyz_0, tg_xz_xyzz_0, tg_xz_xzzz_0, tg_xz_yyyy_0, tg_xz_yyyz_0, \
                                         tg_xz_yyzz_0, tg_xz_yzzz_0, tg_xz_zzzz_0, tg_y_xxx_1, tg_y_xxxx_0, tg_y_xxxx_1, \
                                         tg_y_xxxy_0, tg_y_xxxy_1, tg_y_xxxz_0, tg_y_xxxz_1, tg_y_xxy_1, tg_y_xxyy_0, \
                                         tg_y_xxyy_1, tg_y_xxyz_0, tg_y_xxyz_1, tg_y_xxz_1, tg_y_xxzz_0, tg_y_xxzz_1, \
                                         tg_y_xyy_1, tg_y_xyyy_0, tg_y_xyyy_1, tg_y_xyyz_0, tg_y_xyyz_1, tg_y_xyz_1, \
                                         tg_y_xyzz_0, tg_y_xyzz_1, tg_y_xzz_1, tg_y_xzzz_0, tg_y_xzzz_1, tg_y_yyy_1, \
                                         tg_y_yyyy_0, tg_y_yyyy_1, tg_y_yyyz_0, tg_y_yyyz_1, tg_y_yyz_1, tg_y_yyzz_0, \
                                         tg_y_yyzz_1, tg_y_yzz_1, tg_y_yzzz_0, tg_y_yzzz_1, tg_y_zzz_1, tg_y_zzzz_0, \
                                         tg_y_zzzz_1, tg_yy_xxxx_0, tg_yy_xxxy_0, tg_yy_xxxz_0, tg_yy_xxyy_0, tg_yy_xxyz_0, \
                                         tg_yy_xxzz_0, tg_yy_xyyy_0, tg_yy_xyyz_0, tg_yy_xyzz_0, tg_yy_xzzz_0, tg_yy_yyyy_0, \
                                         tg_yy_yyyz_0, tg_yy_yyzz_0, tg_yy_yzzz_0, tg_yy_zzzz_0, tg_yz_xxxx_0, tg_yz_xxxy_0, \
                                         tg_yz_xxxz_0, tg_yz_xxyy_0, tg_yz_xxyz_0, tg_yz_xxzz_0, tg_yz_xyyy_0, tg_yz_xyyz_0, \
                                         tg_yz_xyzz_0, tg_yz_xzzz_0, tg_yz_yyyy_0, tg_yz_yyyz_0, tg_yz_yyzz_0, tg_yz_yzzz_0, \
                                         tg_yz_zzzz_0, tg_z_xxx_1, tg_z_xxxx_0, tg_z_xxxx_1, tg_z_xxxy_0, tg_z_xxxy_1, \
                                         tg_z_xxxz_0, tg_z_xxxz_1, tg_z_xxy_1, tg_z_xxyy_0, tg_z_xxyy_1, tg_z_xxyz_0, \
                                         tg_z_xxyz_1, tg_z_xxz_1, tg_z_xxzz_0, tg_z_xxzz_1, tg_z_xyy_1, tg_z_xyyy_0, \
                                         tg_z_xyyy_1, tg_z_xyyz_0, tg_z_xyyz_1, tg_z_xyz_1, tg_z_xyzz_0, tg_z_xyzz_1, \
                                         tg_z_xzz_1, tg_z_xzzz_0, tg_z_xzzz_1, tg_z_yyy_1, tg_z_yyyy_0, tg_z_yyyy_1, \
                                         tg_z_yyyz_0, tg_z_yyyz_1, tg_z_yyz_1, tg_z_yyzz_0, tg_z_yyzz_1, tg_z_yzz_1, \
                                         tg_z_yzzz_0, tg_z_yzzz_1, tg_z_zzz_1, tg_z_zzzz_0, tg_z_zzzz_1, tg_zz_xxxx_0, \
                                         tg_zz_xxxy_0, tg_zz_xxxz_0, tg_zz_xxyy_0, tg_zz_xxyz_0, tg_zz_xxzz_0, tg_zz_xyyy_0, \
                                         tg_zz_xyyz_0, tg_zz_xyzz_0, tg_zz_xzzz_0, tg_zz_yyyy_0, tg_zz_yyyz_0, tg_zz_yyzz_0, \
                                         tg_zz_yzzz_0, tg_zz_zzzz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxxx_0[j] = pb_x * tg_x_xxxx_0[j] + fr * tg_x_xxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxx_0[j] - tg_0_xxxx_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxx_1[j];

                    tg_xx_xxxy_0[j] = pb_x * tg_x_xxxy_0[j] + fr * tg_x_xxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxy_0[j] - tg_0_xxxy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxy_1[j];

                    tg_xx_xxxz_0[j] = pb_x * tg_x_xxxz_0[j] + fr * tg_x_xxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxz_0[j] - tg_0_xxxz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxz_1[j];

                    tg_xx_xxyy_0[j] = pb_x * tg_x_xxyy_0[j] + fr * tg_x_xxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyy_0[j] - tg_0_xxyy_1[j] * fl1_fza) + fl1_fxn * tg_x_xyy_1[j];

                    tg_xx_xxyz_0[j] = pb_x * tg_x_xxyz_0[j] + fr * tg_x_xxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyz_0[j] - tg_0_xxyz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyz_1[j];

                    tg_xx_xxzz_0[j] = pb_x * tg_x_xxzz_0[j] + fr * tg_x_xxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzz_0[j] - tg_0_xxzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xzz_1[j];

                    tg_xx_xyyy_0[j] = pb_x * tg_x_xyyy_0[j] + fr * tg_x_xyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyy_0[j] - tg_0_xyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyy_1[j];

                    tg_xx_xyyz_0[j] = pb_x * tg_x_xyyz_0[j] + fr * tg_x_xyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyz_0[j] - tg_0_xyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyz_1[j];

                    tg_xx_xyzz_0[j] = pb_x * tg_x_xyzz_0[j] + fr * tg_x_xyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzz_0[j] - tg_0_xyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yzz_1[j];

                    tg_xx_xzzz_0[j] = pb_x * tg_x_xzzz_0[j] + fr * tg_x_xzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzz_0[j] - tg_0_xzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zzz_1[j];

                    tg_xx_yyyy_0[j] = pb_x * tg_x_yyyy_0[j] + fr * tg_x_yyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyy_0[j] - tg_0_yyyy_1[j] * fl1_fza);

                    tg_xx_yyyz_0[j] = pb_x * tg_x_yyyz_0[j] + fr * tg_x_yyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyz_0[j] - tg_0_yyyz_1[j] * fl1_fza);

                    tg_xx_yyzz_0[j] = pb_x * tg_x_yyzz_0[j] + fr * tg_x_yyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzz_0[j] - tg_0_yyzz_1[j] * fl1_fza);

                    tg_xx_yzzz_0[j] = pb_x * tg_x_yzzz_0[j] + fr * tg_x_yzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzz_0[j] - tg_0_yzzz_1[j] * fl1_fza);

                    tg_xx_zzzz_0[j] = pb_x * tg_x_zzzz_0[j] + fr * tg_x_zzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzz_0[j] - tg_0_zzzz_1[j] * fl1_fza);

                    tg_xy_xxxx_0[j] = pb_x * tg_y_xxxx_0[j] + fr * tg_y_xxxx_1[j] + 2.0 * fl1_fxn * tg_y_xxx_1[j];

                    tg_xy_xxxy_0[j] = pb_x * tg_y_xxxy_0[j] + fr * tg_y_xxxy_1[j] + 1.5 * fl1_fxn * tg_y_xxy_1[j];

                    tg_xy_xxxz_0[j] = pb_x * tg_y_xxxz_0[j] + fr * tg_y_xxxz_1[j] + 1.5 * fl1_fxn * tg_y_xxz_1[j];

                    tg_xy_xxyy_0[j] = pb_x * tg_y_xxyy_0[j] + fr * tg_y_xxyy_1[j] + fl1_fxn * tg_y_xyy_1[j];

                    tg_xy_xxyz_0[j] = pb_x * tg_y_xxyz_0[j] + fr * tg_y_xxyz_1[j] + fl1_fxn * tg_y_xyz_1[j];

                    tg_xy_xxzz_0[j] = pb_x * tg_y_xxzz_0[j] + fr * tg_y_xxzz_1[j] + fl1_fxn * tg_y_xzz_1[j];

                    tg_xy_xyyy_0[j] = pb_x * tg_y_xyyy_0[j] + fr * tg_y_xyyy_1[j] + 0.5 * fl1_fxn * tg_y_yyy_1[j];

                    tg_xy_xyyz_0[j] = pb_x * tg_y_xyyz_0[j] + fr * tg_y_xyyz_1[j] + 0.5 * fl1_fxn * tg_y_yyz_1[j];

                    tg_xy_xyzz_0[j] = pb_x * tg_y_xyzz_0[j] + fr * tg_y_xyzz_1[j] + 0.5 * fl1_fxn * tg_y_yzz_1[j];

                    tg_xy_xzzz_0[j] = pb_x * tg_y_xzzz_0[j] + fr * tg_y_xzzz_1[j] + 0.5 * fl1_fxn * tg_y_zzz_1[j];

                    tg_xy_yyyy_0[j] = pb_x * tg_y_yyyy_0[j] + fr * tg_y_yyyy_1[j];

                    tg_xy_yyyz_0[j] = pb_x * tg_y_yyyz_0[j] + fr * tg_y_yyyz_1[j];

                    tg_xy_yyzz_0[j] = pb_x * tg_y_yyzz_0[j] + fr * tg_y_yyzz_1[j];

                    tg_xy_yzzz_0[j] = pb_x * tg_y_yzzz_0[j] + fr * tg_y_yzzz_1[j];

                    tg_xy_zzzz_0[j] = pb_x * tg_y_zzzz_0[j] + fr * tg_y_zzzz_1[j];

                    tg_xz_xxxx_0[j] = pb_x * tg_z_xxxx_0[j] + fr * tg_z_xxxx_1[j] + 2.0 * fl1_fxn * tg_z_xxx_1[j];

                    tg_xz_xxxy_0[j] = pb_x * tg_z_xxxy_0[j] + fr * tg_z_xxxy_1[j] + 1.5 * fl1_fxn * tg_z_xxy_1[j];

                    tg_xz_xxxz_0[j] = pb_x * tg_z_xxxz_0[j] + fr * tg_z_xxxz_1[j] + 1.5 * fl1_fxn * tg_z_xxz_1[j];

                    tg_xz_xxyy_0[j] = pb_x * tg_z_xxyy_0[j] + fr * tg_z_xxyy_1[j] + fl1_fxn * tg_z_xyy_1[j];

                    tg_xz_xxyz_0[j] = pb_x * tg_z_xxyz_0[j] + fr * tg_z_xxyz_1[j] + fl1_fxn * tg_z_xyz_1[j];

                    tg_xz_xxzz_0[j] = pb_x * tg_z_xxzz_0[j] + fr * tg_z_xxzz_1[j] + fl1_fxn * tg_z_xzz_1[j];

                    tg_xz_xyyy_0[j] = pb_x * tg_z_xyyy_0[j] + fr * tg_z_xyyy_1[j] + 0.5 * fl1_fxn * tg_z_yyy_1[j];

                    tg_xz_xyyz_0[j] = pb_x * tg_z_xyyz_0[j] + fr * tg_z_xyyz_1[j] + 0.5 * fl1_fxn * tg_z_yyz_1[j];

                    tg_xz_xyzz_0[j] = pb_x * tg_z_xyzz_0[j] + fr * tg_z_xyzz_1[j] + 0.5 * fl1_fxn * tg_z_yzz_1[j];

                    tg_xz_xzzz_0[j] = pb_x * tg_z_xzzz_0[j] + fr * tg_z_xzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzz_1[j];

                    tg_xz_yyyy_0[j] = pb_x * tg_z_yyyy_0[j] + fr * tg_z_yyyy_1[j];

                    tg_xz_yyyz_0[j] = pb_x * tg_z_yyyz_0[j] + fr * tg_z_yyyz_1[j];

                    tg_xz_yyzz_0[j] = pb_x * tg_z_yyzz_0[j] + fr * tg_z_yyzz_1[j];

                    tg_xz_yzzz_0[j] = pb_x * tg_z_yzzz_0[j] + fr * tg_z_yzzz_1[j];

                    tg_xz_zzzz_0[j] = pb_x * tg_z_zzzz_0[j] + fr * tg_z_zzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yy_xxxx_0[j] = pb_y * tg_y_xxxx_0[j] + fr * tg_y_xxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxx_0[j] - tg_0_xxxx_1[j] * fl1_fza);

                    tg_yy_xxxy_0[j] = pb_y * tg_y_xxxy_0[j] + fr * tg_y_xxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxy_0[j] - tg_0_xxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxx_1[j];

                    tg_yy_xxxz_0[j] = pb_y * tg_y_xxxz_0[j] + fr * tg_y_xxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxz_0[j] - tg_0_xxxz_1[j] * fl1_fza);

                    tg_yy_xxyy_0[j] = pb_y * tg_y_xxyy_0[j] + fr * tg_y_xxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyy_0[j] - tg_0_xxyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xxy_1[j];

                    tg_yy_xxyz_0[j] = pb_y * tg_y_xxyz_0[j] + fr * tg_y_xxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyz_0[j] - tg_0_xxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxz_1[j];

                    tg_yy_xxzz_0[j] = pb_y * tg_y_xxzz_0[j] + fr * tg_y_xxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzz_0[j] - tg_0_xxzz_1[j] * fl1_fza);

                    tg_yy_xyyy_0[j] = pb_y * tg_y_xyyy_0[j] + fr * tg_y_xyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyy_0[j] - tg_0_xyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xyy_1[j];

                    tg_yy_xyyz_0[j] = pb_y * tg_y_xyyz_0[j] + fr * tg_y_xyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyz_0[j] - tg_0_xyyz_1[j] * fl1_fza) + fl1_fxn * tg_y_xyz_1[j];

                    tg_yy_xyzz_0[j] = pb_y * tg_y_xyzz_0[j] + fr * tg_y_xyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzz_0[j] - tg_0_xyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xzz_1[j];

                    tg_yy_xzzz_0[j] = pb_y * tg_y_xzzz_0[j] + fr * tg_y_xzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzz_0[j] - tg_0_xzzz_1[j] * fl1_fza);

                    tg_yy_yyyy_0[j] = pb_y * tg_y_yyyy_0[j] + fr * tg_y_yyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyy_0[j] - tg_0_yyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_yyy_1[j];

                    tg_yy_yyyz_0[j] = pb_y * tg_y_yyyz_0[j] + fr * tg_y_yyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyz_0[j] - tg_0_yyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yyz_1[j];

                    tg_yy_yyzz_0[j] = pb_y * tg_y_yyzz_0[j] + fr * tg_y_yyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzz_0[j] - tg_0_yyzz_1[j] * fl1_fza) + fl1_fxn * tg_y_yzz_1[j];

                    tg_yy_yzzz_0[j] = pb_y * tg_y_yzzz_0[j] + fr * tg_y_yzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzz_0[j] - tg_0_yzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zzz_1[j];

                    tg_yy_zzzz_0[j] = pb_y * tg_y_zzzz_0[j] + fr * tg_y_zzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzz_0[j] - tg_0_zzzz_1[j] * fl1_fza);

                    tg_yz_xxxx_0[j] = pb_y * tg_z_xxxx_0[j] + fr * tg_z_xxxx_1[j];

                    tg_yz_xxxy_0[j] = pb_y * tg_z_xxxy_0[j] + fr * tg_z_xxxy_1[j] + 0.5 * fl1_fxn * tg_z_xxx_1[j];

                    tg_yz_xxxz_0[j] = pb_y * tg_z_xxxz_0[j] + fr * tg_z_xxxz_1[j];

                    tg_yz_xxyy_0[j] = pb_y * tg_z_xxyy_0[j] + fr * tg_z_xxyy_1[j] + fl1_fxn * tg_z_xxy_1[j];

                    tg_yz_xxyz_0[j] = pb_y * tg_z_xxyz_0[j] + fr * tg_z_xxyz_1[j] + 0.5 * fl1_fxn * tg_z_xxz_1[j];

                    tg_yz_xxzz_0[j] = pb_y * tg_z_xxzz_0[j] + fr * tg_z_xxzz_1[j];

                    tg_yz_xyyy_0[j] = pb_y * tg_z_xyyy_0[j] + fr * tg_z_xyyy_1[j] + 1.5 * fl1_fxn * tg_z_xyy_1[j];

                    tg_yz_xyyz_0[j] = pb_y * tg_z_xyyz_0[j] + fr * tg_z_xyyz_1[j] + fl1_fxn * tg_z_xyz_1[j];

                    tg_yz_xyzz_0[j] = pb_y * tg_z_xyzz_0[j] + fr * tg_z_xyzz_1[j] + 0.5 * fl1_fxn * tg_z_xzz_1[j];

                    tg_yz_xzzz_0[j] = pb_y * tg_z_xzzz_0[j] + fr * tg_z_xzzz_1[j];

                    tg_yz_yyyy_0[j] = pb_y * tg_z_yyyy_0[j] + fr * tg_z_yyyy_1[j] + 2.0 * fl1_fxn * tg_z_yyy_1[j];

                    tg_yz_yyyz_0[j] = pb_y * tg_z_yyyz_0[j] + fr * tg_z_yyyz_1[j] + 1.5 * fl1_fxn * tg_z_yyz_1[j];

                    tg_yz_yyzz_0[j] = pb_y * tg_z_yyzz_0[j] + fr * tg_z_yyzz_1[j] + fl1_fxn * tg_z_yzz_1[j];

                    tg_yz_yzzz_0[j] = pb_y * tg_z_yzzz_0[j] + fr * tg_z_yzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzz_1[j];

                    tg_yz_zzzz_0[j] = pb_y * tg_z_zzzz_0[j] + fr * tg_z_zzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxxx_0[j] = pb_z * tg_z_xxxx_0[j] + fr * tg_z_xxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxx_0[j] - tg_0_xxxx_1[j] * fl1_fza);

                    tg_zz_xxxy_0[j] = pb_z * tg_z_xxxy_0[j] + fr * tg_z_xxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxy_0[j] - tg_0_xxxy_1[j] * fl1_fza);

                    tg_zz_xxxz_0[j] = pb_z * tg_z_xxxz_0[j] + fr * tg_z_xxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxz_0[j] - tg_0_xxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxx_1[j];

                    tg_zz_xxyy_0[j] = pb_z * tg_z_xxyy_0[j] + fr * tg_z_xxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyy_0[j] - tg_0_xxyy_1[j] * fl1_fza);

                    tg_zz_xxyz_0[j] = pb_z * tg_z_xxyz_0[j] + fr * tg_z_xxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyz_0[j] - tg_0_xxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxy_1[j];

                    tg_zz_xxzz_0[j] = pb_z * tg_z_xxzz_0[j] + fr * tg_z_xxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzz_0[j] - tg_0_xxzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxz_1[j];

                    tg_zz_xyyy_0[j] = pb_z * tg_z_xyyy_0[j] + fr * tg_z_xyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyy_0[j] - tg_0_xyyy_1[j] * fl1_fza);

                    tg_zz_xyyz_0[j] = pb_z * tg_z_xyyz_0[j] + fr * tg_z_xyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyz_0[j] - tg_0_xyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xyy_1[j];

                    tg_zz_xyzz_0[j] = pb_z * tg_z_xyzz_0[j] + fr * tg_z_xyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzz_0[j] - tg_0_xyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xyz_1[j];

                    tg_zz_xzzz_0[j] = pb_z * tg_z_xzzz_0[j] + fr * tg_z_xzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzz_0[j] - tg_0_xzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xzz_1[j];

                    tg_zz_yyyy_0[j] = pb_z * tg_z_yyyy_0[j] + fr * tg_z_yyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyy_0[j] - tg_0_yyyy_1[j] * fl1_fza);

                    tg_zz_yyyz_0[j] = pb_z * tg_z_yyyz_0[j] + fr * tg_z_yyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyz_0[j] - tg_0_yyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yyy_1[j];

                    tg_zz_yyzz_0[j] = pb_z * tg_z_yyzz_0[j] + fr * tg_z_yyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzz_0[j] - tg_0_yyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yyz_1[j];

                    tg_zz_yzzz_0[j] = pb_z * tg_z_yzzz_0[j] + fr * tg_z_yzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzz_0[j] - tg_0_yzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_yzz_1[j];

                    tg_zz_zzzz_0[j] = pb_z * tg_z_zzzz_0[j] + fr * tg_z_zzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzz_0[j] - tg_0_zzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_zzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSGSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {4, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_4_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_4_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_3_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_3_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_2_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_2_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_3_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_xxx_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx); 

                auto tg_xxx_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 1); 

                auto tg_xxx_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 2); 

                auto tg_xxx_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 3); 

                auto tg_xxx_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 4); 

                auto tg_xxx_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 5); 

                auto tg_xxy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 6); 

                auto tg_xxy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 7); 

                auto tg_xxy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 8); 

                auto tg_xxy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 9); 

                auto tg_xxy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 10); 

                auto tg_xxy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 11); 

                auto tg_xxz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 12); 

                auto tg_xxz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 13); 

                auto tg_xxz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 14); 

                auto tg_xxz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 15); 

                auto tg_xxz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 16); 

                auto tg_xxz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 17); 

                auto tg_xyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 18); 

                auto tg_xyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 19); 

                auto tg_xyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 20); 

                auto tg_xyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 21); 

                auto tg_xyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 22); 

                auto tg_xyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 23); 

                auto tg_xyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 24); 

                auto tg_xyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 25); 

                auto tg_xyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 26); 

                auto tg_xyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 27); 

                auto tg_xyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 28); 

                auto tg_xyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 29); 

                auto tg_xzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 30); 

                auto tg_xzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 31); 

                auto tg_xzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 32); 

                auto tg_xzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 33); 

                auto tg_xzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 34); 

                auto tg_xzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 35); 

                auto tg_yyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 36); 

                auto tg_yyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 37); 

                auto tg_yyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 38); 

                auto tg_yyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 39); 

                auto tg_yyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 40); 

                auto tg_yyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 41); 

                auto tg_yyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 42); 

                auto tg_yyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 43); 

                auto tg_yyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 44); 

                auto tg_yyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 45); 

                auto tg_yyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 46); 

                auto tg_yyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 47); 

                auto tg_yzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 48); 

                auto tg_yzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 49); 

                auto tg_yzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 50); 

                auto tg_yzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 51); 

                auto tg_yzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 52); 

                auto tg_yzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 53); 

                auto tg_zzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 54); 

                auto tg_zzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 55); 

                auto tg_zzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 56); 

                auto tg_zzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 57); 

                auto tg_zzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 58); 

                auto tg_zzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 59); 

                auto tg_xxx_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx); 

                auto tg_xxx_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 1); 

                auto tg_xxx_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 2); 

                auto tg_xxx_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 3); 

                auto tg_xxx_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 4); 

                auto tg_xxx_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 5); 

                auto tg_xxy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 6); 

                auto tg_xxy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 7); 

                auto tg_xxy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 8); 

                auto tg_xxy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 9); 

                auto tg_xxy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 10); 

                auto tg_xxy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 11); 

                auto tg_xxz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 12); 

                auto tg_xxz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 13); 

                auto tg_xxz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 14); 

                auto tg_xxz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 15); 

                auto tg_xxz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 16); 

                auto tg_xxz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 17); 

                auto tg_xyy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 18); 

                auto tg_xyy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 19); 

                auto tg_xyy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 20); 

                auto tg_xyy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 21); 

                auto tg_xyy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 22); 

                auto tg_xyy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 23); 

                auto tg_xyz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 24); 

                auto tg_xyz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 25); 

                auto tg_xyz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 26); 

                auto tg_xyz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 27); 

                auto tg_xyz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 28); 

                auto tg_xyz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 29); 

                auto tg_xzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 30); 

                auto tg_xzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 31); 

                auto tg_xzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 32); 

                auto tg_xzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 33); 

                auto tg_xzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 34); 

                auto tg_xzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 35); 

                auto tg_yyy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 36); 

                auto tg_yyy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 37); 

                auto tg_yyy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 38); 

                auto tg_yyy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 39); 

                auto tg_yyy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 40); 

                auto tg_yyy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 41); 

                auto tg_yyz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 42); 

                auto tg_yyz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 43); 

                auto tg_yyz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 44); 

                auto tg_yyz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 45); 

                auto tg_yyz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 46); 

                auto tg_yyz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 47); 

                auto tg_yzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 48); 

                auto tg_yzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 49); 

                auto tg_yzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 50); 

                auto tg_yzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 51); 

                auto tg_yzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 52); 

                auto tg_yzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 53); 

                auto tg_zzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 54); 

                auto tg_zzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 55); 

                auto tg_zzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 56); 

                auto tg_zzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 57); 

                auto tg_zzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 58); 

                auto tg_zzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 59); 

                auto tg_xx_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx); 

                auto tg_xx_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 1); 

                auto tg_xx_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 2); 

                auto tg_xx_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 3); 

                auto tg_xx_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 4); 

                auto tg_xx_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 5); 

                auto tg_xy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 6); 

                auto tg_xy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 7); 

                auto tg_xy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 8); 

                auto tg_xy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 9); 

                auto tg_xy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 10); 

                auto tg_xy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 11); 

                auto tg_xz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 12); 

                auto tg_xz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 13); 

                auto tg_xz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 14); 

                auto tg_xz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 15); 

                auto tg_xz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 16); 

                auto tg_xz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 17); 

                auto tg_yy_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 18); 

                auto tg_yy_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 19); 

                auto tg_yy_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 20); 

                auto tg_yy_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 21); 

                auto tg_yy_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 22); 

                auto tg_yy_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 23); 

                auto tg_yz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 24); 

                auto tg_yz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 25); 

                auto tg_yz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 26); 

                auto tg_yz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 27); 

                auto tg_yz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 28); 

                auto tg_yz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 29); 

                auto tg_zz_xx_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 30); 

                auto tg_zz_xy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 31); 

                auto tg_zz_xz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 32); 

                auto tg_zz_yy_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 33); 

                auto tg_zz_yz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 34); 

                auto tg_zz_zz_0 = primBuffer[pidx_g_2_2_m0].data(36 * idx + 35); 

                auto tg_xx_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx); 

                auto tg_xx_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 1); 

                auto tg_xx_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 2); 

                auto tg_xx_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 3); 

                auto tg_xx_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 4); 

                auto tg_xx_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 5); 

                auto tg_xy_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 6); 

                auto tg_xy_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 7); 

                auto tg_xy_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 8); 

                auto tg_xy_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 9); 

                auto tg_xy_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 10); 

                auto tg_xy_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 11); 

                auto tg_xz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 12); 

                auto tg_xz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 13); 

                auto tg_xz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 14); 

                auto tg_xz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 15); 

                auto tg_xz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 16); 

                auto tg_xz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 17); 

                auto tg_yy_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 18); 

                auto tg_yy_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 19); 

                auto tg_yy_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 20); 

                auto tg_yy_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 21); 

                auto tg_yy_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 22); 

                auto tg_yy_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 23); 

                auto tg_yz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 24); 

                auto tg_yz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 25); 

                auto tg_yz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 26); 

                auto tg_yz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 27); 

                auto tg_yz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 28); 

                auto tg_yz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 29); 

                auto tg_zz_xx_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 30); 

                auto tg_zz_xy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 31); 

                auto tg_zz_xz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 32); 

                auto tg_zz_yy_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 33); 

                auto tg_zz_yz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 34); 

                auto tg_zz_zz_1 = primBuffer[pidx_g_2_2_m1].data(36 * idx + 35); 

                auto tg_xxx_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx); 

                auto tg_xxx_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 1); 

                auto tg_xxx_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 2); 

                auto tg_xxy_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 3); 

                auto tg_xxy_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 4); 

                auto tg_xxy_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 5); 

                auto tg_xxz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 6); 

                auto tg_xxz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 7); 

                auto tg_xxz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 8); 

                auto tg_xyy_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 9); 

                auto tg_xyy_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 10); 

                auto tg_xyy_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 11); 

                auto tg_xyz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 12); 

                auto tg_xyz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 13); 

                auto tg_xyz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 14); 

                auto tg_xzz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 15); 

                auto tg_xzz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 16); 

                auto tg_xzz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 17); 

                auto tg_yyy_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 18); 

                auto tg_yyy_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 19); 

                auto tg_yyy_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 20); 

                auto tg_yyz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 21); 

                auto tg_yyz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 22); 

                auto tg_yyz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 23); 

                auto tg_yzz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 24); 

                auto tg_yzz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 25); 

                auto tg_yzz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 26); 

                auto tg_zzz_x_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 27); 

                auto tg_zzz_y_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 28); 

                auto tg_zzz_z_1 = primBuffer[pidx_g_3_1_m1].data(30 * idx + 29); 

                // set up pointers to integrals

                auto tg_xxxx_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx); 

                auto tg_xxxx_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 1); 

                auto tg_xxxx_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 2); 

                auto tg_xxxx_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 3); 

                auto tg_xxxx_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 4); 

                auto tg_xxxx_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 5); 

                auto tg_xxxy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 6); 

                auto tg_xxxy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 7); 

                auto tg_xxxy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 8); 

                auto tg_xxxy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 9); 

                auto tg_xxxy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 10); 

                auto tg_xxxy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 11); 

                auto tg_xxxz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 12); 

                auto tg_xxxz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 13); 

                auto tg_xxxz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 14); 

                auto tg_xxxz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 15); 

                auto tg_xxxz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 16); 

                auto tg_xxxz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 17); 

                auto tg_xxyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 18); 

                auto tg_xxyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 19); 

                auto tg_xxyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 20); 

                auto tg_xxyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 21); 

                auto tg_xxyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 22); 

                auto tg_xxyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 23); 

                auto tg_xxyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 24); 

                auto tg_xxyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 25); 

                auto tg_xxyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 26); 

                auto tg_xxyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 27); 

                auto tg_xxyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 28); 

                auto tg_xxyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 29); 

                auto tg_xxzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 30); 

                auto tg_xxzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 31); 

                auto tg_xxzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 32); 

                auto tg_xxzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 33); 

                auto tg_xxzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 34); 

                auto tg_xxzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 35); 

                auto tg_xyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 36); 

                auto tg_xyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 37); 

                auto tg_xyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 38); 

                auto tg_xyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 39); 

                auto tg_xyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 40); 

                auto tg_xyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 41); 

                auto tg_xyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 42); 

                auto tg_xyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 43); 

                auto tg_xyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 44); 

                auto tg_xyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 45); 

                auto tg_xyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 46); 

                auto tg_xyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 47); 

                auto tg_xyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 48); 

                auto tg_xyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 49); 

                auto tg_xyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 50); 

                auto tg_xyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 51); 

                auto tg_xyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 52); 

                auto tg_xyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 53); 

                auto tg_xzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 54); 

                auto tg_xzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 55); 

                auto tg_xzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 56); 

                auto tg_xzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 57); 

                auto tg_xzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 58); 

                auto tg_xzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 59); 

                auto tg_yyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 60); 

                auto tg_yyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 61); 

                auto tg_yyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 62); 

                auto tg_yyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 63); 

                auto tg_yyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 64); 

                auto tg_yyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 65); 

                auto tg_yyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 66); 

                auto tg_yyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 67); 

                auto tg_yyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 68); 

                auto tg_yyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 69); 

                auto tg_yyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 70); 

                auto tg_yyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 71); 

                auto tg_yyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 72); 

                auto tg_yyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 73); 

                auto tg_yyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 74); 

                auto tg_yyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 75); 

                auto tg_yyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 76); 

                auto tg_yyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 77); 

                auto tg_yzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 78); 

                auto tg_yzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 79); 

                auto tg_yzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 80); 

                auto tg_yzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 81); 

                auto tg_yzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 82); 

                auto tg_yzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 83); 

                auto tg_zzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 84); 

                auto tg_zzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 85); 

                auto tg_zzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 86); 

                auto tg_zzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 87); 

                auto tg_zzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 88); 

                auto tg_zzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 89); 

                #pragma omp simd aligned(fxn, fza, tg_xx_xx_0, tg_xx_xx_1, tg_xx_xy_0, tg_xx_xy_1, tg_xx_xz_0, \
                                         tg_xx_xz_1, tg_xx_yy_0, tg_xx_yy_1, tg_xx_yz_0, tg_xx_yz_1, tg_xx_zz_0, tg_xx_zz_1, \
                                         tg_xxx_x_1, tg_xxx_xx_0, tg_xxx_xx_1, tg_xxx_xy_0, tg_xxx_xy_1, tg_xxx_xz_0, \
                                         tg_xxx_xz_1, tg_xxx_y_1, tg_xxx_yy_0, tg_xxx_yy_1, tg_xxx_yz_0, tg_xxx_yz_1, \
                                         tg_xxx_z_1, tg_xxx_zz_0, tg_xxx_zz_1, tg_xxxx_xx_0, tg_xxxx_xy_0, tg_xxxx_xz_0, \
                                         tg_xxxx_yy_0, tg_xxxx_yz_0, tg_xxxx_zz_0, tg_xxxy_xx_0, tg_xxxy_xy_0, tg_xxxy_xz_0, \
                                         tg_xxxy_yy_0, tg_xxxy_yz_0, tg_xxxy_zz_0, tg_xxxz_xx_0, tg_xxxz_xy_0, tg_xxxz_xz_0, \
                                         tg_xxxz_yy_0, tg_xxxz_yz_0, tg_xxxz_zz_0, tg_xxy_x_1, tg_xxy_xx_0, tg_xxy_xx_1, \
                                         tg_xxy_xy_0, tg_xxy_xy_1, tg_xxy_xz_0, tg_xxy_xz_1, tg_xxy_y_1, tg_xxy_yy_0, \
                                         tg_xxy_yy_1, tg_xxy_yz_0, tg_xxy_yz_1, tg_xxy_z_1, tg_xxy_zz_0, tg_xxy_zz_1, \
                                         tg_xxyy_xx_0, tg_xxyy_xy_0, tg_xxyy_xz_0, tg_xxyy_yy_0, tg_xxyy_yz_0, tg_xxyy_zz_0, \
                                         tg_xxyz_xx_0, tg_xxyz_xy_0, tg_xxyz_xz_0, tg_xxyz_yy_0, tg_xxyz_yz_0, tg_xxyz_zz_0, \
                                         tg_xxz_x_1, tg_xxz_xx_0, tg_xxz_xx_1, tg_xxz_xy_0, tg_xxz_xy_1, tg_xxz_xz_0, \
                                         tg_xxz_xz_1, tg_xxz_y_1, tg_xxz_yy_0, tg_xxz_yy_1, tg_xxz_yz_0, tg_xxz_yz_1, \
                                         tg_xxz_z_1, tg_xxz_zz_0, tg_xxz_zz_1, tg_xxzz_xx_0, tg_xxzz_xy_0, tg_xxzz_xz_0, \
                                         tg_xxzz_yy_0, tg_xxzz_yz_0, tg_xxzz_zz_0, tg_xy_xx_0, tg_xy_xx_1, tg_xy_xy_0, \
                                         tg_xy_xy_1, tg_xy_xz_0, tg_xy_xz_1, tg_xy_yy_0, tg_xy_yy_1, tg_xy_yz_0, tg_xy_yz_1, \
                                         tg_xy_zz_0, tg_xy_zz_1, tg_xyy_x_1, tg_xyy_xx_0, tg_xyy_xx_1, tg_xyy_xy_0, \
                                         tg_xyy_xy_1, tg_xyy_xz_0, tg_xyy_xz_1, tg_xyy_y_1, tg_xyy_yy_0, tg_xyy_yy_1, \
                                         tg_xyy_yz_0, tg_xyy_yz_1, tg_xyy_z_1, tg_xyy_zz_0, tg_xyy_zz_1, tg_xyyy_xx_0, \
                                         tg_xyyy_xy_0, tg_xyyy_xz_0, tg_xyyy_yy_0, tg_xyyy_yz_0, tg_xyyy_zz_0, tg_xyyz_xx_0, \
                                         tg_xyyz_xy_0, tg_xyyz_xz_0, tg_xyyz_yy_0, tg_xyyz_yz_0, tg_xyyz_zz_0, tg_xyz_x_1, \
                                         tg_xyz_xx_0, tg_xyz_xx_1, tg_xyz_xy_0, tg_xyz_xy_1, tg_xyz_xz_0, tg_xyz_xz_1, \
                                         tg_xyz_y_1, tg_xyz_yy_0, tg_xyz_yy_1, tg_xyz_yz_0, tg_xyz_yz_1, tg_xyz_z_1, \
                                         tg_xyz_zz_0, tg_xyz_zz_1, tg_xyzz_xx_0, tg_xyzz_xy_0, tg_xyzz_xz_0, tg_xyzz_yy_0, \
                                         tg_xyzz_yz_0, tg_xyzz_zz_0, tg_xz_xx_0, tg_xz_xx_1, tg_xz_xy_0, tg_xz_xy_1, \
                                         tg_xz_xz_0, tg_xz_xz_1, tg_xz_yy_0, tg_xz_yy_1, tg_xz_yz_0, tg_xz_yz_1, tg_xz_zz_0, \
                                         tg_xz_zz_1, tg_xzz_x_1, tg_xzz_xx_0, tg_xzz_xx_1, tg_xzz_xy_0, tg_xzz_xy_1, \
                                         tg_xzz_xz_0, tg_xzz_xz_1, tg_xzz_y_1, tg_xzz_yy_0, tg_xzz_yy_1, tg_xzz_yz_0, \
                                         tg_xzz_yz_1, tg_xzz_z_1, tg_xzz_zz_0, tg_xzz_zz_1, tg_xzzz_xx_0, tg_xzzz_xy_0, \
                                         tg_xzzz_xz_0, tg_xzzz_yy_0, tg_xzzz_yz_0, tg_xzzz_zz_0, tg_yy_xx_0, tg_yy_xx_1, \
                                         tg_yy_xy_0, tg_yy_xy_1, tg_yy_xz_0, tg_yy_xz_1, tg_yy_yy_0, tg_yy_yy_1, tg_yy_yz_0, \
                                         tg_yy_yz_1, tg_yy_zz_0, tg_yy_zz_1, tg_yyy_x_1, tg_yyy_xx_0, tg_yyy_xx_1, \
                                         tg_yyy_xy_0, tg_yyy_xy_1, tg_yyy_xz_0, tg_yyy_xz_1, tg_yyy_y_1, tg_yyy_yy_0, \
                                         tg_yyy_yy_1, tg_yyy_yz_0, tg_yyy_yz_1, tg_yyy_z_1, tg_yyy_zz_0, tg_yyy_zz_1, \
                                         tg_yyyy_xx_0, tg_yyyy_xy_0, tg_yyyy_xz_0, tg_yyyy_yy_0, tg_yyyy_yz_0, tg_yyyy_zz_0, \
                                         tg_yyyz_xx_0, tg_yyyz_xy_0, tg_yyyz_xz_0, tg_yyyz_yy_0, tg_yyyz_yz_0, tg_yyyz_zz_0, \
                                         tg_yyz_x_1, tg_yyz_xx_0, tg_yyz_xx_1, tg_yyz_xy_0, tg_yyz_xy_1, tg_yyz_xz_0, \
                                         tg_yyz_xz_1, tg_yyz_y_1, tg_yyz_yy_0, tg_yyz_yy_1, tg_yyz_yz_0, tg_yyz_yz_1, \
                                         tg_yyz_z_1, tg_yyz_zz_0, tg_yyz_zz_1, tg_yyzz_xx_0, tg_yyzz_xy_0, tg_yyzz_xz_0, \
                                         tg_yyzz_yy_0, tg_yyzz_yz_0, tg_yyzz_zz_0, tg_yz_xx_0, tg_yz_xx_1, tg_yz_xy_0, \
                                         tg_yz_xy_1, tg_yz_xz_0, tg_yz_xz_1, tg_yz_yy_0, tg_yz_yy_1, tg_yz_yz_0, tg_yz_yz_1, \
                                         tg_yz_zz_0, tg_yz_zz_1, tg_yzz_x_1, tg_yzz_xx_0, tg_yzz_xx_1, tg_yzz_xy_0, \
                                         tg_yzz_xy_1, tg_yzz_xz_0, tg_yzz_xz_1, tg_yzz_y_1, tg_yzz_yy_0, tg_yzz_yy_1, \
                                         tg_yzz_yz_0, tg_yzz_yz_1, tg_yzz_z_1, tg_yzz_zz_0, tg_yzz_zz_1, tg_yzzz_xx_0, \
                                         tg_yzzz_xy_0, tg_yzzz_xz_0, tg_yzzz_yy_0, tg_yzzz_yz_0, tg_yzzz_zz_0, tg_zz_xx_0, \
                                         tg_zz_xx_1, tg_zz_xy_0, tg_zz_xy_1, tg_zz_xz_0, tg_zz_xz_1, tg_zz_yy_0, tg_zz_yy_1, \
                                         tg_zz_yz_0, tg_zz_yz_1, tg_zz_zz_0, tg_zz_zz_1, tg_zzz_x_1, tg_zzz_xx_0, \
                                         tg_zzz_xx_1, tg_zzz_xy_0, tg_zzz_xy_1, tg_zzz_xz_0, tg_zzz_xz_1, tg_zzz_y_1, \
                                         tg_zzz_yy_0, tg_zzz_yy_1, tg_zzz_yz_0, tg_zzz_yz_1, tg_zzz_z_1, tg_zzz_zz_0, \
                                         tg_zzz_zz_1, tg_zzzz_xx_0, tg_zzzz_xy_0, tg_zzzz_xz_0, tg_zzzz_yy_0, tg_zzzz_yz_0, \
                                         tg_zzzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxx_xx_0[j] = pb_x * tg_xxx_xx_0[j] + fr * tg_xxx_xx_1[j] + 1.5 * fl1_fx * (tg_xx_xx_0[j] - tg_xx_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxx_x_1[j];

                    tg_xxxx_xy_0[j] = pb_x * tg_xxx_xy_0[j] + fr * tg_xxx_xy_1[j] + 1.5 * fl1_fx * (tg_xx_xy_0[j] - tg_xx_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxx_y_1[j];

                    tg_xxxx_xz_0[j] = pb_x * tg_xxx_xz_0[j] + fr * tg_xxx_xz_1[j] + 1.5 * fl1_fx * (tg_xx_xz_0[j] - tg_xx_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxx_z_1[j];

                    tg_xxxx_yy_0[j] = pb_x * tg_xxx_yy_0[j] + fr * tg_xxx_yy_1[j] + 1.5 * fl1_fx * (tg_xx_yy_0[j] - tg_xx_yy_1[j] * fl1_fza);

                    tg_xxxx_yz_0[j] = pb_x * tg_xxx_yz_0[j] + fr * tg_xxx_yz_1[j] + 1.5 * fl1_fx * (tg_xx_yz_0[j] - tg_xx_yz_1[j] * fl1_fza);

                    tg_xxxx_zz_0[j] = pb_x * tg_xxx_zz_0[j] + fr * tg_xxx_zz_1[j] + 1.5 * fl1_fx * (tg_xx_zz_0[j] - tg_xx_zz_1[j] * fl1_fza);

                    tg_xxxy_xx_0[j] = pb_x * tg_xxy_xx_0[j] + fr * tg_xxy_xx_1[j] + fl1_fx * (tg_xy_xx_0[j] - tg_xy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxy_x_1[j];

                    tg_xxxy_xy_0[j] = pb_x * tg_xxy_xy_0[j] + fr * tg_xxy_xy_1[j] + fl1_fx * (tg_xy_xy_0[j] - tg_xy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxy_y_1[j];

                    tg_xxxy_xz_0[j] = pb_x * tg_xxy_xz_0[j] + fr * tg_xxy_xz_1[j] + fl1_fx * (tg_xy_xz_0[j] - tg_xy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxy_z_1[j];

                    tg_xxxy_yy_0[j] = pb_x * tg_xxy_yy_0[j] + fr * tg_xxy_yy_1[j] + fl1_fx * (tg_xy_yy_0[j] - tg_xy_yy_1[j] * fl1_fza);

                    tg_xxxy_yz_0[j] = pb_x * tg_xxy_yz_0[j] + fr * tg_xxy_yz_1[j] + fl1_fx * (tg_xy_yz_0[j] - tg_xy_yz_1[j] * fl1_fza);

                    tg_xxxy_zz_0[j] = pb_x * tg_xxy_zz_0[j] + fr * tg_xxy_zz_1[j] + fl1_fx * (tg_xy_zz_0[j] - tg_xy_zz_1[j] * fl1_fza);

                    tg_xxxz_xx_0[j] = pb_x * tg_xxz_xx_0[j] + fr * tg_xxz_xx_1[j] + fl1_fx * (tg_xz_xx_0[j] - tg_xz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxz_x_1[j];

                    tg_xxxz_xy_0[j] = pb_x * tg_xxz_xy_0[j] + fr * tg_xxz_xy_1[j] + fl1_fx * (tg_xz_xy_0[j] - tg_xz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxz_y_1[j];

                    tg_xxxz_xz_0[j] = pb_x * tg_xxz_xz_0[j] + fr * tg_xxz_xz_1[j] + fl1_fx * (tg_xz_xz_0[j] - tg_xz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxz_z_1[j];

                    tg_xxxz_yy_0[j] = pb_x * tg_xxz_yy_0[j] + fr * tg_xxz_yy_1[j] + fl1_fx * (tg_xz_yy_0[j] - tg_xz_yy_1[j] * fl1_fza);

                    tg_xxxz_yz_0[j] = pb_x * tg_xxz_yz_0[j] + fr * tg_xxz_yz_1[j] + fl1_fx * (tg_xz_yz_0[j] - tg_xz_yz_1[j] * fl1_fza);

                    tg_xxxz_zz_0[j] = pb_x * tg_xxz_zz_0[j] + fr * tg_xxz_zz_1[j] + fl1_fx * (tg_xz_zz_0[j] - tg_xz_zz_1[j] * fl1_fza);

                    tg_xxyy_xx_0[j] = pb_x * tg_xyy_xx_0[j] + fr * tg_xyy_xx_1[j] + 0.5 * fl1_fx * (tg_yy_xx_0[j] - tg_yy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyy_x_1[j];

                    tg_xxyy_xy_0[j] = pb_x * tg_xyy_xy_0[j] + fr * tg_xyy_xy_1[j] + 0.5 * fl1_fx * (tg_yy_xy_0[j] - tg_yy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyy_y_1[j];

                    tg_xxyy_xz_0[j] = pb_x * tg_xyy_xz_0[j] + fr * tg_xyy_xz_1[j] + 0.5 * fl1_fx * (tg_yy_xz_0[j] - tg_yy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyy_z_1[j];

                    tg_xxyy_yy_0[j] = pb_x * tg_xyy_yy_0[j] + fr * tg_xyy_yy_1[j] + 0.5 * fl1_fx * (tg_yy_yy_0[j] - tg_yy_yy_1[j] * fl1_fza);

                    tg_xxyy_yz_0[j] = pb_x * tg_xyy_yz_0[j] + fr * tg_xyy_yz_1[j] + 0.5 * fl1_fx * (tg_yy_yz_0[j] - tg_yy_yz_1[j] * fl1_fza);

                    tg_xxyy_zz_0[j] = pb_x * tg_xyy_zz_0[j] + fr * tg_xyy_zz_1[j] + 0.5 * fl1_fx * (tg_yy_zz_0[j] - tg_yy_zz_1[j] * fl1_fza);

                    tg_xxyz_xx_0[j] = pb_x * tg_xyz_xx_0[j] + fr * tg_xyz_xx_1[j] + 0.5 * fl1_fx * (tg_yz_xx_0[j] - tg_yz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyz_x_1[j];

                    tg_xxyz_xy_0[j] = pb_x * tg_xyz_xy_0[j] + fr * tg_xyz_xy_1[j] + 0.5 * fl1_fx * (tg_yz_xy_0[j] - tg_yz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyz_y_1[j];

                    tg_xxyz_xz_0[j] = pb_x * tg_xyz_xz_0[j] + fr * tg_xyz_xz_1[j] + 0.5 * fl1_fx * (tg_yz_xz_0[j] - tg_yz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyz_z_1[j];

                    tg_xxyz_yy_0[j] = pb_x * tg_xyz_yy_0[j] + fr * tg_xyz_yy_1[j] + 0.5 * fl1_fx * (tg_yz_yy_0[j] - tg_yz_yy_1[j] * fl1_fza);

                    tg_xxyz_yz_0[j] = pb_x * tg_xyz_yz_0[j] + fr * tg_xyz_yz_1[j] + 0.5 * fl1_fx * (tg_yz_yz_0[j] - tg_yz_yz_1[j] * fl1_fza);

                    tg_xxyz_zz_0[j] = pb_x * tg_xyz_zz_0[j] + fr * tg_xyz_zz_1[j] + 0.5 * fl1_fx * (tg_yz_zz_0[j] - tg_yz_zz_1[j] * fl1_fza);

                    tg_xxzz_xx_0[j] = pb_x * tg_xzz_xx_0[j] + fr * tg_xzz_xx_1[j] + 0.5 * fl1_fx * (tg_zz_xx_0[j] - tg_zz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xzz_x_1[j];

                    tg_xxzz_xy_0[j] = pb_x * tg_xzz_xy_0[j] + fr * tg_xzz_xy_1[j] + 0.5 * fl1_fx * (tg_zz_xy_0[j] - tg_zz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzz_y_1[j];

                    tg_xxzz_xz_0[j] = pb_x * tg_xzz_xz_0[j] + fr * tg_xzz_xz_1[j] + 0.5 * fl1_fx * (tg_zz_xz_0[j] - tg_zz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzz_z_1[j];

                    tg_xxzz_yy_0[j] = pb_x * tg_xzz_yy_0[j] + fr * tg_xzz_yy_1[j] + 0.5 * fl1_fx * (tg_zz_yy_0[j] - tg_zz_yy_1[j] * fl1_fza);

                    tg_xxzz_yz_0[j] = pb_x * tg_xzz_yz_0[j] + fr * tg_xzz_yz_1[j] + 0.5 * fl1_fx * (tg_zz_yz_0[j] - tg_zz_yz_1[j] * fl1_fza);

                    tg_xxzz_zz_0[j] = pb_x * tg_xzz_zz_0[j] + fr * tg_xzz_zz_1[j] + 0.5 * fl1_fx * (tg_zz_zz_0[j] - tg_zz_zz_1[j] * fl1_fza);

                    tg_xyyy_xx_0[j] = pb_x * tg_yyy_xx_0[j] + fr * tg_yyy_xx_1[j] + fl1_fxn * tg_yyy_x_1[j];

                    tg_xyyy_xy_0[j] = pb_x * tg_yyy_xy_0[j] + fr * tg_yyy_xy_1[j] + 0.5 * fl1_fxn * tg_yyy_y_1[j];

                    tg_xyyy_xz_0[j] = pb_x * tg_yyy_xz_0[j] + fr * tg_yyy_xz_1[j] + 0.5 * fl1_fxn * tg_yyy_z_1[j];

                    tg_xyyy_yy_0[j] = pb_x * tg_yyy_yy_0[j] + fr * tg_yyy_yy_1[j];

                    tg_xyyy_yz_0[j] = pb_x * tg_yyy_yz_0[j] + fr * tg_yyy_yz_1[j];

                    tg_xyyy_zz_0[j] = pb_x * tg_yyy_zz_0[j] + fr * tg_yyy_zz_1[j];

                    tg_xyyz_xx_0[j] = pb_x * tg_yyz_xx_0[j] + fr * tg_yyz_xx_1[j] + fl1_fxn * tg_yyz_x_1[j];

                    tg_xyyz_xy_0[j] = pb_x * tg_yyz_xy_0[j] + fr * tg_yyz_xy_1[j] + 0.5 * fl1_fxn * tg_yyz_y_1[j];

                    tg_xyyz_xz_0[j] = pb_x * tg_yyz_xz_0[j] + fr * tg_yyz_xz_1[j] + 0.5 * fl1_fxn * tg_yyz_z_1[j];

                    tg_xyyz_yy_0[j] = pb_x * tg_yyz_yy_0[j] + fr * tg_yyz_yy_1[j];

                    tg_xyyz_yz_0[j] = pb_x * tg_yyz_yz_0[j] + fr * tg_yyz_yz_1[j];

                    tg_xyyz_zz_0[j] = pb_x * tg_yyz_zz_0[j] + fr * tg_yyz_zz_1[j];

                    tg_xyzz_xx_0[j] = pb_x * tg_yzz_xx_0[j] + fr * tg_yzz_xx_1[j] + fl1_fxn * tg_yzz_x_1[j];

                    tg_xyzz_xy_0[j] = pb_x * tg_yzz_xy_0[j] + fr * tg_yzz_xy_1[j] + 0.5 * fl1_fxn * tg_yzz_y_1[j];

                    tg_xyzz_xz_0[j] = pb_x * tg_yzz_xz_0[j] + fr * tg_yzz_xz_1[j] + 0.5 * fl1_fxn * tg_yzz_z_1[j];

                    tg_xyzz_yy_0[j] = pb_x * tg_yzz_yy_0[j] + fr * tg_yzz_yy_1[j];

                    tg_xyzz_yz_0[j] = pb_x * tg_yzz_yz_0[j] + fr * tg_yzz_yz_1[j];

                    tg_xyzz_zz_0[j] = pb_x * tg_yzz_zz_0[j] + fr * tg_yzz_zz_1[j];

                    tg_xzzz_xx_0[j] = pb_x * tg_zzz_xx_0[j] + fr * tg_zzz_xx_1[j] + fl1_fxn * tg_zzz_x_1[j];

                    tg_xzzz_xy_0[j] = pb_x * tg_zzz_xy_0[j] + fr * tg_zzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzz_y_1[j];

                    tg_xzzz_xz_0[j] = pb_x * tg_zzz_xz_0[j] + fr * tg_zzz_xz_1[j] + 0.5 * fl1_fxn * tg_zzz_z_1[j];

                    tg_xzzz_yy_0[j] = pb_x * tg_zzz_yy_0[j] + fr * tg_zzz_yy_1[j];

                    tg_xzzz_yz_0[j] = pb_x * tg_zzz_yz_0[j] + fr * tg_zzz_yz_1[j];

                    tg_xzzz_zz_0[j] = pb_x * tg_zzz_zz_0[j] + fr * tg_zzz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyy_xx_0[j] = pb_y * tg_yyy_xx_0[j] + fr * tg_yyy_xx_1[j] + 1.5 * fl1_fx * (tg_yy_xx_0[j] - tg_yy_xx_1[j] * fl1_fza);

                    tg_yyyy_xy_0[j] = pb_y * tg_yyy_xy_0[j] + fr * tg_yyy_xy_1[j] + 1.5 * fl1_fx * (tg_yy_xy_0[j] - tg_yy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyy_x_1[j];

                    tg_yyyy_xz_0[j] = pb_y * tg_yyy_xz_0[j] + fr * tg_yyy_xz_1[j] + 1.5 * fl1_fx * (tg_yy_xz_0[j] - tg_yy_xz_1[j] * fl1_fza);

                    tg_yyyy_yy_0[j] = pb_y * tg_yyy_yy_0[j] + fr * tg_yyy_yy_1[j] + 1.5 * fl1_fx * (tg_yy_yy_0[j] - tg_yy_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyy_y_1[j];

                    tg_yyyy_yz_0[j] = pb_y * tg_yyy_yz_0[j] + fr * tg_yyy_yz_1[j] + 1.5 * fl1_fx * (tg_yy_yz_0[j] - tg_yy_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyy_z_1[j];

                    tg_yyyy_zz_0[j] = pb_y * tg_yyy_zz_0[j] + fr * tg_yyy_zz_1[j] + 1.5 * fl1_fx * (tg_yy_zz_0[j] - tg_yy_zz_1[j] * fl1_fza);

                    tg_yyyz_xx_0[j] = pb_y * tg_yyz_xx_0[j] + fr * tg_yyz_xx_1[j] + fl1_fx * (tg_yz_xx_0[j] - tg_yz_xx_1[j] * fl1_fza);

                    tg_yyyz_xy_0[j] = pb_y * tg_yyz_xy_0[j] + fr * tg_yyz_xy_1[j] + fl1_fx * (tg_yz_xy_0[j] - tg_yz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyz_x_1[j];

                    tg_yyyz_xz_0[j] = pb_y * tg_yyz_xz_0[j] + fr * tg_yyz_xz_1[j] + fl1_fx * (tg_yz_xz_0[j] - tg_yz_xz_1[j] * fl1_fza);

                    tg_yyyz_yy_0[j] = pb_y * tg_yyz_yy_0[j] + fr * tg_yyz_yy_1[j] + fl1_fx * (tg_yz_yy_0[j] - tg_yz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyz_y_1[j];

                    tg_yyyz_yz_0[j] = pb_y * tg_yyz_yz_0[j] + fr * tg_yyz_yz_1[j] + fl1_fx * (tg_yz_yz_0[j] - tg_yz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyz_z_1[j];

                    tg_yyyz_zz_0[j] = pb_y * tg_yyz_zz_0[j] + fr * tg_yyz_zz_1[j] + fl1_fx * (tg_yz_zz_0[j] - tg_yz_zz_1[j] * fl1_fza);

                    tg_yyzz_xx_0[j] = pb_y * tg_yzz_xx_0[j] + fr * tg_yzz_xx_1[j] + 0.5 * fl1_fx * (tg_zz_xx_0[j] - tg_zz_xx_1[j] * fl1_fza);

                    tg_yyzz_xy_0[j] = pb_y * tg_yzz_xy_0[j] + fr * tg_yzz_xy_1[j] + 0.5 * fl1_fx * (tg_zz_xy_0[j] - tg_zz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzz_x_1[j];

                    tg_yyzz_xz_0[j] = pb_y * tg_yzz_xz_0[j] + fr * tg_yzz_xz_1[j] + 0.5 * fl1_fx * (tg_zz_xz_0[j] - tg_zz_xz_1[j] * fl1_fza);

                    tg_yyzz_yy_0[j] = pb_y * tg_yzz_yy_0[j] + fr * tg_yzz_yy_1[j] + 0.5 * fl1_fx * (tg_zz_yy_0[j] - tg_zz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yzz_y_1[j];

                    tg_yyzz_yz_0[j] = pb_y * tg_yzz_yz_0[j] + fr * tg_yzz_yz_1[j] + 0.5 * fl1_fx * (tg_zz_yz_0[j] - tg_zz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzz_z_1[j];

                    tg_yyzz_zz_0[j] = pb_y * tg_yzz_zz_0[j] + fr * tg_yzz_zz_1[j] + 0.5 * fl1_fx * (tg_zz_zz_0[j] - tg_zz_zz_1[j] * fl1_fza);

                    tg_yzzz_xx_0[j] = pb_y * tg_zzz_xx_0[j] + fr * tg_zzz_xx_1[j];

                    tg_yzzz_xy_0[j] = pb_y * tg_zzz_xy_0[j] + fr * tg_zzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzz_x_1[j];

                    tg_yzzz_xz_0[j] = pb_y * tg_zzz_xz_0[j] + fr * tg_zzz_xz_1[j];

                    tg_yzzz_yy_0[j] = pb_y * tg_zzz_yy_0[j] + fr * tg_zzz_yy_1[j] + fl1_fxn * tg_zzz_y_1[j];

                    tg_yzzz_yz_0[j] = pb_y * tg_zzz_yz_0[j] + fr * tg_zzz_yz_1[j] + 0.5 * fl1_fxn * tg_zzz_z_1[j];

                    tg_yzzz_zz_0[j] = pb_y * tg_zzz_zz_0[j] + fr * tg_zzz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzz_xx_0[j] = pb_z * tg_zzz_xx_0[j] + fr * tg_zzz_xx_1[j] + 1.5 * fl1_fx * (tg_zz_xx_0[j] - tg_zz_xx_1[j] * fl1_fza);

                    tg_zzzz_xy_0[j] = pb_z * tg_zzz_xy_0[j] + fr * tg_zzz_xy_1[j] + 1.5 * fl1_fx * (tg_zz_xy_0[j] - tg_zz_xy_1[j] * fl1_fza);

                    tg_zzzz_xz_0[j] = pb_z * tg_zzz_xz_0[j] + fr * tg_zzz_xz_1[j] + 1.5 * fl1_fx * (tg_zz_xz_0[j] - tg_zz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzz_x_1[j];

                    tg_zzzz_yy_0[j] = pb_z * tg_zzz_yy_0[j] + fr * tg_zzz_yy_1[j] + 1.5 * fl1_fx * (tg_zz_yy_0[j] - tg_zz_yy_1[j] * fl1_fza);

                    tg_zzzz_yz_0[j] = pb_z * tg_zzz_yz_0[j] + fr * tg_zzz_yz_1[j] + 1.5 * fl1_fx * (tg_zz_yz_0[j] - tg_zz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzz_y_1[j];

                    tg_zzzz_zz_0[j] = pb_z * tg_zzz_zz_0[j] + fr * tg_zzz_zz_1[j] + 1.5 * fl1_fx * (tg_zz_zz_0[j] - tg_zz_zz_1[j] * fl1_fza) + fl1_fxn * tg_zzz_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSH(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSDSH_0_63(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSDSH_63_126(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 
    }

    void
    compElectronRepulsionForSDSH_0_63(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,63)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {5, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_5_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_4_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_x_xxxxx_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx); 

                auto tg_x_xxxxy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 1); 

                auto tg_x_xxxxz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 2); 

                auto tg_x_xxxyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 3); 

                auto tg_x_xxxyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 4); 

                auto tg_x_xxxzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 5); 

                auto tg_x_xxyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 6); 

                auto tg_x_xxyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 7); 

                auto tg_x_xxyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 8); 

                auto tg_x_xxzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 9); 

                auto tg_x_xyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 10); 

                auto tg_x_xyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 11); 

                auto tg_x_xyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 12); 

                auto tg_x_xyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 13); 

                auto tg_x_xzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 14); 

                auto tg_x_yyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 15); 

                auto tg_x_yyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 16); 

                auto tg_x_yyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 17); 

                auto tg_x_yyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 18); 

                auto tg_x_yzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 19); 

                auto tg_x_zzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 20); 

                auto tg_y_xxxxx_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 21); 

                auto tg_y_xxxxy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 22); 

                auto tg_y_xxxxz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 23); 

                auto tg_y_xxxyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 24); 

                auto tg_y_xxxyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 25); 

                auto tg_y_xxxzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 26); 

                auto tg_y_xxyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 27); 

                auto tg_y_xxyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 28); 

                auto tg_y_xxyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 29); 

                auto tg_y_xxzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 30); 

                auto tg_y_xyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 31); 

                auto tg_y_xyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 32); 

                auto tg_y_xyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 33); 

                auto tg_y_xyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 34); 

                auto tg_y_xzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 35); 

                auto tg_y_yyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 36); 

                auto tg_y_yyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 37); 

                auto tg_y_yyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 38); 

                auto tg_y_yyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 39); 

                auto tg_y_yzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 40); 

                auto tg_y_zzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 41); 

                auto tg_z_xxxxx_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 42); 

                auto tg_z_xxxxy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 43); 

                auto tg_z_xxxxz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 44); 

                auto tg_z_xxxyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 45); 

                auto tg_z_xxxyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 46); 

                auto tg_z_xxxzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 47); 

                auto tg_z_xxyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 48); 

                auto tg_z_xxyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 49); 

                auto tg_z_xxyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 50); 

                auto tg_z_xxzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 51); 

                auto tg_z_xyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 52); 

                auto tg_z_xyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 53); 

                auto tg_z_xyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 54); 

                auto tg_z_xyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 55); 

                auto tg_z_xzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 56); 

                auto tg_z_yyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 57); 

                auto tg_z_yyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 58); 

                auto tg_z_yyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 59); 

                auto tg_z_yyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 60); 

                auto tg_z_yzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 61); 

                auto tg_z_zzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 62); 

                auto tg_x_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx); 

                auto tg_x_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 1); 

                auto tg_x_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 2); 

                auto tg_x_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 3); 

                auto tg_x_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 4); 

                auto tg_x_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 5); 

                auto tg_x_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 6); 

                auto tg_x_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 7); 

                auto tg_x_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 8); 

                auto tg_x_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 9); 

                auto tg_x_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 10); 

                auto tg_x_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 11); 

                auto tg_x_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 12); 

                auto tg_x_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 13); 

                auto tg_x_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 14); 

                auto tg_x_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 15); 

                auto tg_x_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 16); 

                auto tg_x_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 17); 

                auto tg_x_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 18); 

                auto tg_x_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 19); 

                auto tg_x_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 20); 

                auto tg_y_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 21); 

                auto tg_y_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 22); 

                auto tg_y_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 23); 

                auto tg_y_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 24); 

                auto tg_y_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 25); 

                auto tg_y_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 26); 

                auto tg_y_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 27); 

                auto tg_y_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 28); 

                auto tg_y_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 29); 

                auto tg_y_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 30); 

                auto tg_y_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 31); 

                auto tg_y_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 32); 

                auto tg_y_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 33); 

                auto tg_y_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 34); 

                auto tg_y_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 35); 

                auto tg_y_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 36); 

                auto tg_y_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 37); 

                auto tg_y_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 38); 

                auto tg_y_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 39); 

                auto tg_y_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 40); 

                auto tg_y_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 41); 

                auto tg_z_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 42); 

                auto tg_z_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 43); 

                auto tg_z_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 44); 

                auto tg_z_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 45); 

                auto tg_z_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 46); 

                auto tg_z_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 47); 

                auto tg_z_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 48); 

                auto tg_z_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 49); 

                auto tg_z_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 50); 

                auto tg_z_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 51); 

                auto tg_z_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 52); 

                auto tg_z_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 53); 

                auto tg_z_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 54); 

                auto tg_z_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 55); 

                auto tg_z_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 56); 

                auto tg_z_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 57); 

                auto tg_z_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 58); 

                auto tg_z_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 59); 

                auto tg_z_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 60); 

                auto tg_z_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 61); 

                auto tg_z_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 62); 

                auto tg_0_xxxxx_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx); 

                auto tg_0_xxxxy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 1); 

                auto tg_0_xxxxz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 2); 

                auto tg_0_xxxyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 3); 

                auto tg_0_xxxyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 4); 

                auto tg_0_xxxzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 5); 

                auto tg_0_xxyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 6); 

                auto tg_0_xxyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 7); 

                auto tg_0_xxyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 8); 

                auto tg_0_xxzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 9); 

                auto tg_0_xyyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 10); 

                auto tg_0_xyyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 11); 

                auto tg_0_xyyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 12); 

                auto tg_0_xyzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 13); 

                auto tg_0_xzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 14); 

                auto tg_0_yyyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 15); 

                auto tg_0_yyyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 16); 

                auto tg_0_yyyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 17); 

                auto tg_0_yyzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 18); 

                auto tg_0_yzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 19); 

                auto tg_0_zzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 20); 

                auto tg_0_xxxxx_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx); 

                auto tg_0_xxxxy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 1); 

                auto tg_0_xxxxz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 2); 

                auto tg_0_xxxyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 3); 

                auto tg_0_xxxyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 4); 

                auto tg_0_xxxzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 5); 

                auto tg_0_xxyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 6); 

                auto tg_0_xxyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 7); 

                auto tg_0_xxyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 8); 

                auto tg_0_xxzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 9); 

                auto tg_0_xyyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 10); 

                auto tg_0_xyyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 11); 

                auto tg_0_xyyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 12); 

                auto tg_0_xyzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 13); 

                auto tg_0_xzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 14); 

                auto tg_0_yyyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 15); 

                auto tg_0_yyyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 16); 

                auto tg_0_yyyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 17); 

                auto tg_0_yyzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 18); 

                auto tg_0_yzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 19); 

                auto tg_0_zzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 20); 

                auto tg_x_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx); 

                auto tg_x_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 1); 

                auto tg_x_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 2); 

                auto tg_x_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 3); 

                auto tg_x_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 4); 

                auto tg_x_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 5); 

                auto tg_x_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 6); 

                auto tg_x_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 7); 

                auto tg_x_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 8); 

                auto tg_x_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 9); 

                auto tg_x_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 10); 

                auto tg_x_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 11); 

                auto tg_x_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 12); 

                auto tg_x_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 13); 

                auto tg_x_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 14); 

                auto tg_y_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 15); 

                auto tg_y_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 16); 

                auto tg_y_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 17); 

                auto tg_y_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 18); 

                auto tg_y_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 19); 

                auto tg_y_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 20); 

                auto tg_y_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 21); 

                auto tg_y_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 22); 

                auto tg_y_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 23); 

                auto tg_y_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 24); 

                auto tg_y_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 25); 

                auto tg_y_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 26); 

                auto tg_y_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 27); 

                auto tg_y_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 28); 

                auto tg_y_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 29); 

                auto tg_z_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 30); 

                auto tg_z_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 31); 

                auto tg_z_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 32); 

                auto tg_z_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 33); 

                auto tg_z_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 34); 

                auto tg_z_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 35); 

                auto tg_z_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 36); 

                auto tg_z_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 37); 

                auto tg_z_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 38); 

                auto tg_z_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 39); 

                auto tg_z_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 40); 

                auto tg_z_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 41); 

                auto tg_z_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 42); 

                auto tg_z_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 43); 

                auto tg_z_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 44); 

                // set up pointers to integrals

                auto tg_xx_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx); 

                auto tg_xx_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 1); 

                auto tg_xx_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 2); 

                auto tg_xx_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 3); 

                auto tg_xx_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 4); 

                auto tg_xx_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 5); 

                auto tg_xx_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 6); 

                auto tg_xx_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 7); 

                auto tg_xx_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 8); 

                auto tg_xx_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 9); 

                auto tg_xx_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 10); 

                auto tg_xx_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 11); 

                auto tg_xx_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 12); 

                auto tg_xx_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 13); 

                auto tg_xx_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 14); 

                auto tg_xx_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 15); 

                auto tg_xx_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 16); 

                auto tg_xx_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 17); 

                auto tg_xx_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 18); 

                auto tg_xx_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 19); 

                auto tg_xx_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 20); 

                auto tg_xy_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 21); 

                auto tg_xy_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 22); 

                auto tg_xy_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 23); 

                auto tg_xy_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 24); 

                auto tg_xy_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 25); 

                auto tg_xy_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 26); 

                auto tg_xy_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 27); 

                auto tg_xy_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 28); 

                auto tg_xy_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 29); 

                auto tg_xy_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 30); 

                auto tg_xy_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 31); 

                auto tg_xy_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 32); 

                auto tg_xy_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 33); 

                auto tg_xy_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 34); 

                auto tg_xy_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 35); 

                auto tg_xy_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 36); 

                auto tg_xy_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 37); 

                auto tg_xy_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 38); 

                auto tg_xy_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 39); 

                auto tg_xy_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 40); 

                auto tg_xy_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 41); 

                auto tg_xz_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 42); 

                auto tg_xz_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 43); 

                auto tg_xz_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 44); 

                auto tg_xz_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 45); 

                auto tg_xz_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 46); 

                auto tg_xz_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 47); 

                auto tg_xz_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 48); 

                auto tg_xz_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 49); 

                auto tg_xz_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 50); 

                auto tg_xz_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 51); 

                auto tg_xz_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 52); 

                auto tg_xz_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 53); 

                auto tg_xz_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 54); 

                auto tg_xz_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 55); 

                auto tg_xz_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 56); 

                auto tg_xz_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 57); 

                auto tg_xz_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 58); 

                auto tg_xz_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 59); 

                auto tg_xz_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 60); 

                auto tg_xz_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 61); 

                auto tg_xz_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 62); 

                // Batch of Integrals (0,63)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxx_0, tg_0_xxxxx_1, tg_0_xxxxy_0, tg_0_xxxxy_1, \
                                         tg_0_xxxxz_0, tg_0_xxxxz_1, tg_0_xxxyy_0, tg_0_xxxyy_1, tg_0_xxxyz_0, tg_0_xxxyz_1, \
                                         tg_0_xxxzz_0, tg_0_xxxzz_1, tg_0_xxyyy_0, tg_0_xxyyy_1, tg_0_xxyyz_0, tg_0_xxyyz_1, \
                                         tg_0_xxyzz_0, tg_0_xxyzz_1, tg_0_xxzzz_0, tg_0_xxzzz_1, tg_0_xyyyy_0, tg_0_xyyyy_1, \
                                         tg_0_xyyyz_0, tg_0_xyyyz_1, tg_0_xyyzz_0, tg_0_xyyzz_1, tg_0_xyzzz_0, tg_0_xyzzz_1, \
                                         tg_0_xzzzz_0, tg_0_xzzzz_1, tg_0_yyyyy_0, tg_0_yyyyy_1, tg_0_yyyyz_0, tg_0_yyyyz_1, \
                                         tg_0_yyyzz_0, tg_0_yyyzz_1, tg_0_yyzzz_0, tg_0_yyzzz_1, tg_0_yzzzz_0, tg_0_yzzzz_1, \
                                         tg_0_zzzzz_0, tg_0_zzzzz_1, tg_x_xxxx_1, tg_x_xxxxx_0, tg_x_xxxxx_1, tg_x_xxxxy_0, \
                                         tg_x_xxxxy_1, tg_x_xxxxz_0, tg_x_xxxxz_1, tg_x_xxxy_1, tg_x_xxxyy_0, tg_x_xxxyy_1, \
                                         tg_x_xxxyz_0, tg_x_xxxyz_1, tg_x_xxxz_1, tg_x_xxxzz_0, tg_x_xxxzz_1, tg_x_xxyy_1, \
                                         tg_x_xxyyy_0, tg_x_xxyyy_1, tg_x_xxyyz_0, tg_x_xxyyz_1, tg_x_xxyz_1, tg_x_xxyzz_0, \
                                         tg_x_xxyzz_1, tg_x_xxzz_1, tg_x_xxzzz_0, tg_x_xxzzz_1, tg_x_xyyy_1, tg_x_xyyyy_0, \
                                         tg_x_xyyyy_1, tg_x_xyyyz_0, tg_x_xyyyz_1, tg_x_xyyz_1, tg_x_xyyzz_0, tg_x_xyyzz_1, \
                                         tg_x_xyzz_1, tg_x_xyzzz_0, tg_x_xyzzz_1, tg_x_xzzz_1, tg_x_xzzzz_0, tg_x_xzzzz_1, \
                                         tg_x_yyyy_1, tg_x_yyyyy_0, tg_x_yyyyy_1, tg_x_yyyyz_0, tg_x_yyyyz_1, tg_x_yyyz_1, \
                                         tg_x_yyyzz_0, tg_x_yyyzz_1, tg_x_yyzz_1, tg_x_yyzzz_0, tg_x_yyzzz_1, tg_x_yzzz_1, \
                                         tg_x_yzzzz_0, tg_x_yzzzz_1, tg_x_zzzz_1, tg_x_zzzzz_0, tg_x_zzzzz_1, tg_xx_xxxxx_0, \
                                         tg_xx_xxxxy_0, tg_xx_xxxxz_0, tg_xx_xxxyy_0, tg_xx_xxxyz_0, tg_xx_xxxzz_0, \
                                         tg_xx_xxyyy_0, tg_xx_xxyyz_0, tg_xx_xxyzz_0, tg_xx_xxzzz_0, tg_xx_xyyyy_0, \
                                         tg_xx_xyyyz_0, tg_xx_xyyzz_0, tg_xx_xyzzz_0, tg_xx_xzzzz_0, tg_xx_yyyyy_0, \
                                         tg_xx_yyyyz_0, tg_xx_yyyzz_0, tg_xx_yyzzz_0, tg_xx_yzzzz_0, tg_xx_zzzzz_0, \
                                         tg_xy_xxxxx_0, tg_xy_xxxxy_0, tg_xy_xxxxz_0, tg_xy_xxxyy_0, tg_xy_xxxyz_0, \
                                         tg_xy_xxxzz_0, tg_xy_xxyyy_0, tg_xy_xxyyz_0, tg_xy_xxyzz_0, tg_xy_xxzzz_0, \
                                         tg_xy_xyyyy_0, tg_xy_xyyyz_0, tg_xy_xyyzz_0, tg_xy_xyzzz_0, tg_xy_xzzzz_0, \
                                         tg_xy_yyyyy_0, tg_xy_yyyyz_0, tg_xy_yyyzz_0, tg_xy_yyzzz_0, tg_xy_yzzzz_0, \
                                         tg_xy_zzzzz_0, tg_xz_xxxxx_0, tg_xz_xxxxy_0, tg_xz_xxxxz_0, tg_xz_xxxyy_0, \
                                         tg_xz_xxxyz_0, tg_xz_xxxzz_0, tg_xz_xxyyy_0, tg_xz_xxyyz_0, tg_xz_xxyzz_0, \
                                         tg_xz_xxzzz_0, tg_xz_xyyyy_0, tg_xz_xyyyz_0, tg_xz_xyyzz_0, tg_xz_xyzzz_0, \
                                         tg_xz_xzzzz_0, tg_xz_yyyyy_0, tg_xz_yyyyz_0, tg_xz_yyyzz_0, tg_xz_yyzzz_0, \
                                         tg_xz_yzzzz_0, tg_xz_zzzzz_0, tg_y_xxxx_1, tg_y_xxxxx_0, tg_y_xxxxx_1, tg_y_xxxxy_0, \
                                         tg_y_xxxxy_1, tg_y_xxxxz_0, tg_y_xxxxz_1, tg_y_xxxy_1, tg_y_xxxyy_0, tg_y_xxxyy_1, \
                                         tg_y_xxxyz_0, tg_y_xxxyz_1, tg_y_xxxz_1, tg_y_xxxzz_0, tg_y_xxxzz_1, tg_y_xxyy_1, \
                                         tg_y_xxyyy_0, tg_y_xxyyy_1, tg_y_xxyyz_0, tg_y_xxyyz_1, tg_y_xxyz_1, tg_y_xxyzz_0, \
                                         tg_y_xxyzz_1, tg_y_xxzz_1, tg_y_xxzzz_0, tg_y_xxzzz_1, tg_y_xyyy_1, tg_y_xyyyy_0, \
                                         tg_y_xyyyy_1, tg_y_xyyyz_0, tg_y_xyyyz_1, tg_y_xyyz_1, tg_y_xyyzz_0, tg_y_xyyzz_1, \
                                         tg_y_xyzz_1, tg_y_xyzzz_0, tg_y_xyzzz_1, tg_y_xzzz_1, tg_y_xzzzz_0, tg_y_xzzzz_1, \
                                         tg_y_yyyy_1, tg_y_yyyyy_0, tg_y_yyyyy_1, tg_y_yyyyz_0, tg_y_yyyyz_1, tg_y_yyyz_1, \
                                         tg_y_yyyzz_0, tg_y_yyyzz_1, tg_y_yyzz_1, tg_y_yyzzz_0, tg_y_yyzzz_1, tg_y_yzzz_1, \
                                         tg_y_yzzzz_0, tg_y_yzzzz_1, tg_y_zzzz_1, tg_y_zzzzz_0, tg_y_zzzzz_1, tg_z_xxxx_1, \
                                         tg_z_xxxxx_0, tg_z_xxxxx_1, tg_z_xxxxy_0, tg_z_xxxxy_1, tg_z_xxxxz_0, tg_z_xxxxz_1, \
                                         tg_z_xxxy_1, tg_z_xxxyy_0, tg_z_xxxyy_1, tg_z_xxxyz_0, tg_z_xxxyz_1, tg_z_xxxz_1, \
                                         tg_z_xxxzz_0, tg_z_xxxzz_1, tg_z_xxyy_1, tg_z_xxyyy_0, tg_z_xxyyy_1, tg_z_xxyyz_0, \
                                         tg_z_xxyyz_1, tg_z_xxyz_1, tg_z_xxyzz_0, tg_z_xxyzz_1, tg_z_xxzz_1, tg_z_xxzzz_0, \
                                         tg_z_xxzzz_1, tg_z_xyyy_1, tg_z_xyyyy_0, tg_z_xyyyy_1, tg_z_xyyyz_0, tg_z_xyyyz_1, \
                                         tg_z_xyyz_1, tg_z_xyyzz_0, tg_z_xyyzz_1, tg_z_xyzz_1, tg_z_xyzzz_0, tg_z_xyzzz_1, \
                                         tg_z_xzzz_1, tg_z_xzzzz_0, tg_z_xzzzz_1, tg_z_yyyy_1, tg_z_yyyyy_0, tg_z_yyyyy_1, \
                                         tg_z_yyyyz_0, tg_z_yyyyz_1, tg_z_yyyz_1, tg_z_yyyzz_0, tg_z_yyyzz_1, tg_z_yyzz_1, \
                                         tg_z_yyzzz_0, tg_z_yyzzz_1, tg_z_yzzz_1, tg_z_yzzzz_0, tg_z_yzzzz_1, tg_z_zzzz_1, \
                                         tg_z_zzzzz_0, tg_z_zzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxxxx_0[j] = pb_x * tg_x_xxxxx_0[j] + fr * tg_x_xxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxx_0[j] - tg_0_xxxxx_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxx_1[j];

                    tg_xx_xxxxy_0[j] = pb_x * tg_x_xxxxy_0[j] + fr * tg_x_xxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxy_0[j] - tg_0_xxxxy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxy_1[j];

                    tg_xx_xxxxz_0[j] = pb_x * tg_x_xxxxz_0[j] + fr * tg_x_xxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxz_0[j] - tg_0_xxxxz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxz_1[j];

                    tg_xx_xxxyy_0[j] = pb_x * tg_x_xxxyy_0[j] + fr * tg_x_xxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyy_0[j] - tg_0_xxxyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyy_1[j];

                    tg_xx_xxxyz_0[j] = pb_x * tg_x_xxxyz_0[j] + fr * tg_x_xxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyz_0[j] - tg_0_xxxyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyz_1[j];

                    tg_xx_xxxzz_0[j] = pb_x * tg_x_xxxzz_0[j] + fr * tg_x_xxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzz_0[j] - tg_0_xxxzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxzz_1[j];

                    tg_xx_xxyyy_0[j] = pb_x * tg_x_xxyyy_0[j] + fr * tg_x_xxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyy_0[j] - tg_0_xxyyy_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyy_1[j];

                    tg_xx_xxyyz_0[j] = pb_x * tg_x_xxyyz_0[j] + fr * tg_x_xxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyz_0[j] - tg_0_xxyyz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyz_1[j];

                    tg_xx_xxyzz_0[j] = pb_x * tg_x_xxyzz_0[j] + fr * tg_x_xxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzz_0[j] - tg_0_xxyzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyzz_1[j];

                    tg_xx_xxzzz_0[j] = pb_x * tg_x_xxzzz_0[j] + fr * tg_x_xxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzz_0[j] - tg_0_xxzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xzzz_1[j];

                    tg_xx_xyyyy_0[j] = pb_x * tg_x_xyyyy_0[j] + fr * tg_x_xyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyy_0[j] - tg_0_xyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyy_1[j];

                    tg_xx_xyyyz_0[j] = pb_x * tg_x_xyyyz_0[j] + fr * tg_x_xyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyz_0[j] - tg_0_xyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyz_1[j];

                    tg_xx_xyyzz_0[j] = pb_x * tg_x_xyyzz_0[j] + fr * tg_x_xyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzz_0[j] - tg_0_xyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyzz_1[j];

                    tg_xx_xyzzz_0[j] = pb_x * tg_x_xyzzz_0[j] + fr * tg_x_xyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzz_0[j] - tg_0_xyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yzzz_1[j];

                    tg_xx_xzzzz_0[j] = pb_x * tg_x_xzzzz_0[j] + fr * tg_x_xzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzz_0[j] - tg_0_xzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zzzz_1[j];

                    tg_xx_yyyyy_0[j] = pb_x * tg_x_yyyyy_0[j] + fr * tg_x_yyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyy_0[j] - tg_0_yyyyy_1[j] * fl1_fza);

                    tg_xx_yyyyz_0[j] = pb_x * tg_x_yyyyz_0[j] + fr * tg_x_yyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyz_0[j] - tg_0_yyyyz_1[j] * fl1_fza);

                    tg_xx_yyyzz_0[j] = pb_x * tg_x_yyyzz_0[j] + fr * tg_x_yyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzz_0[j] - tg_0_yyyzz_1[j] * fl1_fza);

                    tg_xx_yyzzz_0[j] = pb_x * tg_x_yyzzz_0[j] + fr * tg_x_yyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzz_0[j] - tg_0_yyzzz_1[j] * fl1_fza);

                    tg_xx_yzzzz_0[j] = pb_x * tg_x_yzzzz_0[j] + fr * tg_x_yzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzz_0[j] - tg_0_yzzzz_1[j] * fl1_fza);

                    tg_xx_zzzzz_0[j] = pb_x * tg_x_zzzzz_0[j] + fr * tg_x_zzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzz_0[j] - tg_0_zzzzz_1[j] * fl1_fza);

                    tg_xy_xxxxx_0[j] = pb_x * tg_y_xxxxx_0[j] + fr * tg_y_xxxxx_1[j] + 2.5 * fl1_fxn * tg_y_xxxx_1[j];

                    tg_xy_xxxxy_0[j] = pb_x * tg_y_xxxxy_0[j] + fr * tg_y_xxxxy_1[j] + 2.0 * fl1_fxn * tg_y_xxxy_1[j];

                    tg_xy_xxxxz_0[j] = pb_x * tg_y_xxxxz_0[j] + fr * tg_y_xxxxz_1[j] + 2.0 * fl1_fxn * tg_y_xxxz_1[j];

                    tg_xy_xxxyy_0[j] = pb_x * tg_y_xxxyy_0[j] + fr * tg_y_xxxyy_1[j] + 1.5 * fl1_fxn * tg_y_xxyy_1[j];

                    tg_xy_xxxyz_0[j] = pb_x * tg_y_xxxyz_0[j] + fr * tg_y_xxxyz_1[j] + 1.5 * fl1_fxn * tg_y_xxyz_1[j];

                    tg_xy_xxxzz_0[j] = pb_x * tg_y_xxxzz_0[j] + fr * tg_y_xxxzz_1[j] + 1.5 * fl1_fxn * tg_y_xxzz_1[j];

                    tg_xy_xxyyy_0[j] = pb_x * tg_y_xxyyy_0[j] + fr * tg_y_xxyyy_1[j] + fl1_fxn * tg_y_xyyy_1[j];

                    tg_xy_xxyyz_0[j] = pb_x * tg_y_xxyyz_0[j] + fr * tg_y_xxyyz_1[j] + fl1_fxn * tg_y_xyyz_1[j];

                    tg_xy_xxyzz_0[j] = pb_x * tg_y_xxyzz_0[j] + fr * tg_y_xxyzz_1[j] + fl1_fxn * tg_y_xyzz_1[j];

                    tg_xy_xxzzz_0[j] = pb_x * tg_y_xxzzz_0[j] + fr * tg_y_xxzzz_1[j] + fl1_fxn * tg_y_xzzz_1[j];

                    tg_xy_xyyyy_0[j] = pb_x * tg_y_xyyyy_0[j] + fr * tg_y_xyyyy_1[j] + 0.5 * fl1_fxn * tg_y_yyyy_1[j];

                    tg_xy_xyyyz_0[j] = pb_x * tg_y_xyyyz_0[j] + fr * tg_y_xyyyz_1[j] + 0.5 * fl1_fxn * tg_y_yyyz_1[j];

                    tg_xy_xyyzz_0[j] = pb_x * tg_y_xyyzz_0[j] + fr * tg_y_xyyzz_1[j] + 0.5 * fl1_fxn * tg_y_yyzz_1[j];

                    tg_xy_xyzzz_0[j] = pb_x * tg_y_xyzzz_0[j] + fr * tg_y_xyzzz_1[j] + 0.5 * fl1_fxn * tg_y_yzzz_1[j];

                    tg_xy_xzzzz_0[j] = pb_x * tg_y_xzzzz_0[j] + fr * tg_y_xzzzz_1[j] + 0.5 * fl1_fxn * tg_y_zzzz_1[j];

                    tg_xy_yyyyy_0[j] = pb_x * tg_y_yyyyy_0[j] + fr * tg_y_yyyyy_1[j];

                    tg_xy_yyyyz_0[j] = pb_x * tg_y_yyyyz_0[j] + fr * tg_y_yyyyz_1[j];

                    tg_xy_yyyzz_0[j] = pb_x * tg_y_yyyzz_0[j] + fr * tg_y_yyyzz_1[j];

                    tg_xy_yyzzz_0[j] = pb_x * tg_y_yyzzz_0[j] + fr * tg_y_yyzzz_1[j];

                    tg_xy_yzzzz_0[j] = pb_x * tg_y_yzzzz_0[j] + fr * tg_y_yzzzz_1[j];

                    tg_xy_zzzzz_0[j] = pb_x * tg_y_zzzzz_0[j] + fr * tg_y_zzzzz_1[j];

                    tg_xz_xxxxx_0[j] = pb_x * tg_z_xxxxx_0[j] + fr * tg_z_xxxxx_1[j] + 2.5 * fl1_fxn * tg_z_xxxx_1[j];

                    tg_xz_xxxxy_0[j] = pb_x * tg_z_xxxxy_0[j] + fr * tg_z_xxxxy_1[j] + 2.0 * fl1_fxn * tg_z_xxxy_1[j];

                    tg_xz_xxxxz_0[j] = pb_x * tg_z_xxxxz_0[j] + fr * tg_z_xxxxz_1[j] + 2.0 * fl1_fxn * tg_z_xxxz_1[j];

                    tg_xz_xxxyy_0[j] = pb_x * tg_z_xxxyy_0[j] + fr * tg_z_xxxyy_1[j] + 1.5 * fl1_fxn * tg_z_xxyy_1[j];

                    tg_xz_xxxyz_0[j] = pb_x * tg_z_xxxyz_0[j] + fr * tg_z_xxxyz_1[j] + 1.5 * fl1_fxn * tg_z_xxyz_1[j];

                    tg_xz_xxxzz_0[j] = pb_x * tg_z_xxxzz_0[j] + fr * tg_z_xxxzz_1[j] + 1.5 * fl1_fxn * tg_z_xxzz_1[j];

                    tg_xz_xxyyy_0[j] = pb_x * tg_z_xxyyy_0[j] + fr * tg_z_xxyyy_1[j] + fl1_fxn * tg_z_xyyy_1[j];

                    tg_xz_xxyyz_0[j] = pb_x * tg_z_xxyyz_0[j] + fr * tg_z_xxyyz_1[j] + fl1_fxn * tg_z_xyyz_1[j];

                    tg_xz_xxyzz_0[j] = pb_x * tg_z_xxyzz_0[j] + fr * tg_z_xxyzz_1[j] + fl1_fxn * tg_z_xyzz_1[j];

                    tg_xz_xxzzz_0[j] = pb_x * tg_z_xxzzz_0[j] + fr * tg_z_xxzzz_1[j] + fl1_fxn * tg_z_xzzz_1[j];

                    tg_xz_xyyyy_0[j] = pb_x * tg_z_xyyyy_0[j] + fr * tg_z_xyyyy_1[j] + 0.5 * fl1_fxn * tg_z_yyyy_1[j];

                    tg_xz_xyyyz_0[j] = pb_x * tg_z_xyyyz_0[j] + fr * tg_z_xyyyz_1[j] + 0.5 * fl1_fxn * tg_z_yyyz_1[j];

                    tg_xz_xyyzz_0[j] = pb_x * tg_z_xyyzz_0[j] + fr * tg_z_xyyzz_1[j] + 0.5 * fl1_fxn * tg_z_yyzz_1[j];

                    tg_xz_xyzzz_0[j] = pb_x * tg_z_xyzzz_0[j] + fr * tg_z_xyzzz_1[j] + 0.5 * fl1_fxn * tg_z_yzzz_1[j];

                    tg_xz_xzzzz_0[j] = pb_x * tg_z_xzzzz_0[j] + fr * tg_z_xzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzz_1[j];

                    tg_xz_yyyyy_0[j] = pb_x * tg_z_yyyyy_0[j] + fr * tg_z_yyyyy_1[j];

                    tg_xz_yyyyz_0[j] = pb_x * tg_z_yyyyz_0[j] + fr * tg_z_yyyyz_1[j];

                    tg_xz_yyyzz_0[j] = pb_x * tg_z_yyyzz_0[j] + fr * tg_z_yyyzz_1[j];

                    tg_xz_yyzzz_0[j] = pb_x * tg_z_yyzzz_0[j] + fr * tg_z_yyzzz_1[j];

                    tg_xz_yzzzz_0[j] = pb_x * tg_z_yzzzz_0[j] + fr * tg_z_yzzzz_1[j];

                    tg_xz_zzzzz_0[j] = pb_x * tg_z_zzzzz_0[j] + fr * tg_z_zzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSH_63_126(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (63,126)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {5, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_5_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_5_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_4_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {4, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_y_xxxxx_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 21); 

                auto tg_y_xxxxy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 22); 

                auto tg_y_xxxxz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 23); 

                auto tg_y_xxxyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 24); 

                auto tg_y_xxxyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 25); 

                auto tg_y_xxxzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 26); 

                auto tg_y_xxyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 27); 

                auto tg_y_xxyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 28); 

                auto tg_y_xxyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 29); 

                auto tg_y_xxzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 30); 

                auto tg_y_xyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 31); 

                auto tg_y_xyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 32); 

                auto tg_y_xyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 33); 

                auto tg_y_xyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 34); 

                auto tg_y_xzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 35); 

                auto tg_y_yyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 36); 

                auto tg_y_yyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 37); 

                auto tg_y_yyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 38); 

                auto tg_y_yyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 39); 

                auto tg_y_yzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 40); 

                auto tg_y_zzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 41); 

                auto tg_z_xxxxx_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 42); 

                auto tg_z_xxxxy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 43); 

                auto tg_z_xxxxz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 44); 

                auto tg_z_xxxyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 45); 

                auto tg_z_xxxyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 46); 

                auto tg_z_xxxzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 47); 

                auto tg_z_xxyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 48); 

                auto tg_z_xxyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 49); 

                auto tg_z_xxyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 50); 

                auto tg_z_xxzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 51); 

                auto tg_z_xyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 52); 

                auto tg_z_xyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 53); 

                auto tg_z_xyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 54); 

                auto tg_z_xyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 55); 

                auto tg_z_xzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 56); 

                auto tg_z_yyyyy_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 57); 

                auto tg_z_yyyyz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 58); 

                auto tg_z_yyyzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 59); 

                auto tg_z_yyzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 60); 

                auto tg_z_yzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 61); 

                auto tg_z_zzzzz_0 = primBuffer[pidx_g_1_5_m0].data(63 * idx + 62); 

                auto tg_y_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 21); 

                auto tg_y_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 22); 

                auto tg_y_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 23); 

                auto tg_y_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 24); 

                auto tg_y_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 25); 

                auto tg_y_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 26); 

                auto tg_y_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 27); 

                auto tg_y_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 28); 

                auto tg_y_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 29); 

                auto tg_y_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 30); 

                auto tg_y_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 31); 

                auto tg_y_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 32); 

                auto tg_y_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 33); 

                auto tg_y_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 34); 

                auto tg_y_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 35); 

                auto tg_y_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 36); 

                auto tg_y_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 37); 

                auto tg_y_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 38); 

                auto tg_y_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 39); 

                auto tg_y_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 40); 

                auto tg_y_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 41); 

                auto tg_z_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 42); 

                auto tg_z_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 43); 

                auto tg_z_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 44); 

                auto tg_z_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 45); 

                auto tg_z_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 46); 

                auto tg_z_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 47); 

                auto tg_z_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 48); 

                auto tg_z_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 49); 

                auto tg_z_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 50); 

                auto tg_z_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 51); 

                auto tg_z_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 52); 

                auto tg_z_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 53); 

                auto tg_z_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 54); 

                auto tg_z_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 55); 

                auto tg_z_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 56); 

                auto tg_z_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 57); 

                auto tg_z_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 58); 

                auto tg_z_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 59); 

                auto tg_z_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 60); 

                auto tg_z_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 61); 

                auto tg_z_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 62); 

                auto tg_0_xxxxx_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx); 

                auto tg_0_xxxxy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 1); 

                auto tg_0_xxxxz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 2); 

                auto tg_0_xxxyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 3); 

                auto tg_0_xxxyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 4); 

                auto tg_0_xxxzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 5); 

                auto tg_0_xxyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 6); 

                auto tg_0_xxyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 7); 

                auto tg_0_xxyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 8); 

                auto tg_0_xxzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 9); 

                auto tg_0_xyyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 10); 

                auto tg_0_xyyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 11); 

                auto tg_0_xyyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 12); 

                auto tg_0_xyzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 13); 

                auto tg_0_xzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 14); 

                auto tg_0_yyyyy_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 15); 

                auto tg_0_yyyyz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 16); 

                auto tg_0_yyyzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 17); 

                auto tg_0_yyzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 18); 

                auto tg_0_yzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 19); 

                auto tg_0_zzzzz_0 = primBuffer[pidx_g_0_5_m0].data(21 * idx + 20); 

                auto tg_0_xxxxx_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx); 

                auto tg_0_xxxxy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 1); 

                auto tg_0_xxxxz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 2); 

                auto tg_0_xxxyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 3); 

                auto tg_0_xxxyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 4); 

                auto tg_0_xxxzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 5); 

                auto tg_0_xxyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 6); 

                auto tg_0_xxyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 7); 

                auto tg_0_xxyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 8); 

                auto tg_0_xxzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 9); 

                auto tg_0_xyyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 10); 

                auto tg_0_xyyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 11); 

                auto tg_0_xyyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 12); 

                auto tg_0_xyzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 13); 

                auto tg_0_xzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 14); 

                auto tg_0_yyyyy_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 15); 

                auto tg_0_yyyyz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 16); 

                auto tg_0_yyyzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 17); 

                auto tg_0_yyzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 18); 

                auto tg_0_yzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 19); 

                auto tg_0_zzzzz_1 = primBuffer[pidx_g_0_5_m1].data(21 * idx + 20); 

                auto tg_y_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 15); 

                auto tg_y_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 16); 

                auto tg_y_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 17); 

                auto tg_y_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 18); 

                auto tg_y_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 19); 

                auto tg_y_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 20); 

                auto tg_y_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 21); 

                auto tg_y_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 22); 

                auto tg_y_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 23); 

                auto tg_y_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 24); 

                auto tg_y_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 25); 

                auto tg_y_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 26); 

                auto tg_y_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 27); 

                auto tg_y_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 28); 

                auto tg_y_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 29); 

                auto tg_z_xxxx_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 30); 

                auto tg_z_xxxy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 31); 

                auto tg_z_xxxz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 32); 

                auto tg_z_xxyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 33); 

                auto tg_z_xxyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 34); 

                auto tg_z_xxzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 35); 

                auto tg_z_xyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 36); 

                auto tg_z_xyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 37); 

                auto tg_z_xyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 38); 

                auto tg_z_xzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 39); 

                auto tg_z_yyyy_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 40); 

                auto tg_z_yyyz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 41); 

                auto tg_z_yyzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 42); 

                auto tg_z_yzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 43); 

                auto tg_z_zzzz_1 = primBuffer[pidx_g_1_4_m1].data(45 * idx + 44); 

                // set up pointers to integrals

                auto tg_yy_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 63); 

                auto tg_yy_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 64); 

                auto tg_yy_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 65); 

                auto tg_yy_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 66); 

                auto tg_yy_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 67); 

                auto tg_yy_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 68); 

                auto tg_yy_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 69); 

                auto tg_yy_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 70); 

                auto tg_yy_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 71); 

                auto tg_yy_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 72); 

                auto tg_yy_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 73); 

                auto tg_yy_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 74); 

                auto tg_yy_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 75); 

                auto tg_yy_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 76); 

                auto tg_yy_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 77); 

                auto tg_yy_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 78); 

                auto tg_yy_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 79); 

                auto tg_yy_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 80); 

                auto tg_yy_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 81); 

                auto tg_yy_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 82); 

                auto tg_yy_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 83); 

                auto tg_yz_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 84); 

                auto tg_yz_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 85); 

                auto tg_yz_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 86); 

                auto tg_yz_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 87); 

                auto tg_yz_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 88); 

                auto tg_yz_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 89); 

                auto tg_yz_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 90); 

                auto tg_yz_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 91); 

                auto tg_yz_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 92); 

                auto tg_yz_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 93); 

                auto tg_yz_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 94); 

                auto tg_yz_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 95); 

                auto tg_yz_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 96); 

                auto tg_yz_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 97); 

                auto tg_yz_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 98); 

                auto tg_yz_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 99); 

                auto tg_yz_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 100); 

                auto tg_yz_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 101); 

                auto tg_yz_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 102); 

                auto tg_yz_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 103); 

                auto tg_yz_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 104); 

                auto tg_zz_xxxxx_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 105); 

                auto tg_zz_xxxxy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 106); 

                auto tg_zz_xxxxz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 107); 

                auto tg_zz_xxxyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 108); 

                auto tg_zz_xxxyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 109); 

                auto tg_zz_xxxzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 110); 

                auto tg_zz_xxyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 111); 

                auto tg_zz_xxyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 112); 

                auto tg_zz_xxyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 113); 

                auto tg_zz_xxzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 114); 

                auto tg_zz_xyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 115); 

                auto tg_zz_xyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 116); 

                auto tg_zz_xyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 117); 

                auto tg_zz_xyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 118); 

                auto tg_zz_xzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 119); 

                auto tg_zz_yyyyy_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 120); 

                auto tg_zz_yyyyz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 121); 

                auto tg_zz_yyyzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 122); 

                auto tg_zz_yyzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 123); 

                auto tg_zz_yzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 124); 

                auto tg_zz_zzzzz_0 = primBuffer[pidx_g_2_5_m0].data(126 * idx + 125); 

                // Batch of Integrals (63,126)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxx_0, tg_0_xxxxx_1, tg_0_xxxxy_0, tg_0_xxxxy_1, \
                                         tg_0_xxxxz_0, tg_0_xxxxz_1, tg_0_xxxyy_0, tg_0_xxxyy_1, tg_0_xxxyz_0, tg_0_xxxyz_1, \
                                         tg_0_xxxzz_0, tg_0_xxxzz_1, tg_0_xxyyy_0, tg_0_xxyyy_1, tg_0_xxyyz_0, tg_0_xxyyz_1, \
                                         tg_0_xxyzz_0, tg_0_xxyzz_1, tg_0_xxzzz_0, tg_0_xxzzz_1, tg_0_xyyyy_0, tg_0_xyyyy_1, \
                                         tg_0_xyyyz_0, tg_0_xyyyz_1, tg_0_xyyzz_0, tg_0_xyyzz_1, tg_0_xyzzz_0, tg_0_xyzzz_1, \
                                         tg_0_xzzzz_0, tg_0_xzzzz_1, tg_0_yyyyy_0, tg_0_yyyyy_1, tg_0_yyyyz_0, tg_0_yyyyz_1, \
                                         tg_0_yyyzz_0, tg_0_yyyzz_1, tg_0_yyzzz_0, tg_0_yyzzz_1, tg_0_yzzzz_0, tg_0_yzzzz_1, \
                                         tg_0_zzzzz_0, tg_0_zzzzz_1, tg_y_xxxx_1, tg_y_xxxxx_0, tg_y_xxxxx_1, tg_y_xxxxy_0, \
                                         tg_y_xxxxy_1, tg_y_xxxxz_0, tg_y_xxxxz_1, tg_y_xxxy_1, tg_y_xxxyy_0, tg_y_xxxyy_1, \
                                         tg_y_xxxyz_0, tg_y_xxxyz_1, tg_y_xxxz_1, tg_y_xxxzz_0, tg_y_xxxzz_1, tg_y_xxyy_1, \
                                         tg_y_xxyyy_0, tg_y_xxyyy_1, tg_y_xxyyz_0, tg_y_xxyyz_1, tg_y_xxyz_1, tg_y_xxyzz_0, \
                                         tg_y_xxyzz_1, tg_y_xxzz_1, tg_y_xxzzz_0, tg_y_xxzzz_1, tg_y_xyyy_1, tg_y_xyyyy_0, \
                                         tg_y_xyyyy_1, tg_y_xyyyz_0, tg_y_xyyyz_1, tg_y_xyyz_1, tg_y_xyyzz_0, tg_y_xyyzz_1, \
                                         tg_y_xyzz_1, tg_y_xyzzz_0, tg_y_xyzzz_1, tg_y_xzzz_1, tg_y_xzzzz_0, tg_y_xzzzz_1, \
                                         tg_y_yyyy_1, tg_y_yyyyy_0, tg_y_yyyyy_1, tg_y_yyyyz_0, tg_y_yyyyz_1, tg_y_yyyz_1, \
                                         tg_y_yyyzz_0, tg_y_yyyzz_1, tg_y_yyzz_1, tg_y_yyzzz_0, tg_y_yyzzz_1, tg_y_yzzz_1, \
                                         tg_y_yzzzz_0, tg_y_yzzzz_1, tg_y_zzzz_1, tg_y_zzzzz_0, tg_y_zzzzz_1, tg_yy_xxxxx_0, \
                                         tg_yy_xxxxy_0, tg_yy_xxxxz_0, tg_yy_xxxyy_0, tg_yy_xxxyz_0, tg_yy_xxxzz_0, \
                                         tg_yy_xxyyy_0, tg_yy_xxyyz_0, tg_yy_xxyzz_0, tg_yy_xxzzz_0, tg_yy_xyyyy_0, \
                                         tg_yy_xyyyz_0, tg_yy_xyyzz_0, tg_yy_xyzzz_0, tg_yy_xzzzz_0, tg_yy_yyyyy_0, \
                                         tg_yy_yyyyz_0, tg_yy_yyyzz_0, tg_yy_yyzzz_0, tg_yy_yzzzz_0, tg_yy_zzzzz_0, \
                                         tg_yz_xxxxx_0, tg_yz_xxxxy_0, tg_yz_xxxxz_0, tg_yz_xxxyy_0, tg_yz_xxxyz_0, \
                                         tg_yz_xxxzz_0, tg_yz_xxyyy_0, tg_yz_xxyyz_0, tg_yz_xxyzz_0, tg_yz_xxzzz_0, \
                                         tg_yz_xyyyy_0, tg_yz_xyyyz_0, tg_yz_xyyzz_0, tg_yz_xyzzz_0, tg_yz_xzzzz_0, \
                                         tg_yz_yyyyy_0, tg_yz_yyyyz_0, tg_yz_yyyzz_0, tg_yz_yyzzz_0, tg_yz_yzzzz_0, \
                                         tg_yz_zzzzz_0, tg_z_xxxx_1, tg_z_xxxxx_0, tg_z_xxxxx_1, tg_z_xxxxy_0, tg_z_xxxxy_1, \
                                         tg_z_xxxxz_0, tg_z_xxxxz_1, tg_z_xxxy_1, tg_z_xxxyy_0, tg_z_xxxyy_1, tg_z_xxxyz_0, \
                                         tg_z_xxxyz_1, tg_z_xxxz_1, tg_z_xxxzz_0, tg_z_xxxzz_1, tg_z_xxyy_1, tg_z_xxyyy_0, \
                                         tg_z_xxyyy_1, tg_z_xxyyz_0, tg_z_xxyyz_1, tg_z_xxyz_1, tg_z_xxyzz_0, tg_z_xxyzz_1, \
                                         tg_z_xxzz_1, tg_z_xxzzz_0, tg_z_xxzzz_1, tg_z_xyyy_1, tg_z_xyyyy_0, tg_z_xyyyy_1, \
                                         tg_z_xyyyz_0, tg_z_xyyyz_1, tg_z_xyyz_1, tg_z_xyyzz_0, tg_z_xyyzz_1, tg_z_xyzz_1, \
                                         tg_z_xyzzz_0, tg_z_xyzzz_1, tg_z_xzzz_1, tg_z_xzzzz_0, tg_z_xzzzz_1, tg_z_yyyy_1, \
                                         tg_z_yyyyy_0, tg_z_yyyyy_1, tg_z_yyyyz_0, tg_z_yyyyz_1, tg_z_yyyz_1, tg_z_yyyzz_0, \
                                         tg_z_yyyzz_1, tg_z_yyzz_1, tg_z_yyzzz_0, tg_z_yyzzz_1, tg_z_yzzz_1, tg_z_yzzzz_0, \
                                         tg_z_yzzzz_1, tg_z_zzzz_1, tg_z_zzzzz_0, tg_z_zzzzz_1, tg_zz_xxxxx_0, \
                                         tg_zz_xxxxy_0, tg_zz_xxxxz_0, tg_zz_xxxyy_0, tg_zz_xxxyz_0, tg_zz_xxxzz_0, \
                                         tg_zz_xxyyy_0, tg_zz_xxyyz_0, tg_zz_xxyzz_0, tg_zz_xxzzz_0, tg_zz_xyyyy_0, \
                                         tg_zz_xyyyz_0, tg_zz_xyyzz_0, tg_zz_xyzzz_0, tg_zz_xzzzz_0, tg_zz_yyyyy_0, \
                                         tg_zz_yyyyz_0, tg_zz_yyyzz_0, tg_zz_yyzzz_0, tg_zz_yzzzz_0, tg_zz_zzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yy_xxxxx_0[j] = pb_y * tg_y_xxxxx_0[j] + fr * tg_y_xxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxx_0[j] - tg_0_xxxxx_1[j] * fl1_fza);

                    tg_yy_xxxxy_0[j] = pb_y * tg_y_xxxxy_0[j] + fr * tg_y_xxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxy_0[j] - tg_0_xxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxx_1[j];

                    tg_yy_xxxxz_0[j] = pb_y * tg_y_xxxxz_0[j] + fr * tg_y_xxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxz_0[j] - tg_0_xxxxz_1[j] * fl1_fza);

                    tg_yy_xxxyy_0[j] = pb_y * tg_y_xxxyy_0[j] + fr * tg_y_xxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyy_0[j] - tg_0_xxxyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxy_1[j];

                    tg_yy_xxxyz_0[j] = pb_y * tg_y_xxxyz_0[j] + fr * tg_y_xxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyz_0[j] - tg_0_xxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxz_1[j];

                    tg_yy_xxxzz_0[j] = pb_y * tg_y_xxxzz_0[j] + fr * tg_y_xxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzz_0[j] - tg_0_xxxzz_1[j] * fl1_fza);

                    tg_yy_xxyyy_0[j] = pb_y * tg_y_xxyyy_0[j] + fr * tg_y_xxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyy_0[j] - tg_0_xxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxyy_1[j];

                    tg_yy_xxyyz_0[j] = pb_y * tg_y_xxyyz_0[j] + fr * tg_y_xxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyz_0[j] - tg_0_xxyyz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxyz_1[j];

                    tg_yy_xxyzz_0[j] = pb_y * tg_y_xxyzz_0[j] + fr * tg_y_xxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzz_0[j] - tg_0_xxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxzz_1[j];

                    tg_yy_xxzzz_0[j] = pb_y * tg_y_xxzzz_0[j] + fr * tg_y_xxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzz_0[j] - tg_0_xxzzz_1[j] * fl1_fza);

                    tg_yy_xyyyy_0[j] = pb_y * tg_y_xyyyy_0[j] + fr * tg_y_xyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyy_0[j] - tg_0_xyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xyyy_1[j];

                    tg_yy_xyyyz_0[j] = pb_y * tg_y_xyyyz_0[j] + fr * tg_y_xyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyz_0[j] - tg_0_xyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xyyz_1[j];

                    tg_yy_xyyzz_0[j] = pb_y * tg_y_xyyzz_0[j] + fr * tg_y_xyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzz_0[j] - tg_0_xyyzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xyzz_1[j];

                    tg_yy_xyzzz_0[j] = pb_y * tg_y_xyzzz_0[j] + fr * tg_y_xyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzz_0[j] - tg_0_xyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xzzz_1[j];

                    tg_yy_xzzzz_0[j] = pb_y * tg_y_xzzzz_0[j] + fr * tg_y_xzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzz_0[j] - tg_0_xzzzz_1[j] * fl1_fza);

                    tg_yy_yyyyy_0[j] = pb_y * tg_y_yyyyy_0[j] + fr * tg_y_yyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyy_0[j] - tg_0_yyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_yyyy_1[j];

                    tg_yy_yyyyz_0[j] = pb_y * tg_y_yyyyz_0[j] + fr * tg_y_yyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyz_0[j] - tg_0_yyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_yyyz_1[j];

                    tg_yy_yyyzz_0[j] = pb_y * tg_y_yyyzz_0[j] + fr * tg_y_yyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzz_0[j] - tg_0_yyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yyzz_1[j];

                    tg_yy_yyzzz_0[j] = pb_y * tg_y_yyzzz_0[j] + fr * tg_y_yyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzz_0[j] - tg_0_yyzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_yzzz_1[j];

                    tg_yy_yzzzz_0[j] = pb_y * tg_y_yzzzz_0[j] + fr * tg_y_yzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzz_0[j] - tg_0_yzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zzzz_1[j];

                    tg_yy_zzzzz_0[j] = pb_y * tg_y_zzzzz_0[j] + fr * tg_y_zzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzz_0[j] - tg_0_zzzzz_1[j] * fl1_fza);

                    tg_yz_xxxxx_0[j] = pb_y * tg_z_xxxxx_0[j] + fr * tg_z_xxxxx_1[j];

                    tg_yz_xxxxy_0[j] = pb_y * tg_z_xxxxy_0[j] + fr * tg_z_xxxxy_1[j] + 0.5 * fl1_fxn * tg_z_xxxx_1[j];

                    tg_yz_xxxxz_0[j] = pb_y * tg_z_xxxxz_0[j] + fr * tg_z_xxxxz_1[j];

                    tg_yz_xxxyy_0[j] = pb_y * tg_z_xxxyy_0[j] + fr * tg_z_xxxyy_1[j] + fl1_fxn * tg_z_xxxy_1[j];

                    tg_yz_xxxyz_0[j] = pb_y * tg_z_xxxyz_0[j] + fr * tg_z_xxxyz_1[j] + 0.5 * fl1_fxn * tg_z_xxxz_1[j];

                    tg_yz_xxxzz_0[j] = pb_y * tg_z_xxxzz_0[j] + fr * tg_z_xxxzz_1[j];

                    tg_yz_xxyyy_0[j] = pb_y * tg_z_xxyyy_0[j] + fr * tg_z_xxyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxyy_1[j];

                    tg_yz_xxyyz_0[j] = pb_y * tg_z_xxyyz_0[j] + fr * tg_z_xxyyz_1[j] + fl1_fxn * tg_z_xxyz_1[j];

                    tg_yz_xxyzz_0[j] = pb_y * tg_z_xxyzz_0[j] + fr * tg_z_xxyzz_1[j] + 0.5 * fl1_fxn * tg_z_xxzz_1[j];

                    tg_yz_xxzzz_0[j] = pb_y * tg_z_xxzzz_0[j] + fr * tg_z_xxzzz_1[j];

                    tg_yz_xyyyy_0[j] = pb_y * tg_z_xyyyy_0[j] + fr * tg_z_xyyyy_1[j] + 2.0 * fl1_fxn * tg_z_xyyy_1[j];

                    tg_yz_xyyyz_0[j] = pb_y * tg_z_xyyyz_0[j] + fr * tg_z_xyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xyyz_1[j];

                    tg_yz_xyyzz_0[j] = pb_y * tg_z_xyyzz_0[j] + fr * tg_z_xyyzz_1[j] + fl1_fxn * tg_z_xyzz_1[j];

                    tg_yz_xyzzz_0[j] = pb_y * tg_z_xyzzz_0[j] + fr * tg_z_xyzzz_1[j] + 0.5 * fl1_fxn * tg_z_xzzz_1[j];

                    tg_yz_xzzzz_0[j] = pb_y * tg_z_xzzzz_0[j] + fr * tg_z_xzzzz_1[j];

                    tg_yz_yyyyy_0[j] = pb_y * tg_z_yyyyy_0[j] + fr * tg_z_yyyyy_1[j] + 2.5 * fl1_fxn * tg_z_yyyy_1[j];

                    tg_yz_yyyyz_0[j] = pb_y * tg_z_yyyyz_0[j] + fr * tg_z_yyyyz_1[j] + 2.0 * fl1_fxn * tg_z_yyyz_1[j];

                    tg_yz_yyyzz_0[j] = pb_y * tg_z_yyyzz_0[j] + fr * tg_z_yyyzz_1[j] + 1.5 * fl1_fxn * tg_z_yyzz_1[j];

                    tg_yz_yyzzz_0[j] = pb_y * tg_z_yyzzz_0[j] + fr * tg_z_yyzzz_1[j] + fl1_fxn * tg_z_yzzz_1[j];

                    tg_yz_yzzzz_0[j] = pb_y * tg_z_yzzzz_0[j] + fr * tg_z_yzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzz_1[j];

                    tg_yz_zzzzz_0[j] = pb_y * tg_z_zzzzz_0[j] + fr * tg_z_zzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxxxx_0[j] = pb_z * tg_z_xxxxx_0[j] + fr * tg_z_xxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxx_0[j] - tg_0_xxxxx_1[j] * fl1_fza);

                    tg_zz_xxxxy_0[j] = pb_z * tg_z_xxxxy_0[j] + fr * tg_z_xxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxy_0[j] - tg_0_xxxxy_1[j] * fl1_fza);

                    tg_zz_xxxxz_0[j] = pb_z * tg_z_xxxxz_0[j] + fr * tg_z_xxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxz_0[j] - tg_0_xxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxx_1[j];

                    tg_zz_xxxyy_0[j] = pb_z * tg_z_xxxyy_0[j] + fr * tg_z_xxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyy_0[j] - tg_0_xxxyy_1[j] * fl1_fza);

                    tg_zz_xxxyz_0[j] = pb_z * tg_z_xxxyz_0[j] + fr * tg_z_xxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyz_0[j] - tg_0_xxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxy_1[j];

                    tg_zz_xxxzz_0[j] = pb_z * tg_z_xxxzz_0[j] + fr * tg_z_xxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzz_0[j] - tg_0_xxxzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxz_1[j];

                    tg_zz_xxyyy_0[j] = pb_z * tg_z_xxyyy_0[j] + fr * tg_z_xxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyy_0[j] - tg_0_xxyyy_1[j] * fl1_fza);

                    tg_zz_xxyyz_0[j] = pb_z * tg_z_xxyyz_0[j] + fr * tg_z_xxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyz_0[j] - tg_0_xxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxyy_1[j];

                    tg_zz_xxyzz_0[j] = pb_z * tg_z_xxyzz_0[j] + fr * tg_z_xxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzz_0[j] - tg_0_xxyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxyz_1[j];

                    tg_zz_xxzzz_0[j] = pb_z * tg_z_xxzzz_0[j] + fr * tg_z_xxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzz_0[j] - tg_0_xxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxzz_1[j];

                    tg_zz_xyyyy_0[j] = pb_z * tg_z_xyyyy_0[j] + fr * tg_z_xyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyy_0[j] - tg_0_xyyyy_1[j] * fl1_fza);

                    tg_zz_xyyyz_0[j] = pb_z * tg_z_xyyyz_0[j] + fr * tg_z_xyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyz_0[j] - tg_0_xyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xyyy_1[j];

                    tg_zz_xyyzz_0[j] = pb_z * tg_z_xyyzz_0[j] + fr * tg_z_xyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzz_0[j] - tg_0_xyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xyyz_1[j];

                    tg_zz_xyzzz_0[j] = pb_z * tg_z_xyzzz_0[j] + fr * tg_z_xyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzz_0[j] - tg_0_xyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xyzz_1[j];

                    tg_zz_xzzzz_0[j] = pb_z * tg_z_xzzzz_0[j] + fr * tg_z_xzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzz_0[j] - tg_0_xzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xzzz_1[j];

                    tg_zz_yyyyy_0[j] = pb_z * tg_z_yyyyy_0[j] + fr * tg_z_yyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyy_0[j] - tg_0_yyyyy_1[j] * fl1_fza);

                    tg_zz_yyyyz_0[j] = pb_z * tg_z_yyyyz_0[j] + fr * tg_z_yyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyz_0[j] - tg_0_yyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yyyy_1[j];

                    tg_zz_yyyzz_0[j] = pb_z * tg_z_yyyzz_0[j] + fr * tg_z_yyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzz_0[j] - tg_0_yyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yyyz_1[j];

                    tg_zz_yyzzz_0[j] = pb_z * tg_z_yyzzz_0[j] + fr * tg_z_yyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzz_0[j] - tg_0_yyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_yyzz_1[j];

                    tg_zz_yzzzz_0[j] = pb_z * tg_z_yzzzz_0[j] + fr * tg_z_yzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzz_0[j] - tg_0_yzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_yzzz_1[j];

                    tg_zz_zzzzz_0[j] = pb_z * tg_z_zzzzz_0[j] + fr * tg_z_zzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzz_0[j] - tg_0_zzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_zzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSHSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSHSD_0_63(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSHSD_63_126(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 
    }

    void
    compElectronRepulsionForSHSD_0_63(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,63)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {5, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_5_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_4_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_3_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_3_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxx_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx); 

                auto tg_xxxx_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 1); 

                auto tg_xxxx_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 2); 

                auto tg_xxxx_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 3); 

                auto tg_xxxx_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 4); 

                auto tg_xxxx_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 5); 

                auto tg_xxxy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 6); 

                auto tg_xxxy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 7); 

                auto tg_xxxy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 8); 

                auto tg_xxxy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 9); 

                auto tg_xxxy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 10); 

                auto tg_xxxy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 11); 

                auto tg_xxxz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 12); 

                auto tg_xxxz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 13); 

                auto tg_xxxz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 14); 

                auto tg_xxxz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 15); 

                auto tg_xxxz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 16); 

                auto tg_xxxz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 17); 

                auto tg_xxyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 18); 

                auto tg_xxyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 19); 

                auto tg_xxyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 20); 

                auto tg_xxyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 21); 

                auto tg_xxyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 22); 

                auto tg_xxyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 23); 

                auto tg_xxyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 24); 

                auto tg_xxyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 25); 

                auto tg_xxyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 26); 

                auto tg_xxyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 27); 

                auto tg_xxyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 28); 

                auto tg_xxyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 29); 

                auto tg_xxzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 30); 

                auto tg_xxzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 31); 

                auto tg_xxzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 32); 

                auto tg_xxzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 33); 

                auto tg_xxzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 34); 

                auto tg_xxzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 35); 

                auto tg_xyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 36); 

                auto tg_xyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 37); 

                auto tg_xyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 38); 

                auto tg_xyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 39); 

                auto tg_xyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 40); 

                auto tg_xyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 41); 

                auto tg_xyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 42); 

                auto tg_xyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 43); 

                auto tg_xyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 44); 

                auto tg_xyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 45); 

                auto tg_xyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 46); 

                auto tg_xyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 47); 

                auto tg_xyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 48); 

                auto tg_xyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 49); 

                auto tg_xyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 50); 

                auto tg_xyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 51); 

                auto tg_xyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 52); 

                auto tg_xyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 53); 

                auto tg_xzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 54); 

                auto tg_xzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 55); 

                auto tg_xzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 56); 

                auto tg_xzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 57); 

                auto tg_xzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 58); 

                auto tg_xzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 59); 

                auto tg_yyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 60); 

                auto tg_yyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 61); 

                auto tg_yyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 62); 

                auto tg_xxxx_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx); 

                auto tg_xxxx_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 1); 

                auto tg_xxxx_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 2); 

                auto tg_xxxx_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 3); 

                auto tg_xxxx_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 4); 

                auto tg_xxxx_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 5); 

                auto tg_xxxy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 6); 

                auto tg_xxxy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 7); 

                auto tg_xxxy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 8); 

                auto tg_xxxy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 9); 

                auto tg_xxxy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 10); 

                auto tg_xxxy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 11); 

                auto tg_xxxz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 12); 

                auto tg_xxxz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 13); 

                auto tg_xxxz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 14); 

                auto tg_xxxz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 15); 

                auto tg_xxxz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 16); 

                auto tg_xxxz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 17); 

                auto tg_xxyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 18); 

                auto tg_xxyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 19); 

                auto tg_xxyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 20); 

                auto tg_xxyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 21); 

                auto tg_xxyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 22); 

                auto tg_xxyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 23); 

                auto tg_xxyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 24); 

                auto tg_xxyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 25); 

                auto tg_xxyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 26); 

                auto tg_xxyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 27); 

                auto tg_xxyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 28); 

                auto tg_xxyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 29); 

                auto tg_xxzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 30); 

                auto tg_xxzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 31); 

                auto tg_xxzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 32); 

                auto tg_xxzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 33); 

                auto tg_xxzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 34); 

                auto tg_xxzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 35); 

                auto tg_xyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 36); 

                auto tg_xyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 37); 

                auto tg_xyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 38); 

                auto tg_xyyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 39); 

                auto tg_xyyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 40); 

                auto tg_xyyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 41); 

                auto tg_xyyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 42); 

                auto tg_xyyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 43); 

                auto tg_xyyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 44); 

                auto tg_xyyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 45); 

                auto tg_xyyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 46); 

                auto tg_xyyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 47); 

                auto tg_xyzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 48); 

                auto tg_xyzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 49); 

                auto tg_xyzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 50); 

                auto tg_xyzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 51); 

                auto tg_xyzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 52); 

                auto tg_xyzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 53); 

                auto tg_xzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 54); 

                auto tg_xzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 55); 

                auto tg_xzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 56); 

                auto tg_xzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 57); 

                auto tg_xzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 58); 

                auto tg_xzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 59); 

                auto tg_yyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 60); 

                auto tg_yyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 61); 

                auto tg_yyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 62); 

                auto tg_xxx_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx); 

                auto tg_xxx_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 1); 

                auto tg_xxx_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 2); 

                auto tg_xxx_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 3); 

                auto tg_xxx_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 4); 

                auto tg_xxx_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 5); 

                auto tg_xxy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 6); 

                auto tg_xxy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 7); 

                auto tg_xxy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 8); 

                auto tg_xxy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 9); 

                auto tg_xxy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 10); 

                auto tg_xxy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 11); 

                auto tg_xxz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 12); 

                auto tg_xxz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 13); 

                auto tg_xxz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 14); 

                auto tg_xxz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 15); 

                auto tg_xxz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 16); 

                auto tg_xxz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 17); 

                auto tg_xyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 18); 

                auto tg_xyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 19); 

                auto tg_xyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 20); 

                auto tg_xyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 21); 

                auto tg_xyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 22); 

                auto tg_xyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 23); 

                auto tg_xyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 24); 

                auto tg_xyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 25); 

                auto tg_xyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 26); 

                auto tg_xyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 27); 

                auto tg_xyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 28); 

                auto tg_xyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 29); 

                auto tg_xzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 30); 

                auto tg_xzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 31); 

                auto tg_xzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 32); 

                auto tg_xzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 33); 

                auto tg_xzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 34); 

                auto tg_xzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 35); 

                auto tg_yyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 36); 

                auto tg_yyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 37); 

                auto tg_yyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 38); 

                auto tg_yyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 39); 

                auto tg_yyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 40); 

                auto tg_yyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 41); 

                auto tg_yyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 42); 

                auto tg_yyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 43); 

                auto tg_yyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 44); 

                auto tg_yyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 45); 

                auto tg_yyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 46); 

                auto tg_yyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 47); 

                auto tg_yzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 48); 

                auto tg_yzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 49); 

                auto tg_yzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 50); 

                auto tg_yzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 51); 

                auto tg_yzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 52); 

                auto tg_yzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 53); 

                auto tg_zzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 54); 

                auto tg_zzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 55); 

                auto tg_zzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 56); 

                auto tg_zzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 57); 

                auto tg_zzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 58); 

                auto tg_zzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 59); 

                auto tg_xxx_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx); 

                auto tg_xxx_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 1); 

                auto tg_xxx_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 2); 

                auto tg_xxx_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 3); 

                auto tg_xxx_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 4); 

                auto tg_xxx_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 5); 

                auto tg_xxy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 6); 

                auto tg_xxy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 7); 

                auto tg_xxy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 8); 

                auto tg_xxy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 9); 

                auto tg_xxy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 10); 

                auto tg_xxy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 11); 

                auto tg_xxz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 12); 

                auto tg_xxz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 13); 

                auto tg_xxz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 14); 

                auto tg_xxz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 15); 

                auto tg_xxz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 16); 

                auto tg_xxz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 17); 

                auto tg_xyy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 18); 

                auto tg_xyy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 19); 

                auto tg_xyy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 20); 

                auto tg_xyy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 21); 

                auto tg_xyy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 22); 

                auto tg_xyy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 23); 

                auto tg_xyz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 24); 

                auto tg_xyz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 25); 

                auto tg_xyz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 26); 

                auto tg_xyz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 27); 

                auto tg_xyz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 28); 

                auto tg_xyz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 29); 

                auto tg_xzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 30); 

                auto tg_xzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 31); 

                auto tg_xzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 32); 

                auto tg_xzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 33); 

                auto tg_xzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 34); 

                auto tg_xzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 35); 

                auto tg_yyy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 36); 

                auto tg_yyy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 37); 

                auto tg_yyy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 38); 

                auto tg_yyy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 39); 

                auto tg_yyy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 40); 

                auto tg_yyy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 41); 

                auto tg_yyz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 42); 

                auto tg_yyz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 43); 

                auto tg_yyz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 44); 

                auto tg_yyz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 45); 

                auto tg_yyz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 46); 

                auto tg_yyz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 47); 

                auto tg_yzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 48); 

                auto tg_yzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 49); 

                auto tg_yzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 50); 

                auto tg_yzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 51); 

                auto tg_yzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 52); 

                auto tg_yzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 53); 

                auto tg_zzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 54); 

                auto tg_zzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 55); 

                auto tg_zzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 56); 

                auto tg_zzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 57); 

                auto tg_zzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 58); 

                auto tg_zzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 59); 

                auto tg_xxxx_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx); 

                auto tg_xxxx_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 1); 

                auto tg_xxxx_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 2); 

                auto tg_xxxy_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 3); 

                auto tg_xxxy_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 4); 

                auto tg_xxxy_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 5); 

                auto tg_xxxz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 6); 

                auto tg_xxxz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 7); 

                auto tg_xxxz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 8); 

                auto tg_xxyy_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 9); 

                auto tg_xxyy_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 10); 

                auto tg_xxyy_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 11); 

                auto tg_xxyz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 12); 

                auto tg_xxyz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 13); 

                auto tg_xxyz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 14); 

                auto tg_xxzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 15); 

                auto tg_xxzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 16); 

                auto tg_xxzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 17); 

                auto tg_xyyy_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 18); 

                auto tg_xyyy_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 19); 

                auto tg_xyyy_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 20); 

                auto tg_xyyz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 21); 

                auto tg_xyyz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 22); 

                auto tg_xyyz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 23); 

                auto tg_xyzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 24); 

                auto tg_xyzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 25); 

                auto tg_xyzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 26); 

                auto tg_xzzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 27); 

                auto tg_xzzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 28); 

                auto tg_xzzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 29); 

                auto tg_yyyy_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 30); 

                auto tg_yyyy_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 31); 

                auto tg_yyyy_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 32); 

                // set up pointers to integrals

                auto tg_xxxxx_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx); 

                auto tg_xxxxx_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 1); 

                auto tg_xxxxx_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 2); 

                auto tg_xxxxx_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 3); 

                auto tg_xxxxx_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 4); 

                auto tg_xxxxx_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 5); 

                auto tg_xxxxy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 6); 

                auto tg_xxxxy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 7); 

                auto tg_xxxxy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 8); 

                auto tg_xxxxy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 9); 

                auto tg_xxxxy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 10); 

                auto tg_xxxxy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 11); 

                auto tg_xxxxz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 12); 

                auto tg_xxxxz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 13); 

                auto tg_xxxxz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 14); 

                auto tg_xxxxz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 15); 

                auto tg_xxxxz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 16); 

                auto tg_xxxxz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 17); 

                auto tg_xxxyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 18); 

                auto tg_xxxyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 19); 

                auto tg_xxxyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 20); 

                auto tg_xxxyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 21); 

                auto tg_xxxyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 22); 

                auto tg_xxxyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 23); 

                auto tg_xxxyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 24); 

                auto tg_xxxyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 25); 

                auto tg_xxxyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 26); 

                auto tg_xxxyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 27); 

                auto tg_xxxyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 28); 

                auto tg_xxxyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 29); 

                auto tg_xxxzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 30); 

                auto tg_xxxzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 31); 

                auto tg_xxxzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 32); 

                auto tg_xxxzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 33); 

                auto tg_xxxzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 34); 

                auto tg_xxxzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 35); 

                auto tg_xxyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 36); 

                auto tg_xxyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 37); 

                auto tg_xxyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 38); 

                auto tg_xxyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 39); 

                auto tg_xxyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 40); 

                auto tg_xxyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 41); 

                auto tg_xxyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 42); 

                auto tg_xxyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 43); 

                auto tg_xxyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 44); 

                auto tg_xxyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 45); 

                auto tg_xxyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 46); 

                auto tg_xxyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 47); 

                auto tg_xxyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 48); 

                auto tg_xxyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 49); 

                auto tg_xxyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 50); 

                auto tg_xxyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 51); 

                auto tg_xxyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 52); 

                auto tg_xxyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 53); 

                auto tg_xxzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 54); 

                auto tg_xxzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 55); 

                auto tg_xxzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 56); 

                auto tg_xxzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 57); 

                auto tg_xxzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 58); 

                auto tg_xxzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 59); 

                auto tg_xyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 60); 

                auto tg_xyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 61); 

                auto tg_xyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 62); 

                // Batch of Integrals (0,63)

                #pragma omp simd aligned(fxn, fza, tg_xxx_xx_0, tg_xxx_xx_1, tg_xxx_xy_0, tg_xxx_xy_1, \
                                         tg_xxx_xz_0, tg_xxx_xz_1, tg_xxx_yy_0, tg_xxx_yy_1, tg_xxx_yz_0, tg_xxx_yz_1, \
                                         tg_xxx_zz_0, tg_xxx_zz_1, tg_xxxx_x_1, tg_xxxx_xx_0, tg_xxxx_xx_1, tg_xxxx_xy_0, \
                                         tg_xxxx_xy_1, tg_xxxx_xz_0, tg_xxxx_xz_1, tg_xxxx_y_1, tg_xxxx_yy_0, tg_xxxx_yy_1, \
                                         tg_xxxx_yz_0, tg_xxxx_yz_1, tg_xxxx_z_1, tg_xxxx_zz_0, tg_xxxx_zz_1, tg_xxxxx_xx_0, \
                                         tg_xxxxx_xy_0, tg_xxxxx_xz_0, tg_xxxxx_yy_0, tg_xxxxx_yz_0, tg_xxxxx_zz_0, \
                                         tg_xxxxy_xx_0, tg_xxxxy_xy_0, tg_xxxxy_xz_0, tg_xxxxy_yy_0, tg_xxxxy_yz_0, \
                                         tg_xxxxy_zz_0, tg_xxxxz_xx_0, tg_xxxxz_xy_0, tg_xxxxz_xz_0, tg_xxxxz_yy_0, \
                                         tg_xxxxz_yz_0, tg_xxxxz_zz_0, tg_xxxy_x_1, tg_xxxy_xx_0, tg_xxxy_xx_1, tg_xxxy_xy_0, \
                                         tg_xxxy_xy_1, tg_xxxy_xz_0, tg_xxxy_xz_1, tg_xxxy_y_1, tg_xxxy_yy_0, tg_xxxy_yy_1, \
                                         tg_xxxy_yz_0, tg_xxxy_yz_1, tg_xxxy_z_1, tg_xxxy_zz_0, tg_xxxy_zz_1, tg_xxxyy_xx_0, \
                                         tg_xxxyy_xy_0, tg_xxxyy_xz_0, tg_xxxyy_yy_0, tg_xxxyy_yz_0, tg_xxxyy_zz_0, \
                                         tg_xxxyz_xx_0, tg_xxxyz_xy_0, tg_xxxyz_xz_0, tg_xxxyz_yy_0, tg_xxxyz_yz_0, \
                                         tg_xxxyz_zz_0, tg_xxxz_x_1, tg_xxxz_xx_0, tg_xxxz_xx_1, tg_xxxz_xy_0, tg_xxxz_xy_1, \
                                         tg_xxxz_xz_0, tg_xxxz_xz_1, tg_xxxz_y_1, tg_xxxz_yy_0, tg_xxxz_yy_1, tg_xxxz_yz_0, \
                                         tg_xxxz_yz_1, tg_xxxz_z_1, tg_xxxz_zz_0, tg_xxxz_zz_1, tg_xxxzz_xx_0, \
                                         tg_xxxzz_xy_0, tg_xxxzz_xz_0, tg_xxxzz_yy_0, tg_xxxzz_yz_0, tg_xxxzz_zz_0, \
                                         tg_xxy_xx_0, tg_xxy_xx_1, tg_xxy_xy_0, tg_xxy_xy_1, tg_xxy_xz_0, tg_xxy_xz_1, \
                                         tg_xxy_yy_0, tg_xxy_yy_1, tg_xxy_yz_0, tg_xxy_yz_1, tg_xxy_zz_0, tg_xxy_zz_1, \
                                         tg_xxyy_x_1, tg_xxyy_xx_0, tg_xxyy_xx_1, tg_xxyy_xy_0, tg_xxyy_xy_1, tg_xxyy_xz_0, \
                                         tg_xxyy_xz_1, tg_xxyy_y_1, tg_xxyy_yy_0, tg_xxyy_yy_1, tg_xxyy_yz_0, tg_xxyy_yz_1, \
                                         tg_xxyy_z_1, tg_xxyy_zz_0, tg_xxyy_zz_1, tg_xxyyy_xx_0, tg_xxyyy_xy_0, \
                                         tg_xxyyy_xz_0, tg_xxyyy_yy_0, tg_xxyyy_yz_0, tg_xxyyy_zz_0, tg_xxyyz_xx_0, \
                                         tg_xxyyz_xy_0, tg_xxyyz_xz_0, tg_xxyyz_yy_0, tg_xxyyz_yz_0, tg_xxyyz_zz_0, \
                                         tg_xxyz_x_1, tg_xxyz_xx_0, tg_xxyz_xx_1, tg_xxyz_xy_0, tg_xxyz_xy_1, tg_xxyz_xz_0, \
                                         tg_xxyz_xz_1, tg_xxyz_y_1, tg_xxyz_yy_0, tg_xxyz_yy_1, tg_xxyz_yz_0, tg_xxyz_yz_1, \
                                         tg_xxyz_z_1, tg_xxyz_zz_0, tg_xxyz_zz_1, tg_xxyzz_xx_0, tg_xxyzz_xy_0, \
                                         tg_xxyzz_xz_0, tg_xxyzz_yy_0, tg_xxyzz_yz_0, tg_xxyzz_zz_0, tg_xxz_xx_0, \
                                         tg_xxz_xx_1, tg_xxz_xy_0, tg_xxz_xy_1, tg_xxz_xz_0, tg_xxz_xz_1, tg_xxz_yy_0, \
                                         tg_xxz_yy_1, tg_xxz_yz_0, tg_xxz_yz_1, tg_xxz_zz_0, tg_xxz_zz_1, tg_xxzz_x_1, \
                                         tg_xxzz_xx_0, tg_xxzz_xx_1, tg_xxzz_xy_0, tg_xxzz_xy_1, tg_xxzz_xz_0, tg_xxzz_xz_1, \
                                         tg_xxzz_y_1, tg_xxzz_yy_0, tg_xxzz_yy_1, tg_xxzz_yz_0, tg_xxzz_yz_1, tg_xxzz_z_1, \
                                         tg_xxzz_zz_0, tg_xxzz_zz_1, tg_xxzzz_xx_0, tg_xxzzz_xy_0, tg_xxzzz_xz_0, \
                                         tg_xxzzz_yy_0, tg_xxzzz_yz_0, tg_xxzzz_zz_0, tg_xyy_xx_0, tg_xyy_xx_1, tg_xyy_xy_0, \
                                         tg_xyy_xy_1, tg_xyy_xz_0, tg_xyy_xz_1, tg_xyy_yy_0, tg_xyy_yy_1, tg_xyy_yz_0, \
                                         tg_xyy_yz_1, tg_xyy_zz_0, tg_xyy_zz_1, tg_xyyy_x_1, tg_xyyy_xx_0, tg_xyyy_xx_1, \
                                         tg_xyyy_xy_0, tg_xyyy_xy_1, tg_xyyy_xz_0, tg_xyyy_xz_1, tg_xyyy_y_1, tg_xyyy_yy_0, \
                                         tg_xyyy_yy_1, tg_xyyy_yz_0, tg_xyyy_yz_1, tg_xyyy_z_1, tg_xyyy_zz_0, tg_xyyy_zz_1, \
                                         tg_xyyyy_xx_0, tg_xyyyy_xy_0, tg_xyyyy_xz_0, tg_xyyz_x_1, tg_xyyz_xx_0, \
                                         tg_xyyz_xx_1, tg_xyyz_xy_0, tg_xyyz_xy_1, tg_xyyz_xz_0, tg_xyyz_xz_1, tg_xyyz_y_1, \
                                         tg_xyyz_yy_0, tg_xyyz_yy_1, tg_xyyz_yz_0, tg_xyyz_yz_1, tg_xyyz_z_1, tg_xyyz_zz_0, \
                                         tg_xyyz_zz_1, tg_xyz_xx_0, tg_xyz_xx_1, tg_xyz_xy_0, tg_xyz_xy_1, tg_xyz_xz_0, \
                                         tg_xyz_xz_1, tg_xyz_yy_0, tg_xyz_yy_1, tg_xyz_yz_0, tg_xyz_yz_1, tg_xyz_zz_0, \
                                         tg_xyz_zz_1, tg_xyzz_x_1, tg_xyzz_xx_0, tg_xyzz_xx_1, tg_xyzz_xy_0, tg_xyzz_xy_1, \
                                         tg_xyzz_xz_0, tg_xyzz_xz_1, tg_xyzz_y_1, tg_xyzz_yy_0, tg_xyzz_yy_1, tg_xyzz_yz_0, \
                                         tg_xyzz_yz_1, tg_xyzz_z_1, tg_xyzz_zz_0, tg_xyzz_zz_1, tg_xzz_xx_0, tg_xzz_xx_1, \
                                         tg_xzz_xy_0, tg_xzz_xy_1, tg_xzz_xz_0, tg_xzz_xz_1, tg_xzz_yy_0, tg_xzz_yy_1, \
                                         tg_xzz_yz_0, tg_xzz_yz_1, tg_xzz_zz_0, tg_xzz_zz_1, tg_xzzz_x_1, tg_xzzz_xx_0, \
                                         tg_xzzz_xx_1, tg_xzzz_xy_0, tg_xzzz_xy_1, tg_xzzz_xz_0, tg_xzzz_xz_1, tg_xzzz_y_1, \
                                         tg_xzzz_yy_0, tg_xzzz_yy_1, tg_xzzz_yz_0, tg_xzzz_yz_1, tg_xzzz_z_1, tg_xzzz_zz_0, \
                                         tg_xzzz_zz_1, tg_yyy_xx_0, tg_yyy_xx_1, tg_yyy_xy_0, tg_yyy_xy_1, tg_yyy_xz_0, \
                                         tg_yyy_xz_1, tg_yyy_yy_0, tg_yyy_yy_1, tg_yyy_yz_0, tg_yyy_yz_1, tg_yyy_zz_0, \
                                         tg_yyy_zz_1, tg_yyyy_x_1, tg_yyyy_xx_0, tg_yyyy_xx_1, tg_yyyy_xy_0, tg_yyyy_xy_1, \
                                         tg_yyyy_xz_0, tg_yyyy_xz_1, tg_yyyy_y_1, tg_yyyy_z_1, tg_yyz_xx_0, tg_yyz_xx_1, \
                                         tg_yyz_xy_0, tg_yyz_xy_1, tg_yyz_xz_0, tg_yyz_xz_1, tg_yyz_yy_0, tg_yyz_yy_1, \
                                         tg_yyz_yz_0, tg_yyz_yz_1, tg_yyz_zz_0, tg_yyz_zz_1, tg_yzz_xx_0, tg_yzz_xx_1, \
                                         tg_yzz_xy_0, tg_yzz_xy_1, tg_yzz_xz_0, tg_yzz_xz_1, tg_yzz_yy_0, tg_yzz_yy_1, \
                                         tg_yzz_yz_0, tg_yzz_yz_1, tg_yzz_zz_0, tg_yzz_zz_1, tg_zzz_xx_0, tg_zzz_xx_1, \
                                         tg_zzz_xy_0, tg_zzz_xy_1, tg_zzz_xz_0, tg_zzz_xz_1, tg_zzz_yy_0, tg_zzz_yy_1, \
                                         tg_zzz_yz_0, tg_zzz_yz_1, tg_zzz_zz_0, tg_zzz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxx_xx_0[j] = pb_x * tg_xxxx_xx_0[j] + fr * tg_xxxx_xx_1[j] + 2.0 * fl1_fx * (tg_xxx_xx_0[j] - tg_xxx_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxx_x_1[j];

                    tg_xxxxx_xy_0[j] = pb_x * tg_xxxx_xy_0[j] + fr * tg_xxxx_xy_1[j] + 2.0 * fl1_fx * (tg_xxx_xy_0[j] - tg_xxx_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxx_y_1[j];

                    tg_xxxxx_xz_0[j] = pb_x * tg_xxxx_xz_0[j] + fr * tg_xxxx_xz_1[j] + 2.0 * fl1_fx * (tg_xxx_xz_0[j] - tg_xxx_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxx_z_1[j];

                    tg_xxxxx_yy_0[j] = pb_x * tg_xxxx_yy_0[j] + fr * tg_xxxx_yy_1[j] + 2.0 * fl1_fx * (tg_xxx_yy_0[j] - tg_xxx_yy_1[j] * fl1_fza);

                    tg_xxxxx_yz_0[j] = pb_x * tg_xxxx_yz_0[j] + fr * tg_xxxx_yz_1[j] + 2.0 * fl1_fx * (tg_xxx_yz_0[j] - tg_xxx_yz_1[j] * fl1_fza);

                    tg_xxxxx_zz_0[j] = pb_x * tg_xxxx_zz_0[j] + fr * tg_xxxx_zz_1[j] + 2.0 * fl1_fx * (tg_xxx_zz_0[j] - tg_xxx_zz_1[j] * fl1_fza);

                    tg_xxxxy_xx_0[j] = pb_x * tg_xxxy_xx_0[j] + fr * tg_xxxy_xx_1[j] + 1.5 * fl1_fx * (tg_xxy_xx_0[j] - tg_xxy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxy_x_1[j];

                    tg_xxxxy_xy_0[j] = pb_x * tg_xxxy_xy_0[j] + fr * tg_xxxy_xy_1[j] + 1.5 * fl1_fx * (tg_xxy_xy_0[j] - tg_xxy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxy_y_1[j];

                    tg_xxxxy_xz_0[j] = pb_x * tg_xxxy_xz_0[j] + fr * tg_xxxy_xz_1[j] + 1.5 * fl1_fx * (tg_xxy_xz_0[j] - tg_xxy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxy_z_1[j];

                    tg_xxxxy_yy_0[j] = pb_x * tg_xxxy_yy_0[j] + fr * tg_xxxy_yy_1[j] + 1.5 * fl1_fx * (tg_xxy_yy_0[j] - tg_xxy_yy_1[j] * fl1_fza);

                    tg_xxxxy_yz_0[j] = pb_x * tg_xxxy_yz_0[j] + fr * tg_xxxy_yz_1[j] + 1.5 * fl1_fx * (tg_xxy_yz_0[j] - tg_xxy_yz_1[j] * fl1_fza);

                    tg_xxxxy_zz_0[j] = pb_x * tg_xxxy_zz_0[j] + fr * tg_xxxy_zz_1[j] + 1.5 * fl1_fx * (tg_xxy_zz_0[j] - tg_xxy_zz_1[j] * fl1_fza);

                    tg_xxxxz_xx_0[j] = pb_x * tg_xxxz_xx_0[j] + fr * tg_xxxz_xx_1[j] + 1.5 * fl1_fx * (tg_xxz_xx_0[j] - tg_xxz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxz_x_1[j];

                    tg_xxxxz_xy_0[j] = pb_x * tg_xxxz_xy_0[j] + fr * tg_xxxz_xy_1[j] + 1.5 * fl1_fx * (tg_xxz_xy_0[j] - tg_xxz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxz_y_1[j];

                    tg_xxxxz_xz_0[j] = pb_x * tg_xxxz_xz_0[j] + fr * tg_xxxz_xz_1[j] + 1.5 * fl1_fx * (tg_xxz_xz_0[j] - tg_xxz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxz_z_1[j];

                    tg_xxxxz_yy_0[j] = pb_x * tg_xxxz_yy_0[j] + fr * tg_xxxz_yy_1[j] + 1.5 * fl1_fx * (tg_xxz_yy_0[j] - tg_xxz_yy_1[j] * fl1_fza);

                    tg_xxxxz_yz_0[j] = pb_x * tg_xxxz_yz_0[j] + fr * tg_xxxz_yz_1[j] + 1.5 * fl1_fx * (tg_xxz_yz_0[j] - tg_xxz_yz_1[j] * fl1_fza);

                    tg_xxxxz_zz_0[j] = pb_x * tg_xxxz_zz_0[j] + fr * tg_xxxz_zz_1[j] + 1.5 * fl1_fx * (tg_xxz_zz_0[j] - tg_xxz_zz_1[j] * fl1_fza);

                    tg_xxxyy_xx_0[j] = pb_x * tg_xxyy_xx_0[j] + fr * tg_xxyy_xx_1[j] + fl1_fx * (tg_xyy_xx_0[j] - tg_xyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyy_x_1[j];

                    tg_xxxyy_xy_0[j] = pb_x * tg_xxyy_xy_0[j] + fr * tg_xxyy_xy_1[j] + fl1_fx * (tg_xyy_xy_0[j] - tg_xyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyy_y_1[j];

                    tg_xxxyy_xz_0[j] = pb_x * tg_xxyy_xz_0[j] + fr * tg_xxyy_xz_1[j] + fl1_fx * (tg_xyy_xz_0[j] - tg_xyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyy_z_1[j];

                    tg_xxxyy_yy_0[j] = pb_x * tg_xxyy_yy_0[j] + fr * tg_xxyy_yy_1[j] + fl1_fx * (tg_xyy_yy_0[j] - tg_xyy_yy_1[j] * fl1_fza);

                    tg_xxxyy_yz_0[j] = pb_x * tg_xxyy_yz_0[j] + fr * tg_xxyy_yz_1[j] + fl1_fx * (tg_xyy_yz_0[j] - tg_xyy_yz_1[j] * fl1_fza);

                    tg_xxxyy_zz_0[j] = pb_x * tg_xxyy_zz_0[j] + fr * tg_xxyy_zz_1[j] + fl1_fx * (tg_xyy_zz_0[j] - tg_xyy_zz_1[j] * fl1_fza);

                    tg_xxxyz_xx_0[j] = pb_x * tg_xxyz_xx_0[j] + fr * tg_xxyz_xx_1[j] + fl1_fx * (tg_xyz_xx_0[j] - tg_xyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyz_x_1[j];

                    tg_xxxyz_xy_0[j] = pb_x * tg_xxyz_xy_0[j] + fr * tg_xxyz_xy_1[j] + fl1_fx * (tg_xyz_xy_0[j] - tg_xyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyz_y_1[j];

                    tg_xxxyz_xz_0[j] = pb_x * tg_xxyz_xz_0[j] + fr * tg_xxyz_xz_1[j] + fl1_fx * (tg_xyz_xz_0[j] - tg_xyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyz_z_1[j];

                    tg_xxxyz_yy_0[j] = pb_x * tg_xxyz_yy_0[j] + fr * tg_xxyz_yy_1[j] + fl1_fx * (tg_xyz_yy_0[j] - tg_xyz_yy_1[j] * fl1_fza);

                    tg_xxxyz_yz_0[j] = pb_x * tg_xxyz_yz_0[j] + fr * tg_xxyz_yz_1[j] + fl1_fx * (tg_xyz_yz_0[j] - tg_xyz_yz_1[j] * fl1_fza);

                    tg_xxxyz_zz_0[j] = pb_x * tg_xxyz_zz_0[j] + fr * tg_xxyz_zz_1[j] + fl1_fx * (tg_xyz_zz_0[j] - tg_xyz_zz_1[j] * fl1_fza);

                    tg_xxxzz_xx_0[j] = pb_x * tg_xxzz_xx_0[j] + fr * tg_xxzz_xx_1[j] + fl1_fx * (tg_xzz_xx_0[j] - tg_xzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxzz_x_1[j];

                    tg_xxxzz_xy_0[j] = pb_x * tg_xxzz_xy_0[j] + fr * tg_xxzz_xy_1[j] + fl1_fx * (tg_xzz_xy_0[j] - tg_xzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzz_y_1[j];

                    tg_xxxzz_xz_0[j] = pb_x * tg_xxzz_xz_0[j] + fr * tg_xxzz_xz_1[j] + fl1_fx * (tg_xzz_xz_0[j] - tg_xzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzz_z_1[j];

                    tg_xxxzz_yy_0[j] = pb_x * tg_xxzz_yy_0[j] + fr * tg_xxzz_yy_1[j] + fl1_fx * (tg_xzz_yy_0[j] - tg_xzz_yy_1[j] * fl1_fza);

                    tg_xxxzz_yz_0[j] = pb_x * tg_xxzz_yz_0[j] + fr * tg_xxzz_yz_1[j] + fl1_fx * (tg_xzz_yz_0[j] - tg_xzz_yz_1[j] * fl1_fza);

                    tg_xxxzz_zz_0[j] = pb_x * tg_xxzz_zz_0[j] + fr * tg_xxzz_zz_1[j] + fl1_fx * (tg_xzz_zz_0[j] - tg_xzz_zz_1[j] * fl1_fza);

                    tg_xxyyy_xx_0[j] = pb_x * tg_xyyy_xx_0[j] + fr * tg_xyyy_xx_1[j] + 0.5 * fl1_fx * (tg_yyy_xx_0[j] - tg_yyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyy_x_1[j];

                    tg_xxyyy_xy_0[j] = pb_x * tg_xyyy_xy_0[j] + fr * tg_xyyy_xy_1[j] + 0.5 * fl1_fx * (tg_yyy_xy_0[j] - tg_yyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyy_y_1[j];

                    tg_xxyyy_xz_0[j] = pb_x * tg_xyyy_xz_0[j] + fr * tg_xyyy_xz_1[j] + 0.5 * fl1_fx * (tg_yyy_xz_0[j] - tg_yyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyy_z_1[j];

                    tg_xxyyy_yy_0[j] = pb_x * tg_xyyy_yy_0[j] + fr * tg_xyyy_yy_1[j] + 0.5 * fl1_fx * (tg_yyy_yy_0[j] - tg_yyy_yy_1[j] * fl1_fza);

                    tg_xxyyy_yz_0[j] = pb_x * tg_xyyy_yz_0[j] + fr * tg_xyyy_yz_1[j] + 0.5 * fl1_fx * (tg_yyy_yz_0[j] - tg_yyy_yz_1[j] * fl1_fza);

                    tg_xxyyy_zz_0[j] = pb_x * tg_xyyy_zz_0[j] + fr * tg_xyyy_zz_1[j] + 0.5 * fl1_fx * (tg_yyy_zz_0[j] - tg_yyy_zz_1[j] * fl1_fza);

                    tg_xxyyz_xx_0[j] = pb_x * tg_xyyz_xx_0[j] + fr * tg_xyyz_xx_1[j] + 0.5 * fl1_fx * (tg_yyz_xx_0[j] - tg_yyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyz_x_1[j];

                    tg_xxyyz_xy_0[j] = pb_x * tg_xyyz_xy_0[j] + fr * tg_xyyz_xy_1[j] + 0.5 * fl1_fx * (tg_yyz_xy_0[j] - tg_yyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyz_y_1[j];

                    tg_xxyyz_xz_0[j] = pb_x * tg_xyyz_xz_0[j] + fr * tg_xyyz_xz_1[j] + 0.5 * fl1_fx * (tg_yyz_xz_0[j] - tg_yyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyz_z_1[j];

                    tg_xxyyz_yy_0[j] = pb_x * tg_xyyz_yy_0[j] + fr * tg_xyyz_yy_1[j] + 0.5 * fl1_fx * (tg_yyz_yy_0[j] - tg_yyz_yy_1[j] * fl1_fza);

                    tg_xxyyz_yz_0[j] = pb_x * tg_xyyz_yz_0[j] + fr * tg_xyyz_yz_1[j] + 0.5 * fl1_fx * (tg_yyz_yz_0[j] - tg_yyz_yz_1[j] * fl1_fza);

                    tg_xxyyz_zz_0[j] = pb_x * tg_xyyz_zz_0[j] + fr * tg_xyyz_zz_1[j] + 0.5 * fl1_fx * (tg_yyz_zz_0[j] - tg_yyz_zz_1[j] * fl1_fza);

                    tg_xxyzz_xx_0[j] = pb_x * tg_xyzz_xx_0[j] + fr * tg_xyzz_xx_1[j] + 0.5 * fl1_fx * (tg_yzz_xx_0[j] - tg_yzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyzz_x_1[j];

                    tg_xxyzz_xy_0[j] = pb_x * tg_xyzz_xy_0[j] + fr * tg_xyzz_xy_1[j] + 0.5 * fl1_fx * (tg_yzz_xy_0[j] - tg_yzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzz_y_1[j];

                    tg_xxyzz_xz_0[j] = pb_x * tg_xyzz_xz_0[j] + fr * tg_xyzz_xz_1[j] + 0.5 * fl1_fx * (tg_yzz_xz_0[j] - tg_yzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzz_z_1[j];

                    tg_xxyzz_yy_0[j] = pb_x * tg_xyzz_yy_0[j] + fr * tg_xyzz_yy_1[j] + 0.5 * fl1_fx * (tg_yzz_yy_0[j] - tg_yzz_yy_1[j] * fl1_fza);

                    tg_xxyzz_yz_0[j] = pb_x * tg_xyzz_yz_0[j] + fr * tg_xyzz_yz_1[j] + 0.5 * fl1_fx * (tg_yzz_yz_0[j] - tg_yzz_yz_1[j] * fl1_fza);

                    tg_xxyzz_zz_0[j] = pb_x * tg_xyzz_zz_0[j] + fr * tg_xyzz_zz_1[j] + 0.5 * fl1_fx * (tg_yzz_zz_0[j] - tg_yzz_zz_1[j] * fl1_fza);

                    tg_xxzzz_xx_0[j] = pb_x * tg_xzzz_xx_0[j] + fr * tg_xzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzz_xx_0[j] - tg_zzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xzzz_x_1[j];

                    tg_xxzzz_xy_0[j] = pb_x * tg_xzzz_xy_0[j] + fr * tg_xzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzz_xy_0[j] - tg_zzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzz_y_1[j];

                    tg_xxzzz_xz_0[j] = pb_x * tg_xzzz_xz_0[j] + fr * tg_xzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzz_xz_0[j] - tg_zzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzz_z_1[j];

                    tg_xxzzz_yy_0[j] = pb_x * tg_xzzz_yy_0[j] + fr * tg_xzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzz_yy_0[j] - tg_zzz_yy_1[j] * fl1_fza);

                    tg_xxzzz_yz_0[j] = pb_x * tg_xzzz_yz_0[j] + fr * tg_xzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzz_yz_0[j] - tg_zzz_yz_1[j] * fl1_fza);

                    tg_xxzzz_zz_0[j] = pb_x * tg_xzzz_zz_0[j] + fr * tg_xzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzz_zz_0[j] - tg_zzz_zz_1[j] * fl1_fza);

                    tg_xyyyy_xx_0[j] = pb_x * tg_yyyy_xx_0[j] + fr * tg_yyyy_xx_1[j] + fl1_fxn * tg_yyyy_x_1[j];

                    tg_xyyyy_xy_0[j] = pb_x * tg_yyyy_xy_0[j] + fr * tg_yyyy_xy_1[j] + 0.5 * fl1_fxn * tg_yyyy_y_1[j];

                    tg_xyyyy_xz_0[j] = pb_x * tg_yyyy_xz_0[j] + fr * tg_yyyy_xz_1[j] + 0.5 * fl1_fxn * tg_yyyy_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSHSD_63_126(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (63,126)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {5, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_5_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_4_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_3_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_3_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {3, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 60); 

                auto tg_yyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 61); 

                auto tg_yyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 62); 

                auto tg_yyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 63); 

                auto tg_yyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 64); 

                auto tg_yyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 65); 

                auto tg_yyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 66); 

                auto tg_yyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 67); 

                auto tg_yyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 68); 

                auto tg_yyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 69); 

                auto tg_yyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 70); 

                auto tg_yyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 71); 

                auto tg_yyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 72); 

                auto tg_yyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 73); 

                auto tg_yyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 74); 

                auto tg_yyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 75); 

                auto tg_yyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 76); 

                auto tg_yyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 77); 

                auto tg_yzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 78); 

                auto tg_yzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 79); 

                auto tg_yzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 80); 

                auto tg_yzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 81); 

                auto tg_yzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 82); 

                auto tg_yzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 83); 

                auto tg_zzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 84); 

                auto tg_zzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 85); 

                auto tg_zzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 86); 

                auto tg_zzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 87); 

                auto tg_zzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 88); 

                auto tg_zzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 89); 

                auto tg_yyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 60); 

                auto tg_yyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 61); 

                auto tg_yyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 62); 

                auto tg_yyyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 63); 

                auto tg_yyyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 64); 

                auto tg_yyyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 65); 

                auto tg_yyyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 66); 

                auto tg_yyyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 67); 

                auto tg_yyyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 68); 

                auto tg_yyyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 69); 

                auto tg_yyyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 70); 

                auto tg_yyyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 71); 

                auto tg_yyzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 72); 

                auto tg_yyzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 73); 

                auto tg_yyzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 74); 

                auto tg_yyzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 75); 

                auto tg_yyzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 76); 

                auto tg_yyzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 77); 

                auto tg_yzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 78); 

                auto tg_yzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 79); 

                auto tg_yzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 80); 

                auto tg_yzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 81); 

                auto tg_yzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 82); 

                auto tg_yzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 83); 

                auto tg_zzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 84); 

                auto tg_zzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 85); 

                auto tg_zzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 86); 

                auto tg_zzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 87); 

                auto tg_zzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 88); 

                auto tg_zzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 89); 

                auto tg_yyy_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 36); 

                auto tg_yyy_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 37); 

                auto tg_yyy_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 38); 

                auto tg_yyy_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 39); 

                auto tg_yyy_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 40); 

                auto tg_yyy_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 41); 

                auto tg_yyz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 42); 

                auto tg_yyz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 43); 

                auto tg_yyz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 44); 

                auto tg_yyz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 45); 

                auto tg_yyz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 46); 

                auto tg_yyz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 47); 

                auto tg_yzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 48); 

                auto tg_yzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 49); 

                auto tg_yzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 50); 

                auto tg_yzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 51); 

                auto tg_yzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 52); 

                auto tg_yzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 53); 

                auto tg_zzz_xx_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 54); 

                auto tg_zzz_xy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 55); 

                auto tg_zzz_xz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 56); 

                auto tg_zzz_yy_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 57); 

                auto tg_zzz_yz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 58); 

                auto tg_zzz_zz_0 = primBuffer[pidx_g_3_2_m0].data(60 * idx + 59); 

                auto tg_yyy_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 36); 

                auto tg_yyy_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 37); 

                auto tg_yyy_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 38); 

                auto tg_yyy_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 39); 

                auto tg_yyy_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 40); 

                auto tg_yyy_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 41); 

                auto tg_yyz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 42); 

                auto tg_yyz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 43); 

                auto tg_yyz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 44); 

                auto tg_yyz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 45); 

                auto tg_yyz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 46); 

                auto tg_yyz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 47); 

                auto tg_yzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 48); 

                auto tg_yzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 49); 

                auto tg_yzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 50); 

                auto tg_yzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 51); 

                auto tg_yzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 52); 

                auto tg_yzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 53); 

                auto tg_zzz_xx_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 54); 

                auto tg_zzz_xy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 55); 

                auto tg_zzz_xz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 56); 

                auto tg_zzz_yy_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 57); 

                auto tg_zzz_yz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 58); 

                auto tg_zzz_zz_1 = primBuffer[pidx_g_3_2_m1].data(60 * idx + 59); 

                auto tg_yyyy_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 30); 

                auto tg_yyyy_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 31); 

                auto tg_yyyy_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 32); 

                auto tg_yyyz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 33); 

                auto tg_yyyz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 34); 

                auto tg_yyyz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 35); 

                auto tg_yyzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 36); 

                auto tg_yyzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 37); 

                auto tg_yyzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 38); 

                auto tg_yzzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 39); 

                auto tg_yzzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 40); 

                auto tg_yzzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 41); 

                auto tg_zzzz_x_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 42); 

                auto tg_zzzz_y_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 43); 

                auto tg_zzzz_z_1 = primBuffer[pidx_g_4_1_m1].data(45 * idx + 44); 

                // set up pointers to integrals

                auto tg_xyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 63); 

                auto tg_xyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 64); 

                auto tg_xyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 65); 

                auto tg_xyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 66); 

                auto tg_xyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 67); 

                auto tg_xyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 68); 

                auto tg_xyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 69); 

                auto tg_xyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 70); 

                auto tg_xyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 71); 

                auto tg_xyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 72); 

                auto tg_xyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 73); 

                auto tg_xyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 74); 

                auto tg_xyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 75); 

                auto tg_xyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 76); 

                auto tg_xyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 77); 

                auto tg_xyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 78); 

                auto tg_xyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 79); 

                auto tg_xyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 80); 

                auto tg_xyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 81); 

                auto tg_xyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 82); 

                auto tg_xyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 83); 

                auto tg_xzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 84); 

                auto tg_xzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 85); 

                auto tg_xzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 86); 

                auto tg_xzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 87); 

                auto tg_xzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 88); 

                auto tg_xzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 89); 

                auto tg_yyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 90); 

                auto tg_yyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 91); 

                auto tg_yyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 92); 

                auto tg_yyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 93); 

                auto tg_yyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 94); 

                auto tg_yyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 95); 

                auto tg_yyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 96); 

                auto tg_yyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 97); 

                auto tg_yyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 98); 

                auto tg_yyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 99); 

                auto tg_yyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 100); 

                auto tg_yyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 101); 

                auto tg_yyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 102); 

                auto tg_yyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 103); 

                auto tg_yyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 104); 

                auto tg_yyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 105); 

                auto tg_yyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 106); 

                auto tg_yyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 107); 

                auto tg_yyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 108); 

                auto tg_yyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 109); 

                auto tg_yyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 110); 

                auto tg_yyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 111); 

                auto tg_yyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 112); 

                auto tg_yyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 113); 

                auto tg_yzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 114); 

                auto tg_yzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 115); 

                auto tg_yzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 116); 

                auto tg_yzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 117); 

                auto tg_yzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 118); 

                auto tg_yzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 119); 

                auto tg_zzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 120); 

                auto tg_zzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 121); 

                auto tg_zzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 122); 

                auto tg_zzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 123); 

                auto tg_zzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 124); 

                auto tg_zzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 125); 

                // Batch of Integrals (63,126)

                #pragma omp simd aligned(fxn, fza, tg_xyyyy_yy_0, tg_xyyyy_yz_0, tg_xyyyy_zz_0, tg_xyyyz_xx_0, \
                                         tg_xyyyz_xy_0, tg_xyyyz_xz_0, tg_xyyyz_yy_0, tg_xyyyz_yz_0, tg_xyyyz_zz_0, \
                                         tg_xyyzz_xx_0, tg_xyyzz_xy_0, tg_xyyzz_xz_0, tg_xyyzz_yy_0, tg_xyyzz_yz_0, \
                                         tg_xyyzz_zz_0, tg_xyzzz_xx_0, tg_xyzzz_xy_0, tg_xyzzz_xz_0, tg_xyzzz_yy_0, \
                                         tg_xyzzz_yz_0, tg_xyzzz_zz_0, tg_xzzzz_xx_0, tg_xzzzz_xy_0, tg_xzzzz_xz_0, \
                                         tg_xzzzz_yy_0, tg_xzzzz_yz_0, tg_xzzzz_zz_0, tg_yyy_xx_0, tg_yyy_xx_1, tg_yyy_xy_0, \
                                         tg_yyy_xy_1, tg_yyy_xz_0, tg_yyy_xz_1, tg_yyy_yy_0, tg_yyy_yy_1, tg_yyy_yz_0, \
                                         tg_yyy_yz_1, tg_yyy_zz_0, tg_yyy_zz_1, tg_yyyy_x_1, tg_yyyy_xx_0, tg_yyyy_xx_1, \
                                         tg_yyyy_xy_0, tg_yyyy_xy_1, tg_yyyy_xz_0, tg_yyyy_xz_1, tg_yyyy_y_1, tg_yyyy_yy_0, \
                                         tg_yyyy_yy_1, tg_yyyy_yz_0, tg_yyyy_yz_1, tg_yyyy_z_1, tg_yyyy_zz_0, tg_yyyy_zz_1, \
                                         tg_yyyyy_xx_0, tg_yyyyy_xy_0, tg_yyyyy_xz_0, tg_yyyyy_yy_0, tg_yyyyy_yz_0, \
                                         tg_yyyyy_zz_0, tg_yyyyz_xx_0, tg_yyyyz_xy_0, tg_yyyyz_xz_0, tg_yyyyz_yy_0, \
                                         tg_yyyyz_yz_0, tg_yyyyz_zz_0, tg_yyyz_x_1, tg_yyyz_xx_0, tg_yyyz_xx_1, tg_yyyz_xy_0, \
                                         tg_yyyz_xy_1, tg_yyyz_xz_0, tg_yyyz_xz_1, tg_yyyz_y_1, tg_yyyz_yy_0, tg_yyyz_yy_1, \
                                         tg_yyyz_yz_0, tg_yyyz_yz_1, tg_yyyz_z_1, tg_yyyz_zz_0, tg_yyyz_zz_1, tg_yyyzz_xx_0, \
                                         tg_yyyzz_xy_0, tg_yyyzz_xz_0, tg_yyyzz_yy_0, tg_yyyzz_yz_0, tg_yyyzz_zz_0, \
                                         tg_yyz_xx_0, tg_yyz_xx_1, tg_yyz_xy_0, tg_yyz_xy_1, tg_yyz_xz_0, tg_yyz_xz_1, \
                                         tg_yyz_yy_0, tg_yyz_yy_1, tg_yyz_yz_0, tg_yyz_yz_1, tg_yyz_zz_0, tg_yyz_zz_1, \
                                         tg_yyzz_x_1, tg_yyzz_xx_0, tg_yyzz_xx_1, tg_yyzz_xy_0, tg_yyzz_xy_1, tg_yyzz_xz_0, \
                                         tg_yyzz_xz_1, tg_yyzz_y_1, tg_yyzz_yy_0, tg_yyzz_yy_1, tg_yyzz_yz_0, tg_yyzz_yz_1, \
                                         tg_yyzz_z_1, tg_yyzz_zz_0, tg_yyzz_zz_1, tg_yyzzz_xx_0, tg_yyzzz_xy_0, \
                                         tg_yyzzz_xz_0, tg_yyzzz_yy_0, tg_yyzzz_yz_0, tg_yyzzz_zz_0, tg_yzz_xx_0, \
                                         tg_yzz_xx_1, tg_yzz_xy_0, tg_yzz_xy_1, tg_yzz_xz_0, tg_yzz_xz_1, tg_yzz_yy_0, \
                                         tg_yzz_yy_1, tg_yzz_yz_0, tg_yzz_yz_1, tg_yzz_zz_0, tg_yzz_zz_1, tg_yzzz_x_1, \
                                         tg_yzzz_xx_0, tg_yzzz_xx_1, tg_yzzz_xy_0, tg_yzzz_xy_1, tg_yzzz_xz_0, tg_yzzz_xz_1, \
                                         tg_yzzz_y_1, tg_yzzz_yy_0, tg_yzzz_yy_1, tg_yzzz_yz_0, tg_yzzz_yz_1, tg_yzzz_z_1, \
                                         tg_yzzz_zz_0, tg_yzzz_zz_1, tg_yzzzz_xx_0, tg_yzzzz_xy_0, tg_yzzzz_xz_0, \
                                         tg_yzzzz_yy_0, tg_yzzzz_yz_0, tg_yzzzz_zz_0, tg_zzz_xx_0, tg_zzz_xx_1, tg_zzz_xy_0, \
                                         tg_zzz_xy_1, tg_zzz_xz_0, tg_zzz_xz_1, tg_zzz_yy_0, tg_zzz_yy_1, tg_zzz_yz_0, \
                                         tg_zzz_yz_1, tg_zzz_zz_0, tg_zzz_zz_1, tg_zzzz_x_1, tg_zzzz_xx_0, tg_zzzz_xx_1, \
                                         tg_zzzz_xy_0, tg_zzzz_xy_1, tg_zzzz_xz_0, tg_zzzz_xz_1, tg_zzzz_y_1, tg_zzzz_yy_0, \
                                         tg_zzzz_yy_1, tg_zzzz_yz_0, tg_zzzz_yz_1, tg_zzzz_z_1, tg_zzzz_zz_0, tg_zzzz_zz_1, \
                                         tg_zzzzz_xx_0, tg_zzzzz_xy_0, tg_zzzzz_xz_0, tg_zzzzz_yy_0, tg_zzzzz_yz_0, \
                                         tg_zzzzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xyyyy_yy_0[j] = pb_x * tg_yyyy_yy_0[j] + fr * tg_yyyy_yy_1[j];

                    tg_xyyyy_yz_0[j] = pb_x * tg_yyyy_yz_0[j] + fr * tg_yyyy_yz_1[j];

                    tg_xyyyy_zz_0[j] = pb_x * tg_yyyy_zz_0[j] + fr * tg_yyyy_zz_1[j];

                    tg_xyyyz_xx_0[j] = pb_x * tg_yyyz_xx_0[j] + fr * tg_yyyz_xx_1[j] + fl1_fxn * tg_yyyz_x_1[j];

                    tg_xyyyz_xy_0[j] = pb_x * tg_yyyz_xy_0[j] + fr * tg_yyyz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyz_y_1[j];

                    tg_xyyyz_xz_0[j] = pb_x * tg_yyyz_xz_0[j] + fr * tg_yyyz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyz_z_1[j];

                    tg_xyyyz_yy_0[j] = pb_x * tg_yyyz_yy_0[j] + fr * tg_yyyz_yy_1[j];

                    tg_xyyyz_yz_0[j] = pb_x * tg_yyyz_yz_0[j] + fr * tg_yyyz_yz_1[j];

                    tg_xyyyz_zz_0[j] = pb_x * tg_yyyz_zz_0[j] + fr * tg_yyyz_zz_1[j];

                    tg_xyyzz_xx_0[j] = pb_x * tg_yyzz_xx_0[j] + fr * tg_yyzz_xx_1[j] + fl1_fxn * tg_yyzz_x_1[j];

                    tg_xyyzz_xy_0[j] = pb_x * tg_yyzz_xy_0[j] + fr * tg_yyzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyzz_y_1[j];

                    tg_xyyzz_xz_0[j] = pb_x * tg_yyzz_xz_0[j] + fr * tg_yyzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyzz_z_1[j];

                    tg_xyyzz_yy_0[j] = pb_x * tg_yyzz_yy_0[j] + fr * tg_yyzz_yy_1[j];

                    tg_xyyzz_yz_0[j] = pb_x * tg_yyzz_yz_0[j] + fr * tg_yyzz_yz_1[j];

                    tg_xyyzz_zz_0[j] = pb_x * tg_yyzz_zz_0[j] + fr * tg_yyzz_zz_1[j];

                    tg_xyzzz_xx_0[j] = pb_x * tg_yzzz_xx_0[j] + fr * tg_yzzz_xx_1[j] + fl1_fxn * tg_yzzz_x_1[j];

                    tg_xyzzz_xy_0[j] = pb_x * tg_yzzz_xy_0[j] + fr * tg_yzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yzzz_y_1[j];

                    tg_xyzzz_xz_0[j] = pb_x * tg_yzzz_xz_0[j] + fr * tg_yzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yzzz_z_1[j];

                    tg_xyzzz_yy_0[j] = pb_x * tg_yzzz_yy_0[j] + fr * tg_yzzz_yy_1[j];

                    tg_xyzzz_yz_0[j] = pb_x * tg_yzzz_yz_0[j] + fr * tg_yzzz_yz_1[j];

                    tg_xyzzz_zz_0[j] = pb_x * tg_yzzz_zz_0[j] + fr * tg_yzzz_zz_1[j];

                    tg_xzzzz_xx_0[j] = pb_x * tg_zzzz_xx_0[j] + fr * tg_zzzz_xx_1[j] + fl1_fxn * tg_zzzz_x_1[j];

                    tg_xzzzz_xy_0[j] = pb_x * tg_zzzz_xy_0[j] + fr * tg_zzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzz_y_1[j];

                    tg_xzzzz_xz_0[j] = pb_x * tg_zzzz_xz_0[j] + fr * tg_zzzz_xz_1[j] + 0.5 * fl1_fxn * tg_zzzz_z_1[j];

                    tg_xzzzz_yy_0[j] = pb_x * tg_zzzz_yy_0[j] + fr * tg_zzzz_yy_1[j];

                    tg_xzzzz_yz_0[j] = pb_x * tg_zzzz_yz_0[j] + fr * tg_zzzz_yz_1[j];

                    tg_xzzzz_zz_0[j] = pb_x * tg_zzzz_zz_0[j] + fr * tg_zzzz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyy_xx_0[j] = pb_y * tg_yyyy_xx_0[j] + fr * tg_yyyy_xx_1[j] + 2.0 * fl1_fx * (tg_yyy_xx_0[j] - tg_yyy_xx_1[j] * fl1_fza);

                    tg_yyyyy_xy_0[j] = pb_y * tg_yyyy_xy_0[j] + fr * tg_yyyy_xy_1[j] + 2.0 * fl1_fx * (tg_yyy_xy_0[j] - tg_yyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyy_x_1[j];

                    tg_yyyyy_xz_0[j] = pb_y * tg_yyyy_xz_0[j] + fr * tg_yyyy_xz_1[j] + 2.0 * fl1_fx * (tg_yyy_xz_0[j] - tg_yyy_xz_1[j] * fl1_fza);

                    tg_yyyyy_yy_0[j] = pb_y * tg_yyyy_yy_0[j] + fr * tg_yyyy_yy_1[j] + 2.0 * fl1_fx * (tg_yyy_yy_0[j] - tg_yyy_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyy_y_1[j];

                    tg_yyyyy_yz_0[j] = pb_y * tg_yyyy_yz_0[j] + fr * tg_yyyy_yz_1[j] + 2.0 * fl1_fx * (tg_yyy_yz_0[j] - tg_yyy_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyy_z_1[j];

                    tg_yyyyy_zz_0[j] = pb_y * tg_yyyy_zz_0[j] + fr * tg_yyyy_zz_1[j] + 2.0 * fl1_fx * (tg_yyy_zz_0[j] - tg_yyy_zz_1[j] * fl1_fza);

                    tg_yyyyz_xx_0[j] = pb_y * tg_yyyz_xx_0[j] + fr * tg_yyyz_xx_1[j] + 1.5 * fl1_fx * (tg_yyz_xx_0[j] - tg_yyz_xx_1[j] * fl1_fza);

                    tg_yyyyz_xy_0[j] = pb_y * tg_yyyz_xy_0[j] + fr * tg_yyyz_xy_1[j] + 1.5 * fl1_fx * (tg_yyz_xy_0[j] - tg_yyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyz_x_1[j];

                    tg_yyyyz_xz_0[j] = pb_y * tg_yyyz_xz_0[j] + fr * tg_yyyz_xz_1[j] + 1.5 * fl1_fx * (tg_yyz_xz_0[j] - tg_yyz_xz_1[j] * fl1_fza);

                    tg_yyyyz_yy_0[j] = pb_y * tg_yyyz_yy_0[j] + fr * tg_yyyz_yy_1[j] + 1.5 * fl1_fx * (tg_yyz_yy_0[j] - tg_yyz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyz_y_1[j];

                    tg_yyyyz_yz_0[j] = pb_y * tg_yyyz_yz_0[j] + fr * tg_yyyz_yz_1[j] + 1.5 * fl1_fx * (tg_yyz_yz_0[j] - tg_yyz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyz_z_1[j];

                    tg_yyyyz_zz_0[j] = pb_y * tg_yyyz_zz_0[j] + fr * tg_yyyz_zz_1[j] + 1.5 * fl1_fx * (tg_yyz_zz_0[j] - tg_yyz_zz_1[j] * fl1_fza);

                    tg_yyyzz_xx_0[j] = pb_y * tg_yyzz_xx_0[j] + fr * tg_yyzz_xx_1[j] + fl1_fx * (tg_yzz_xx_0[j] - tg_yzz_xx_1[j] * fl1_fza);

                    tg_yyyzz_xy_0[j] = pb_y * tg_yyzz_xy_0[j] + fr * tg_yyzz_xy_1[j] + fl1_fx * (tg_yzz_xy_0[j] - tg_yzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzz_x_1[j];

                    tg_yyyzz_xz_0[j] = pb_y * tg_yyzz_xz_0[j] + fr * tg_yyzz_xz_1[j] + fl1_fx * (tg_yzz_xz_0[j] - tg_yzz_xz_1[j] * fl1_fza);

                    tg_yyyzz_yy_0[j] = pb_y * tg_yyzz_yy_0[j] + fr * tg_yyzz_yy_1[j] + fl1_fx * (tg_yzz_yy_0[j] - tg_yzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyzz_y_1[j];

                    tg_yyyzz_yz_0[j] = pb_y * tg_yyzz_yz_0[j] + fr * tg_yyzz_yz_1[j] + fl1_fx * (tg_yzz_yz_0[j] - tg_yzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzz_z_1[j];

                    tg_yyyzz_zz_0[j] = pb_y * tg_yyzz_zz_0[j] + fr * tg_yyzz_zz_1[j] + fl1_fx * (tg_yzz_zz_0[j] - tg_yzz_zz_1[j] * fl1_fza);

                    tg_yyzzz_xx_0[j] = pb_y * tg_yzzz_xx_0[j] + fr * tg_yzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzz_xx_0[j] - tg_zzz_xx_1[j] * fl1_fza);

                    tg_yyzzz_xy_0[j] = pb_y * tg_yzzz_xy_0[j] + fr * tg_yzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzz_xy_0[j] - tg_zzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzz_x_1[j];

                    tg_yyzzz_xz_0[j] = pb_y * tg_yzzz_xz_0[j] + fr * tg_yzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzz_xz_0[j] - tg_zzz_xz_1[j] * fl1_fza);

                    tg_yyzzz_yy_0[j] = pb_y * tg_yzzz_yy_0[j] + fr * tg_yzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzz_yy_0[j] - tg_zzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yzzz_y_1[j];

                    tg_yyzzz_yz_0[j] = pb_y * tg_yzzz_yz_0[j] + fr * tg_yzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzz_yz_0[j] - tg_zzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzz_z_1[j];

                    tg_yyzzz_zz_0[j] = pb_y * tg_yzzz_zz_0[j] + fr * tg_yzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzz_zz_0[j] - tg_zzz_zz_1[j] * fl1_fza);

                    tg_yzzzz_xx_0[j] = pb_y * tg_zzzz_xx_0[j] + fr * tg_zzzz_xx_1[j];

                    tg_yzzzz_xy_0[j] = pb_y * tg_zzzz_xy_0[j] + fr * tg_zzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzz_x_1[j];

                    tg_yzzzz_xz_0[j] = pb_y * tg_zzzz_xz_0[j] + fr * tg_zzzz_xz_1[j];

                    tg_yzzzz_yy_0[j] = pb_y * tg_zzzz_yy_0[j] + fr * tg_zzzz_yy_1[j] + fl1_fxn * tg_zzzz_y_1[j];

                    tg_yzzzz_yz_0[j] = pb_y * tg_zzzz_yz_0[j] + fr * tg_zzzz_yz_1[j] + 0.5 * fl1_fxn * tg_zzzz_z_1[j];

                    tg_yzzzz_zz_0[j] = pb_y * tg_zzzz_zz_0[j] + fr * tg_zzzz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzz_xx_0[j] = pb_z * tg_zzzz_xx_0[j] + fr * tg_zzzz_xx_1[j] + 2.0 * fl1_fx * (tg_zzz_xx_0[j] - tg_zzz_xx_1[j] * fl1_fza);

                    tg_zzzzz_xy_0[j] = pb_z * tg_zzzz_xy_0[j] + fr * tg_zzzz_xy_1[j] + 2.0 * fl1_fx * (tg_zzz_xy_0[j] - tg_zzz_xy_1[j] * fl1_fza);

                    tg_zzzzz_xz_0[j] = pb_z * tg_zzzz_xz_0[j] + fr * tg_zzzz_xz_1[j] + 2.0 * fl1_fx * (tg_zzz_xz_0[j] - tg_zzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzz_x_1[j];

                    tg_zzzzz_yy_0[j] = pb_z * tg_zzzz_yy_0[j] + fr * tg_zzzz_yy_1[j] + 2.0 * fl1_fx * (tg_zzz_yy_0[j] - tg_zzz_yy_1[j] * fl1_fza);

                    tg_zzzzz_yz_0[j] = pb_z * tg_zzzz_yz_0[j] + fr * tg_zzzz_yz_1[j] + 2.0 * fl1_fx * (tg_zzz_yz_0[j] - tg_zzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzz_y_1[j];

                    tg_zzzzz_zz_0[j] = pb_z * tg_zzzz_zz_0[j] + fr * tg_zzzz_zz_1[j] + 2.0 * fl1_fx * (tg_zzz_zz_0[j] - tg_zzz_zz_1[j] * fl1_fza) + fl1_fxn * tg_zzzz_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSI(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSDSI_0_84(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSDSI_84_168(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 
    }

    void
    compElectronRepulsionForSDSI_0_84(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,84)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_x_xxxxxx_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx); 

                auto tg_x_xxxxxy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 1); 

                auto tg_x_xxxxxz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 2); 

                auto tg_x_xxxxyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 3); 

                auto tg_x_xxxxyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 4); 

                auto tg_x_xxxxzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 5); 

                auto tg_x_xxxyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 6); 

                auto tg_x_xxxyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 7); 

                auto tg_x_xxxyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 8); 

                auto tg_x_xxxzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 9); 

                auto tg_x_xxyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 10); 

                auto tg_x_xxyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 11); 

                auto tg_x_xxyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 12); 

                auto tg_x_xxyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 13); 

                auto tg_x_xxzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 14); 

                auto tg_x_xyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 15); 

                auto tg_x_xyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 16); 

                auto tg_x_xyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 17); 

                auto tg_x_xyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 18); 

                auto tg_x_xyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 19); 

                auto tg_x_xzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 20); 

                auto tg_x_yyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 21); 

                auto tg_x_yyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 22); 

                auto tg_x_yyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 23); 

                auto tg_x_yyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 24); 

                auto tg_x_yyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 25); 

                auto tg_x_yzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 26); 

                auto tg_x_zzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 27); 

                auto tg_y_xxxxxx_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 28); 

                auto tg_y_xxxxxy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 29); 

                auto tg_y_xxxxxz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 30); 

                auto tg_y_xxxxyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 31); 

                auto tg_y_xxxxyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 32); 

                auto tg_y_xxxxzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 33); 

                auto tg_y_xxxyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 34); 

                auto tg_y_xxxyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 35); 

                auto tg_y_xxxyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 36); 

                auto tg_y_xxxzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 37); 

                auto tg_y_xxyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 38); 

                auto tg_y_xxyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 39); 

                auto tg_y_xxyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 40); 

                auto tg_y_xxyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 41); 

                auto tg_y_xxzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 42); 

                auto tg_y_xyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 43); 

                auto tg_y_xyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 44); 

                auto tg_y_xyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 45); 

                auto tg_y_xyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 46); 

                auto tg_y_xyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 47); 

                auto tg_y_xzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 48); 

                auto tg_y_yyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 49); 

                auto tg_y_yyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 50); 

                auto tg_y_yyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 51); 

                auto tg_y_yyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 52); 

                auto tg_y_yyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 53); 

                auto tg_y_yzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 54); 

                auto tg_y_zzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 55); 

                auto tg_z_xxxxxx_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 56); 

                auto tg_z_xxxxxy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 57); 

                auto tg_z_xxxxxz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 58); 

                auto tg_z_xxxxyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 59); 

                auto tg_z_xxxxyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 60); 

                auto tg_z_xxxxzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 61); 

                auto tg_z_xxxyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 62); 

                auto tg_z_xxxyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 63); 

                auto tg_z_xxxyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 64); 

                auto tg_z_xxxzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 65); 

                auto tg_z_xxyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 66); 

                auto tg_z_xxyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 67); 

                auto tg_z_xxyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 68); 

                auto tg_z_xxyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 69); 

                auto tg_z_xxzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 70); 

                auto tg_z_xyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 71); 

                auto tg_z_xyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 72); 

                auto tg_z_xyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 73); 

                auto tg_z_xyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 74); 

                auto tg_z_xyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 75); 

                auto tg_z_xzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 76); 

                auto tg_z_yyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 77); 

                auto tg_z_yyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 78); 

                auto tg_z_yyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 79); 

                auto tg_z_yyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 80); 

                auto tg_z_yyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 81); 

                auto tg_z_yzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 82); 

                auto tg_z_zzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 83); 

                auto tg_x_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx); 

                auto tg_x_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 1); 

                auto tg_x_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 2); 

                auto tg_x_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 3); 

                auto tg_x_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 4); 

                auto tg_x_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 5); 

                auto tg_x_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 6); 

                auto tg_x_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 7); 

                auto tg_x_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 8); 

                auto tg_x_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 9); 

                auto tg_x_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 10); 

                auto tg_x_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 11); 

                auto tg_x_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 12); 

                auto tg_x_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 13); 

                auto tg_x_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 14); 

                auto tg_x_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 15); 

                auto tg_x_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 16); 

                auto tg_x_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 17); 

                auto tg_x_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 18); 

                auto tg_x_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 19); 

                auto tg_x_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 20); 

                auto tg_x_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 21); 

                auto tg_x_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 22); 

                auto tg_x_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 23); 

                auto tg_x_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 24); 

                auto tg_x_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 25); 

                auto tg_x_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 26); 

                auto tg_x_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 27); 

                auto tg_y_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 28); 

                auto tg_y_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 29); 

                auto tg_y_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 30); 

                auto tg_y_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 31); 

                auto tg_y_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 32); 

                auto tg_y_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 33); 

                auto tg_y_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 34); 

                auto tg_y_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 35); 

                auto tg_y_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 36); 

                auto tg_y_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 37); 

                auto tg_y_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 38); 

                auto tg_y_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 39); 

                auto tg_y_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 40); 

                auto tg_y_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 41); 

                auto tg_y_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 42); 

                auto tg_y_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 43); 

                auto tg_y_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 44); 

                auto tg_y_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 45); 

                auto tg_y_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 46); 

                auto tg_y_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 47); 

                auto tg_y_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 48); 

                auto tg_y_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 49); 

                auto tg_y_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 50); 

                auto tg_y_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 51); 

                auto tg_y_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 52); 

                auto tg_y_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 53); 

                auto tg_y_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 54); 

                auto tg_y_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 55); 

                auto tg_z_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 56); 

                auto tg_z_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 57); 

                auto tg_z_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 58); 

                auto tg_z_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 59); 

                auto tg_z_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 60); 

                auto tg_z_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 61); 

                auto tg_z_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 62); 

                auto tg_z_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 63); 

                auto tg_z_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 64); 

                auto tg_z_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 65); 

                auto tg_z_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 66); 

                auto tg_z_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 67); 

                auto tg_z_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 68); 

                auto tg_z_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 69); 

                auto tg_z_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 70); 

                auto tg_z_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 71); 

                auto tg_z_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 72); 

                auto tg_z_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 73); 

                auto tg_z_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 74); 

                auto tg_z_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 75); 

                auto tg_z_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 76); 

                auto tg_z_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 77); 

                auto tg_z_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 78); 

                auto tg_z_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 79); 

                auto tg_z_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 80); 

                auto tg_z_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 81); 

                auto tg_z_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 82); 

                auto tg_z_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 83); 

                auto tg_0_xxxxxx_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx); 

                auto tg_0_xxxxxy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 1); 

                auto tg_0_xxxxxz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 2); 

                auto tg_0_xxxxyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 3); 

                auto tg_0_xxxxyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 4); 

                auto tg_0_xxxxzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 5); 

                auto tg_0_xxxyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 6); 

                auto tg_0_xxxyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 7); 

                auto tg_0_xxxyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 8); 

                auto tg_0_xxxzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 9); 

                auto tg_0_xxyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 10); 

                auto tg_0_xxyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 11); 

                auto tg_0_xxyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 12); 

                auto tg_0_xxyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 13); 

                auto tg_0_xxzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 14); 

                auto tg_0_xyyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 15); 

                auto tg_0_xyyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 16); 

                auto tg_0_xyyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 17); 

                auto tg_0_xyyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 18); 

                auto tg_0_xyzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 19); 

                auto tg_0_xzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 20); 

                auto tg_0_yyyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 21); 

                auto tg_0_yyyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 22); 

                auto tg_0_yyyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 23); 

                auto tg_0_yyyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 24); 

                auto tg_0_yyzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 25); 

                auto tg_0_yzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 26); 

                auto tg_0_zzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 27); 

                auto tg_0_xxxxxx_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx); 

                auto tg_0_xxxxxy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 1); 

                auto tg_0_xxxxxz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 2); 

                auto tg_0_xxxxyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 3); 

                auto tg_0_xxxxyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 4); 

                auto tg_0_xxxxzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 5); 

                auto tg_0_xxxyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 6); 

                auto tg_0_xxxyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 7); 

                auto tg_0_xxxyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 8); 

                auto tg_0_xxxzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 9); 

                auto tg_0_xxyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 10); 

                auto tg_0_xxyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 11); 

                auto tg_0_xxyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 12); 

                auto tg_0_xxyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 13); 

                auto tg_0_xxzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 14); 

                auto tg_0_xyyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 15); 

                auto tg_0_xyyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 16); 

                auto tg_0_xyyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 17); 

                auto tg_0_xyyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 18); 

                auto tg_0_xyzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 19); 

                auto tg_0_xzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 20); 

                auto tg_0_yyyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 21); 

                auto tg_0_yyyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 22); 

                auto tg_0_yyyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 23); 

                auto tg_0_yyyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 24); 

                auto tg_0_yyzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 25); 

                auto tg_0_yzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 26); 

                auto tg_0_zzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 27); 

                auto tg_x_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx); 

                auto tg_x_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 1); 

                auto tg_x_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 2); 

                auto tg_x_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 3); 

                auto tg_x_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 4); 

                auto tg_x_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 5); 

                auto tg_x_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 6); 

                auto tg_x_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 7); 

                auto tg_x_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 8); 

                auto tg_x_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 9); 

                auto tg_x_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 10); 

                auto tg_x_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 11); 

                auto tg_x_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 12); 

                auto tg_x_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 13); 

                auto tg_x_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 14); 

                auto tg_x_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 15); 

                auto tg_x_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 16); 

                auto tg_x_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 17); 

                auto tg_x_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 18); 

                auto tg_x_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 19); 

                auto tg_x_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 20); 

                auto tg_y_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 21); 

                auto tg_y_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 22); 

                auto tg_y_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 23); 

                auto tg_y_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 24); 

                auto tg_y_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 25); 

                auto tg_y_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 26); 

                auto tg_y_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 27); 

                auto tg_y_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 28); 

                auto tg_y_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 29); 

                auto tg_y_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 30); 

                auto tg_y_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 31); 

                auto tg_y_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 32); 

                auto tg_y_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 33); 

                auto tg_y_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 34); 

                auto tg_y_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 35); 

                auto tg_y_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 36); 

                auto tg_y_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 37); 

                auto tg_y_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 38); 

                auto tg_y_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 39); 

                auto tg_y_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 40); 

                auto tg_y_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 41); 

                auto tg_z_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 42); 

                auto tg_z_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 43); 

                auto tg_z_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 44); 

                auto tg_z_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 45); 

                auto tg_z_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 46); 

                auto tg_z_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 47); 

                auto tg_z_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 48); 

                auto tg_z_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 49); 

                auto tg_z_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 50); 

                auto tg_z_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 51); 

                auto tg_z_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 52); 

                auto tg_z_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 53); 

                auto tg_z_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 54); 

                auto tg_z_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 55); 

                auto tg_z_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 56); 

                auto tg_z_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 57); 

                auto tg_z_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 58); 

                auto tg_z_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 59); 

                auto tg_z_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 60); 

                auto tg_z_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 61); 

                auto tg_z_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 62); 

                // set up pointers to integrals

                auto tg_xx_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx); 

                auto tg_xx_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 1); 

                auto tg_xx_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 2); 

                auto tg_xx_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 3); 

                auto tg_xx_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 4); 

                auto tg_xx_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 5); 

                auto tg_xx_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 6); 

                auto tg_xx_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 7); 

                auto tg_xx_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 8); 

                auto tg_xx_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 9); 

                auto tg_xx_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 10); 

                auto tg_xx_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 11); 

                auto tg_xx_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 12); 

                auto tg_xx_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 13); 

                auto tg_xx_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 14); 

                auto tg_xx_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 15); 

                auto tg_xx_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 16); 

                auto tg_xx_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 17); 

                auto tg_xx_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 18); 

                auto tg_xx_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 19); 

                auto tg_xx_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 20); 

                auto tg_xx_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 21); 

                auto tg_xx_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 22); 

                auto tg_xx_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 23); 

                auto tg_xx_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 24); 

                auto tg_xx_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 25); 

                auto tg_xx_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 26); 

                auto tg_xx_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 27); 

                auto tg_xy_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 28); 

                auto tg_xy_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 29); 

                auto tg_xy_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 30); 

                auto tg_xy_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 31); 

                auto tg_xy_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 32); 

                auto tg_xy_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 33); 

                auto tg_xy_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 34); 

                auto tg_xy_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 35); 

                auto tg_xy_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 36); 

                auto tg_xy_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 37); 

                auto tg_xy_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 38); 

                auto tg_xy_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 39); 

                auto tg_xy_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 40); 

                auto tg_xy_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 41); 

                auto tg_xy_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 42); 

                auto tg_xy_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 43); 

                auto tg_xy_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 44); 

                auto tg_xy_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 45); 

                auto tg_xy_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 46); 

                auto tg_xy_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 47); 

                auto tg_xy_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 48); 

                auto tg_xy_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 49); 

                auto tg_xy_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 50); 

                auto tg_xy_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 51); 

                auto tg_xy_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 52); 

                auto tg_xy_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 53); 

                auto tg_xy_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 54); 

                auto tg_xy_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 55); 

                auto tg_xz_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 56); 

                auto tg_xz_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 57); 

                auto tg_xz_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 58); 

                auto tg_xz_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 59); 

                auto tg_xz_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 60); 

                auto tg_xz_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 61); 

                auto tg_xz_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 62); 

                auto tg_xz_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 63); 

                auto tg_xz_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 64); 

                auto tg_xz_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 65); 

                auto tg_xz_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 66); 

                auto tg_xz_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 67); 

                auto tg_xz_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 68); 

                auto tg_xz_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 69); 

                auto tg_xz_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 70); 

                auto tg_xz_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 71); 

                auto tg_xz_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 72); 

                auto tg_xz_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 73); 

                auto tg_xz_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 74); 

                auto tg_xz_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 75); 

                auto tg_xz_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 76); 

                auto tg_xz_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 77); 

                auto tg_xz_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 78); 

                auto tg_xz_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 79); 

                auto tg_xz_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 80); 

                auto tg_xz_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 81); 

                auto tg_xz_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 82); 

                auto tg_xz_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 83); 

                // Batch of Integrals (0,84)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxx_0, tg_0_xxxxxx_1, tg_0_xxxxxy_0, tg_0_xxxxxy_1, \
                                         tg_0_xxxxxz_0, tg_0_xxxxxz_1, tg_0_xxxxyy_0, tg_0_xxxxyy_1, tg_0_xxxxyz_0, \
                                         tg_0_xxxxyz_1, tg_0_xxxxzz_0, tg_0_xxxxzz_1, tg_0_xxxyyy_0, tg_0_xxxyyy_1, \
                                         tg_0_xxxyyz_0, tg_0_xxxyyz_1, tg_0_xxxyzz_0, tg_0_xxxyzz_1, tg_0_xxxzzz_0, \
                                         tg_0_xxxzzz_1, tg_0_xxyyyy_0, tg_0_xxyyyy_1, tg_0_xxyyyz_0, tg_0_xxyyyz_1, \
                                         tg_0_xxyyzz_0, tg_0_xxyyzz_1, tg_0_xxyzzz_0, tg_0_xxyzzz_1, tg_0_xxzzzz_0, \
                                         tg_0_xxzzzz_1, tg_0_xyyyyy_0, tg_0_xyyyyy_1, tg_0_xyyyyz_0, tg_0_xyyyyz_1, \
                                         tg_0_xyyyzz_0, tg_0_xyyyzz_1, tg_0_xyyzzz_0, tg_0_xyyzzz_1, tg_0_xyzzzz_0, \
                                         tg_0_xyzzzz_1, tg_0_xzzzzz_0, tg_0_xzzzzz_1, tg_0_yyyyyy_0, tg_0_yyyyyy_1, \
                                         tg_0_yyyyyz_0, tg_0_yyyyyz_1, tg_0_yyyyzz_0, tg_0_yyyyzz_1, tg_0_yyyzzz_0, \
                                         tg_0_yyyzzz_1, tg_0_yyzzzz_0, tg_0_yyzzzz_1, tg_0_yzzzzz_0, tg_0_yzzzzz_1, \
                                         tg_0_zzzzzz_0, tg_0_zzzzzz_1, tg_x_xxxxx_1, tg_x_xxxxxx_0, tg_x_xxxxxx_1, \
                                         tg_x_xxxxxy_0, tg_x_xxxxxy_1, tg_x_xxxxxz_0, tg_x_xxxxxz_1, tg_x_xxxxy_1, \
                                         tg_x_xxxxyy_0, tg_x_xxxxyy_1, tg_x_xxxxyz_0, tg_x_xxxxyz_1, tg_x_xxxxz_1, \
                                         tg_x_xxxxzz_0, tg_x_xxxxzz_1, tg_x_xxxyy_1, tg_x_xxxyyy_0, tg_x_xxxyyy_1, \
                                         tg_x_xxxyyz_0, tg_x_xxxyyz_1, tg_x_xxxyz_1, tg_x_xxxyzz_0, tg_x_xxxyzz_1, \
                                         tg_x_xxxzz_1, tg_x_xxxzzz_0, tg_x_xxxzzz_1, tg_x_xxyyy_1, tg_x_xxyyyy_0, \
                                         tg_x_xxyyyy_1, tg_x_xxyyyz_0, tg_x_xxyyyz_1, tg_x_xxyyz_1, tg_x_xxyyzz_0, \
                                         tg_x_xxyyzz_1, tg_x_xxyzz_1, tg_x_xxyzzz_0, tg_x_xxyzzz_1, tg_x_xxzzz_1, \
                                         tg_x_xxzzzz_0, tg_x_xxzzzz_1, tg_x_xyyyy_1, tg_x_xyyyyy_0, tg_x_xyyyyy_1, \
                                         tg_x_xyyyyz_0, tg_x_xyyyyz_1, tg_x_xyyyz_1, tg_x_xyyyzz_0, tg_x_xyyyzz_1, \
                                         tg_x_xyyzz_1, tg_x_xyyzzz_0, tg_x_xyyzzz_1, tg_x_xyzzz_1, tg_x_xyzzzz_0, \
                                         tg_x_xyzzzz_1, tg_x_xzzzz_1, tg_x_xzzzzz_0, tg_x_xzzzzz_1, tg_x_yyyyy_1, \
                                         tg_x_yyyyyy_0, tg_x_yyyyyy_1, tg_x_yyyyyz_0, tg_x_yyyyyz_1, tg_x_yyyyz_1, \
                                         tg_x_yyyyzz_0, tg_x_yyyyzz_1, tg_x_yyyzz_1, tg_x_yyyzzz_0, tg_x_yyyzzz_1, \
                                         tg_x_yyzzz_1, tg_x_yyzzzz_0, tg_x_yyzzzz_1, tg_x_yzzzz_1, tg_x_yzzzzz_0, \
                                         tg_x_yzzzzz_1, tg_x_zzzzz_1, tg_x_zzzzzz_0, tg_x_zzzzzz_1, tg_xx_xxxxxx_0, \
                                         tg_xx_xxxxxy_0, tg_xx_xxxxxz_0, tg_xx_xxxxyy_0, tg_xx_xxxxyz_0, tg_xx_xxxxzz_0, \
                                         tg_xx_xxxyyy_0, tg_xx_xxxyyz_0, tg_xx_xxxyzz_0, tg_xx_xxxzzz_0, tg_xx_xxyyyy_0, \
                                         tg_xx_xxyyyz_0, tg_xx_xxyyzz_0, tg_xx_xxyzzz_0, tg_xx_xxzzzz_0, tg_xx_xyyyyy_0, \
                                         tg_xx_xyyyyz_0, tg_xx_xyyyzz_0, tg_xx_xyyzzz_0, tg_xx_xyzzzz_0, tg_xx_xzzzzz_0, \
                                         tg_xx_yyyyyy_0, tg_xx_yyyyyz_0, tg_xx_yyyyzz_0, tg_xx_yyyzzz_0, tg_xx_yyzzzz_0, \
                                         tg_xx_yzzzzz_0, tg_xx_zzzzzz_0, tg_xy_xxxxxx_0, tg_xy_xxxxxy_0, tg_xy_xxxxxz_0, \
                                         tg_xy_xxxxyy_0, tg_xy_xxxxyz_0, tg_xy_xxxxzz_0, tg_xy_xxxyyy_0, tg_xy_xxxyyz_0, \
                                         tg_xy_xxxyzz_0, tg_xy_xxxzzz_0, tg_xy_xxyyyy_0, tg_xy_xxyyyz_0, tg_xy_xxyyzz_0, \
                                         tg_xy_xxyzzz_0, tg_xy_xxzzzz_0, tg_xy_xyyyyy_0, tg_xy_xyyyyz_0, tg_xy_xyyyzz_0, \
                                         tg_xy_xyyzzz_0, tg_xy_xyzzzz_0, tg_xy_xzzzzz_0, tg_xy_yyyyyy_0, tg_xy_yyyyyz_0, \
                                         tg_xy_yyyyzz_0, tg_xy_yyyzzz_0, tg_xy_yyzzzz_0, tg_xy_yzzzzz_0, tg_xy_zzzzzz_0, \
                                         tg_xz_xxxxxx_0, tg_xz_xxxxxy_0, tg_xz_xxxxxz_0, tg_xz_xxxxyy_0, tg_xz_xxxxyz_0, \
                                         tg_xz_xxxxzz_0, tg_xz_xxxyyy_0, tg_xz_xxxyyz_0, tg_xz_xxxyzz_0, tg_xz_xxxzzz_0, \
                                         tg_xz_xxyyyy_0, tg_xz_xxyyyz_0, tg_xz_xxyyzz_0, tg_xz_xxyzzz_0, tg_xz_xxzzzz_0, \
                                         tg_xz_xyyyyy_0, tg_xz_xyyyyz_0, tg_xz_xyyyzz_0, tg_xz_xyyzzz_0, tg_xz_xyzzzz_0, \
                                         tg_xz_xzzzzz_0, tg_xz_yyyyyy_0, tg_xz_yyyyyz_0, tg_xz_yyyyzz_0, tg_xz_yyyzzz_0, \
                                         tg_xz_yyzzzz_0, tg_xz_yzzzzz_0, tg_xz_zzzzzz_0, tg_y_xxxxx_1, tg_y_xxxxxx_0, \
                                         tg_y_xxxxxx_1, tg_y_xxxxxy_0, tg_y_xxxxxy_1, tg_y_xxxxxz_0, tg_y_xxxxxz_1, \
                                         tg_y_xxxxy_1, tg_y_xxxxyy_0, tg_y_xxxxyy_1, tg_y_xxxxyz_0, tg_y_xxxxyz_1, \
                                         tg_y_xxxxz_1, tg_y_xxxxzz_0, tg_y_xxxxzz_1, tg_y_xxxyy_1, tg_y_xxxyyy_0, \
                                         tg_y_xxxyyy_1, tg_y_xxxyyz_0, tg_y_xxxyyz_1, tg_y_xxxyz_1, tg_y_xxxyzz_0, \
                                         tg_y_xxxyzz_1, tg_y_xxxzz_1, tg_y_xxxzzz_0, tg_y_xxxzzz_1, tg_y_xxyyy_1, \
                                         tg_y_xxyyyy_0, tg_y_xxyyyy_1, tg_y_xxyyyz_0, tg_y_xxyyyz_1, tg_y_xxyyz_1, \
                                         tg_y_xxyyzz_0, tg_y_xxyyzz_1, tg_y_xxyzz_1, tg_y_xxyzzz_0, tg_y_xxyzzz_1, \
                                         tg_y_xxzzz_1, tg_y_xxzzzz_0, tg_y_xxzzzz_1, tg_y_xyyyy_1, tg_y_xyyyyy_0, \
                                         tg_y_xyyyyy_1, tg_y_xyyyyz_0, tg_y_xyyyyz_1, tg_y_xyyyz_1, tg_y_xyyyzz_0, \
                                         tg_y_xyyyzz_1, tg_y_xyyzz_1, tg_y_xyyzzz_0, tg_y_xyyzzz_1, tg_y_xyzzz_1, \
                                         tg_y_xyzzzz_0, tg_y_xyzzzz_1, tg_y_xzzzz_1, tg_y_xzzzzz_0, tg_y_xzzzzz_1, \
                                         tg_y_yyyyy_1, tg_y_yyyyyy_0, tg_y_yyyyyy_1, tg_y_yyyyyz_0, tg_y_yyyyyz_1, \
                                         tg_y_yyyyz_1, tg_y_yyyyzz_0, tg_y_yyyyzz_1, tg_y_yyyzz_1, tg_y_yyyzzz_0, \
                                         tg_y_yyyzzz_1, tg_y_yyzzz_1, tg_y_yyzzzz_0, tg_y_yyzzzz_1, tg_y_yzzzz_1, \
                                         tg_y_yzzzzz_0, tg_y_yzzzzz_1, tg_y_zzzzz_1, tg_y_zzzzzz_0, tg_y_zzzzzz_1, \
                                         tg_z_xxxxx_1, tg_z_xxxxxx_0, tg_z_xxxxxx_1, tg_z_xxxxxy_0, tg_z_xxxxxy_1, \
                                         tg_z_xxxxxz_0, tg_z_xxxxxz_1, tg_z_xxxxy_1, tg_z_xxxxyy_0, tg_z_xxxxyy_1, \
                                         tg_z_xxxxyz_0, tg_z_xxxxyz_1, tg_z_xxxxz_1, tg_z_xxxxzz_0, tg_z_xxxxzz_1, \
                                         tg_z_xxxyy_1, tg_z_xxxyyy_0, tg_z_xxxyyy_1, tg_z_xxxyyz_0, tg_z_xxxyyz_1, \
                                         tg_z_xxxyz_1, tg_z_xxxyzz_0, tg_z_xxxyzz_1, tg_z_xxxzz_1, tg_z_xxxzzz_0, \
                                         tg_z_xxxzzz_1, tg_z_xxyyy_1, tg_z_xxyyyy_0, tg_z_xxyyyy_1, tg_z_xxyyyz_0, \
                                         tg_z_xxyyyz_1, tg_z_xxyyz_1, tg_z_xxyyzz_0, tg_z_xxyyzz_1, tg_z_xxyzz_1, \
                                         tg_z_xxyzzz_0, tg_z_xxyzzz_1, tg_z_xxzzz_1, tg_z_xxzzzz_0, tg_z_xxzzzz_1, \
                                         tg_z_xyyyy_1, tg_z_xyyyyy_0, tg_z_xyyyyy_1, tg_z_xyyyyz_0, tg_z_xyyyyz_1, \
                                         tg_z_xyyyz_1, tg_z_xyyyzz_0, tg_z_xyyyzz_1, tg_z_xyyzz_1, tg_z_xyyzzz_0, \
                                         tg_z_xyyzzz_1, tg_z_xyzzz_1, tg_z_xyzzzz_0, tg_z_xyzzzz_1, tg_z_xzzzz_1, \
                                         tg_z_xzzzzz_0, tg_z_xzzzzz_1, tg_z_yyyyy_1, tg_z_yyyyyy_0, tg_z_yyyyyy_1, \
                                         tg_z_yyyyyz_0, tg_z_yyyyyz_1, tg_z_yyyyz_1, tg_z_yyyyzz_0, tg_z_yyyyzz_1, \
                                         tg_z_yyyzz_1, tg_z_yyyzzz_0, tg_z_yyyzzz_1, tg_z_yyzzz_1, tg_z_yyzzzz_0, \
                                         tg_z_yyzzzz_1, tg_z_yzzzz_1, tg_z_yzzzzz_0, tg_z_yzzzzz_1, tg_z_zzzzz_1, \
                                         tg_z_zzzzzz_0, tg_z_zzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxxxxx_0[j] = pb_x * tg_x_xxxxxx_0[j] + fr * tg_x_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxx_0[j] - tg_0_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxx_1[j];

                    tg_xx_xxxxxy_0[j] = pb_x * tg_x_xxxxxy_0[j] + fr * tg_x_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxy_0[j] - tg_0_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxy_1[j];

                    tg_xx_xxxxxz_0[j] = pb_x * tg_x_xxxxxz_0[j] + fr * tg_x_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxz_0[j] - tg_0_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxz_1[j];

                    tg_xx_xxxxyy_0[j] = pb_x * tg_x_xxxxyy_0[j] + fr * tg_x_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyy_0[j] - tg_0_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyy_1[j];

                    tg_xx_xxxxyz_0[j] = pb_x * tg_x_xxxxyz_0[j] + fr * tg_x_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyz_0[j] - tg_0_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyz_1[j];

                    tg_xx_xxxxzz_0[j] = pb_x * tg_x_xxxxzz_0[j] + fr * tg_x_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzz_0[j] - tg_0_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxzz_1[j];

                    tg_xx_xxxyyy_0[j] = pb_x * tg_x_xxxyyy_0[j] + fr * tg_x_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyy_0[j] - tg_0_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyy_1[j];

                    tg_xx_xxxyyz_0[j] = pb_x * tg_x_xxxyyz_0[j] + fr * tg_x_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyz_0[j] - tg_0_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyz_1[j];

                    tg_xx_xxxyzz_0[j] = pb_x * tg_x_xxxyzz_0[j] + fr * tg_x_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzz_0[j] - tg_0_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyzz_1[j];

                    tg_xx_xxxzzz_0[j] = pb_x * tg_x_xxxzzz_0[j] + fr * tg_x_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzz_0[j] - tg_0_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxzzz_1[j];

                    tg_xx_xxyyyy_0[j] = pb_x * tg_x_xxyyyy_0[j] + fr * tg_x_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyy_0[j] - tg_0_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyy_1[j];

                    tg_xx_xxyyyz_0[j] = pb_x * tg_x_xxyyyz_0[j] + fr * tg_x_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyz_0[j] - tg_0_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyz_1[j];

                    tg_xx_xxyyzz_0[j] = pb_x * tg_x_xxyyzz_0[j] + fr * tg_x_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzz_0[j] - tg_0_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyzz_1[j];

                    tg_xx_xxyzzz_0[j] = pb_x * tg_x_xxyzzz_0[j] + fr * tg_x_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzz_0[j] - tg_0_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyzzz_1[j];

                    tg_xx_xxzzzz_0[j] = pb_x * tg_x_xxzzzz_0[j] + fr * tg_x_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzz_0[j] - tg_0_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xzzzz_1[j];

                    tg_xx_xyyyyy_0[j] = pb_x * tg_x_xyyyyy_0[j] + fr * tg_x_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyy_0[j] - tg_0_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyy_1[j];

                    tg_xx_xyyyyz_0[j] = pb_x * tg_x_xyyyyz_0[j] + fr * tg_x_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyz_0[j] - tg_0_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyz_1[j];

                    tg_xx_xyyyzz_0[j] = pb_x * tg_x_xyyyzz_0[j] + fr * tg_x_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzz_0[j] - tg_0_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyzz_1[j];

                    tg_xx_xyyzzz_0[j] = pb_x * tg_x_xyyzzz_0[j] + fr * tg_x_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzz_0[j] - tg_0_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyzzz_1[j];

                    tg_xx_xyzzzz_0[j] = pb_x * tg_x_xyzzzz_0[j] + fr * tg_x_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzz_0[j] - tg_0_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yzzzz_1[j];

                    tg_xx_xzzzzz_0[j] = pb_x * tg_x_xzzzzz_0[j] + fr * tg_x_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzz_0[j] - tg_0_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zzzzz_1[j];

                    tg_xx_yyyyyy_0[j] = pb_x * tg_x_yyyyyy_0[j] + fr * tg_x_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyy_0[j] - tg_0_yyyyyy_1[j] * fl1_fza);

                    tg_xx_yyyyyz_0[j] = pb_x * tg_x_yyyyyz_0[j] + fr * tg_x_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyz_0[j] - tg_0_yyyyyz_1[j] * fl1_fza);

                    tg_xx_yyyyzz_0[j] = pb_x * tg_x_yyyyzz_0[j] + fr * tg_x_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzz_0[j] - tg_0_yyyyzz_1[j] * fl1_fza);

                    tg_xx_yyyzzz_0[j] = pb_x * tg_x_yyyzzz_0[j] + fr * tg_x_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzz_0[j] - tg_0_yyyzzz_1[j] * fl1_fza);

                    tg_xx_yyzzzz_0[j] = pb_x * tg_x_yyzzzz_0[j] + fr * tg_x_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzz_0[j] - tg_0_yyzzzz_1[j] * fl1_fza);

                    tg_xx_yzzzzz_0[j] = pb_x * tg_x_yzzzzz_0[j] + fr * tg_x_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzz_0[j] - tg_0_yzzzzz_1[j] * fl1_fza);

                    tg_xx_zzzzzz_0[j] = pb_x * tg_x_zzzzzz_0[j] + fr * tg_x_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzz_0[j] - tg_0_zzzzzz_1[j] * fl1_fza);

                    tg_xy_xxxxxx_0[j] = pb_x * tg_y_xxxxxx_0[j] + fr * tg_y_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_y_xxxxx_1[j];

                    tg_xy_xxxxxy_0[j] = pb_x * tg_y_xxxxxy_0[j] + fr * tg_y_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_y_xxxxy_1[j];

                    tg_xy_xxxxxz_0[j] = pb_x * tg_y_xxxxxz_0[j] + fr * tg_y_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxz_1[j];

                    tg_xy_xxxxyy_0[j] = pb_x * tg_y_xxxxyy_0[j] + fr * tg_y_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_y_xxxyy_1[j];

                    tg_xy_xxxxyz_0[j] = pb_x * tg_y_xxxxyz_0[j] + fr * tg_y_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyz_1[j];

                    tg_xy_xxxxzz_0[j] = pb_x * tg_y_xxxxzz_0[j] + fr * tg_y_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxzz_1[j];

                    tg_xy_xxxyyy_0[j] = pb_x * tg_y_xxxyyy_0[j] + fr * tg_y_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_y_xxyyy_1[j];

                    tg_xy_xxxyyz_0[j] = pb_x * tg_y_xxxyyz_0[j] + fr * tg_y_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyz_1[j];

                    tg_xy_xxxyzz_0[j] = pb_x * tg_y_xxxyzz_0[j] + fr * tg_y_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyzz_1[j];

                    tg_xy_xxxzzz_0[j] = pb_x * tg_y_xxxzzz_0[j] + fr * tg_y_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxzzz_1[j];

                    tg_xy_xxyyyy_0[j] = pb_x * tg_y_xxyyyy_0[j] + fr * tg_y_xxyyyy_1[j] + fl1_fxn * tg_y_xyyyy_1[j];

                    tg_xy_xxyyyz_0[j] = pb_x * tg_y_xxyyyz_0[j] + fr * tg_y_xxyyyz_1[j] + fl1_fxn * tg_y_xyyyz_1[j];

                    tg_xy_xxyyzz_0[j] = pb_x * tg_y_xxyyzz_0[j] + fr * tg_y_xxyyzz_1[j] + fl1_fxn * tg_y_xyyzz_1[j];

                    tg_xy_xxyzzz_0[j] = pb_x * tg_y_xxyzzz_0[j] + fr * tg_y_xxyzzz_1[j] + fl1_fxn * tg_y_xyzzz_1[j];

                    tg_xy_xxzzzz_0[j] = pb_x * tg_y_xxzzzz_0[j] + fr * tg_y_xxzzzz_1[j] + fl1_fxn * tg_y_xzzzz_1[j];

                    tg_xy_xyyyyy_0[j] = pb_x * tg_y_xyyyyy_0[j] + fr * tg_y_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_y_yyyyy_1[j];

                    tg_xy_xyyyyz_0[j] = pb_x * tg_y_xyyyyz_0[j] + fr * tg_y_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyz_1[j];

                    tg_xy_xyyyzz_0[j] = pb_x * tg_y_xyyyzz_0[j] + fr * tg_y_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyzz_1[j];

                    tg_xy_xyyzzz_0[j] = pb_x * tg_y_xyyzzz_0[j] + fr * tg_y_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyzzz_1[j];

                    tg_xy_xyzzzz_0[j] = pb_x * tg_y_xyzzzz_0[j] + fr * tg_y_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yzzzz_1[j];

                    tg_xy_xzzzzz_0[j] = pb_x * tg_y_xzzzzz_0[j] + fr * tg_y_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_zzzzz_1[j];

                    tg_xy_yyyyyy_0[j] = pb_x * tg_y_yyyyyy_0[j] + fr * tg_y_yyyyyy_1[j];

                    tg_xy_yyyyyz_0[j] = pb_x * tg_y_yyyyyz_0[j] + fr * tg_y_yyyyyz_1[j];

                    tg_xy_yyyyzz_0[j] = pb_x * tg_y_yyyyzz_0[j] + fr * tg_y_yyyyzz_1[j];

                    tg_xy_yyyzzz_0[j] = pb_x * tg_y_yyyzzz_0[j] + fr * tg_y_yyyzzz_1[j];

                    tg_xy_yyzzzz_0[j] = pb_x * tg_y_yyzzzz_0[j] + fr * tg_y_yyzzzz_1[j];

                    tg_xy_yzzzzz_0[j] = pb_x * tg_y_yzzzzz_0[j] + fr * tg_y_yzzzzz_1[j];

                    tg_xy_zzzzzz_0[j] = pb_x * tg_y_zzzzzz_0[j] + fr * tg_y_zzzzzz_1[j];

                    tg_xz_xxxxxx_0[j] = pb_x * tg_z_xxxxxx_0[j] + fr * tg_z_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_z_xxxxx_1[j];

                    tg_xz_xxxxxy_0[j] = pb_x * tg_z_xxxxxy_0[j] + fr * tg_z_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_z_xxxxy_1[j];

                    tg_xz_xxxxxz_0[j] = pb_x * tg_z_xxxxxz_0[j] + fr * tg_z_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxz_1[j];

                    tg_xz_xxxxyy_0[j] = pb_x * tg_z_xxxxyy_0[j] + fr * tg_z_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_z_xxxyy_1[j];

                    tg_xz_xxxxyz_0[j] = pb_x * tg_z_xxxxyz_0[j] + fr * tg_z_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyz_1[j];

                    tg_xz_xxxxzz_0[j] = pb_x * tg_z_xxxxzz_0[j] + fr * tg_z_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxzz_1[j];

                    tg_xz_xxxyyy_0[j] = pb_x * tg_z_xxxyyy_0[j] + fr * tg_z_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxyyy_1[j];

                    tg_xz_xxxyyz_0[j] = pb_x * tg_z_xxxyyz_0[j] + fr * tg_z_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyz_1[j];

                    tg_xz_xxxyzz_0[j] = pb_x * tg_z_xxxyzz_0[j] + fr * tg_z_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyzz_1[j];

                    tg_xz_xxxzzz_0[j] = pb_x * tg_z_xxxzzz_0[j] + fr * tg_z_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxzzz_1[j];

                    tg_xz_xxyyyy_0[j] = pb_x * tg_z_xxyyyy_0[j] + fr * tg_z_xxyyyy_1[j] + fl1_fxn * tg_z_xyyyy_1[j];

                    tg_xz_xxyyyz_0[j] = pb_x * tg_z_xxyyyz_0[j] + fr * tg_z_xxyyyz_1[j] + fl1_fxn * tg_z_xyyyz_1[j];

                    tg_xz_xxyyzz_0[j] = pb_x * tg_z_xxyyzz_0[j] + fr * tg_z_xxyyzz_1[j] + fl1_fxn * tg_z_xyyzz_1[j];

                    tg_xz_xxyzzz_0[j] = pb_x * tg_z_xxyzzz_0[j] + fr * tg_z_xxyzzz_1[j] + fl1_fxn * tg_z_xyzzz_1[j];

                    tg_xz_xxzzzz_0[j] = pb_x * tg_z_xxzzzz_0[j] + fr * tg_z_xxzzzz_1[j] + fl1_fxn * tg_z_xzzzz_1[j];

                    tg_xz_xyyyyy_0[j] = pb_x * tg_z_xyyyyy_0[j] + fr * tg_z_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_z_yyyyy_1[j];

                    tg_xz_xyyyyz_0[j] = pb_x * tg_z_xyyyyz_0[j] + fr * tg_z_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyz_1[j];

                    tg_xz_xyyyzz_0[j] = pb_x * tg_z_xyyyzz_0[j] + fr * tg_z_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyzz_1[j];

                    tg_xz_xyyzzz_0[j] = pb_x * tg_z_xyyzzz_0[j] + fr * tg_z_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyzzz_1[j];

                    tg_xz_xyzzzz_0[j] = pb_x * tg_z_xyzzzz_0[j] + fr * tg_z_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yzzzz_1[j];

                    tg_xz_xzzzzz_0[j] = pb_x * tg_z_xzzzzz_0[j] + fr * tg_z_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzz_1[j];

                    tg_xz_yyyyyy_0[j] = pb_x * tg_z_yyyyyy_0[j] + fr * tg_z_yyyyyy_1[j];

                    tg_xz_yyyyyz_0[j] = pb_x * tg_z_yyyyyz_0[j] + fr * tg_z_yyyyyz_1[j];

                    tg_xz_yyyyzz_0[j] = pb_x * tg_z_yyyyzz_0[j] + fr * tg_z_yyyyzz_1[j];

                    tg_xz_yyyzzz_0[j] = pb_x * tg_z_yyyzzz_0[j] + fr * tg_z_yyyzzz_1[j];

                    tg_xz_yyzzzz_0[j] = pb_x * tg_z_yyzzzz_0[j] + fr * tg_z_yyzzzz_1[j];

                    tg_xz_yzzzzz_0[j] = pb_x * tg_z_yzzzzz_0[j] + fr * tg_z_yzzzzz_1[j];

                    tg_xz_zzzzzz_0[j] = pb_x * tg_z_zzzzzz_0[j] + fr * tg_z_zzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSI_84_168(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (84,168)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_y_xxxxxx_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 28); 

                auto tg_y_xxxxxy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 29); 

                auto tg_y_xxxxxz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 30); 

                auto tg_y_xxxxyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 31); 

                auto tg_y_xxxxyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 32); 

                auto tg_y_xxxxzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 33); 

                auto tg_y_xxxyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 34); 

                auto tg_y_xxxyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 35); 

                auto tg_y_xxxyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 36); 

                auto tg_y_xxxzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 37); 

                auto tg_y_xxyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 38); 

                auto tg_y_xxyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 39); 

                auto tg_y_xxyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 40); 

                auto tg_y_xxyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 41); 

                auto tg_y_xxzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 42); 

                auto tg_y_xyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 43); 

                auto tg_y_xyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 44); 

                auto tg_y_xyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 45); 

                auto tg_y_xyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 46); 

                auto tg_y_xyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 47); 

                auto tg_y_xzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 48); 

                auto tg_y_yyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 49); 

                auto tg_y_yyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 50); 

                auto tg_y_yyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 51); 

                auto tg_y_yyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 52); 

                auto tg_y_yyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 53); 

                auto tg_y_yzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 54); 

                auto tg_y_zzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 55); 

                auto tg_z_xxxxxx_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 56); 

                auto tg_z_xxxxxy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 57); 

                auto tg_z_xxxxxz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 58); 

                auto tg_z_xxxxyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 59); 

                auto tg_z_xxxxyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 60); 

                auto tg_z_xxxxzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 61); 

                auto tg_z_xxxyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 62); 

                auto tg_z_xxxyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 63); 

                auto tg_z_xxxyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 64); 

                auto tg_z_xxxzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 65); 

                auto tg_z_xxyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 66); 

                auto tg_z_xxyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 67); 

                auto tg_z_xxyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 68); 

                auto tg_z_xxyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 69); 

                auto tg_z_xxzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 70); 

                auto tg_z_xyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 71); 

                auto tg_z_xyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 72); 

                auto tg_z_xyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 73); 

                auto tg_z_xyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 74); 

                auto tg_z_xyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 75); 

                auto tg_z_xzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 76); 

                auto tg_z_yyyyyy_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 77); 

                auto tg_z_yyyyyz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 78); 

                auto tg_z_yyyyzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 79); 

                auto tg_z_yyyzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 80); 

                auto tg_z_yyzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 81); 

                auto tg_z_yzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 82); 

                auto tg_z_zzzzzz_0 = primBuffer[pidx_g_1_6_m0].data(84 * idx + 83); 

                auto tg_y_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 28); 

                auto tg_y_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 29); 

                auto tg_y_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 30); 

                auto tg_y_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 31); 

                auto tg_y_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 32); 

                auto tg_y_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 33); 

                auto tg_y_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 34); 

                auto tg_y_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 35); 

                auto tg_y_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 36); 

                auto tg_y_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 37); 

                auto tg_y_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 38); 

                auto tg_y_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 39); 

                auto tg_y_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 40); 

                auto tg_y_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 41); 

                auto tg_y_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 42); 

                auto tg_y_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 43); 

                auto tg_y_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 44); 

                auto tg_y_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 45); 

                auto tg_y_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 46); 

                auto tg_y_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 47); 

                auto tg_y_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 48); 

                auto tg_y_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 49); 

                auto tg_y_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 50); 

                auto tg_y_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 51); 

                auto tg_y_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 52); 

                auto tg_y_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 53); 

                auto tg_y_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 54); 

                auto tg_y_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 55); 

                auto tg_z_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 56); 

                auto tg_z_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 57); 

                auto tg_z_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 58); 

                auto tg_z_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 59); 

                auto tg_z_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 60); 

                auto tg_z_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 61); 

                auto tg_z_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 62); 

                auto tg_z_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 63); 

                auto tg_z_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 64); 

                auto tg_z_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 65); 

                auto tg_z_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 66); 

                auto tg_z_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 67); 

                auto tg_z_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 68); 

                auto tg_z_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 69); 

                auto tg_z_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 70); 

                auto tg_z_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 71); 

                auto tg_z_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 72); 

                auto tg_z_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 73); 

                auto tg_z_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 74); 

                auto tg_z_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 75); 

                auto tg_z_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 76); 

                auto tg_z_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 77); 

                auto tg_z_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 78); 

                auto tg_z_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 79); 

                auto tg_z_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 80); 

                auto tg_z_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 81); 

                auto tg_z_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 82); 

                auto tg_z_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 83); 

                auto tg_0_xxxxxx_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx); 

                auto tg_0_xxxxxy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 1); 

                auto tg_0_xxxxxz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 2); 

                auto tg_0_xxxxyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 3); 

                auto tg_0_xxxxyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 4); 

                auto tg_0_xxxxzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 5); 

                auto tg_0_xxxyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 6); 

                auto tg_0_xxxyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 7); 

                auto tg_0_xxxyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 8); 

                auto tg_0_xxxzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 9); 

                auto tg_0_xxyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 10); 

                auto tg_0_xxyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 11); 

                auto tg_0_xxyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 12); 

                auto tg_0_xxyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 13); 

                auto tg_0_xxzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 14); 

                auto tg_0_xyyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 15); 

                auto tg_0_xyyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 16); 

                auto tg_0_xyyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 17); 

                auto tg_0_xyyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 18); 

                auto tg_0_xyzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 19); 

                auto tg_0_xzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 20); 

                auto tg_0_yyyyyy_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 21); 

                auto tg_0_yyyyyz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 22); 

                auto tg_0_yyyyzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 23); 

                auto tg_0_yyyzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 24); 

                auto tg_0_yyzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 25); 

                auto tg_0_yzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 26); 

                auto tg_0_zzzzzz_0 = primBuffer[pidx_g_0_6_m0].data(28 * idx + 27); 

                auto tg_0_xxxxxx_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx); 

                auto tg_0_xxxxxy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 1); 

                auto tg_0_xxxxxz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 2); 

                auto tg_0_xxxxyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 3); 

                auto tg_0_xxxxyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 4); 

                auto tg_0_xxxxzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 5); 

                auto tg_0_xxxyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 6); 

                auto tg_0_xxxyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 7); 

                auto tg_0_xxxyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 8); 

                auto tg_0_xxxzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 9); 

                auto tg_0_xxyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 10); 

                auto tg_0_xxyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 11); 

                auto tg_0_xxyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 12); 

                auto tg_0_xxyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 13); 

                auto tg_0_xxzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 14); 

                auto tg_0_xyyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 15); 

                auto tg_0_xyyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 16); 

                auto tg_0_xyyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 17); 

                auto tg_0_xyyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 18); 

                auto tg_0_xyzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 19); 

                auto tg_0_xzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 20); 

                auto tg_0_yyyyyy_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 21); 

                auto tg_0_yyyyyz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 22); 

                auto tg_0_yyyyzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 23); 

                auto tg_0_yyyzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 24); 

                auto tg_0_yyzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 25); 

                auto tg_0_yzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 26); 

                auto tg_0_zzzzzz_1 = primBuffer[pidx_g_0_6_m1].data(28 * idx + 27); 

                auto tg_y_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 21); 

                auto tg_y_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 22); 

                auto tg_y_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 23); 

                auto tg_y_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 24); 

                auto tg_y_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 25); 

                auto tg_y_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 26); 

                auto tg_y_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 27); 

                auto tg_y_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 28); 

                auto tg_y_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 29); 

                auto tg_y_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 30); 

                auto tg_y_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 31); 

                auto tg_y_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 32); 

                auto tg_y_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 33); 

                auto tg_y_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 34); 

                auto tg_y_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 35); 

                auto tg_y_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 36); 

                auto tg_y_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 37); 

                auto tg_y_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 38); 

                auto tg_y_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 39); 

                auto tg_y_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 40); 

                auto tg_y_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 41); 

                auto tg_z_xxxxx_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 42); 

                auto tg_z_xxxxy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 43); 

                auto tg_z_xxxxz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 44); 

                auto tg_z_xxxyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 45); 

                auto tg_z_xxxyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 46); 

                auto tg_z_xxxzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 47); 

                auto tg_z_xxyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 48); 

                auto tg_z_xxyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 49); 

                auto tg_z_xxyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 50); 

                auto tg_z_xxzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 51); 

                auto tg_z_xyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 52); 

                auto tg_z_xyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 53); 

                auto tg_z_xyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 54); 

                auto tg_z_xyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 55); 

                auto tg_z_xzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 56); 

                auto tg_z_yyyyy_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 57); 

                auto tg_z_yyyyz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 58); 

                auto tg_z_yyyzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 59); 

                auto tg_z_yyzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 60); 

                auto tg_z_yzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 61); 

                auto tg_z_zzzzz_1 = primBuffer[pidx_g_1_5_m1].data(63 * idx + 62); 

                // set up pointers to integrals

                auto tg_yy_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 84); 

                auto tg_yy_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 85); 

                auto tg_yy_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 86); 

                auto tg_yy_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 87); 

                auto tg_yy_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 88); 

                auto tg_yy_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 89); 

                auto tg_yy_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 90); 

                auto tg_yy_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 91); 

                auto tg_yy_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 92); 

                auto tg_yy_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 93); 

                auto tg_yy_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 94); 

                auto tg_yy_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 95); 

                auto tg_yy_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 96); 

                auto tg_yy_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 97); 

                auto tg_yy_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 98); 

                auto tg_yy_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 99); 

                auto tg_yy_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 100); 

                auto tg_yy_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 101); 

                auto tg_yy_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 102); 

                auto tg_yy_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 103); 

                auto tg_yy_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 104); 

                auto tg_yy_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 105); 

                auto tg_yy_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 106); 

                auto tg_yy_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 107); 

                auto tg_yy_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 108); 

                auto tg_yy_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 109); 

                auto tg_yy_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 110); 

                auto tg_yy_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 111); 

                auto tg_yz_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 112); 

                auto tg_yz_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 113); 

                auto tg_yz_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 114); 

                auto tg_yz_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 115); 

                auto tg_yz_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 116); 

                auto tg_yz_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 117); 

                auto tg_yz_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 118); 

                auto tg_yz_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 119); 

                auto tg_yz_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 120); 

                auto tg_yz_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 121); 

                auto tg_yz_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 122); 

                auto tg_yz_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 123); 

                auto tg_yz_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 124); 

                auto tg_yz_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 125); 

                auto tg_yz_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 126); 

                auto tg_yz_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 127); 

                auto tg_yz_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 128); 

                auto tg_yz_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 129); 

                auto tg_yz_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 130); 

                auto tg_yz_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 131); 

                auto tg_yz_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 132); 

                auto tg_yz_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 133); 

                auto tg_yz_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 134); 

                auto tg_yz_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 135); 

                auto tg_yz_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 136); 

                auto tg_yz_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 137); 

                auto tg_yz_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 138); 

                auto tg_yz_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 139); 

                auto tg_zz_xxxxxx_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 140); 

                auto tg_zz_xxxxxy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 141); 

                auto tg_zz_xxxxxz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 142); 

                auto tg_zz_xxxxyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 143); 

                auto tg_zz_xxxxyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 144); 

                auto tg_zz_xxxxzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 145); 

                auto tg_zz_xxxyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 146); 

                auto tg_zz_xxxyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 147); 

                auto tg_zz_xxxyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 148); 

                auto tg_zz_xxxzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 149); 

                auto tg_zz_xxyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 150); 

                auto tg_zz_xxyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 151); 

                auto tg_zz_xxyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 152); 

                auto tg_zz_xxyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 153); 

                auto tg_zz_xxzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 154); 

                auto tg_zz_xyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 155); 

                auto tg_zz_xyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 156); 

                auto tg_zz_xyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 157); 

                auto tg_zz_xyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 158); 

                auto tg_zz_xyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 159); 

                auto tg_zz_xzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 160); 

                auto tg_zz_yyyyyy_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 161); 

                auto tg_zz_yyyyyz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 162); 

                auto tg_zz_yyyyzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 163); 

                auto tg_zz_yyyzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 164); 

                auto tg_zz_yyzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 165); 

                auto tg_zz_yzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 166); 

                auto tg_zz_zzzzzz_0 = primBuffer[pidx_g_2_6_m0].data(168 * idx + 167); 

                // Batch of Integrals (84,168)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxx_0, tg_0_xxxxxx_1, tg_0_xxxxxy_0, tg_0_xxxxxy_1, \
                                         tg_0_xxxxxz_0, tg_0_xxxxxz_1, tg_0_xxxxyy_0, tg_0_xxxxyy_1, tg_0_xxxxyz_0, \
                                         tg_0_xxxxyz_1, tg_0_xxxxzz_0, tg_0_xxxxzz_1, tg_0_xxxyyy_0, tg_0_xxxyyy_1, \
                                         tg_0_xxxyyz_0, tg_0_xxxyyz_1, tg_0_xxxyzz_0, tg_0_xxxyzz_1, tg_0_xxxzzz_0, \
                                         tg_0_xxxzzz_1, tg_0_xxyyyy_0, tg_0_xxyyyy_1, tg_0_xxyyyz_0, tg_0_xxyyyz_1, \
                                         tg_0_xxyyzz_0, tg_0_xxyyzz_1, tg_0_xxyzzz_0, tg_0_xxyzzz_1, tg_0_xxzzzz_0, \
                                         tg_0_xxzzzz_1, tg_0_xyyyyy_0, tg_0_xyyyyy_1, tg_0_xyyyyz_0, tg_0_xyyyyz_1, \
                                         tg_0_xyyyzz_0, tg_0_xyyyzz_1, tg_0_xyyzzz_0, tg_0_xyyzzz_1, tg_0_xyzzzz_0, \
                                         tg_0_xyzzzz_1, tg_0_xzzzzz_0, tg_0_xzzzzz_1, tg_0_yyyyyy_0, tg_0_yyyyyy_1, \
                                         tg_0_yyyyyz_0, tg_0_yyyyyz_1, tg_0_yyyyzz_0, tg_0_yyyyzz_1, tg_0_yyyzzz_0, \
                                         tg_0_yyyzzz_1, tg_0_yyzzzz_0, tg_0_yyzzzz_1, tg_0_yzzzzz_0, tg_0_yzzzzz_1, \
                                         tg_0_zzzzzz_0, tg_0_zzzzzz_1, tg_y_xxxxx_1, tg_y_xxxxxx_0, tg_y_xxxxxx_1, \
                                         tg_y_xxxxxy_0, tg_y_xxxxxy_1, tg_y_xxxxxz_0, tg_y_xxxxxz_1, tg_y_xxxxy_1, \
                                         tg_y_xxxxyy_0, tg_y_xxxxyy_1, tg_y_xxxxyz_0, tg_y_xxxxyz_1, tg_y_xxxxz_1, \
                                         tg_y_xxxxzz_0, tg_y_xxxxzz_1, tg_y_xxxyy_1, tg_y_xxxyyy_0, tg_y_xxxyyy_1, \
                                         tg_y_xxxyyz_0, tg_y_xxxyyz_1, tg_y_xxxyz_1, tg_y_xxxyzz_0, tg_y_xxxyzz_1, \
                                         tg_y_xxxzz_1, tg_y_xxxzzz_0, tg_y_xxxzzz_1, tg_y_xxyyy_1, tg_y_xxyyyy_0, \
                                         tg_y_xxyyyy_1, tg_y_xxyyyz_0, tg_y_xxyyyz_1, tg_y_xxyyz_1, tg_y_xxyyzz_0, \
                                         tg_y_xxyyzz_1, tg_y_xxyzz_1, tg_y_xxyzzz_0, tg_y_xxyzzz_1, tg_y_xxzzz_1, \
                                         tg_y_xxzzzz_0, tg_y_xxzzzz_1, tg_y_xyyyy_1, tg_y_xyyyyy_0, tg_y_xyyyyy_1, \
                                         tg_y_xyyyyz_0, tg_y_xyyyyz_1, tg_y_xyyyz_1, tg_y_xyyyzz_0, tg_y_xyyyzz_1, \
                                         tg_y_xyyzz_1, tg_y_xyyzzz_0, tg_y_xyyzzz_1, tg_y_xyzzz_1, tg_y_xyzzzz_0, \
                                         tg_y_xyzzzz_1, tg_y_xzzzz_1, tg_y_xzzzzz_0, tg_y_xzzzzz_1, tg_y_yyyyy_1, \
                                         tg_y_yyyyyy_0, tg_y_yyyyyy_1, tg_y_yyyyyz_0, tg_y_yyyyyz_1, tg_y_yyyyz_1, \
                                         tg_y_yyyyzz_0, tg_y_yyyyzz_1, tg_y_yyyzz_1, tg_y_yyyzzz_0, tg_y_yyyzzz_1, \
                                         tg_y_yyzzz_1, tg_y_yyzzzz_0, tg_y_yyzzzz_1, tg_y_yzzzz_1, tg_y_yzzzzz_0, \
                                         tg_y_yzzzzz_1, tg_y_zzzzz_1, tg_y_zzzzzz_0, tg_y_zzzzzz_1, tg_yy_xxxxxx_0, \
                                         tg_yy_xxxxxy_0, tg_yy_xxxxxz_0, tg_yy_xxxxyy_0, tg_yy_xxxxyz_0, tg_yy_xxxxzz_0, \
                                         tg_yy_xxxyyy_0, tg_yy_xxxyyz_0, tg_yy_xxxyzz_0, tg_yy_xxxzzz_0, tg_yy_xxyyyy_0, \
                                         tg_yy_xxyyyz_0, tg_yy_xxyyzz_0, tg_yy_xxyzzz_0, tg_yy_xxzzzz_0, tg_yy_xyyyyy_0, \
                                         tg_yy_xyyyyz_0, tg_yy_xyyyzz_0, tg_yy_xyyzzz_0, tg_yy_xyzzzz_0, tg_yy_xzzzzz_0, \
                                         tg_yy_yyyyyy_0, tg_yy_yyyyyz_0, tg_yy_yyyyzz_0, tg_yy_yyyzzz_0, tg_yy_yyzzzz_0, \
                                         tg_yy_yzzzzz_0, tg_yy_zzzzzz_0, tg_yz_xxxxxx_0, tg_yz_xxxxxy_0, tg_yz_xxxxxz_0, \
                                         tg_yz_xxxxyy_0, tg_yz_xxxxyz_0, tg_yz_xxxxzz_0, tg_yz_xxxyyy_0, tg_yz_xxxyyz_0, \
                                         tg_yz_xxxyzz_0, tg_yz_xxxzzz_0, tg_yz_xxyyyy_0, tg_yz_xxyyyz_0, tg_yz_xxyyzz_0, \
                                         tg_yz_xxyzzz_0, tg_yz_xxzzzz_0, tg_yz_xyyyyy_0, tg_yz_xyyyyz_0, tg_yz_xyyyzz_0, \
                                         tg_yz_xyyzzz_0, tg_yz_xyzzzz_0, tg_yz_xzzzzz_0, tg_yz_yyyyyy_0, tg_yz_yyyyyz_0, \
                                         tg_yz_yyyyzz_0, tg_yz_yyyzzz_0, tg_yz_yyzzzz_0, tg_yz_yzzzzz_0, tg_yz_zzzzzz_0, \
                                         tg_z_xxxxx_1, tg_z_xxxxxx_0, tg_z_xxxxxx_1, tg_z_xxxxxy_0, tg_z_xxxxxy_1, \
                                         tg_z_xxxxxz_0, tg_z_xxxxxz_1, tg_z_xxxxy_1, tg_z_xxxxyy_0, tg_z_xxxxyy_1, \
                                         tg_z_xxxxyz_0, tg_z_xxxxyz_1, tg_z_xxxxz_1, tg_z_xxxxzz_0, tg_z_xxxxzz_1, \
                                         tg_z_xxxyy_1, tg_z_xxxyyy_0, tg_z_xxxyyy_1, tg_z_xxxyyz_0, tg_z_xxxyyz_1, \
                                         tg_z_xxxyz_1, tg_z_xxxyzz_0, tg_z_xxxyzz_1, tg_z_xxxzz_1, tg_z_xxxzzz_0, \
                                         tg_z_xxxzzz_1, tg_z_xxyyy_1, tg_z_xxyyyy_0, tg_z_xxyyyy_1, tg_z_xxyyyz_0, \
                                         tg_z_xxyyyz_1, tg_z_xxyyz_1, tg_z_xxyyzz_0, tg_z_xxyyzz_1, tg_z_xxyzz_1, \
                                         tg_z_xxyzzz_0, tg_z_xxyzzz_1, tg_z_xxzzz_1, tg_z_xxzzzz_0, tg_z_xxzzzz_1, \
                                         tg_z_xyyyy_1, tg_z_xyyyyy_0, tg_z_xyyyyy_1, tg_z_xyyyyz_0, tg_z_xyyyyz_1, \
                                         tg_z_xyyyz_1, tg_z_xyyyzz_0, tg_z_xyyyzz_1, tg_z_xyyzz_1, tg_z_xyyzzz_0, \
                                         tg_z_xyyzzz_1, tg_z_xyzzz_1, tg_z_xyzzzz_0, tg_z_xyzzzz_1, tg_z_xzzzz_1, \
                                         tg_z_xzzzzz_0, tg_z_xzzzzz_1, tg_z_yyyyy_1, tg_z_yyyyyy_0, tg_z_yyyyyy_1, \
                                         tg_z_yyyyyz_0, tg_z_yyyyyz_1, tg_z_yyyyz_1, tg_z_yyyyzz_0, tg_z_yyyyzz_1, \
                                         tg_z_yyyzz_1, tg_z_yyyzzz_0, tg_z_yyyzzz_1, tg_z_yyzzz_1, tg_z_yyzzzz_0, \
                                         tg_z_yyzzzz_1, tg_z_yzzzz_1, tg_z_yzzzzz_0, tg_z_yzzzzz_1, tg_z_zzzzz_1, \
                                         tg_z_zzzzzz_0, tg_z_zzzzzz_1, tg_zz_xxxxxx_0, tg_zz_xxxxxy_0, tg_zz_xxxxxz_0, \
                                         tg_zz_xxxxyy_0, tg_zz_xxxxyz_0, tg_zz_xxxxzz_0, tg_zz_xxxyyy_0, tg_zz_xxxyyz_0, \
                                         tg_zz_xxxyzz_0, tg_zz_xxxzzz_0, tg_zz_xxyyyy_0, tg_zz_xxyyyz_0, tg_zz_xxyyzz_0, \
                                         tg_zz_xxyzzz_0, tg_zz_xxzzzz_0, tg_zz_xyyyyy_0, tg_zz_xyyyyz_0, tg_zz_xyyyzz_0, \
                                         tg_zz_xyyzzz_0, tg_zz_xyzzzz_0, tg_zz_xzzzzz_0, tg_zz_yyyyyy_0, tg_zz_yyyyyz_0, \
                                         tg_zz_yyyyzz_0, tg_zz_yyyzzz_0, tg_zz_yyzzzz_0, tg_zz_yzzzzz_0, tg_zz_zzzzzz_0, wp_y, \
                                         wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yy_xxxxxx_0[j] = pb_y * tg_y_xxxxxx_0[j] + fr * tg_y_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxx_0[j] - tg_0_xxxxxx_1[j] * fl1_fza);

                    tg_yy_xxxxxy_0[j] = pb_y * tg_y_xxxxxy_0[j] + fr * tg_y_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxy_0[j] - tg_0_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxx_1[j];

                    tg_yy_xxxxxz_0[j] = pb_y * tg_y_xxxxxz_0[j] + fr * tg_y_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxz_0[j] - tg_0_xxxxxz_1[j] * fl1_fza);

                    tg_yy_xxxxyy_0[j] = pb_y * tg_y_xxxxyy_0[j] + fr * tg_y_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyy_0[j] - tg_0_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxy_1[j];

                    tg_yy_xxxxyz_0[j] = pb_y * tg_y_xxxxyz_0[j] + fr * tg_y_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyz_0[j] - tg_0_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxz_1[j];

                    tg_yy_xxxxzz_0[j] = pb_y * tg_y_xxxxzz_0[j] + fr * tg_y_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzz_0[j] - tg_0_xxxxzz_1[j] * fl1_fza);

                    tg_yy_xxxyyy_0[j] = pb_y * tg_y_xxxyyy_0[j] + fr * tg_y_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyy_0[j] - tg_0_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxyy_1[j];

                    tg_yy_xxxyyz_0[j] = pb_y * tg_y_xxxyyz_0[j] + fr * tg_y_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyz_0[j] - tg_0_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxyz_1[j];

                    tg_yy_xxxyzz_0[j] = pb_y * tg_y_xxxyzz_0[j] + fr * tg_y_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzz_0[j] - tg_0_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxzz_1[j];

                    tg_yy_xxxzzz_0[j] = pb_y * tg_y_xxxzzz_0[j] + fr * tg_y_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzz_0[j] - tg_0_xxxzzz_1[j] * fl1_fza);

                    tg_yy_xxyyyy_0[j] = pb_y * tg_y_xxyyyy_0[j] + fr * tg_y_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyy_0[j] - tg_0_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxyyy_1[j];

                    tg_yy_xxyyyz_0[j] = pb_y * tg_y_xxyyyz_0[j] + fr * tg_y_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyz_0[j] - tg_0_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxyyz_1[j];

                    tg_yy_xxyyzz_0[j] = pb_y * tg_y_xxyyzz_0[j] + fr * tg_y_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzz_0[j] - tg_0_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxyzz_1[j];

                    tg_yy_xxyzzz_0[j] = pb_y * tg_y_xxyzzz_0[j] + fr * tg_y_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzz_0[j] - tg_0_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxzzz_1[j];

                    tg_yy_xxzzzz_0[j] = pb_y * tg_y_xxzzzz_0[j] + fr * tg_y_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzz_0[j] - tg_0_xxzzzz_1[j] * fl1_fza);

                    tg_yy_xyyyyy_0[j] = pb_y * tg_y_xyyyyy_0[j] + fr * tg_y_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyy_0[j] - tg_0_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xyyyy_1[j];

                    tg_yy_xyyyyz_0[j] = pb_y * tg_y_xyyyyz_0[j] + fr * tg_y_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyz_0[j] - tg_0_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xyyyz_1[j];

                    tg_yy_xyyyzz_0[j] = pb_y * tg_y_xyyyzz_0[j] + fr * tg_y_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzz_0[j] - tg_0_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xyyzz_1[j];

                    tg_yy_xyyzzz_0[j] = pb_y * tg_y_xyyzzz_0[j] + fr * tg_y_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzz_0[j] - tg_0_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xyzzz_1[j];

                    tg_yy_xyzzzz_0[j] = pb_y * tg_y_xyzzzz_0[j] + fr * tg_y_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzz_0[j] - tg_0_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xzzzz_1[j];

                    tg_yy_xzzzzz_0[j] = pb_y * tg_y_xzzzzz_0[j] + fr * tg_y_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzz_0[j] - tg_0_xzzzzz_1[j] * fl1_fza);

                    tg_yy_yyyyyy_0[j] = pb_y * tg_y_yyyyyy_0[j] + fr * tg_y_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyy_0[j] - tg_0_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_yyyyy_1[j];

                    tg_yy_yyyyyz_0[j] = pb_y * tg_y_yyyyyz_0[j] + fr * tg_y_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyz_0[j] - tg_0_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_yyyyz_1[j];

                    tg_yy_yyyyzz_0[j] = pb_y * tg_y_yyyyzz_0[j] + fr * tg_y_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzz_0[j] - tg_0_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_yyyzz_1[j];

                    tg_yy_yyyzzz_0[j] = pb_y * tg_y_yyyzzz_0[j] + fr * tg_y_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzz_0[j] - tg_0_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yyzzz_1[j];

                    tg_yy_yyzzzz_0[j] = pb_y * tg_y_yyzzzz_0[j] + fr * tg_y_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzz_0[j] - tg_0_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_yzzzz_1[j];

                    tg_yy_yzzzzz_0[j] = pb_y * tg_y_yzzzzz_0[j] + fr * tg_y_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzz_0[j] - tg_0_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zzzzz_1[j];

                    tg_yy_zzzzzz_0[j] = pb_y * tg_y_zzzzzz_0[j] + fr * tg_y_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzz_0[j] - tg_0_zzzzzz_1[j] * fl1_fza);

                    tg_yz_xxxxxx_0[j] = pb_y * tg_z_xxxxxx_0[j] + fr * tg_z_xxxxxx_1[j];

                    tg_yz_xxxxxy_0[j] = pb_y * tg_z_xxxxxy_0[j] + fr * tg_z_xxxxxy_1[j] + 0.5 * fl1_fxn * tg_z_xxxxx_1[j];

                    tg_yz_xxxxxz_0[j] = pb_y * tg_z_xxxxxz_0[j] + fr * tg_z_xxxxxz_1[j];

                    tg_yz_xxxxyy_0[j] = pb_y * tg_z_xxxxyy_0[j] + fr * tg_z_xxxxyy_1[j] + fl1_fxn * tg_z_xxxxy_1[j];

                    tg_yz_xxxxyz_0[j] = pb_y * tg_z_xxxxyz_0[j] + fr * tg_z_xxxxyz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxz_1[j];

                    tg_yz_xxxxzz_0[j] = pb_y * tg_z_xxxxzz_0[j] + fr * tg_z_xxxxzz_1[j];

                    tg_yz_xxxyyy_0[j] = pb_y * tg_z_xxxyyy_0[j] + fr * tg_z_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxxyy_1[j];

                    tg_yz_xxxyyz_0[j] = pb_y * tg_z_xxxyyz_0[j] + fr * tg_z_xxxyyz_1[j] + fl1_fxn * tg_z_xxxyz_1[j];

                    tg_yz_xxxyzz_0[j] = pb_y * tg_z_xxxyzz_0[j] + fr * tg_z_xxxyzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxzz_1[j];

                    tg_yz_xxxzzz_0[j] = pb_y * tg_z_xxxzzz_0[j] + fr * tg_z_xxxzzz_1[j];

                    tg_yz_xxyyyy_0[j] = pb_y * tg_z_xxyyyy_0[j] + fr * tg_z_xxyyyy_1[j] + 2.0 * fl1_fxn * tg_z_xxyyy_1[j];

                    tg_yz_xxyyyz_0[j] = pb_y * tg_z_xxyyyz_0[j] + fr * tg_z_xxyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyz_1[j];

                    tg_yz_xxyyzz_0[j] = pb_y * tg_z_xxyyzz_0[j] + fr * tg_z_xxyyzz_1[j] + fl1_fxn * tg_z_xxyzz_1[j];

                    tg_yz_xxyzzz_0[j] = pb_y * tg_z_xxyzzz_0[j] + fr * tg_z_xxyzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxzzz_1[j];

                    tg_yz_xxzzzz_0[j] = pb_y * tg_z_xxzzzz_0[j] + fr * tg_z_xxzzzz_1[j];

                    tg_yz_xyyyyy_0[j] = pb_y * tg_z_xyyyyy_0[j] + fr * tg_z_xyyyyy_1[j] + 2.5 * fl1_fxn * tg_z_xyyyy_1[j];

                    tg_yz_xyyyyz_0[j] = pb_y * tg_z_xyyyyz_0[j] + fr * tg_z_xyyyyz_1[j] + 2.0 * fl1_fxn * tg_z_xyyyz_1[j];

                    tg_yz_xyyyzz_0[j] = pb_y * tg_z_xyyyzz_0[j] + fr * tg_z_xyyyzz_1[j] + 1.5 * fl1_fxn * tg_z_xyyzz_1[j];

                    tg_yz_xyyzzz_0[j] = pb_y * tg_z_xyyzzz_0[j] + fr * tg_z_xyyzzz_1[j] + fl1_fxn * tg_z_xyzzz_1[j];

                    tg_yz_xyzzzz_0[j] = pb_y * tg_z_xyzzzz_0[j] + fr * tg_z_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xzzzz_1[j];

                    tg_yz_xzzzzz_0[j] = pb_y * tg_z_xzzzzz_0[j] + fr * tg_z_xzzzzz_1[j];

                    tg_yz_yyyyyy_0[j] = pb_y * tg_z_yyyyyy_0[j] + fr * tg_z_yyyyyy_1[j] + 3.0 * fl1_fxn * tg_z_yyyyy_1[j];

                    tg_yz_yyyyyz_0[j] = pb_y * tg_z_yyyyyz_0[j] + fr * tg_z_yyyyyz_1[j] + 2.5 * fl1_fxn * tg_z_yyyyz_1[j];

                    tg_yz_yyyyzz_0[j] = pb_y * tg_z_yyyyzz_0[j] + fr * tg_z_yyyyzz_1[j] + 2.0 * fl1_fxn * tg_z_yyyzz_1[j];

                    tg_yz_yyyzzz_0[j] = pb_y * tg_z_yyyzzz_0[j] + fr * tg_z_yyyzzz_1[j] + 1.5 * fl1_fxn * tg_z_yyzzz_1[j];

                    tg_yz_yyzzzz_0[j] = pb_y * tg_z_yyzzzz_0[j] + fr * tg_z_yyzzzz_1[j] + fl1_fxn * tg_z_yzzzz_1[j];

                    tg_yz_yzzzzz_0[j] = pb_y * tg_z_yzzzzz_0[j] + fr * tg_z_yzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzz_1[j];

                    tg_yz_zzzzzz_0[j] = pb_y * tg_z_zzzzzz_0[j] + fr * tg_z_zzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxxxxx_0[j] = pb_z * tg_z_xxxxxx_0[j] + fr * tg_z_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxx_0[j] - tg_0_xxxxxx_1[j] * fl1_fza);

                    tg_zz_xxxxxy_0[j] = pb_z * tg_z_xxxxxy_0[j] + fr * tg_z_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxy_0[j] - tg_0_xxxxxy_1[j] * fl1_fza);

                    tg_zz_xxxxxz_0[j] = pb_z * tg_z_xxxxxz_0[j] + fr * tg_z_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxz_0[j] - tg_0_xxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxx_1[j];

                    tg_zz_xxxxyy_0[j] = pb_z * tg_z_xxxxyy_0[j] + fr * tg_z_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyy_0[j] - tg_0_xxxxyy_1[j] * fl1_fza);

                    tg_zz_xxxxyz_0[j] = pb_z * tg_z_xxxxyz_0[j] + fr * tg_z_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyz_0[j] - tg_0_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxy_1[j];

                    tg_zz_xxxxzz_0[j] = pb_z * tg_z_xxxxzz_0[j] + fr * tg_z_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzz_0[j] - tg_0_xxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxz_1[j];

                    tg_zz_xxxyyy_0[j] = pb_z * tg_z_xxxyyy_0[j] + fr * tg_z_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyy_0[j] - tg_0_xxxyyy_1[j] * fl1_fza);

                    tg_zz_xxxyyz_0[j] = pb_z * tg_z_xxxyyz_0[j] + fr * tg_z_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyz_0[j] - tg_0_xxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxyy_1[j];

                    tg_zz_xxxyzz_0[j] = pb_z * tg_z_xxxyzz_0[j] + fr * tg_z_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzz_0[j] - tg_0_xxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxyz_1[j];

                    tg_zz_xxxzzz_0[j] = pb_z * tg_z_xxxzzz_0[j] + fr * tg_z_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzz_0[j] - tg_0_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxzz_1[j];

                    tg_zz_xxyyyy_0[j] = pb_z * tg_z_xxyyyy_0[j] + fr * tg_z_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyy_0[j] - tg_0_xxyyyy_1[j] * fl1_fza);

                    tg_zz_xxyyyz_0[j] = pb_z * tg_z_xxyyyz_0[j] + fr * tg_z_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyz_0[j] - tg_0_xxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxyyy_1[j];

                    tg_zz_xxyyzz_0[j] = pb_z * tg_z_xxyyzz_0[j] + fr * tg_z_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzz_0[j] - tg_0_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxyyz_1[j];

                    tg_zz_xxyzzz_0[j] = pb_z * tg_z_xxyzzz_0[j] + fr * tg_z_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzz_0[j] - tg_0_xxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxyzz_1[j];

                    tg_zz_xxzzzz_0[j] = pb_z * tg_z_xxzzzz_0[j] + fr * tg_z_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzz_0[j] - tg_0_xxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxzzz_1[j];

                    tg_zz_xyyyyy_0[j] = pb_z * tg_z_xyyyyy_0[j] + fr * tg_z_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyy_0[j] - tg_0_xyyyyy_1[j] * fl1_fza);

                    tg_zz_xyyyyz_0[j] = pb_z * tg_z_xyyyyz_0[j] + fr * tg_z_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyz_0[j] - tg_0_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xyyyy_1[j];

                    tg_zz_xyyyzz_0[j] = pb_z * tg_z_xyyyzz_0[j] + fr * tg_z_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzz_0[j] - tg_0_xyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xyyyz_1[j];

                    tg_zz_xyyzzz_0[j] = pb_z * tg_z_xyyzzz_0[j] + fr * tg_z_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzz_0[j] - tg_0_xyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xyyzz_1[j];

                    tg_zz_xyzzzz_0[j] = pb_z * tg_z_xyzzzz_0[j] + fr * tg_z_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzz_0[j] - tg_0_xyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xyzzz_1[j];

                    tg_zz_xzzzzz_0[j] = pb_z * tg_z_xzzzzz_0[j] + fr * tg_z_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzz_0[j] - tg_0_xzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xzzzz_1[j];

                    tg_zz_yyyyyy_0[j] = pb_z * tg_z_yyyyyy_0[j] + fr * tg_z_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyy_0[j] - tg_0_yyyyyy_1[j] * fl1_fza);

                    tg_zz_yyyyyz_0[j] = pb_z * tg_z_yyyyyz_0[j] + fr * tg_z_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyz_0[j] - tg_0_yyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yyyyy_1[j];

                    tg_zz_yyyyzz_0[j] = pb_z * tg_z_yyyyzz_0[j] + fr * tg_z_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzz_0[j] - tg_0_yyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yyyyz_1[j];

                    tg_zz_yyyzzz_0[j] = pb_z * tg_z_yyyzzz_0[j] + fr * tg_z_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzz_0[j] - tg_0_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_yyyzz_1[j];

                    tg_zz_yyzzzz_0[j] = pb_z * tg_z_yyzzzz_0[j] + fr * tg_z_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzz_0[j] - tg_0_yyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_yyzzz_1[j];

                    tg_zz_yzzzzz_0[j] = pb_z * tg_z_yzzzzz_0[j] + fr * tg_z_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzz_0[j] - tg_0_yzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_yzzzz_1[j];

                    tg_zz_zzzzzz_0[j] = pb_z * tg_z_zzzzzz_0[j] + fr * tg_z_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzz_0[j] - tg_0_zzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_zzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSISD_0_84(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSISD_84_168(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 
    }

    void
    compElectronRepulsionForSISD_0_84(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,84)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxx_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx); 

                auto tg_xxxxx_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 1); 

                auto tg_xxxxx_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 2); 

                auto tg_xxxxx_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 3); 

                auto tg_xxxxx_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 4); 

                auto tg_xxxxx_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 5); 

                auto tg_xxxxy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 6); 

                auto tg_xxxxy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 7); 

                auto tg_xxxxy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 8); 

                auto tg_xxxxy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 9); 

                auto tg_xxxxy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 10); 

                auto tg_xxxxy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 11); 

                auto tg_xxxxz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 12); 

                auto tg_xxxxz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 13); 

                auto tg_xxxxz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 14); 

                auto tg_xxxxz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 15); 

                auto tg_xxxxz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 16); 

                auto tg_xxxxz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 17); 

                auto tg_xxxyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 18); 

                auto tg_xxxyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 19); 

                auto tg_xxxyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 20); 

                auto tg_xxxyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 21); 

                auto tg_xxxyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 22); 

                auto tg_xxxyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 23); 

                auto tg_xxxyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 24); 

                auto tg_xxxyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 25); 

                auto tg_xxxyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 26); 

                auto tg_xxxyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 27); 

                auto tg_xxxyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 28); 

                auto tg_xxxyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 29); 

                auto tg_xxxzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 30); 

                auto tg_xxxzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 31); 

                auto tg_xxxzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 32); 

                auto tg_xxxzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 33); 

                auto tg_xxxzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 34); 

                auto tg_xxxzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 35); 

                auto tg_xxyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 36); 

                auto tg_xxyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 37); 

                auto tg_xxyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 38); 

                auto tg_xxyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 39); 

                auto tg_xxyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 40); 

                auto tg_xxyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 41); 

                auto tg_xxyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 42); 

                auto tg_xxyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 43); 

                auto tg_xxyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 44); 

                auto tg_xxyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 45); 

                auto tg_xxyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 46); 

                auto tg_xxyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 47); 

                auto tg_xxyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 48); 

                auto tg_xxyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 49); 

                auto tg_xxyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 50); 

                auto tg_xxyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 51); 

                auto tg_xxyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 52); 

                auto tg_xxyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 53); 

                auto tg_xxzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 54); 

                auto tg_xxzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 55); 

                auto tg_xxzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 56); 

                auto tg_xxzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 57); 

                auto tg_xxzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 58); 

                auto tg_xxzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 59); 

                auto tg_xyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 60); 

                auto tg_xyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 61); 

                auto tg_xyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 62); 

                auto tg_xyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 63); 

                auto tg_xyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 64); 

                auto tg_xyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 65); 

                auto tg_xyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 66); 

                auto tg_xyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 67); 

                auto tg_xyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 68); 

                auto tg_xyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 69); 

                auto tg_xyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 70); 

                auto tg_xyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 71); 

                auto tg_xyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 72); 

                auto tg_xyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 73); 

                auto tg_xyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 74); 

                auto tg_xyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 75); 

                auto tg_xyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 76); 

                auto tg_xyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 77); 

                auto tg_xyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 78); 

                auto tg_xyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 79); 

                auto tg_xyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 80); 

                auto tg_xyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 81); 

                auto tg_xyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 82); 

                auto tg_xyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 83); 

                auto tg_xxxxx_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx); 

                auto tg_xxxxx_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 1); 

                auto tg_xxxxx_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 2); 

                auto tg_xxxxx_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 3); 

                auto tg_xxxxx_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 4); 

                auto tg_xxxxx_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 5); 

                auto tg_xxxxy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 6); 

                auto tg_xxxxy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 7); 

                auto tg_xxxxy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 8); 

                auto tg_xxxxy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 9); 

                auto tg_xxxxy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 10); 

                auto tg_xxxxy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 11); 

                auto tg_xxxxz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 12); 

                auto tg_xxxxz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 13); 

                auto tg_xxxxz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 14); 

                auto tg_xxxxz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 15); 

                auto tg_xxxxz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 16); 

                auto tg_xxxxz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 17); 

                auto tg_xxxyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 18); 

                auto tg_xxxyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 19); 

                auto tg_xxxyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 20); 

                auto tg_xxxyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 21); 

                auto tg_xxxyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 22); 

                auto tg_xxxyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 23); 

                auto tg_xxxyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 24); 

                auto tg_xxxyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 25); 

                auto tg_xxxyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 26); 

                auto tg_xxxyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 27); 

                auto tg_xxxyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 28); 

                auto tg_xxxyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 29); 

                auto tg_xxxzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 30); 

                auto tg_xxxzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 31); 

                auto tg_xxxzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 32); 

                auto tg_xxxzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 33); 

                auto tg_xxxzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 34); 

                auto tg_xxxzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 35); 

                auto tg_xxyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 36); 

                auto tg_xxyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 37); 

                auto tg_xxyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 38); 

                auto tg_xxyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 39); 

                auto tg_xxyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 40); 

                auto tg_xxyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 41); 

                auto tg_xxyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 42); 

                auto tg_xxyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 43); 

                auto tg_xxyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 44); 

                auto tg_xxyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 45); 

                auto tg_xxyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 46); 

                auto tg_xxyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 47); 

                auto tg_xxyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 48); 

                auto tg_xxyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 49); 

                auto tg_xxyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 50); 

                auto tg_xxyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 51); 

                auto tg_xxyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 52); 

                auto tg_xxyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 53); 

                auto tg_xxzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 54); 

                auto tg_xxzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 55); 

                auto tg_xxzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 56); 

                auto tg_xxzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 57); 

                auto tg_xxzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 58); 

                auto tg_xxzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 59); 

                auto tg_xyyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 60); 

                auto tg_xyyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 61); 

                auto tg_xyyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 62); 

                auto tg_xyyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 63); 

                auto tg_xyyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 64); 

                auto tg_xyyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 65); 

                auto tg_xyyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 66); 

                auto tg_xyyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 67); 

                auto tg_xyyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 68); 

                auto tg_xyyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 69); 

                auto tg_xyyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 70); 

                auto tg_xyyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 71); 

                auto tg_xyyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 72); 

                auto tg_xyyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 73); 

                auto tg_xyyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 74); 

                auto tg_xyyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 75); 

                auto tg_xyyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 76); 

                auto tg_xyyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 77); 

                auto tg_xyzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 78); 

                auto tg_xyzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 79); 

                auto tg_xyzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 80); 

                auto tg_xyzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 81); 

                auto tg_xyzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 82); 

                auto tg_xyzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 83); 

                auto tg_xxxx_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx); 

                auto tg_xxxx_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 1); 

                auto tg_xxxx_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 2); 

                auto tg_xxxx_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 3); 

                auto tg_xxxx_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 4); 

                auto tg_xxxx_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 5); 

                auto tg_xxxy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 6); 

                auto tg_xxxy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 7); 

                auto tg_xxxy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 8); 

                auto tg_xxxy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 9); 

                auto tg_xxxy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 10); 

                auto tg_xxxy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 11); 

                auto tg_xxxz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 12); 

                auto tg_xxxz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 13); 

                auto tg_xxxz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 14); 

                auto tg_xxxz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 15); 

                auto tg_xxxz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 16); 

                auto tg_xxxz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 17); 

                auto tg_xxyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 18); 

                auto tg_xxyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 19); 

                auto tg_xxyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 20); 

                auto tg_xxyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 21); 

                auto tg_xxyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 22); 

                auto tg_xxyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 23); 

                auto tg_xxyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 24); 

                auto tg_xxyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 25); 

                auto tg_xxyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 26); 

                auto tg_xxyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 27); 

                auto tg_xxyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 28); 

                auto tg_xxyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 29); 

                auto tg_xxzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 30); 

                auto tg_xxzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 31); 

                auto tg_xxzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 32); 

                auto tg_xxzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 33); 

                auto tg_xxzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 34); 

                auto tg_xxzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 35); 

                auto tg_xyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 36); 

                auto tg_xyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 37); 

                auto tg_xyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 38); 

                auto tg_xyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 39); 

                auto tg_xyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 40); 

                auto tg_xyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 41); 

                auto tg_xyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 42); 

                auto tg_xyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 43); 

                auto tg_xyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 44); 

                auto tg_xyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 45); 

                auto tg_xyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 46); 

                auto tg_xyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 47); 

                auto tg_xyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 48); 

                auto tg_xyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 49); 

                auto tg_xyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 50); 

                auto tg_xyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 51); 

                auto tg_xyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 52); 

                auto tg_xyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 53); 

                auto tg_xzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 54); 

                auto tg_xzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 55); 

                auto tg_xzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 56); 

                auto tg_xzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 57); 

                auto tg_xzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 58); 

                auto tg_xzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 59); 

                auto tg_yyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 60); 

                auto tg_yyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 61); 

                auto tg_yyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 62); 

                auto tg_yyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 63); 

                auto tg_yyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 64); 

                auto tg_yyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 65); 

                auto tg_yyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 66); 

                auto tg_yyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 67); 

                auto tg_yyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 68); 

                auto tg_yyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 69); 

                auto tg_yyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 70); 

                auto tg_yyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 71); 

                auto tg_yyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 72); 

                auto tg_yyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 73); 

                auto tg_yyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 74); 

                auto tg_yyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 75); 

                auto tg_yyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 76); 

                auto tg_yyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 77); 

                auto tg_yzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 78); 

                auto tg_yzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 79); 

                auto tg_yzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 80); 

                auto tg_yzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 81); 

                auto tg_yzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 82); 

                auto tg_yzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 83); 

                auto tg_xxxx_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx); 

                auto tg_xxxx_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 1); 

                auto tg_xxxx_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 2); 

                auto tg_xxxx_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 3); 

                auto tg_xxxx_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 4); 

                auto tg_xxxx_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 5); 

                auto tg_xxxy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 6); 

                auto tg_xxxy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 7); 

                auto tg_xxxy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 8); 

                auto tg_xxxy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 9); 

                auto tg_xxxy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 10); 

                auto tg_xxxy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 11); 

                auto tg_xxxz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 12); 

                auto tg_xxxz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 13); 

                auto tg_xxxz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 14); 

                auto tg_xxxz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 15); 

                auto tg_xxxz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 16); 

                auto tg_xxxz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 17); 

                auto tg_xxyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 18); 

                auto tg_xxyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 19); 

                auto tg_xxyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 20); 

                auto tg_xxyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 21); 

                auto tg_xxyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 22); 

                auto tg_xxyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 23); 

                auto tg_xxyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 24); 

                auto tg_xxyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 25); 

                auto tg_xxyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 26); 

                auto tg_xxyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 27); 

                auto tg_xxyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 28); 

                auto tg_xxyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 29); 

                auto tg_xxzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 30); 

                auto tg_xxzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 31); 

                auto tg_xxzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 32); 

                auto tg_xxzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 33); 

                auto tg_xxzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 34); 

                auto tg_xxzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 35); 

                auto tg_xyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 36); 

                auto tg_xyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 37); 

                auto tg_xyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 38); 

                auto tg_xyyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 39); 

                auto tg_xyyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 40); 

                auto tg_xyyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 41); 

                auto tg_xyyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 42); 

                auto tg_xyyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 43); 

                auto tg_xyyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 44); 

                auto tg_xyyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 45); 

                auto tg_xyyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 46); 

                auto tg_xyyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 47); 

                auto tg_xyzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 48); 

                auto tg_xyzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 49); 

                auto tg_xyzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 50); 

                auto tg_xyzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 51); 

                auto tg_xyzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 52); 

                auto tg_xyzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 53); 

                auto tg_xzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 54); 

                auto tg_xzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 55); 

                auto tg_xzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 56); 

                auto tg_xzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 57); 

                auto tg_xzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 58); 

                auto tg_xzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 59); 

                auto tg_yyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 60); 

                auto tg_yyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 61); 

                auto tg_yyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 62); 

                auto tg_yyyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 63); 

                auto tg_yyyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 64); 

                auto tg_yyyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 65); 

                auto tg_yyyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 66); 

                auto tg_yyyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 67); 

                auto tg_yyyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 68); 

                auto tg_yyyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 69); 

                auto tg_yyyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 70); 

                auto tg_yyyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 71); 

                auto tg_yyzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 72); 

                auto tg_yyzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 73); 

                auto tg_yyzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 74); 

                auto tg_yyzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 75); 

                auto tg_yyzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 76); 

                auto tg_yyzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 77); 

                auto tg_yzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 78); 

                auto tg_yzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 79); 

                auto tg_yzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 80); 

                auto tg_yzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 81); 

                auto tg_yzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 82); 

                auto tg_yzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 83); 

                auto tg_xxxxx_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx); 

                auto tg_xxxxx_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 1); 

                auto tg_xxxxx_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 2); 

                auto tg_xxxxy_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 3); 

                auto tg_xxxxy_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 4); 

                auto tg_xxxxy_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 5); 

                auto tg_xxxxz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 6); 

                auto tg_xxxxz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 7); 

                auto tg_xxxxz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 8); 

                auto tg_xxxyy_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 9); 

                auto tg_xxxyy_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 10); 

                auto tg_xxxyy_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 11); 

                auto tg_xxxyz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 12); 

                auto tg_xxxyz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 13); 

                auto tg_xxxyz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 14); 

                auto tg_xxxzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 15); 

                auto tg_xxxzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 16); 

                auto tg_xxxzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 17); 

                auto tg_xxyyy_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 18); 

                auto tg_xxyyy_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 19); 

                auto tg_xxyyy_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 20); 

                auto tg_xxyyz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 21); 

                auto tg_xxyyz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 22); 

                auto tg_xxyyz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 23); 

                auto tg_xxyzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 24); 

                auto tg_xxyzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 25); 

                auto tg_xxyzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 26); 

                auto tg_xxzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 27); 

                auto tg_xxzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 28); 

                auto tg_xxzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 29); 

                auto tg_xyyyy_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 30); 

                auto tg_xyyyy_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 31); 

                auto tg_xyyyy_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 32); 

                auto tg_xyyyz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 33); 

                auto tg_xyyyz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 34); 

                auto tg_xyyyz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 35); 

                auto tg_xyyzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 36); 

                auto tg_xyyzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 37); 

                auto tg_xyyzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 38); 

                auto tg_xyzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 39); 

                auto tg_xyzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 40); 

                auto tg_xyzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 41); 

                // set up pointers to integrals

                auto tg_xxxxxx_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx); 

                auto tg_xxxxxx_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 1); 

                auto tg_xxxxxx_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 2); 

                auto tg_xxxxxx_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 3); 

                auto tg_xxxxxx_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 4); 

                auto tg_xxxxxx_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 5); 

                auto tg_xxxxxy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 6); 

                auto tg_xxxxxy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 7); 

                auto tg_xxxxxy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 8); 

                auto tg_xxxxxy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 9); 

                auto tg_xxxxxy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 10); 

                auto tg_xxxxxy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 11); 

                auto tg_xxxxxz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 12); 

                auto tg_xxxxxz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 13); 

                auto tg_xxxxxz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 14); 

                auto tg_xxxxxz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 15); 

                auto tg_xxxxxz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 16); 

                auto tg_xxxxxz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 17); 

                auto tg_xxxxyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 18); 

                auto tg_xxxxyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 19); 

                auto tg_xxxxyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 20); 

                auto tg_xxxxyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 21); 

                auto tg_xxxxyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 22); 

                auto tg_xxxxyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 23); 

                auto tg_xxxxyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 24); 

                auto tg_xxxxyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 25); 

                auto tg_xxxxyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 26); 

                auto tg_xxxxyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 27); 

                auto tg_xxxxyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 28); 

                auto tg_xxxxyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 29); 

                auto tg_xxxxzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 30); 

                auto tg_xxxxzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 31); 

                auto tg_xxxxzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 32); 

                auto tg_xxxxzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 33); 

                auto tg_xxxxzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 34); 

                auto tg_xxxxzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 35); 

                auto tg_xxxyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 36); 

                auto tg_xxxyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 37); 

                auto tg_xxxyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 38); 

                auto tg_xxxyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 39); 

                auto tg_xxxyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 40); 

                auto tg_xxxyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 41); 

                auto tg_xxxyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 42); 

                auto tg_xxxyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 43); 

                auto tg_xxxyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 44); 

                auto tg_xxxyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 45); 

                auto tg_xxxyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 46); 

                auto tg_xxxyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 47); 

                auto tg_xxxyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 48); 

                auto tg_xxxyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 49); 

                auto tg_xxxyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 50); 

                auto tg_xxxyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 51); 

                auto tg_xxxyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 52); 

                auto tg_xxxyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 53); 

                auto tg_xxxzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 54); 

                auto tg_xxxzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 55); 

                auto tg_xxxzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 56); 

                auto tg_xxxzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 57); 

                auto tg_xxxzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 58); 

                auto tg_xxxzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 59); 

                auto tg_xxyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 60); 

                auto tg_xxyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 61); 

                auto tg_xxyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 62); 

                auto tg_xxyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 63); 

                auto tg_xxyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 64); 

                auto tg_xxyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 65); 

                auto tg_xxyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 66); 

                auto tg_xxyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 67); 

                auto tg_xxyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 68); 

                auto tg_xxyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 69); 

                auto tg_xxyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 70); 

                auto tg_xxyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 71); 

                auto tg_xxyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 72); 

                auto tg_xxyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 73); 

                auto tg_xxyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 74); 

                auto tg_xxyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 75); 

                auto tg_xxyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 76); 

                auto tg_xxyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 77); 

                auto tg_xxyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 78); 

                auto tg_xxyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 79); 

                auto tg_xxyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 80); 

                auto tg_xxyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 81); 

                auto tg_xxyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 82); 

                auto tg_xxyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 83); 

                // Batch of Integrals (0,84)

                #pragma omp simd aligned(fxn, fza, tg_xxxx_xx_0, tg_xxxx_xx_1, tg_xxxx_xy_0, tg_xxxx_xy_1, \
                                         tg_xxxx_xz_0, tg_xxxx_xz_1, tg_xxxx_yy_0, tg_xxxx_yy_1, tg_xxxx_yz_0, tg_xxxx_yz_1, \
                                         tg_xxxx_zz_0, tg_xxxx_zz_1, tg_xxxxx_x_1, tg_xxxxx_xx_0, tg_xxxxx_xx_1, \
                                         tg_xxxxx_xy_0, tg_xxxxx_xy_1, tg_xxxxx_xz_0, tg_xxxxx_xz_1, tg_xxxxx_y_1, \
                                         tg_xxxxx_yy_0, tg_xxxxx_yy_1, tg_xxxxx_yz_0, tg_xxxxx_yz_1, tg_xxxxx_z_1, \
                                         tg_xxxxx_zz_0, tg_xxxxx_zz_1, tg_xxxxxx_xx_0, tg_xxxxxx_xy_0, tg_xxxxxx_xz_0, \
                                         tg_xxxxxx_yy_0, tg_xxxxxx_yz_0, tg_xxxxxx_zz_0, tg_xxxxxy_xx_0, tg_xxxxxy_xy_0, \
                                         tg_xxxxxy_xz_0, tg_xxxxxy_yy_0, tg_xxxxxy_yz_0, tg_xxxxxy_zz_0, tg_xxxxxz_xx_0, \
                                         tg_xxxxxz_xy_0, tg_xxxxxz_xz_0, tg_xxxxxz_yy_0, tg_xxxxxz_yz_0, tg_xxxxxz_zz_0, \
                                         tg_xxxxy_x_1, tg_xxxxy_xx_0, tg_xxxxy_xx_1, tg_xxxxy_xy_0, tg_xxxxy_xy_1, \
                                         tg_xxxxy_xz_0, tg_xxxxy_xz_1, tg_xxxxy_y_1, tg_xxxxy_yy_0, tg_xxxxy_yy_1, \
                                         tg_xxxxy_yz_0, tg_xxxxy_yz_1, tg_xxxxy_z_1, tg_xxxxy_zz_0, tg_xxxxy_zz_1, \
                                         tg_xxxxyy_xx_0, tg_xxxxyy_xy_0, tg_xxxxyy_xz_0, tg_xxxxyy_yy_0, tg_xxxxyy_yz_0, \
                                         tg_xxxxyy_zz_0, tg_xxxxyz_xx_0, tg_xxxxyz_xy_0, tg_xxxxyz_xz_0, tg_xxxxyz_yy_0, \
                                         tg_xxxxyz_yz_0, tg_xxxxyz_zz_0, tg_xxxxz_x_1, tg_xxxxz_xx_0, tg_xxxxz_xx_1, \
                                         tg_xxxxz_xy_0, tg_xxxxz_xy_1, tg_xxxxz_xz_0, tg_xxxxz_xz_1, tg_xxxxz_y_1, \
                                         tg_xxxxz_yy_0, tg_xxxxz_yy_1, tg_xxxxz_yz_0, tg_xxxxz_yz_1, tg_xxxxz_z_1, \
                                         tg_xxxxz_zz_0, tg_xxxxz_zz_1, tg_xxxxzz_xx_0, tg_xxxxzz_xy_0, tg_xxxxzz_xz_0, \
                                         tg_xxxxzz_yy_0, tg_xxxxzz_yz_0, tg_xxxxzz_zz_0, tg_xxxy_xx_0, tg_xxxy_xx_1, \
                                         tg_xxxy_xy_0, tg_xxxy_xy_1, tg_xxxy_xz_0, tg_xxxy_xz_1, tg_xxxy_yy_0, tg_xxxy_yy_1, \
                                         tg_xxxy_yz_0, tg_xxxy_yz_1, tg_xxxy_zz_0, tg_xxxy_zz_1, tg_xxxyy_x_1, \
                                         tg_xxxyy_xx_0, tg_xxxyy_xx_1, tg_xxxyy_xy_0, tg_xxxyy_xy_1, tg_xxxyy_xz_0, \
                                         tg_xxxyy_xz_1, tg_xxxyy_y_1, tg_xxxyy_yy_0, tg_xxxyy_yy_1, tg_xxxyy_yz_0, \
                                         tg_xxxyy_yz_1, tg_xxxyy_z_1, tg_xxxyy_zz_0, tg_xxxyy_zz_1, tg_xxxyyy_xx_0, \
                                         tg_xxxyyy_xy_0, tg_xxxyyy_xz_0, tg_xxxyyy_yy_0, tg_xxxyyy_yz_0, tg_xxxyyy_zz_0, \
                                         tg_xxxyyz_xx_0, tg_xxxyyz_xy_0, tg_xxxyyz_xz_0, tg_xxxyyz_yy_0, tg_xxxyyz_yz_0, \
                                         tg_xxxyyz_zz_0, tg_xxxyz_x_1, tg_xxxyz_xx_0, tg_xxxyz_xx_1, tg_xxxyz_xy_0, \
                                         tg_xxxyz_xy_1, tg_xxxyz_xz_0, tg_xxxyz_xz_1, tg_xxxyz_y_1, tg_xxxyz_yy_0, \
                                         tg_xxxyz_yy_1, tg_xxxyz_yz_0, tg_xxxyz_yz_1, tg_xxxyz_z_1, tg_xxxyz_zz_0, \
                                         tg_xxxyz_zz_1, tg_xxxyzz_xx_0, tg_xxxyzz_xy_0, tg_xxxyzz_xz_0, tg_xxxyzz_yy_0, \
                                         tg_xxxyzz_yz_0, tg_xxxyzz_zz_0, tg_xxxz_xx_0, tg_xxxz_xx_1, tg_xxxz_xy_0, \
                                         tg_xxxz_xy_1, tg_xxxz_xz_0, tg_xxxz_xz_1, tg_xxxz_yy_0, tg_xxxz_yy_1, tg_xxxz_yz_0, \
                                         tg_xxxz_yz_1, tg_xxxz_zz_0, tg_xxxz_zz_1, tg_xxxzz_x_1, tg_xxxzz_xx_0, \
                                         tg_xxxzz_xx_1, tg_xxxzz_xy_0, tg_xxxzz_xy_1, tg_xxxzz_xz_0, tg_xxxzz_xz_1, \
                                         tg_xxxzz_y_1, tg_xxxzz_yy_0, tg_xxxzz_yy_1, tg_xxxzz_yz_0, tg_xxxzz_yz_1, \
                                         tg_xxxzz_z_1, tg_xxxzz_zz_0, tg_xxxzz_zz_1, tg_xxxzzz_xx_0, tg_xxxzzz_xy_0, \
                                         tg_xxxzzz_xz_0, tg_xxxzzz_yy_0, tg_xxxzzz_yz_0, tg_xxxzzz_zz_0, tg_xxyy_xx_0, \
                                         tg_xxyy_xx_1, tg_xxyy_xy_0, tg_xxyy_xy_1, tg_xxyy_xz_0, tg_xxyy_xz_1, tg_xxyy_yy_0, \
                                         tg_xxyy_yy_1, tg_xxyy_yz_0, tg_xxyy_yz_1, tg_xxyy_zz_0, tg_xxyy_zz_1, tg_xxyyy_x_1, \
                                         tg_xxyyy_xx_0, tg_xxyyy_xx_1, tg_xxyyy_xy_0, tg_xxyyy_xy_1, tg_xxyyy_xz_0, \
                                         tg_xxyyy_xz_1, tg_xxyyy_y_1, tg_xxyyy_yy_0, tg_xxyyy_yy_1, tg_xxyyy_yz_0, \
                                         tg_xxyyy_yz_1, tg_xxyyy_z_1, tg_xxyyy_zz_0, tg_xxyyy_zz_1, tg_xxyyyy_xx_0, \
                                         tg_xxyyyy_xy_0, tg_xxyyyy_xz_0, tg_xxyyyy_yy_0, tg_xxyyyy_yz_0, tg_xxyyyy_zz_0, \
                                         tg_xxyyyz_xx_0, tg_xxyyyz_xy_0, tg_xxyyyz_xz_0, tg_xxyyyz_yy_0, tg_xxyyyz_yz_0, \
                                         tg_xxyyyz_zz_0, tg_xxyyz_x_1, tg_xxyyz_xx_0, tg_xxyyz_xx_1, tg_xxyyz_xy_0, \
                                         tg_xxyyz_xy_1, tg_xxyyz_xz_0, tg_xxyyz_xz_1, tg_xxyyz_y_1, tg_xxyyz_yy_0, \
                                         tg_xxyyz_yy_1, tg_xxyyz_yz_0, tg_xxyyz_yz_1, tg_xxyyz_z_1, tg_xxyyz_zz_0, \
                                         tg_xxyyz_zz_1, tg_xxyyzz_xx_0, tg_xxyyzz_xy_0, tg_xxyyzz_xz_0, tg_xxyyzz_yy_0, \
                                         tg_xxyyzz_yz_0, tg_xxyyzz_zz_0, tg_xxyz_xx_0, tg_xxyz_xx_1, tg_xxyz_xy_0, \
                                         tg_xxyz_xy_1, tg_xxyz_xz_0, tg_xxyz_xz_1, tg_xxyz_yy_0, tg_xxyz_yy_1, tg_xxyz_yz_0, \
                                         tg_xxyz_yz_1, tg_xxyz_zz_0, tg_xxyz_zz_1, tg_xxyzz_x_1, tg_xxyzz_xx_0, \
                                         tg_xxyzz_xx_1, tg_xxyzz_xy_0, tg_xxyzz_xy_1, tg_xxyzz_xz_0, tg_xxyzz_xz_1, \
                                         tg_xxyzz_y_1, tg_xxyzz_yy_0, tg_xxyzz_yy_1, tg_xxyzz_yz_0, tg_xxyzz_yz_1, \
                                         tg_xxyzz_z_1, tg_xxyzz_zz_0, tg_xxyzz_zz_1, tg_xxyzzz_xx_0, tg_xxyzzz_xy_0, \
                                         tg_xxyzzz_xz_0, tg_xxyzzz_yy_0, tg_xxyzzz_yz_0, tg_xxyzzz_zz_0, tg_xxzz_xx_0, \
                                         tg_xxzz_xx_1, tg_xxzz_xy_0, tg_xxzz_xy_1, tg_xxzz_xz_0, tg_xxzz_xz_1, tg_xxzz_yy_0, \
                                         tg_xxzz_yy_1, tg_xxzz_yz_0, tg_xxzz_yz_1, tg_xxzz_zz_0, tg_xxzz_zz_1, tg_xxzzz_x_1, \
                                         tg_xxzzz_xx_0, tg_xxzzz_xx_1, tg_xxzzz_xy_0, tg_xxzzz_xy_1, tg_xxzzz_xz_0, \
                                         tg_xxzzz_xz_1, tg_xxzzz_y_1, tg_xxzzz_yy_0, tg_xxzzz_yy_1, tg_xxzzz_yz_0, \
                                         tg_xxzzz_yz_1, tg_xxzzz_z_1, tg_xxzzz_zz_0, tg_xxzzz_zz_1, tg_xyyy_xx_0, \
                                         tg_xyyy_xx_1, tg_xyyy_xy_0, tg_xyyy_xy_1, tg_xyyy_xz_0, tg_xyyy_xz_1, tg_xyyy_yy_0, \
                                         tg_xyyy_yy_1, tg_xyyy_yz_0, tg_xyyy_yz_1, tg_xyyy_zz_0, tg_xyyy_zz_1, tg_xyyyy_x_1, \
                                         tg_xyyyy_xx_0, tg_xyyyy_xx_1, tg_xyyyy_xy_0, tg_xyyyy_xy_1, tg_xyyyy_xz_0, \
                                         tg_xyyyy_xz_1, tg_xyyyy_y_1, tg_xyyyy_yy_0, tg_xyyyy_yy_1, tg_xyyyy_yz_0, \
                                         tg_xyyyy_yz_1, tg_xyyyy_z_1, tg_xyyyy_zz_0, tg_xyyyy_zz_1, tg_xyyyz_x_1, \
                                         tg_xyyyz_xx_0, tg_xyyyz_xx_1, tg_xyyyz_xy_0, tg_xyyyz_xy_1, tg_xyyyz_xz_0, \
                                         tg_xyyyz_xz_1, tg_xyyyz_y_1, tg_xyyyz_yy_0, tg_xyyyz_yy_1, tg_xyyyz_yz_0, \
                                         tg_xyyyz_yz_1, tg_xyyyz_z_1, tg_xyyyz_zz_0, tg_xyyyz_zz_1, tg_xyyz_xx_0, \
                                         tg_xyyz_xx_1, tg_xyyz_xy_0, tg_xyyz_xy_1, tg_xyyz_xz_0, tg_xyyz_xz_1, tg_xyyz_yy_0, \
                                         tg_xyyz_yy_1, tg_xyyz_yz_0, tg_xyyz_yz_1, tg_xyyz_zz_0, tg_xyyz_zz_1, tg_xyyzz_x_1, \
                                         tg_xyyzz_xx_0, tg_xyyzz_xx_1, tg_xyyzz_xy_0, tg_xyyzz_xy_1, tg_xyyzz_xz_0, \
                                         tg_xyyzz_xz_1, tg_xyyzz_y_1, tg_xyyzz_yy_0, tg_xyyzz_yy_1, tg_xyyzz_yz_0, \
                                         tg_xyyzz_yz_1, tg_xyyzz_z_1, tg_xyyzz_zz_0, tg_xyyzz_zz_1, tg_xyzz_xx_0, \
                                         tg_xyzz_xx_1, tg_xyzz_xy_0, tg_xyzz_xy_1, tg_xyzz_xz_0, tg_xyzz_xz_1, tg_xyzz_yy_0, \
                                         tg_xyzz_yy_1, tg_xyzz_yz_0, tg_xyzz_yz_1, tg_xyzz_zz_0, tg_xyzz_zz_1, tg_xyzzz_x_1, \
                                         tg_xyzzz_xx_0, tg_xyzzz_xx_1, tg_xyzzz_xy_0, tg_xyzzz_xy_1, tg_xyzzz_xz_0, \
                                         tg_xyzzz_xz_1, tg_xyzzz_y_1, tg_xyzzz_yy_0, tg_xyzzz_yy_1, tg_xyzzz_yz_0, \
                                         tg_xyzzz_yz_1, tg_xyzzz_z_1, tg_xyzzz_zz_0, tg_xyzzz_zz_1, tg_xzzz_xx_0, \
                                         tg_xzzz_xx_1, tg_xzzz_xy_0, tg_xzzz_xy_1, tg_xzzz_xz_0, tg_xzzz_xz_1, tg_xzzz_yy_0, \
                                         tg_xzzz_yy_1, tg_xzzz_yz_0, tg_xzzz_yz_1, tg_xzzz_zz_0, tg_xzzz_zz_1, tg_yyyy_xx_0, \
                                         tg_yyyy_xx_1, tg_yyyy_xy_0, tg_yyyy_xy_1, tg_yyyy_xz_0, tg_yyyy_xz_1, tg_yyyy_yy_0, \
                                         tg_yyyy_yy_1, tg_yyyy_yz_0, tg_yyyy_yz_1, tg_yyyy_zz_0, tg_yyyy_zz_1, tg_yyyz_xx_0, \
                                         tg_yyyz_xx_1, tg_yyyz_xy_0, tg_yyyz_xy_1, tg_yyyz_xz_0, tg_yyyz_xz_1, tg_yyyz_yy_0, \
                                         tg_yyyz_yy_1, tg_yyyz_yz_0, tg_yyyz_yz_1, tg_yyyz_zz_0, tg_yyyz_zz_1, tg_yyzz_xx_0, \
                                         tg_yyzz_xx_1, tg_yyzz_xy_0, tg_yyzz_xy_1, tg_yyzz_xz_0, tg_yyzz_xz_1, tg_yyzz_yy_0, \
                                         tg_yyzz_yy_1, tg_yyzz_yz_0, tg_yyzz_yz_1, tg_yyzz_zz_0, tg_yyzz_zz_1, tg_yzzz_xx_0, \
                                         tg_yzzz_xx_1, tg_yzzz_xy_0, tg_yzzz_xy_1, tg_yzzz_xz_0, tg_yzzz_xz_1, tg_yzzz_yy_0, \
                                         tg_yzzz_yy_1, tg_yzzz_yz_0, tg_yzzz_yz_1, tg_yzzz_zz_0, tg_yzzz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxx_xx_0[j] = pb_x * tg_xxxxx_xx_0[j] + fr * tg_xxxxx_xx_1[j] + 2.5 * fl1_fx * (tg_xxxx_xx_0[j] - tg_xxxx_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_x_1[j];

                    tg_xxxxxx_xy_0[j] = pb_x * tg_xxxxx_xy_0[j] + fr * tg_xxxxx_xy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xy_0[j] - tg_xxxx_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_y_1[j];

                    tg_xxxxxx_xz_0[j] = pb_x * tg_xxxxx_xz_0[j] + fr * tg_xxxxx_xz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xz_0[j] - tg_xxxx_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_z_1[j];

                    tg_xxxxxx_yy_0[j] = pb_x * tg_xxxxx_yy_0[j] + fr * tg_xxxxx_yy_1[j] + 2.5 * fl1_fx * (tg_xxxx_yy_0[j] - tg_xxxx_yy_1[j] * fl1_fza);

                    tg_xxxxxx_yz_0[j] = pb_x * tg_xxxxx_yz_0[j] + fr * tg_xxxxx_yz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yz_0[j] - tg_xxxx_yz_1[j] * fl1_fza);

                    tg_xxxxxx_zz_0[j] = pb_x * tg_xxxxx_zz_0[j] + fr * tg_xxxxx_zz_1[j] + 2.5 * fl1_fx * (tg_xxxx_zz_0[j] - tg_xxxx_zz_1[j] * fl1_fza);

                    tg_xxxxxy_xx_0[j] = pb_x * tg_xxxxy_xx_0[j] + fr * tg_xxxxy_xx_1[j] + 2.0 * fl1_fx * (tg_xxxy_xx_0[j] - tg_xxxy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_x_1[j];

                    tg_xxxxxy_xy_0[j] = pb_x * tg_xxxxy_xy_0[j] + fr * tg_xxxxy_xy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xy_0[j] - tg_xxxy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_y_1[j];

                    tg_xxxxxy_xz_0[j] = pb_x * tg_xxxxy_xz_0[j] + fr * tg_xxxxy_xz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xz_0[j] - tg_xxxy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_z_1[j];

                    tg_xxxxxy_yy_0[j] = pb_x * tg_xxxxy_yy_0[j] + fr * tg_xxxxy_yy_1[j] + 2.0 * fl1_fx * (tg_xxxy_yy_0[j] - tg_xxxy_yy_1[j] * fl1_fza);

                    tg_xxxxxy_yz_0[j] = pb_x * tg_xxxxy_yz_0[j] + fr * tg_xxxxy_yz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yz_0[j] - tg_xxxy_yz_1[j] * fl1_fza);

                    tg_xxxxxy_zz_0[j] = pb_x * tg_xxxxy_zz_0[j] + fr * tg_xxxxy_zz_1[j] + 2.0 * fl1_fx * (tg_xxxy_zz_0[j] - tg_xxxy_zz_1[j] * fl1_fza);

                    tg_xxxxxz_xx_0[j] = pb_x * tg_xxxxz_xx_0[j] + fr * tg_xxxxz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxz_xx_0[j] - tg_xxxz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_x_1[j];

                    tg_xxxxxz_xy_0[j] = pb_x * tg_xxxxz_xy_0[j] + fr * tg_xxxxz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xy_0[j] - tg_xxxz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_y_1[j];

                    tg_xxxxxz_xz_0[j] = pb_x * tg_xxxxz_xz_0[j] + fr * tg_xxxxz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xz_0[j] - tg_xxxz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_z_1[j];

                    tg_xxxxxz_yy_0[j] = pb_x * tg_xxxxz_yy_0[j] + fr * tg_xxxxz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxz_yy_0[j] - tg_xxxz_yy_1[j] * fl1_fza);

                    tg_xxxxxz_yz_0[j] = pb_x * tg_xxxxz_yz_0[j] + fr * tg_xxxxz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yz_0[j] - tg_xxxz_yz_1[j] * fl1_fza);

                    tg_xxxxxz_zz_0[j] = pb_x * tg_xxxxz_zz_0[j] + fr * tg_xxxxz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxz_zz_0[j] - tg_xxxz_zz_1[j] * fl1_fza);

                    tg_xxxxyy_xx_0[j] = pb_x * tg_xxxyy_xx_0[j] + fr * tg_xxxyy_xx_1[j] + 1.5 * fl1_fx * (tg_xxyy_xx_0[j] - tg_xxyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_x_1[j];

                    tg_xxxxyy_xy_0[j] = pb_x * tg_xxxyy_xy_0[j] + fr * tg_xxxyy_xy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xy_0[j] - tg_xxyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_y_1[j];

                    tg_xxxxyy_xz_0[j] = pb_x * tg_xxxyy_xz_0[j] + fr * tg_xxxyy_xz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xz_0[j] - tg_xxyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_z_1[j];

                    tg_xxxxyy_yy_0[j] = pb_x * tg_xxxyy_yy_0[j] + fr * tg_xxxyy_yy_1[j] + 1.5 * fl1_fx * (tg_xxyy_yy_0[j] - tg_xxyy_yy_1[j] * fl1_fza);

                    tg_xxxxyy_yz_0[j] = pb_x * tg_xxxyy_yz_0[j] + fr * tg_xxxyy_yz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yz_0[j] - tg_xxyy_yz_1[j] * fl1_fza);

                    tg_xxxxyy_zz_0[j] = pb_x * tg_xxxyy_zz_0[j] + fr * tg_xxxyy_zz_1[j] + 1.5 * fl1_fx * (tg_xxyy_zz_0[j] - tg_xxyy_zz_1[j] * fl1_fza);

                    tg_xxxxyz_xx_0[j] = pb_x * tg_xxxyz_xx_0[j] + fr * tg_xxxyz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyz_xx_0[j] - tg_xxyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_x_1[j];

                    tg_xxxxyz_xy_0[j] = pb_x * tg_xxxyz_xy_0[j] + fr * tg_xxxyz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xy_0[j] - tg_xxyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_y_1[j];

                    tg_xxxxyz_xz_0[j] = pb_x * tg_xxxyz_xz_0[j] + fr * tg_xxxyz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xz_0[j] - tg_xxyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_z_1[j];

                    tg_xxxxyz_yy_0[j] = pb_x * tg_xxxyz_yy_0[j] + fr * tg_xxxyz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyz_yy_0[j] - tg_xxyz_yy_1[j] * fl1_fza);

                    tg_xxxxyz_yz_0[j] = pb_x * tg_xxxyz_yz_0[j] + fr * tg_xxxyz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yz_0[j] - tg_xxyz_yz_1[j] * fl1_fza);

                    tg_xxxxyz_zz_0[j] = pb_x * tg_xxxyz_zz_0[j] + fr * tg_xxxyz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyz_zz_0[j] - tg_xxyz_zz_1[j] * fl1_fza);

                    tg_xxxxzz_xx_0[j] = pb_x * tg_xxxzz_xx_0[j] + fr * tg_xxxzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxzz_xx_0[j] - tg_xxzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_x_1[j];

                    tg_xxxxzz_xy_0[j] = pb_x * tg_xxxzz_xy_0[j] + fr * tg_xxxzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xy_0[j] - tg_xxzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_y_1[j];

                    tg_xxxxzz_xz_0[j] = pb_x * tg_xxxzz_xz_0[j] + fr * tg_xxxzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xz_0[j] - tg_xxzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_z_1[j];

                    tg_xxxxzz_yy_0[j] = pb_x * tg_xxxzz_yy_0[j] + fr * tg_xxxzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxzz_yy_0[j] - tg_xxzz_yy_1[j] * fl1_fza);

                    tg_xxxxzz_yz_0[j] = pb_x * tg_xxxzz_yz_0[j] + fr * tg_xxxzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yz_0[j] - tg_xxzz_yz_1[j] * fl1_fza);

                    tg_xxxxzz_zz_0[j] = pb_x * tg_xxxzz_zz_0[j] + fr * tg_xxxzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxzz_zz_0[j] - tg_xxzz_zz_1[j] * fl1_fza);

                    tg_xxxyyy_xx_0[j] = pb_x * tg_xxyyy_xx_0[j] + fr * tg_xxyyy_xx_1[j] + fl1_fx * (tg_xyyy_xx_0[j] - tg_xyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_x_1[j];

                    tg_xxxyyy_xy_0[j] = pb_x * tg_xxyyy_xy_0[j] + fr * tg_xxyyy_xy_1[j] + fl1_fx * (tg_xyyy_xy_0[j] - tg_xyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_y_1[j];

                    tg_xxxyyy_xz_0[j] = pb_x * tg_xxyyy_xz_0[j] + fr * tg_xxyyy_xz_1[j] + fl1_fx * (tg_xyyy_xz_0[j] - tg_xyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_z_1[j];

                    tg_xxxyyy_yy_0[j] = pb_x * tg_xxyyy_yy_0[j] + fr * tg_xxyyy_yy_1[j] + fl1_fx * (tg_xyyy_yy_0[j] - tg_xyyy_yy_1[j] * fl1_fza);

                    tg_xxxyyy_yz_0[j] = pb_x * tg_xxyyy_yz_0[j] + fr * tg_xxyyy_yz_1[j] + fl1_fx * (tg_xyyy_yz_0[j] - tg_xyyy_yz_1[j] * fl1_fza);

                    tg_xxxyyy_zz_0[j] = pb_x * tg_xxyyy_zz_0[j] + fr * tg_xxyyy_zz_1[j] + fl1_fx * (tg_xyyy_zz_0[j] - tg_xyyy_zz_1[j] * fl1_fza);

                    tg_xxxyyz_xx_0[j] = pb_x * tg_xxyyz_xx_0[j] + fr * tg_xxyyz_xx_1[j] + fl1_fx * (tg_xyyz_xx_0[j] - tg_xyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_x_1[j];

                    tg_xxxyyz_xy_0[j] = pb_x * tg_xxyyz_xy_0[j] + fr * tg_xxyyz_xy_1[j] + fl1_fx * (tg_xyyz_xy_0[j] - tg_xyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_y_1[j];

                    tg_xxxyyz_xz_0[j] = pb_x * tg_xxyyz_xz_0[j] + fr * tg_xxyyz_xz_1[j] + fl1_fx * (tg_xyyz_xz_0[j] - tg_xyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_z_1[j];

                    tg_xxxyyz_yy_0[j] = pb_x * tg_xxyyz_yy_0[j] + fr * tg_xxyyz_yy_1[j] + fl1_fx * (tg_xyyz_yy_0[j] - tg_xyyz_yy_1[j] * fl1_fza);

                    tg_xxxyyz_yz_0[j] = pb_x * tg_xxyyz_yz_0[j] + fr * tg_xxyyz_yz_1[j] + fl1_fx * (tg_xyyz_yz_0[j] - tg_xyyz_yz_1[j] * fl1_fza);

                    tg_xxxyyz_zz_0[j] = pb_x * tg_xxyyz_zz_0[j] + fr * tg_xxyyz_zz_1[j] + fl1_fx * (tg_xyyz_zz_0[j] - tg_xyyz_zz_1[j] * fl1_fza);

                    tg_xxxyzz_xx_0[j] = pb_x * tg_xxyzz_xx_0[j] + fr * tg_xxyzz_xx_1[j] + fl1_fx * (tg_xyzz_xx_0[j] - tg_xyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_x_1[j];

                    tg_xxxyzz_xy_0[j] = pb_x * tg_xxyzz_xy_0[j] + fr * tg_xxyzz_xy_1[j] + fl1_fx * (tg_xyzz_xy_0[j] - tg_xyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_y_1[j];

                    tg_xxxyzz_xz_0[j] = pb_x * tg_xxyzz_xz_0[j] + fr * tg_xxyzz_xz_1[j] + fl1_fx * (tg_xyzz_xz_0[j] - tg_xyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_z_1[j];

                    tg_xxxyzz_yy_0[j] = pb_x * tg_xxyzz_yy_0[j] + fr * tg_xxyzz_yy_1[j] + fl1_fx * (tg_xyzz_yy_0[j] - tg_xyzz_yy_1[j] * fl1_fza);

                    tg_xxxyzz_yz_0[j] = pb_x * tg_xxyzz_yz_0[j] + fr * tg_xxyzz_yz_1[j] + fl1_fx * (tg_xyzz_yz_0[j] - tg_xyzz_yz_1[j] * fl1_fza);

                    tg_xxxyzz_zz_0[j] = pb_x * tg_xxyzz_zz_0[j] + fr * tg_xxyzz_zz_1[j] + fl1_fx * (tg_xyzz_zz_0[j] - tg_xyzz_zz_1[j] * fl1_fza);

                    tg_xxxzzz_xx_0[j] = pb_x * tg_xxzzz_xx_0[j] + fr * tg_xxzzz_xx_1[j] + fl1_fx * (tg_xzzz_xx_0[j] - tg_xzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_x_1[j];

                    tg_xxxzzz_xy_0[j] = pb_x * tg_xxzzz_xy_0[j] + fr * tg_xxzzz_xy_1[j] + fl1_fx * (tg_xzzz_xy_0[j] - tg_xzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_y_1[j];

                    tg_xxxzzz_xz_0[j] = pb_x * tg_xxzzz_xz_0[j] + fr * tg_xxzzz_xz_1[j] + fl1_fx * (tg_xzzz_xz_0[j] - tg_xzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_z_1[j];

                    tg_xxxzzz_yy_0[j] = pb_x * tg_xxzzz_yy_0[j] + fr * tg_xxzzz_yy_1[j] + fl1_fx * (tg_xzzz_yy_0[j] - tg_xzzz_yy_1[j] * fl1_fza);

                    tg_xxxzzz_yz_0[j] = pb_x * tg_xxzzz_yz_0[j] + fr * tg_xxzzz_yz_1[j] + fl1_fx * (tg_xzzz_yz_0[j] - tg_xzzz_yz_1[j] * fl1_fza);

                    tg_xxxzzz_zz_0[j] = pb_x * tg_xxzzz_zz_0[j] + fr * tg_xxzzz_zz_1[j] + fl1_fx * (tg_xzzz_zz_0[j] - tg_xzzz_zz_1[j] * fl1_fza);

                    tg_xxyyyy_xx_0[j] = pb_x * tg_xyyyy_xx_0[j] + fr * tg_xyyyy_xx_1[j] + 0.5 * fl1_fx * (tg_yyyy_xx_0[j] - tg_yyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_x_1[j];

                    tg_xxyyyy_xy_0[j] = pb_x * tg_xyyyy_xy_0[j] + fr * tg_xyyyy_xy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xy_0[j] - tg_yyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_y_1[j];

                    tg_xxyyyy_xz_0[j] = pb_x * tg_xyyyy_xz_0[j] + fr * tg_xyyyy_xz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xz_0[j] - tg_yyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_z_1[j];

                    tg_xxyyyy_yy_0[j] = pb_x * tg_xyyyy_yy_0[j] + fr * tg_xyyyy_yy_1[j] + 0.5 * fl1_fx * (tg_yyyy_yy_0[j] - tg_yyyy_yy_1[j] * fl1_fza);

                    tg_xxyyyy_yz_0[j] = pb_x * tg_xyyyy_yz_0[j] + fr * tg_xyyyy_yz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yz_0[j] - tg_yyyy_yz_1[j] * fl1_fza);

                    tg_xxyyyy_zz_0[j] = pb_x * tg_xyyyy_zz_0[j] + fr * tg_xyyyy_zz_1[j] + 0.5 * fl1_fx * (tg_yyyy_zz_0[j] - tg_yyyy_zz_1[j] * fl1_fza);

                    tg_xxyyyz_xx_0[j] = pb_x * tg_xyyyz_xx_0[j] + fr * tg_xyyyz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyz_xx_0[j] - tg_yyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_x_1[j];

                    tg_xxyyyz_xy_0[j] = pb_x * tg_xyyyz_xy_0[j] + fr * tg_xyyyz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xy_0[j] - tg_yyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_y_1[j];

                    tg_xxyyyz_xz_0[j] = pb_x * tg_xyyyz_xz_0[j] + fr * tg_xyyyz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xz_0[j] - tg_yyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_z_1[j];

                    tg_xxyyyz_yy_0[j] = pb_x * tg_xyyyz_yy_0[j] + fr * tg_xyyyz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyz_yy_0[j] - tg_yyyz_yy_1[j] * fl1_fza);

                    tg_xxyyyz_yz_0[j] = pb_x * tg_xyyyz_yz_0[j] + fr * tg_xyyyz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yz_0[j] - tg_yyyz_yz_1[j] * fl1_fza);

                    tg_xxyyyz_zz_0[j] = pb_x * tg_xyyyz_zz_0[j] + fr * tg_xyyyz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyz_zz_0[j] - tg_yyyz_zz_1[j] * fl1_fza);

                    tg_xxyyzz_xx_0[j] = pb_x * tg_xyyzz_xx_0[j] + fr * tg_xyyzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyzz_xx_0[j] - tg_yyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_x_1[j];

                    tg_xxyyzz_xy_0[j] = pb_x * tg_xyyzz_xy_0[j] + fr * tg_xyyzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xy_0[j] - tg_yyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_y_1[j];

                    tg_xxyyzz_xz_0[j] = pb_x * tg_xyyzz_xz_0[j] + fr * tg_xyyzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xz_0[j] - tg_yyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_z_1[j];

                    tg_xxyyzz_yy_0[j] = pb_x * tg_xyyzz_yy_0[j] + fr * tg_xyyzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyzz_yy_0[j] - tg_yyzz_yy_1[j] * fl1_fza);

                    tg_xxyyzz_yz_0[j] = pb_x * tg_xyyzz_yz_0[j] + fr * tg_xyyzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yz_0[j] - tg_yyzz_yz_1[j] * fl1_fza);

                    tg_xxyyzz_zz_0[j] = pb_x * tg_xyyzz_zz_0[j] + fr * tg_xyyzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyzz_zz_0[j] - tg_yyzz_zz_1[j] * fl1_fza);

                    tg_xxyzzz_xx_0[j] = pb_x * tg_xyzzz_xx_0[j] + fr * tg_xyzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yzzz_xx_0[j] - tg_yzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_x_1[j];

                    tg_xxyzzz_xy_0[j] = pb_x * tg_xyzzz_xy_0[j] + fr * tg_xyzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xy_0[j] - tg_yzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_y_1[j];

                    tg_xxyzzz_xz_0[j] = pb_x * tg_xyzzz_xz_0[j] + fr * tg_xyzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xz_0[j] - tg_yzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_z_1[j];

                    tg_xxyzzz_yy_0[j] = pb_x * tg_xyzzz_yy_0[j] + fr * tg_xyzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yzzz_yy_0[j] - tg_yzzz_yy_1[j] * fl1_fza);

                    tg_xxyzzz_yz_0[j] = pb_x * tg_xyzzz_yz_0[j] + fr * tg_xyzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yz_0[j] - tg_yzzz_yz_1[j] * fl1_fza);

                    tg_xxyzzz_zz_0[j] = pb_x * tg_xyzzz_zz_0[j] + fr * tg_xyzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yzzz_zz_0[j] - tg_yzzz_zz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISD_84_168(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (84,168)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_xzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 84); 

                auto tg_xzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 85); 

                auto tg_xzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 86); 

                auto tg_xzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 87); 

                auto tg_xzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 88); 

                auto tg_xzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 89); 

                auto tg_yyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 90); 

                auto tg_yyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 91); 

                auto tg_yyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 92); 

                auto tg_yyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 93); 

                auto tg_yyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 94); 

                auto tg_yyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 95); 

                auto tg_yyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 96); 

                auto tg_yyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 97); 

                auto tg_yyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 98); 

                auto tg_yyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 99); 

                auto tg_yyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 100); 

                auto tg_yyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 101); 

                auto tg_yyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 102); 

                auto tg_yyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 103); 

                auto tg_yyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 104); 

                auto tg_yyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 105); 

                auto tg_yyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 106); 

                auto tg_yyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 107); 

                auto tg_yyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 108); 

                auto tg_yyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 109); 

                auto tg_yyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 110); 

                auto tg_yyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 111); 

                auto tg_yyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 112); 

                auto tg_yyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 113); 

                auto tg_yzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 114); 

                auto tg_yzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 115); 

                auto tg_yzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 116); 

                auto tg_yzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 117); 

                auto tg_yzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 118); 

                auto tg_yzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 119); 

                auto tg_zzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 120); 

                auto tg_zzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 121); 

                auto tg_zzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 122); 

                auto tg_zzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 123); 

                auto tg_zzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 124); 

                auto tg_zzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 125); 

                auto tg_xzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 84); 

                auto tg_xzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 85); 

                auto tg_xzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 86); 

                auto tg_xzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 87); 

                auto tg_xzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 88); 

                auto tg_xzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 89); 

                auto tg_yyyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 90); 

                auto tg_yyyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 91); 

                auto tg_yyyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 92); 

                auto tg_yyyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 93); 

                auto tg_yyyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 94); 

                auto tg_yyyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 95); 

                auto tg_yyyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 96); 

                auto tg_yyyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 97); 

                auto tg_yyyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 98); 

                auto tg_yyyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 99); 

                auto tg_yyyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 100); 

                auto tg_yyyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 101); 

                auto tg_yyyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 102); 

                auto tg_yyyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 103); 

                auto tg_yyyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 104); 

                auto tg_yyyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 105); 

                auto tg_yyyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 106); 

                auto tg_yyyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 107); 

                auto tg_yyzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 108); 

                auto tg_yyzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 109); 

                auto tg_yyzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 110); 

                auto tg_yyzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 111); 

                auto tg_yyzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 112); 

                auto tg_yyzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 113); 

                auto tg_yzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 114); 

                auto tg_yzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 115); 

                auto tg_yzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 116); 

                auto tg_yzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 117); 

                auto tg_yzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 118); 

                auto tg_yzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 119); 

                auto tg_zzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 120); 

                auto tg_zzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 121); 

                auto tg_zzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 122); 

                auto tg_zzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 123); 

                auto tg_zzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 124); 

                auto tg_zzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 125); 

                auto tg_yyyy_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 60); 

                auto tg_yyyy_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 61); 

                auto tg_yyyy_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 62); 

                auto tg_yyyy_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 63); 

                auto tg_yyyy_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 64); 

                auto tg_yyyy_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 65); 

                auto tg_yyyz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 66); 

                auto tg_yyyz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 67); 

                auto tg_yyyz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 68); 

                auto tg_yyyz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 69); 

                auto tg_yyyz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 70); 

                auto tg_yyyz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 71); 

                auto tg_yyzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 72); 

                auto tg_yyzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 73); 

                auto tg_yyzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 74); 

                auto tg_yyzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 75); 

                auto tg_yyzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 76); 

                auto tg_yyzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 77); 

                auto tg_yzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 78); 

                auto tg_yzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 79); 

                auto tg_yzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 80); 

                auto tg_yzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 81); 

                auto tg_yzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 82); 

                auto tg_yzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 83); 

                auto tg_zzzz_xx_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 84); 

                auto tg_zzzz_xy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 85); 

                auto tg_zzzz_xz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 86); 

                auto tg_zzzz_yy_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 87); 

                auto tg_zzzz_yz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 88); 

                auto tg_zzzz_zz_0 = primBuffer[pidx_g_4_2_m0].data(90 * idx + 89); 

                auto tg_yyyy_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 60); 

                auto tg_yyyy_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 61); 

                auto tg_yyyy_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 62); 

                auto tg_yyyy_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 63); 

                auto tg_yyyy_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 64); 

                auto tg_yyyy_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 65); 

                auto tg_yyyz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 66); 

                auto tg_yyyz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 67); 

                auto tg_yyyz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 68); 

                auto tg_yyyz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 69); 

                auto tg_yyyz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 70); 

                auto tg_yyyz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 71); 

                auto tg_yyzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 72); 

                auto tg_yyzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 73); 

                auto tg_yyzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 74); 

                auto tg_yyzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 75); 

                auto tg_yyzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 76); 

                auto tg_yyzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 77); 

                auto tg_yzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 78); 

                auto tg_yzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 79); 

                auto tg_yzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 80); 

                auto tg_yzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 81); 

                auto tg_yzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 82); 

                auto tg_yzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 83); 

                auto tg_zzzz_xx_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 84); 

                auto tg_zzzz_xy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 85); 

                auto tg_zzzz_xz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 86); 

                auto tg_zzzz_yy_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 87); 

                auto tg_zzzz_yz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 88); 

                auto tg_zzzz_zz_1 = primBuffer[pidx_g_4_2_m1].data(90 * idx + 89); 

                auto tg_xzzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 42); 

                auto tg_xzzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 43); 

                auto tg_xzzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 44); 

                auto tg_yyyyy_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 45); 

                auto tg_yyyyy_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 46); 

                auto tg_yyyyy_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 47); 

                auto tg_yyyyz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 48); 

                auto tg_yyyyz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 49); 

                auto tg_yyyyz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 50); 

                auto tg_yyyzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 51); 

                auto tg_yyyzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 52); 

                auto tg_yyyzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 53); 

                auto tg_yyzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 54); 

                auto tg_yyzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 55); 

                auto tg_yyzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 56); 

                auto tg_yzzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 57); 

                auto tg_yzzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 58); 

                auto tg_yzzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 59); 

                auto tg_zzzzz_x_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 60); 

                auto tg_zzzzz_y_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 61); 

                auto tg_zzzzz_z_1 = primBuffer[pidx_g_5_1_m1].data(63 * idx + 62); 

                // set up pointers to integrals

                auto tg_xxzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 84); 

                auto tg_xxzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 85); 

                auto tg_xxzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 86); 

                auto tg_xxzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 87); 

                auto tg_xxzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 88); 

                auto tg_xxzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 89); 

                auto tg_xyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 90); 

                auto tg_xyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 91); 

                auto tg_xyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 92); 

                auto tg_xyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 93); 

                auto tg_xyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 94); 

                auto tg_xyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 95); 

                auto tg_xyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 96); 

                auto tg_xyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 97); 

                auto tg_xyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 98); 

                auto tg_xyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 99); 

                auto tg_xyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 100); 

                auto tg_xyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 101); 

                auto tg_xyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 102); 

                auto tg_xyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 103); 

                auto tg_xyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 104); 

                auto tg_xyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 105); 

                auto tg_xyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 106); 

                auto tg_xyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 107); 

                auto tg_xyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 108); 

                auto tg_xyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 109); 

                auto tg_xyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 110); 

                auto tg_xyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 111); 

                auto tg_xyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 112); 

                auto tg_xyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 113); 

                auto tg_xyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 114); 

                auto tg_xyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 115); 

                auto tg_xyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 116); 

                auto tg_xyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 117); 

                auto tg_xyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 118); 

                auto tg_xyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 119); 

                auto tg_xzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 120); 

                auto tg_xzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 121); 

                auto tg_xzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 122); 

                auto tg_xzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 123); 

                auto tg_xzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 124); 

                auto tg_xzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 125); 

                auto tg_yyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 167); 

                // Batch of Integrals (84,168)

                #pragma omp simd aligned(fxn, fza, tg_xxzzzz_xx_0, tg_xxzzzz_xy_0, tg_xxzzzz_xz_0, \
                                         tg_xxzzzz_yy_0, tg_xxzzzz_yz_0, tg_xxzzzz_zz_0, tg_xyyyyy_xx_0, tg_xyyyyy_xy_0, \
                                         tg_xyyyyy_xz_0, tg_xyyyyy_yy_0, tg_xyyyyy_yz_0, tg_xyyyyy_zz_0, tg_xyyyyz_xx_0, \
                                         tg_xyyyyz_xy_0, tg_xyyyyz_xz_0, tg_xyyyyz_yy_0, tg_xyyyyz_yz_0, tg_xyyyyz_zz_0, \
                                         tg_xyyyzz_xx_0, tg_xyyyzz_xy_0, tg_xyyyzz_xz_0, tg_xyyyzz_yy_0, tg_xyyyzz_yz_0, \
                                         tg_xyyyzz_zz_0, tg_xyyzzz_xx_0, tg_xyyzzz_xy_0, tg_xyyzzz_xz_0, tg_xyyzzz_yy_0, \
                                         tg_xyyzzz_yz_0, tg_xyyzzz_zz_0, tg_xyzzzz_xx_0, tg_xyzzzz_xy_0, tg_xyzzzz_xz_0, \
                                         tg_xyzzzz_yy_0, tg_xyzzzz_yz_0, tg_xyzzzz_zz_0, tg_xzzzz_x_1, tg_xzzzz_xx_0, \
                                         tg_xzzzz_xx_1, tg_xzzzz_xy_0, tg_xzzzz_xy_1, tg_xzzzz_xz_0, tg_xzzzz_xz_1, \
                                         tg_xzzzz_y_1, tg_xzzzz_yy_0, tg_xzzzz_yy_1, tg_xzzzz_yz_0, tg_xzzzz_yz_1, \
                                         tg_xzzzz_z_1, tg_xzzzz_zz_0, tg_xzzzz_zz_1, tg_xzzzzz_xx_0, tg_xzzzzz_xy_0, \
                                         tg_xzzzzz_xz_0, tg_xzzzzz_yy_0, tg_xzzzzz_yz_0, tg_xzzzzz_zz_0, tg_yyyy_xx_0, \
                                         tg_yyyy_xx_1, tg_yyyy_xy_0, tg_yyyy_xy_1, tg_yyyy_xz_0, tg_yyyy_xz_1, tg_yyyy_yy_0, \
                                         tg_yyyy_yy_1, tg_yyyy_yz_0, tg_yyyy_yz_1, tg_yyyy_zz_0, tg_yyyy_zz_1, tg_yyyyy_x_1, \
                                         tg_yyyyy_xx_0, tg_yyyyy_xx_1, tg_yyyyy_xy_0, tg_yyyyy_xy_1, tg_yyyyy_xz_0, \
                                         tg_yyyyy_xz_1, tg_yyyyy_y_1, tg_yyyyy_yy_0, tg_yyyyy_yy_1, tg_yyyyy_yz_0, \
                                         tg_yyyyy_yz_1, tg_yyyyy_z_1, tg_yyyyy_zz_0, tg_yyyyy_zz_1, tg_yyyyyy_xx_0, \
                                         tg_yyyyyy_xy_0, tg_yyyyyy_xz_0, tg_yyyyyy_yy_0, tg_yyyyyy_yz_0, tg_yyyyyy_zz_0, \
                                         tg_yyyyyz_xx_0, tg_yyyyyz_xy_0, tg_yyyyyz_xz_0, tg_yyyyyz_yy_0, tg_yyyyyz_yz_0, \
                                         tg_yyyyyz_zz_0, tg_yyyyz_x_1, tg_yyyyz_xx_0, tg_yyyyz_xx_1, tg_yyyyz_xy_0, \
                                         tg_yyyyz_xy_1, tg_yyyyz_xz_0, tg_yyyyz_xz_1, tg_yyyyz_y_1, tg_yyyyz_yy_0, \
                                         tg_yyyyz_yy_1, tg_yyyyz_yz_0, tg_yyyyz_yz_1, tg_yyyyz_z_1, tg_yyyyz_zz_0, \
                                         tg_yyyyz_zz_1, tg_yyyyzz_xx_0, tg_yyyyzz_xy_0, tg_yyyyzz_xz_0, tg_yyyyzz_yy_0, \
                                         tg_yyyyzz_yz_0, tg_yyyyzz_zz_0, tg_yyyz_xx_0, tg_yyyz_xx_1, tg_yyyz_xy_0, \
                                         tg_yyyz_xy_1, tg_yyyz_xz_0, tg_yyyz_xz_1, tg_yyyz_yy_0, tg_yyyz_yy_1, tg_yyyz_yz_0, \
                                         tg_yyyz_yz_1, tg_yyyz_zz_0, tg_yyyz_zz_1, tg_yyyzz_x_1, tg_yyyzz_xx_0, \
                                         tg_yyyzz_xx_1, tg_yyyzz_xy_0, tg_yyyzz_xy_1, tg_yyyzz_xz_0, tg_yyyzz_xz_1, \
                                         tg_yyyzz_y_1, tg_yyyzz_yy_0, tg_yyyzz_yy_1, tg_yyyzz_yz_0, tg_yyyzz_yz_1, \
                                         tg_yyyzz_z_1, tg_yyyzz_zz_0, tg_yyyzz_zz_1, tg_yyyzzz_xx_0, tg_yyyzzz_xy_0, \
                                         tg_yyyzzz_xz_0, tg_yyyzzz_yy_0, tg_yyyzzz_yz_0, tg_yyyzzz_zz_0, tg_yyzz_xx_0, \
                                         tg_yyzz_xx_1, tg_yyzz_xy_0, tg_yyzz_xy_1, tg_yyzz_xz_0, tg_yyzz_xz_1, tg_yyzz_yy_0, \
                                         tg_yyzz_yy_1, tg_yyzz_yz_0, tg_yyzz_yz_1, tg_yyzz_zz_0, tg_yyzz_zz_1, tg_yyzzz_x_1, \
                                         tg_yyzzz_xx_0, tg_yyzzz_xx_1, tg_yyzzz_xy_0, tg_yyzzz_xy_1, tg_yyzzz_xz_0, \
                                         tg_yyzzz_xz_1, tg_yyzzz_y_1, tg_yyzzz_yy_0, tg_yyzzz_yy_1, tg_yyzzz_yz_0, \
                                         tg_yyzzz_yz_1, tg_yyzzz_z_1, tg_yyzzz_zz_0, tg_yyzzz_zz_1, tg_yyzzzz_xx_0, \
                                         tg_yyzzzz_xy_0, tg_yyzzzz_xz_0, tg_yyzzzz_yy_0, tg_yyzzzz_yz_0, tg_yyzzzz_zz_0, \
                                         tg_yzzz_xx_0, tg_yzzz_xx_1, tg_yzzz_xy_0, tg_yzzz_xy_1, tg_yzzz_xz_0, tg_yzzz_xz_1, \
                                         tg_yzzz_yy_0, tg_yzzz_yy_1, tg_yzzz_yz_0, tg_yzzz_yz_1, tg_yzzz_zz_0, tg_yzzz_zz_1, \
                                         tg_yzzzz_x_1, tg_yzzzz_xx_0, tg_yzzzz_xx_1, tg_yzzzz_xy_0, tg_yzzzz_xy_1, \
                                         tg_yzzzz_xz_0, tg_yzzzz_xz_1, tg_yzzzz_y_1, tg_yzzzz_yy_0, tg_yzzzz_yy_1, \
                                         tg_yzzzz_yz_0, tg_yzzzz_yz_1, tg_yzzzz_z_1, tg_yzzzz_zz_0, tg_yzzzz_zz_1, \
                                         tg_yzzzzz_xx_0, tg_yzzzzz_xy_0, tg_yzzzzz_xz_0, tg_yzzzzz_yy_0, tg_yzzzzz_yz_0, \
                                         tg_yzzzzz_zz_0, tg_zzzz_xx_0, tg_zzzz_xx_1, tg_zzzz_xy_0, tg_zzzz_xy_1, tg_zzzz_xz_0, \
                                         tg_zzzz_xz_1, tg_zzzz_yy_0, tg_zzzz_yy_1, tg_zzzz_yz_0, tg_zzzz_yz_1, tg_zzzz_zz_0, \
                                         tg_zzzz_zz_1, tg_zzzzz_x_1, tg_zzzzz_xx_0, tg_zzzzz_xx_1, tg_zzzzz_xy_0, \
                                         tg_zzzzz_xy_1, tg_zzzzz_xz_0, tg_zzzzz_xz_1, tg_zzzzz_y_1, tg_zzzzz_yy_0, \
                                         tg_zzzzz_yy_1, tg_zzzzz_yz_0, tg_zzzzz_yz_1, tg_zzzzz_z_1, tg_zzzzz_zz_0, \
                                         tg_zzzzz_zz_1, tg_zzzzzz_xx_0, tg_zzzzzz_xy_0, tg_zzzzzz_xz_0, tg_zzzzzz_yy_0, \
                                         tg_zzzzzz_yz_0, tg_zzzzzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxzzzz_xx_0[j] = pb_x * tg_xzzzz_xx_0[j] + fr * tg_xzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzz_xx_0[j] - tg_zzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_x_1[j];

                    tg_xxzzzz_xy_0[j] = pb_x * tg_xzzzz_xy_0[j] + fr * tg_xzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xy_0[j] - tg_zzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_y_1[j];

                    tg_xxzzzz_xz_0[j] = pb_x * tg_xzzzz_xz_0[j] + fr * tg_xzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xz_0[j] - tg_zzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_z_1[j];

                    tg_xxzzzz_yy_0[j] = pb_x * tg_xzzzz_yy_0[j] + fr * tg_xzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzz_yy_0[j] - tg_zzzz_yy_1[j] * fl1_fza);

                    tg_xxzzzz_yz_0[j] = pb_x * tg_xzzzz_yz_0[j] + fr * tg_xzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yz_0[j] - tg_zzzz_yz_1[j] * fl1_fza);

                    tg_xxzzzz_zz_0[j] = pb_x * tg_xzzzz_zz_0[j] + fr * tg_xzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzz_zz_0[j] - tg_zzzz_zz_1[j] * fl1_fza);

                    tg_xyyyyy_xx_0[j] = pb_x * tg_yyyyy_xx_0[j] + fr * tg_yyyyy_xx_1[j] + fl1_fxn * tg_yyyyy_x_1[j];

                    tg_xyyyyy_xy_0[j] = pb_x * tg_yyyyy_xy_0[j] + fr * tg_yyyyy_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyy_y_1[j];

                    tg_xyyyyy_xz_0[j] = pb_x * tg_yyyyy_xz_0[j] + fr * tg_yyyyy_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_z_1[j];

                    tg_xyyyyy_yy_0[j] = pb_x * tg_yyyyy_yy_0[j] + fr * tg_yyyyy_yy_1[j];

                    tg_xyyyyy_yz_0[j] = pb_x * tg_yyyyy_yz_0[j] + fr * tg_yyyyy_yz_1[j];

                    tg_xyyyyy_zz_0[j] = pb_x * tg_yyyyy_zz_0[j] + fr * tg_yyyyy_zz_1[j];

                    tg_xyyyyz_xx_0[j] = pb_x * tg_yyyyz_xx_0[j] + fr * tg_yyyyz_xx_1[j] + fl1_fxn * tg_yyyyz_x_1[j];

                    tg_xyyyyz_xy_0[j] = pb_x * tg_yyyyz_xy_0[j] + fr * tg_yyyyz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyz_y_1[j];

                    tg_xyyyyz_xz_0[j] = pb_x * tg_yyyyz_xz_0[j] + fr * tg_yyyyz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_z_1[j];

                    tg_xyyyyz_yy_0[j] = pb_x * tg_yyyyz_yy_0[j] + fr * tg_yyyyz_yy_1[j];

                    tg_xyyyyz_yz_0[j] = pb_x * tg_yyyyz_yz_0[j] + fr * tg_yyyyz_yz_1[j];

                    tg_xyyyyz_zz_0[j] = pb_x * tg_yyyyz_zz_0[j] + fr * tg_yyyyz_zz_1[j];

                    tg_xyyyzz_xx_0[j] = pb_x * tg_yyyzz_xx_0[j] + fr * tg_yyyzz_xx_1[j] + fl1_fxn * tg_yyyzz_x_1[j];

                    tg_xyyyzz_xy_0[j] = pb_x * tg_yyyzz_xy_0[j] + fr * tg_yyyzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyzz_y_1[j];

                    tg_xyyyzz_xz_0[j] = pb_x * tg_yyyzz_xz_0[j] + fr * tg_yyyzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_z_1[j];

                    tg_xyyyzz_yy_0[j] = pb_x * tg_yyyzz_yy_0[j] + fr * tg_yyyzz_yy_1[j];

                    tg_xyyyzz_yz_0[j] = pb_x * tg_yyyzz_yz_0[j] + fr * tg_yyyzz_yz_1[j];

                    tg_xyyyzz_zz_0[j] = pb_x * tg_yyyzz_zz_0[j] + fr * tg_yyyzz_zz_1[j];

                    tg_xyyzzz_xx_0[j] = pb_x * tg_yyzzz_xx_0[j] + fr * tg_yyzzz_xx_1[j] + fl1_fxn * tg_yyzzz_x_1[j];

                    tg_xyyzzz_xy_0[j] = pb_x * tg_yyzzz_xy_0[j] + fr * tg_yyzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyzzz_y_1[j];

                    tg_xyyzzz_xz_0[j] = pb_x * tg_yyzzz_xz_0[j] + fr * tg_yyzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_z_1[j];

                    tg_xyyzzz_yy_0[j] = pb_x * tg_yyzzz_yy_0[j] + fr * tg_yyzzz_yy_1[j];

                    tg_xyyzzz_yz_0[j] = pb_x * tg_yyzzz_yz_0[j] + fr * tg_yyzzz_yz_1[j];

                    tg_xyyzzz_zz_0[j] = pb_x * tg_yyzzz_zz_0[j] + fr * tg_yyzzz_zz_1[j];

                    tg_xyzzzz_xx_0[j] = pb_x * tg_yzzzz_xx_0[j] + fr * tg_yzzzz_xx_1[j] + fl1_fxn * tg_yzzzz_x_1[j];

                    tg_xyzzzz_xy_0[j] = pb_x * tg_yzzzz_xy_0[j] + fr * tg_yzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yzzzz_y_1[j];

                    tg_xyzzzz_xz_0[j] = pb_x * tg_yzzzz_xz_0[j] + fr * tg_yzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_z_1[j];

                    tg_xyzzzz_yy_0[j] = pb_x * tg_yzzzz_yy_0[j] + fr * tg_yzzzz_yy_1[j];

                    tg_xyzzzz_yz_0[j] = pb_x * tg_yzzzz_yz_0[j] + fr * tg_yzzzz_yz_1[j];

                    tg_xyzzzz_zz_0[j] = pb_x * tg_yzzzz_zz_0[j] + fr * tg_yzzzz_zz_1[j];

                    tg_xzzzzz_xx_0[j] = pb_x * tg_zzzzz_xx_0[j] + fr * tg_zzzzz_xx_1[j] + fl1_fxn * tg_zzzzz_x_1[j];

                    tg_xzzzzz_xy_0[j] = pb_x * tg_zzzzz_xy_0[j] + fr * tg_zzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzz_y_1[j];

                    tg_xzzzzz_xz_0[j] = pb_x * tg_zzzzz_xz_0[j] + fr * tg_zzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_z_1[j];

                    tg_xzzzzz_yy_0[j] = pb_x * tg_zzzzz_yy_0[j] + fr * tg_zzzzz_yy_1[j];

                    tg_xzzzzz_yz_0[j] = pb_x * tg_zzzzz_yz_0[j] + fr * tg_zzzzz_yz_1[j];

                    tg_xzzzzz_zz_0[j] = pb_x * tg_zzzzz_zz_0[j] + fr * tg_zzzzz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyy_xx_0[j] = pb_y * tg_yyyyy_xx_0[j] + fr * tg_yyyyy_xx_1[j] + 2.5 * fl1_fx * (tg_yyyy_xx_0[j] - tg_yyyy_xx_1[j] * fl1_fza);

                    tg_yyyyyy_xy_0[j] = pb_y * tg_yyyyy_xy_0[j] + fr * tg_yyyyy_xy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xy_0[j] - tg_yyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_x_1[j];

                    tg_yyyyyy_xz_0[j] = pb_y * tg_yyyyy_xz_0[j] + fr * tg_yyyyy_xz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xz_0[j] - tg_yyyy_xz_1[j] * fl1_fza);

                    tg_yyyyyy_yy_0[j] = pb_y * tg_yyyyy_yy_0[j] + fr * tg_yyyyy_yy_1[j] + 2.5 * fl1_fx * (tg_yyyy_yy_0[j] - tg_yyyy_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_y_1[j];

                    tg_yyyyyy_yz_0[j] = pb_y * tg_yyyyy_yz_0[j] + fr * tg_yyyyy_yz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yz_0[j] - tg_yyyy_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_z_1[j];

                    tg_yyyyyy_zz_0[j] = pb_y * tg_yyyyy_zz_0[j] + fr * tg_yyyyy_zz_1[j] + 2.5 * fl1_fx * (tg_yyyy_zz_0[j] - tg_yyyy_zz_1[j] * fl1_fza);

                    tg_yyyyyz_xx_0[j] = pb_y * tg_yyyyz_xx_0[j] + fr * tg_yyyyz_xx_1[j] + 2.0 * fl1_fx * (tg_yyyz_xx_0[j] - tg_yyyz_xx_1[j] * fl1_fza);

                    tg_yyyyyz_xy_0[j] = pb_y * tg_yyyyz_xy_0[j] + fr * tg_yyyyz_xy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xy_0[j] - tg_yyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_x_1[j];

                    tg_yyyyyz_xz_0[j] = pb_y * tg_yyyyz_xz_0[j] + fr * tg_yyyyz_xz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xz_0[j] - tg_yyyz_xz_1[j] * fl1_fza);

                    tg_yyyyyz_yy_0[j] = pb_y * tg_yyyyz_yy_0[j] + fr * tg_yyyyz_yy_1[j] + 2.0 * fl1_fx * (tg_yyyz_yy_0[j] - tg_yyyz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_y_1[j];

                    tg_yyyyyz_yz_0[j] = pb_y * tg_yyyyz_yz_0[j] + fr * tg_yyyyz_yz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yz_0[j] - tg_yyyz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_z_1[j];

                    tg_yyyyyz_zz_0[j] = pb_y * tg_yyyyz_zz_0[j] + fr * tg_yyyyz_zz_1[j] + 2.0 * fl1_fx * (tg_yyyz_zz_0[j] - tg_yyyz_zz_1[j] * fl1_fza);

                    tg_yyyyzz_xx_0[j] = pb_y * tg_yyyzz_xx_0[j] + fr * tg_yyyzz_xx_1[j] + 1.5 * fl1_fx * (tg_yyzz_xx_0[j] - tg_yyzz_xx_1[j] * fl1_fza);

                    tg_yyyyzz_xy_0[j] = pb_y * tg_yyyzz_xy_0[j] + fr * tg_yyyzz_xy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xy_0[j] - tg_yyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_x_1[j];

                    tg_yyyyzz_xz_0[j] = pb_y * tg_yyyzz_xz_0[j] + fr * tg_yyyzz_xz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xz_0[j] - tg_yyzz_xz_1[j] * fl1_fza);

                    tg_yyyyzz_yy_0[j] = pb_y * tg_yyyzz_yy_0[j] + fr * tg_yyyzz_yy_1[j] + 1.5 * fl1_fx * (tg_yyzz_yy_0[j] - tg_yyzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_y_1[j];

                    tg_yyyyzz_yz_0[j] = pb_y * tg_yyyzz_yz_0[j] + fr * tg_yyyzz_yz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yz_0[j] - tg_yyzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_z_1[j];

                    tg_yyyyzz_zz_0[j] = pb_y * tg_yyyzz_zz_0[j] + fr * tg_yyyzz_zz_1[j] + 1.5 * fl1_fx * (tg_yyzz_zz_0[j] - tg_yyzz_zz_1[j] * fl1_fza);

                    tg_yyyzzz_xx_0[j] = pb_y * tg_yyzzz_xx_0[j] + fr * tg_yyzzz_xx_1[j] + fl1_fx * (tg_yzzz_xx_0[j] - tg_yzzz_xx_1[j] * fl1_fza);

                    tg_yyyzzz_xy_0[j] = pb_y * tg_yyzzz_xy_0[j] + fr * tg_yyzzz_xy_1[j] + fl1_fx * (tg_yzzz_xy_0[j] - tg_yzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_x_1[j];

                    tg_yyyzzz_xz_0[j] = pb_y * tg_yyzzz_xz_0[j] + fr * tg_yyzzz_xz_1[j] + fl1_fx * (tg_yzzz_xz_0[j] - tg_yzzz_xz_1[j] * fl1_fza);

                    tg_yyyzzz_yy_0[j] = pb_y * tg_yyzzz_yy_0[j] + fr * tg_yyzzz_yy_1[j] + fl1_fx * (tg_yzzz_yy_0[j] - tg_yzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_y_1[j];

                    tg_yyyzzz_yz_0[j] = pb_y * tg_yyzzz_yz_0[j] + fr * tg_yyzzz_yz_1[j] + fl1_fx * (tg_yzzz_yz_0[j] - tg_yzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_z_1[j];

                    tg_yyyzzz_zz_0[j] = pb_y * tg_yyzzz_zz_0[j] + fr * tg_yyzzz_zz_1[j] + fl1_fx * (tg_yzzz_zz_0[j] - tg_yzzz_zz_1[j] * fl1_fza);

                    tg_yyzzzz_xx_0[j] = pb_y * tg_yzzzz_xx_0[j] + fr * tg_yzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzz_xx_0[j] - tg_zzzz_xx_1[j] * fl1_fza);

                    tg_yyzzzz_xy_0[j] = pb_y * tg_yzzzz_xy_0[j] + fr * tg_yzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xy_0[j] - tg_zzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_x_1[j];

                    tg_yyzzzz_xz_0[j] = pb_y * tg_yzzzz_xz_0[j] + fr * tg_yzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xz_0[j] - tg_zzzz_xz_1[j] * fl1_fza);

                    tg_yyzzzz_yy_0[j] = pb_y * tg_yzzzz_yy_0[j] + fr * tg_yzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzz_yy_0[j] - tg_zzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_y_1[j];

                    tg_yyzzzz_yz_0[j] = pb_y * tg_yzzzz_yz_0[j] + fr * tg_yzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yz_0[j] - tg_zzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_z_1[j];

                    tg_yyzzzz_zz_0[j] = pb_y * tg_yzzzz_zz_0[j] + fr * tg_yzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzz_zz_0[j] - tg_zzzz_zz_1[j] * fl1_fza);

                    tg_yzzzzz_xx_0[j] = pb_y * tg_zzzzz_xx_0[j] + fr * tg_zzzzz_xx_1[j];

                    tg_yzzzzz_xy_0[j] = pb_y * tg_zzzzz_xy_0[j] + fr * tg_zzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzz_x_1[j];

                    tg_yzzzzz_xz_0[j] = pb_y * tg_zzzzz_xz_0[j] + fr * tg_zzzzz_xz_1[j];

                    tg_yzzzzz_yy_0[j] = pb_y * tg_zzzzz_yy_0[j] + fr * tg_zzzzz_yy_1[j] + fl1_fxn * tg_zzzzz_y_1[j];

                    tg_yzzzzz_yz_0[j] = pb_y * tg_zzzzz_yz_0[j] + fr * tg_zzzzz_yz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_z_1[j];

                    tg_yzzzzz_zz_0[j] = pb_y * tg_zzzzz_zz_0[j] + fr * tg_zzzzz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzz_xx_0[j] = pb_z * tg_zzzzz_xx_0[j] + fr * tg_zzzzz_xx_1[j] + 2.5 * fl1_fx * (tg_zzzz_xx_0[j] - tg_zzzz_xx_1[j] * fl1_fza);

                    tg_zzzzzz_xy_0[j] = pb_z * tg_zzzzz_xy_0[j] + fr * tg_zzzzz_xy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xy_0[j] - tg_zzzz_xy_1[j] * fl1_fza);

                    tg_zzzzzz_xz_0[j] = pb_z * tg_zzzzz_xz_0[j] + fr * tg_zzzzz_xz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xz_0[j] - tg_zzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_x_1[j];

                    tg_zzzzzz_yy_0[j] = pb_z * tg_zzzzz_yy_0[j] + fr * tg_zzzzz_yy_1[j] + 2.5 * fl1_fx * (tg_zzzz_yy_0[j] - tg_zzzz_yy_1[j] * fl1_fza);

                    tg_zzzzzz_yz_0[j] = pb_z * tg_zzzzz_yz_0[j] + fr * tg_zzzzz_yz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yz_0[j] - tg_zzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_y_1[j];

                    tg_zzzzzz_zz_0[j] = pb_z * tg_zzzzz_zz_0[j] + fr * tg_zzzzz_zz_1[j] + 2.5 * fl1_fx * (tg_zzzz_zz_0[j] - tg_zzzz_zz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSK(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSDSK_0_72(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSDSK_72_144(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSDSK_144_216(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 
    }

    void
    compElectronRepulsionForSDSK_0_72(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,72)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_x_xxxxxxx_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx); 

                auto tg_x_xxxxxxy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 1); 

                auto tg_x_xxxxxxz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 2); 

                auto tg_x_xxxxxyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 3); 

                auto tg_x_xxxxxyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 4); 

                auto tg_x_xxxxxzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 5); 

                auto tg_x_xxxxyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 6); 

                auto tg_x_xxxxyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 7); 

                auto tg_x_xxxxyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 8); 

                auto tg_x_xxxxzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 9); 

                auto tg_x_xxxyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 10); 

                auto tg_x_xxxyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 11); 

                auto tg_x_xxxyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 12); 

                auto tg_x_xxxyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 13); 

                auto tg_x_xxxzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 14); 

                auto tg_x_xxyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 15); 

                auto tg_x_xxyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 16); 

                auto tg_x_xxyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 17); 

                auto tg_x_xxyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 18); 

                auto tg_x_xxyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 19); 

                auto tg_x_xxzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 20); 

                auto tg_x_xyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 21); 

                auto tg_x_xyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 22); 

                auto tg_x_xyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 23); 

                auto tg_x_xyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 24); 

                auto tg_x_xyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 25); 

                auto tg_x_xyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 26); 

                auto tg_x_xzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 27); 

                auto tg_x_yyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 28); 

                auto tg_x_yyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 29); 

                auto tg_x_yyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 30); 

                auto tg_x_yyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 31); 

                auto tg_x_yyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 32); 

                auto tg_x_yyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 33); 

                auto tg_x_yzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 34); 

                auto tg_x_zzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 35); 

                auto tg_y_xxxxxxx_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 71); 

                auto tg_x_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx); 

                auto tg_x_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 1); 

                auto tg_x_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 2); 

                auto tg_x_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 3); 

                auto tg_x_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 4); 

                auto tg_x_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 5); 

                auto tg_x_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 6); 

                auto tg_x_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 7); 

                auto tg_x_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 8); 

                auto tg_x_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 9); 

                auto tg_x_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 10); 

                auto tg_x_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 11); 

                auto tg_x_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 12); 

                auto tg_x_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 13); 

                auto tg_x_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 14); 

                auto tg_x_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 15); 

                auto tg_x_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 16); 

                auto tg_x_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 17); 

                auto tg_x_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 18); 

                auto tg_x_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 19); 

                auto tg_x_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 20); 

                auto tg_x_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 21); 

                auto tg_x_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 22); 

                auto tg_x_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 23); 

                auto tg_x_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 24); 

                auto tg_x_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 25); 

                auto tg_x_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 26); 

                auto tg_x_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 27); 

                auto tg_x_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 28); 

                auto tg_x_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 29); 

                auto tg_x_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 30); 

                auto tg_x_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 31); 

                auto tg_x_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 32); 

                auto tg_x_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 33); 

                auto tg_x_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 34); 

                auto tg_x_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 35); 

                auto tg_y_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 71); 

                auto tg_0_xxxxxxx_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx); 

                auto tg_0_xxxxxxy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 35); 

                auto tg_0_xxxxxxx_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx); 

                auto tg_0_xxxxxxy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 35); 

                auto tg_x_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx); 

                auto tg_x_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 1); 

                auto tg_x_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 2); 

                auto tg_x_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 3); 

                auto tg_x_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 4); 

                auto tg_x_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 5); 

                auto tg_x_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 6); 

                auto tg_x_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 7); 

                auto tg_x_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 8); 

                auto tg_x_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 9); 

                auto tg_x_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 10); 

                auto tg_x_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 11); 

                auto tg_x_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 12); 

                auto tg_x_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 13); 

                auto tg_x_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 14); 

                auto tg_x_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 15); 

                auto tg_x_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 16); 

                auto tg_x_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 17); 

                auto tg_x_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 18); 

                auto tg_x_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 19); 

                auto tg_x_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 20); 

                auto tg_x_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 21); 

                auto tg_x_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 22); 

                auto tg_x_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 23); 

                auto tg_x_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 24); 

                auto tg_x_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 25); 

                auto tg_x_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 26); 

                auto tg_x_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 27); 

                auto tg_y_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 28); 

                auto tg_y_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 29); 

                auto tg_y_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 30); 

                auto tg_y_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 31); 

                auto tg_y_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 32); 

                auto tg_y_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 33); 

                auto tg_y_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 34); 

                auto tg_y_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 35); 

                auto tg_y_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 36); 

                auto tg_y_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 37); 

                auto tg_y_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 38); 

                auto tg_y_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 39); 

                auto tg_y_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 40); 

                auto tg_y_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 41); 

                auto tg_y_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 42); 

                auto tg_y_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 43); 

                auto tg_y_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 44); 

                auto tg_y_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 45); 

                auto tg_y_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 46); 

                auto tg_y_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 47); 

                auto tg_y_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 48); 

                auto tg_y_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 49); 

                auto tg_y_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 50); 

                auto tg_y_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 51); 

                auto tg_y_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 52); 

                auto tg_y_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 53); 

                auto tg_y_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 54); 

                auto tg_y_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 55); 

                // set up pointers to integrals

                auto tg_xx_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx); 

                auto tg_xx_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 1); 

                auto tg_xx_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 2); 

                auto tg_xx_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 3); 

                auto tg_xx_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 4); 

                auto tg_xx_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 5); 

                auto tg_xx_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 6); 

                auto tg_xx_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 7); 

                auto tg_xx_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 8); 

                auto tg_xx_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 9); 

                auto tg_xx_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 10); 

                auto tg_xx_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 11); 

                auto tg_xx_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 12); 

                auto tg_xx_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 13); 

                auto tg_xx_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 14); 

                auto tg_xx_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 15); 

                auto tg_xx_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 16); 

                auto tg_xx_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 17); 

                auto tg_xx_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 18); 

                auto tg_xx_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 19); 

                auto tg_xx_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 20); 

                auto tg_xx_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 21); 

                auto tg_xx_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 22); 

                auto tg_xx_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 23); 

                auto tg_xx_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 24); 

                auto tg_xx_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 25); 

                auto tg_xx_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 26); 

                auto tg_xx_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 27); 

                auto tg_xx_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 28); 

                auto tg_xx_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 29); 

                auto tg_xx_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 30); 

                auto tg_xx_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 31); 

                auto tg_xx_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 32); 

                auto tg_xx_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 33); 

                auto tg_xx_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 34); 

                auto tg_xx_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 35); 

                auto tg_xy_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 36); 

                auto tg_xy_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 37); 

                auto tg_xy_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 38); 

                auto tg_xy_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 39); 

                auto tg_xy_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 40); 

                auto tg_xy_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 41); 

                auto tg_xy_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 42); 

                auto tg_xy_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 43); 

                auto tg_xy_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 44); 

                auto tg_xy_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 45); 

                auto tg_xy_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 46); 

                auto tg_xy_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 47); 

                auto tg_xy_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 48); 

                auto tg_xy_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 49); 

                auto tg_xy_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 50); 

                auto tg_xy_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 51); 

                auto tg_xy_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 52); 

                auto tg_xy_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 53); 

                auto tg_xy_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 54); 

                auto tg_xy_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 55); 

                auto tg_xy_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 56); 

                auto tg_xy_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 57); 

                auto tg_xy_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 58); 

                auto tg_xy_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 59); 

                auto tg_xy_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 60); 

                auto tg_xy_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 61); 

                auto tg_xy_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 62); 

                auto tg_xy_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 63); 

                auto tg_xy_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 64); 

                auto tg_xy_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 65); 

                auto tg_xy_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 66); 

                auto tg_xy_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 67); 

                auto tg_xy_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 68); 

                auto tg_xy_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 69); 

                auto tg_xy_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 70); 

                auto tg_xy_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 71); 

                // Batch of Integrals (0,72)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxx_0, tg_0_xxxxxxx_1, tg_0_xxxxxxy_0, \
                                         tg_0_xxxxxxy_1, tg_0_xxxxxxz_0, tg_0_xxxxxxz_1, tg_0_xxxxxyy_0, tg_0_xxxxxyy_1, \
                                         tg_0_xxxxxyz_0, tg_0_xxxxxyz_1, tg_0_xxxxxzz_0, tg_0_xxxxxzz_1, tg_0_xxxxyyy_0, \
                                         tg_0_xxxxyyy_1, tg_0_xxxxyyz_0, tg_0_xxxxyyz_1, tg_0_xxxxyzz_0, tg_0_xxxxyzz_1, \
                                         tg_0_xxxxzzz_0, tg_0_xxxxzzz_1, tg_0_xxxyyyy_0, tg_0_xxxyyyy_1, tg_0_xxxyyyz_0, \
                                         tg_0_xxxyyyz_1, tg_0_xxxyyzz_0, tg_0_xxxyyzz_1, tg_0_xxxyzzz_0, tg_0_xxxyzzz_1, \
                                         tg_0_xxxzzzz_0, tg_0_xxxzzzz_1, tg_0_xxyyyyy_0, tg_0_xxyyyyy_1, tg_0_xxyyyyz_0, \
                                         tg_0_xxyyyyz_1, tg_0_xxyyyzz_0, tg_0_xxyyyzz_1, tg_0_xxyyzzz_0, tg_0_xxyyzzz_1, \
                                         tg_0_xxyzzzz_0, tg_0_xxyzzzz_1, tg_0_xxzzzzz_0, tg_0_xxzzzzz_1, tg_0_xyyyyyy_0, \
                                         tg_0_xyyyyyy_1, tg_0_xyyyyyz_0, tg_0_xyyyyyz_1, tg_0_xyyyyzz_0, tg_0_xyyyyzz_1, \
                                         tg_0_xyyyzzz_0, tg_0_xyyyzzz_1, tg_0_xyyzzzz_0, tg_0_xyyzzzz_1, tg_0_xyzzzzz_0, \
                                         tg_0_xyzzzzz_1, tg_0_xzzzzzz_0, tg_0_xzzzzzz_1, tg_0_yyyyyyy_0, tg_0_yyyyyyy_1, \
                                         tg_0_yyyyyyz_0, tg_0_yyyyyyz_1, tg_0_yyyyyzz_0, tg_0_yyyyyzz_1, tg_0_yyyyzzz_0, \
                                         tg_0_yyyyzzz_1, tg_0_yyyzzzz_0, tg_0_yyyzzzz_1, tg_0_yyzzzzz_0, tg_0_yyzzzzz_1, \
                                         tg_0_yzzzzzz_0, tg_0_yzzzzzz_1, tg_0_zzzzzzz_0, tg_0_zzzzzzz_1, tg_x_xxxxxx_1, \
                                         tg_x_xxxxxxx_0, tg_x_xxxxxxx_1, tg_x_xxxxxxy_0, tg_x_xxxxxxy_1, tg_x_xxxxxxz_0, \
                                         tg_x_xxxxxxz_1, tg_x_xxxxxy_1, tg_x_xxxxxyy_0, tg_x_xxxxxyy_1, tg_x_xxxxxyz_0, \
                                         tg_x_xxxxxyz_1, tg_x_xxxxxz_1, tg_x_xxxxxzz_0, tg_x_xxxxxzz_1, tg_x_xxxxyy_1, \
                                         tg_x_xxxxyyy_0, tg_x_xxxxyyy_1, tg_x_xxxxyyz_0, tg_x_xxxxyyz_1, tg_x_xxxxyz_1, \
                                         tg_x_xxxxyzz_0, tg_x_xxxxyzz_1, tg_x_xxxxzz_1, tg_x_xxxxzzz_0, tg_x_xxxxzzz_1, \
                                         tg_x_xxxyyy_1, tg_x_xxxyyyy_0, tg_x_xxxyyyy_1, tg_x_xxxyyyz_0, tg_x_xxxyyyz_1, \
                                         tg_x_xxxyyz_1, tg_x_xxxyyzz_0, tg_x_xxxyyzz_1, tg_x_xxxyzz_1, tg_x_xxxyzzz_0, \
                                         tg_x_xxxyzzz_1, tg_x_xxxzzz_1, tg_x_xxxzzzz_0, tg_x_xxxzzzz_1, tg_x_xxyyyy_1, \
                                         tg_x_xxyyyyy_0, tg_x_xxyyyyy_1, tg_x_xxyyyyz_0, tg_x_xxyyyyz_1, tg_x_xxyyyz_1, \
                                         tg_x_xxyyyzz_0, tg_x_xxyyyzz_1, tg_x_xxyyzz_1, tg_x_xxyyzzz_0, tg_x_xxyyzzz_1, \
                                         tg_x_xxyzzz_1, tg_x_xxyzzzz_0, tg_x_xxyzzzz_1, tg_x_xxzzzz_1, tg_x_xxzzzzz_0, \
                                         tg_x_xxzzzzz_1, tg_x_xyyyyy_1, tg_x_xyyyyyy_0, tg_x_xyyyyyy_1, tg_x_xyyyyyz_0, \
                                         tg_x_xyyyyyz_1, tg_x_xyyyyz_1, tg_x_xyyyyzz_0, tg_x_xyyyyzz_1, tg_x_xyyyzz_1, \
                                         tg_x_xyyyzzz_0, tg_x_xyyyzzz_1, tg_x_xyyzzz_1, tg_x_xyyzzzz_0, tg_x_xyyzzzz_1, \
                                         tg_x_xyzzzz_1, tg_x_xyzzzzz_0, tg_x_xyzzzzz_1, tg_x_xzzzzz_1, tg_x_xzzzzzz_0, \
                                         tg_x_xzzzzzz_1, tg_x_yyyyyy_1, tg_x_yyyyyyy_0, tg_x_yyyyyyy_1, tg_x_yyyyyyz_0, \
                                         tg_x_yyyyyyz_1, tg_x_yyyyyz_1, tg_x_yyyyyzz_0, tg_x_yyyyyzz_1, tg_x_yyyyzz_1, \
                                         tg_x_yyyyzzz_0, tg_x_yyyyzzz_1, tg_x_yyyzzz_1, tg_x_yyyzzzz_0, tg_x_yyyzzzz_1, \
                                         tg_x_yyzzzz_1, tg_x_yyzzzzz_0, tg_x_yyzzzzz_1, tg_x_yzzzzz_1, tg_x_yzzzzzz_0, \
                                         tg_x_yzzzzzz_1, tg_x_zzzzzz_1, tg_x_zzzzzzz_0, tg_x_zzzzzzz_1, tg_xx_xxxxxxx_0, \
                                         tg_xx_xxxxxxy_0, tg_xx_xxxxxxz_0, tg_xx_xxxxxyy_0, tg_xx_xxxxxyz_0, tg_xx_xxxxxzz_0, \
                                         tg_xx_xxxxyyy_0, tg_xx_xxxxyyz_0, tg_xx_xxxxyzz_0, tg_xx_xxxxzzz_0, tg_xx_xxxyyyy_0, \
                                         tg_xx_xxxyyyz_0, tg_xx_xxxyyzz_0, tg_xx_xxxyzzz_0, tg_xx_xxxzzzz_0, tg_xx_xxyyyyy_0, \
                                         tg_xx_xxyyyyz_0, tg_xx_xxyyyzz_0, tg_xx_xxyyzzz_0, tg_xx_xxyzzzz_0, tg_xx_xxzzzzz_0, \
                                         tg_xx_xyyyyyy_0, tg_xx_xyyyyyz_0, tg_xx_xyyyyzz_0, tg_xx_xyyyzzz_0, tg_xx_xyyzzzz_0, \
                                         tg_xx_xyzzzzz_0, tg_xx_xzzzzzz_0, tg_xx_yyyyyyy_0, tg_xx_yyyyyyz_0, tg_xx_yyyyyzz_0, \
                                         tg_xx_yyyyzzz_0, tg_xx_yyyzzzz_0, tg_xx_yyzzzzz_0, tg_xx_yzzzzzz_0, tg_xx_zzzzzzz_0, \
                                         tg_xy_xxxxxxx_0, tg_xy_xxxxxxy_0, tg_xy_xxxxxxz_0, tg_xy_xxxxxyy_0, tg_xy_xxxxxyz_0, \
                                         tg_xy_xxxxxzz_0, tg_xy_xxxxyyy_0, tg_xy_xxxxyyz_0, tg_xy_xxxxyzz_0, tg_xy_xxxxzzz_0, \
                                         tg_xy_xxxyyyy_0, tg_xy_xxxyyyz_0, tg_xy_xxxyyzz_0, tg_xy_xxxyzzz_0, tg_xy_xxxzzzz_0, \
                                         tg_xy_xxyyyyy_0, tg_xy_xxyyyyz_0, tg_xy_xxyyyzz_0, tg_xy_xxyyzzz_0, tg_xy_xxyzzzz_0, \
                                         tg_xy_xxzzzzz_0, tg_xy_xyyyyyy_0, tg_xy_xyyyyyz_0, tg_xy_xyyyyzz_0, tg_xy_xyyyzzz_0, \
                                         tg_xy_xyyzzzz_0, tg_xy_xyzzzzz_0, tg_xy_xzzzzzz_0, tg_xy_yyyyyyy_0, tg_xy_yyyyyyz_0, \
                                         tg_xy_yyyyyzz_0, tg_xy_yyyyzzz_0, tg_xy_yyyzzzz_0, tg_xy_yyzzzzz_0, tg_xy_yzzzzzz_0, \
                                         tg_xy_zzzzzzz_0, tg_y_xxxxxx_1, tg_y_xxxxxxx_0, tg_y_xxxxxxx_1, tg_y_xxxxxxy_0, \
                                         tg_y_xxxxxxy_1, tg_y_xxxxxxz_0, tg_y_xxxxxxz_1, tg_y_xxxxxy_1, tg_y_xxxxxyy_0, \
                                         tg_y_xxxxxyy_1, tg_y_xxxxxyz_0, tg_y_xxxxxyz_1, tg_y_xxxxxz_1, tg_y_xxxxxzz_0, \
                                         tg_y_xxxxxzz_1, tg_y_xxxxyy_1, tg_y_xxxxyyy_0, tg_y_xxxxyyy_1, tg_y_xxxxyyz_0, \
                                         tg_y_xxxxyyz_1, tg_y_xxxxyz_1, tg_y_xxxxyzz_0, tg_y_xxxxyzz_1, tg_y_xxxxzz_1, \
                                         tg_y_xxxxzzz_0, tg_y_xxxxzzz_1, tg_y_xxxyyy_1, tg_y_xxxyyyy_0, tg_y_xxxyyyy_1, \
                                         tg_y_xxxyyyz_0, tg_y_xxxyyyz_1, tg_y_xxxyyz_1, tg_y_xxxyyzz_0, tg_y_xxxyyzz_1, \
                                         tg_y_xxxyzz_1, tg_y_xxxyzzz_0, tg_y_xxxyzzz_1, tg_y_xxxzzz_1, tg_y_xxxzzzz_0, \
                                         tg_y_xxxzzzz_1, tg_y_xxyyyy_1, tg_y_xxyyyyy_0, tg_y_xxyyyyy_1, tg_y_xxyyyyz_0, \
                                         tg_y_xxyyyyz_1, tg_y_xxyyyz_1, tg_y_xxyyyzz_0, tg_y_xxyyyzz_1, tg_y_xxyyzz_1, \
                                         tg_y_xxyyzzz_0, tg_y_xxyyzzz_1, tg_y_xxyzzz_1, tg_y_xxyzzzz_0, tg_y_xxyzzzz_1, \
                                         tg_y_xxzzzz_1, tg_y_xxzzzzz_0, tg_y_xxzzzzz_1, tg_y_xyyyyy_1, tg_y_xyyyyyy_0, \
                                         tg_y_xyyyyyy_1, tg_y_xyyyyyz_0, tg_y_xyyyyyz_1, tg_y_xyyyyz_1, tg_y_xyyyyzz_0, \
                                         tg_y_xyyyyzz_1, tg_y_xyyyzz_1, tg_y_xyyyzzz_0, tg_y_xyyyzzz_1, tg_y_xyyzzz_1, \
                                         tg_y_xyyzzzz_0, tg_y_xyyzzzz_1, tg_y_xyzzzz_1, tg_y_xyzzzzz_0, tg_y_xyzzzzz_1, \
                                         tg_y_xzzzzz_1, tg_y_xzzzzzz_0, tg_y_xzzzzzz_1, tg_y_yyyyyy_1, tg_y_yyyyyyy_0, \
                                         tg_y_yyyyyyy_1, tg_y_yyyyyyz_0, tg_y_yyyyyyz_1, tg_y_yyyyyz_1, tg_y_yyyyyzz_0, \
                                         tg_y_yyyyyzz_1, tg_y_yyyyzz_1, tg_y_yyyyzzz_0, tg_y_yyyyzzz_1, tg_y_yyyzzz_1, \
                                         tg_y_yyyzzzz_0, tg_y_yyyzzzz_1, tg_y_yyzzzz_1, tg_y_yyzzzzz_0, tg_y_yyzzzzz_1, \
                                         tg_y_yzzzzz_1, tg_y_yzzzzzz_0, tg_y_yzzzzzz_1, tg_y_zzzzzz_1, tg_y_zzzzzzz_0, \
                                         tg_y_zzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxxxxxx_0[j] = pb_x * tg_x_xxxxxxx_0[j] + fr * tg_x_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxx_0[j] - tg_0_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_x_xxxxxx_1[j];

                    tg_xx_xxxxxxy_0[j] = pb_x * tg_x_xxxxxxy_0[j] + fr * tg_x_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxy_0[j] - tg_0_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxxy_1[j];

                    tg_xx_xxxxxxz_0[j] = pb_x * tg_x_xxxxxxz_0[j] + fr * tg_x_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxz_0[j] - tg_0_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxxz_1[j];

                    tg_xx_xxxxxyy_0[j] = pb_x * tg_x_xxxxxyy_0[j] + fr * tg_x_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyy_0[j] - tg_0_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxyy_1[j];

                    tg_xx_xxxxxyz_0[j] = pb_x * tg_x_xxxxxyz_0[j] + fr * tg_x_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyz_0[j] - tg_0_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxyz_1[j];

                    tg_xx_xxxxxzz_0[j] = pb_x * tg_x_xxxxxzz_0[j] + fr * tg_x_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzz_0[j] - tg_0_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxzz_1[j];

                    tg_xx_xxxxyyy_0[j] = pb_x * tg_x_xxxxyyy_0[j] + fr * tg_x_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyy_0[j] - tg_0_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyyy_1[j];

                    tg_xx_xxxxyyz_0[j] = pb_x * tg_x_xxxxyyz_0[j] + fr * tg_x_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyz_0[j] - tg_0_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyyz_1[j];

                    tg_xx_xxxxyzz_0[j] = pb_x * tg_x_xxxxyzz_0[j] + fr * tg_x_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzz_0[j] - tg_0_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyzz_1[j];

                    tg_xx_xxxxzzz_0[j] = pb_x * tg_x_xxxxzzz_0[j] + fr * tg_x_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzz_0[j] - tg_0_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxzzz_1[j];

                    tg_xx_xxxyyyy_0[j] = pb_x * tg_x_xxxyyyy_0[j] + fr * tg_x_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyy_0[j] - tg_0_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyyy_1[j];

                    tg_xx_xxxyyyz_0[j] = pb_x * tg_x_xxxyyyz_0[j] + fr * tg_x_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyz_0[j] - tg_0_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyyz_1[j];

                    tg_xx_xxxyyzz_0[j] = pb_x * tg_x_xxxyyzz_0[j] + fr * tg_x_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzz_0[j] - tg_0_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyzz_1[j];

                    tg_xx_xxxyzzz_0[j] = pb_x * tg_x_xxxyzzz_0[j] + fr * tg_x_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzz_0[j] - tg_0_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyzzz_1[j];

                    tg_xx_xxxzzzz_0[j] = pb_x * tg_x_xxxzzzz_0[j] + fr * tg_x_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzz_0[j] - tg_0_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxzzzz_1[j];

                    tg_xx_xxyyyyy_0[j] = pb_x * tg_x_xxyyyyy_0[j] + fr * tg_x_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyy_0[j] - tg_0_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyyy_1[j];

                    tg_xx_xxyyyyz_0[j] = pb_x * tg_x_xxyyyyz_0[j] + fr * tg_x_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyz_0[j] - tg_0_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyyz_1[j];

                    tg_xx_xxyyyzz_0[j] = pb_x * tg_x_xxyyyzz_0[j] + fr * tg_x_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzz_0[j] - tg_0_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyzz_1[j];

                    tg_xx_xxyyzzz_0[j] = pb_x * tg_x_xxyyzzz_0[j] + fr * tg_x_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzz_0[j] - tg_0_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyzzz_1[j];

                    tg_xx_xxyzzzz_0[j] = pb_x * tg_x_xxyzzzz_0[j] + fr * tg_x_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzz_0[j] - tg_0_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyzzzz_1[j];

                    tg_xx_xxzzzzz_0[j] = pb_x * tg_x_xxzzzzz_0[j] + fr * tg_x_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzz_0[j] - tg_0_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xzzzzz_1[j];

                    tg_xx_xyyyyyy_0[j] = pb_x * tg_x_xyyyyyy_0[j] + fr * tg_x_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyy_0[j] - tg_0_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyyy_1[j];

                    tg_xx_xyyyyyz_0[j] = pb_x * tg_x_xyyyyyz_0[j] + fr * tg_x_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyz_0[j] - tg_0_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyyz_1[j];

                    tg_xx_xyyyyzz_0[j] = pb_x * tg_x_xyyyyzz_0[j] + fr * tg_x_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzz_0[j] - tg_0_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyzz_1[j];

                    tg_xx_xyyyzzz_0[j] = pb_x * tg_x_xyyyzzz_0[j] + fr * tg_x_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzz_0[j] - tg_0_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyzzz_1[j];

                    tg_xx_xyyzzzz_0[j] = pb_x * tg_x_xyyzzzz_0[j] + fr * tg_x_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzz_0[j] - tg_0_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyzzzz_1[j];

                    tg_xx_xyzzzzz_0[j] = pb_x * tg_x_xyzzzzz_0[j] + fr * tg_x_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzz_0[j] - tg_0_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yzzzzz_1[j];

                    tg_xx_xzzzzzz_0[j] = pb_x * tg_x_xzzzzzz_0[j] + fr * tg_x_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzz_0[j] - tg_0_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zzzzzz_1[j];

                    tg_xx_yyyyyyy_0[j] = pb_x * tg_x_yyyyyyy_0[j] + fr * tg_x_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyy_0[j] - tg_0_yyyyyyy_1[j] * fl1_fza);

                    tg_xx_yyyyyyz_0[j] = pb_x * tg_x_yyyyyyz_0[j] + fr * tg_x_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyz_0[j] - tg_0_yyyyyyz_1[j] * fl1_fza);

                    tg_xx_yyyyyzz_0[j] = pb_x * tg_x_yyyyyzz_0[j] + fr * tg_x_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzz_0[j] - tg_0_yyyyyzz_1[j] * fl1_fza);

                    tg_xx_yyyyzzz_0[j] = pb_x * tg_x_yyyyzzz_0[j] + fr * tg_x_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzz_0[j] - tg_0_yyyyzzz_1[j] * fl1_fza);

                    tg_xx_yyyzzzz_0[j] = pb_x * tg_x_yyyzzzz_0[j] + fr * tg_x_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzz_0[j] - tg_0_yyyzzzz_1[j] * fl1_fza);

                    tg_xx_yyzzzzz_0[j] = pb_x * tg_x_yyzzzzz_0[j] + fr * tg_x_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzz_0[j] - tg_0_yyzzzzz_1[j] * fl1_fza);

                    tg_xx_yzzzzzz_0[j] = pb_x * tg_x_yzzzzzz_0[j] + fr * tg_x_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzz_0[j] - tg_0_yzzzzzz_1[j] * fl1_fza);

                    tg_xx_zzzzzzz_0[j] = pb_x * tg_x_zzzzzzz_0[j] + fr * tg_x_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzz_0[j] - tg_0_zzzzzzz_1[j] * fl1_fza);

                    tg_xy_xxxxxxx_0[j] = pb_x * tg_y_xxxxxxx_0[j] + fr * tg_y_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_y_xxxxxx_1[j];

                    tg_xy_xxxxxxy_0[j] = pb_x * tg_y_xxxxxxy_0[j] + fr * tg_y_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_y_xxxxxy_1[j];

                    tg_xy_xxxxxxz_0[j] = pb_x * tg_y_xxxxxxz_0[j] + fr * tg_y_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_y_xxxxxz_1[j];

                    tg_xy_xxxxxyy_0[j] = pb_x * tg_y_xxxxxyy_0[j] + fr * tg_y_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_y_xxxxyy_1[j];

                    tg_xy_xxxxxyz_0[j] = pb_x * tg_y_xxxxxyz_0[j] + fr * tg_y_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxyz_1[j];

                    tg_xy_xxxxxzz_0[j] = pb_x * tg_y_xxxxxzz_0[j] + fr * tg_y_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxzz_1[j];

                    tg_xy_xxxxyyy_0[j] = pb_x * tg_y_xxxxyyy_0[j] + fr * tg_y_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_y_xxxyyy_1[j];

                    tg_xy_xxxxyyz_0[j] = pb_x * tg_y_xxxxyyz_0[j] + fr * tg_y_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyyz_1[j];

                    tg_xy_xxxxyzz_0[j] = pb_x * tg_y_xxxxyzz_0[j] + fr * tg_y_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyzz_1[j];

                    tg_xy_xxxxzzz_0[j] = pb_x * tg_y_xxxxzzz_0[j] + fr * tg_y_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxzzz_1[j];

                    tg_xy_xxxyyyy_0[j] = pb_x * tg_y_xxxyyyy_0[j] + fr * tg_y_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_y_xxyyyy_1[j];

                    tg_xy_xxxyyyz_0[j] = pb_x * tg_y_xxxyyyz_0[j] + fr * tg_y_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyyz_1[j];

                    tg_xy_xxxyyzz_0[j] = pb_x * tg_y_xxxyyzz_0[j] + fr * tg_y_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyzz_1[j];

                    tg_xy_xxxyzzz_0[j] = pb_x * tg_y_xxxyzzz_0[j] + fr * tg_y_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyzzz_1[j];

                    tg_xy_xxxzzzz_0[j] = pb_x * tg_y_xxxzzzz_0[j] + fr * tg_y_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxzzzz_1[j];

                    tg_xy_xxyyyyy_0[j] = pb_x * tg_y_xxyyyyy_0[j] + fr * tg_y_xxyyyyy_1[j] + fl1_fxn * tg_y_xyyyyy_1[j];

                    tg_xy_xxyyyyz_0[j] = pb_x * tg_y_xxyyyyz_0[j] + fr * tg_y_xxyyyyz_1[j] + fl1_fxn * tg_y_xyyyyz_1[j];

                    tg_xy_xxyyyzz_0[j] = pb_x * tg_y_xxyyyzz_0[j] + fr * tg_y_xxyyyzz_1[j] + fl1_fxn * tg_y_xyyyzz_1[j];

                    tg_xy_xxyyzzz_0[j] = pb_x * tg_y_xxyyzzz_0[j] + fr * tg_y_xxyyzzz_1[j] + fl1_fxn * tg_y_xyyzzz_1[j];

                    tg_xy_xxyzzzz_0[j] = pb_x * tg_y_xxyzzzz_0[j] + fr * tg_y_xxyzzzz_1[j] + fl1_fxn * tg_y_xyzzzz_1[j];

                    tg_xy_xxzzzzz_0[j] = pb_x * tg_y_xxzzzzz_0[j] + fr * tg_y_xxzzzzz_1[j] + fl1_fxn * tg_y_xzzzzz_1[j];

                    tg_xy_xyyyyyy_0[j] = pb_x * tg_y_xyyyyyy_0[j] + fr * tg_y_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_y_yyyyyy_1[j];

                    tg_xy_xyyyyyz_0[j] = pb_x * tg_y_xyyyyyz_0[j] + fr * tg_y_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyyz_1[j];

                    tg_xy_xyyyyzz_0[j] = pb_x * tg_y_xyyyyzz_0[j] + fr * tg_y_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyzz_1[j];

                    tg_xy_xyyyzzz_0[j] = pb_x * tg_y_xyyyzzz_0[j] + fr * tg_y_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyzzz_1[j];

                    tg_xy_xyyzzzz_0[j] = pb_x * tg_y_xyyzzzz_0[j] + fr * tg_y_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyzzzz_1[j];

                    tg_xy_xyzzzzz_0[j] = pb_x * tg_y_xyzzzzz_0[j] + fr * tg_y_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yzzzzz_1[j];

                    tg_xy_xzzzzzz_0[j] = pb_x * tg_y_xzzzzzz_0[j] + fr * tg_y_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_zzzzzz_1[j];

                    tg_xy_yyyyyyy_0[j] = pb_x * tg_y_yyyyyyy_0[j] + fr * tg_y_yyyyyyy_1[j];

                    tg_xy_yyyyyyz_0[j] = pb_x * tg_y_yyyyyyz_0[j] + fr * tg_y_yyyyyyz_1[j];

                    tg_xy_yyyyyzz_0[j] = pb_x * tg_y_yyyyyzz_0[j] + fr * tg_y_yyyyyzz_1[j];

                    tg_xy_yyyyzzz_0[j] = pb_x * tg_y_yyyyzzz_0[j] + fr * tg_y_yyyyzzz_1[j];

                    tg_xy_yyyzzzz_0[j] = pb_x * tg_y_yyyzzzz_0[j] + fr * tg_y_yyyzzzz_1[j];

                    tg_xy_yyzzzzz_0[j] = pb_x * tg_y_yyzzzzz_0[j] + fr * tg_y_yyzzzzz_1[j];

                    tg_xy_yzzzzzz_0[j] = pb_x * tg_y_yzzzzzz_0[j] + fr * tg_y_yzzzzzz_1[j];

                    tg_xy_zzzzzzz_0[j] = pb_x * tg_y_zzzzzzz_0[j] + fr * tg_y_zzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSK_72_144(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (72,144)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_y_xxxxxxx_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 71); 

                auto tg_z_xxxxxxx_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 107); 

                auto tg_y_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 71); 

                auto tg_z_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 107); 

                auto tg_0_xxxxxxx_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx); 

                auto tg_0_xxxxxxy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 35); 

                auto tg_0_xxxxxxx_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx); 

                auto tg_0_xxxxxxy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 35); 

                auto tg_y_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 28); 

                auto tg_y_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 29); 

                auto tg_y_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 30); 

                auto tg_y_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 31); 

                auto tg_y_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 32); 

                auto tg_y_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 33); 

                auto tg_y_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 34); 

                auto tg_y_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 35); 

                auto tg_y_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 36); 

                auto tg_y_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 37); 

                auto tg_y_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 38); 

                auto tg_y_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 39); 

                auto tg_y_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 40); 

                auto tg_y_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 41); 

                auto tg_y_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 42); 

                auto tg_y_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 43); 

                auto tg_y_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 44); 

                auto tg_y_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 45); 

                auto tg_y_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 46); 

                auto tg_y_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 47); 

                auto tg_y_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 48); 

                auto tg_y_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 49); 

                auto tg_y_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 50); 

                auto tg_y_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 51); 

                auto tg_y_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 52); 

                auto tg_y_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 53); 

                auto tg_y_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 54); 

                auto tg_y_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 55); 

                auto tg_z_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 56); 

                auto tg_z_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 57); 

                auto tg_z_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 58); 

                auto tg_z_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 59); 

                auto tg_z_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 60); 

                auto tg_z_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 61); 

                auto tg_z_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 62); 

                auto tg_z_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 63); 

                auto tg_z_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 64); 

                auto tg_z_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 65); 

                auto tg_z_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 66); 

                auto tg_z_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 67); 

                auto tg_z_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 68); 

                auto tg_z_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 69); 

                auto tg_z_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 70); 

                auto tg_z_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 71); 

                auto tg_z_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 72); 

                auto tg_z_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 73); 

                auto tg_z_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 74); 

                auto tg_z_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 75); 

                auto tg_z_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 76); 

                auto tg_z_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 77); 

                auto tg_z_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 78); 

                auto tg_z_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 79); 

                auto tg_z_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 80); 

                auto tg_z_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 81); 

                auto tg_z_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 82); 

                auto tg_z_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 83); 

                // set up pointers to integrals

                auto tg_xz_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 72); 

                auto tg_xz_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 73); 

                auto tg_xz_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 74); 

                auto tg_xz_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 75); 

                auto tg_xz_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 76); 

                auto tg_xz_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 77); 

                auto tg_xz_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 78); 

                auto tg_xz_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 79); 

                auto tg_xz_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 80); 

                auto tg_xz_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 81); 

                auto tg_xz_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 82); 

                auto tg_xz_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 83); 

                auto tg_xz_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 84); 

                auto tg_xz_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 85); 

                auto tg_xz_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 86); 

                auto tg_xz_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 87); 

                auto tg_xz_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 88); 

                auto tg_xz_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 89); 

                auto tg_xz_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 90); 

                auto tg_xz_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 91); 

                auto tg_xz_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 92); 

                auto tg_xz_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 93); 

                auto tg_xz_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 94); 

                auto tg_xz_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 95); 

                auto tg_xz_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 96); 

                auto tg_xz_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 97); 

                auto tg_xz_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 98); 

                auto tg_xz_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 99); 

                auto tg_xz_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 100); 

                auto tg_xz_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 101); 

                auto tg_xz_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 102); 

                auto tg_xz_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 103); 

                auto tg_xz_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 104); 

                auto tg_xz_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 105); 

                auto tg_xz_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 106); 

                auto tg_xz_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 107); 

                auto tg_yy_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 108); 

                auto tg_yy_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 109); 

                auto tg_yy_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 110); 

                auto tg_yy_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 111); 

                auto tg_yy_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 112); 

                auto tg_yy_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 113); 

                auto tg_yy_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 114); 

                auto tg_yy_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 115); 

                auto tg_yy_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 116); 

                auto tg_yy_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 117); 

                auto tg_yy_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 118); 

                auto tg_yy_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 119); 

                auto tg_yy_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 120); 

                auto tg_yy_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 121); 

                auto tg_yy_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 122); 

                auto tg_yy_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 123); 

                auto tg_yy_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 124); 

                auto tg_yy_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 125); 

                auto tg_yy_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 126); 

                auto tg_yy_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 127); 

                auto tg_yy_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 128); 

                auto tg_yy_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 129); 

                auto tg_yy_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 130); 

                auto tg_yy_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 131); 

                auto tg_yy_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 132); 

                auto tg_yy_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 133); 

                auto tg_yy_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 134); 

                auto tg_yy_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 135); 

                auto tg_yy_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 136); 

                auto tg_yy_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 137); 

                auto tg_yy_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 138); 

                auto tg_yy_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 139); 

                auto tg_yy_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 140); 

                auto tg_yy_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 141); 

                auto tg_yy_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 142); 

                auto tg_yy_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 143); 

                // Batch of Integrals (72,144)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxx_0, tg_0_xxxxxxx_1, tg_0_xxxxxxy_0, \
                                         tg_0_xxxxxxy_1, tg_0_xxxxxxz_0, tg_0_xxxxxxz_1, tg_0_xxxxxyy_0, tg_0_xxxxxyy_1, \
                                         tg_0_xxxxxyz_0, tg_0_xxxxxyz_1, tg_0_xxxxxzz_0, tg_0_xxxxxzz_1, tg_0_xxxxyyy_0, \
                                         tg_0_xxxxyyy_1, tg_0_xxxxyyz_0, tg_0_xxxxyyz_1, tg_0_xxxxyzz_0, tg_0_xxxxyzz_1, \
                                         tg_0_xxxxzzz_0, tg_0_xxxxzzz_1, tg_0_xxxyyyy_0, tg_0_xxxyyyy_1, tg_0_xxxyyyz_0, \
                                         tg_0_xxxyyyz_1, tg_0_xxxyyzz_0, tg_0_xxxyyzz_1, tg_0_xxxyzzz_0, tg_0_xxxyzzz_1, \
                                         tg_0_xxxzzzz_0, tg_0_xxxzzzz_1, tg_0_xxyyyyy_0, tg_0_xxyyyyy_1, tg_0_xxyyyyz_0, \
                                         tg_0_xxyyyyz_1, tg_0_xxyyyzz_0, tg_0_xxyyyzz_1, tg_0_xxyyzzz_0, tg_0_xxyyzzz_1, \
                                         tg_0_xxyzzzz_0, tg_0_xxyzzzz_1, tg_0_xxzzzzz_0, tg_0_xxzzzzz_1, tg_0_xyyyyyy_0, \
                                         tg_0_xyyyyyy_1, tg_0_xyyyyyz_0, tg_0_xyyyyyz_1, tg_0_xyyyyzz_0, tg_0_xyyyyzz_1, \
                                         tg_0_xyyyzzz_0, tg_0_xyyyzzz_1, tg_0_xyyzzzz_0, tg_0_xyyzzzz_1, tg_0_xyzzzzz_0, \
                                         tg_0_xyzzzzz_1, tg_0_xzzzzzz_0, tg_0_xzzzzzz_1, tg_0_yyyyyyy_0, tg_0_yyyyyyy_1, \
                                         tg_0_yyyyyyz_0, tg_0_yyyyyyz_1, tg_0_yyyyyzz_0, tg_0_yyyyyzz_1, tg_0_yyyyzzz_0, \
                                         tg_0_yyyyzzz_1, tg_0_yyyzzzz_0, tg_0_yyyzzzz_1, tg_0_yyzzzzz_0, tg_0_yyzzzzz_1, \
                                         tg_0_yzzzzzz_0, tg_0_yzzzzzz_1, tg_0_zzzzzzz_0, tg_0_zzzzzzz_1, tg_xz_xxxxxxx_0, \
                                         tg_xz_xxxxxxy_0, tg_xz_xxxxxxz_0, tg_xz_xxxxxyy_0, tg_xz_xxxxxyz_0, tg_xz_xxxxxzz_0, \
                                         tg_xz_xxxxyyy_0, tg_xz_xxxxyyz_0, tg_xz_xxxxyzz_0, tg_xz_xxxxzzz_0, tg_xz_xxxyyyy_0, \
                                         tg_xz_xxxyyyz_0, tg_xz_xxxyyzz_0, tg_xz_xxxyzzz_0, tg_xz_xxxzzzz_0, tg_xz_xxyyyyy_0, \
                                         tg_xz_xxyyyyz_0, tg_xz_xxyyyzz_0, tg_xz_xxyyzzz_0, tg_xz_xxyzzzz_0, tg_xz_xxzzzzz_0, \
                                         tg_xz_xyyyyyy_0, tg_xz_xyyyyyz_0, tg_xz_xyyyyzz_0, tg_xz_xyyyzzz_0, tg_xz_xyyzzzz_0, \
                                         tg_xz_xyzzzzz_0, tg_xz_xzzzzzz_0, tg_xz_yyyyyyy_0, tg_xz_yyyyyyz_0, tg_xz_yyyyyzz_0, \
                                         tg_xz_yyyyzzz_0, tg_xz_yyyzzzz_0, tg_xz_yyzzzzz_0, tg_xz_yzzzzzz_0, tg_xz_zzzzzzz_0, \
                                         tg_y_xxxxxx_1, tg_y_xxxxxxx_0, tg_y_xxxxxxx_1, tg_y_xxxxxxy_0, tg_y_xxxxxxy_1, \
                                         tg_y_xxxxxxz_0, tg_y_xxxxxxz_1, tg_y_xxxxxy_1, tg_y_xxxxxyy_0, tg_y_xxxxxyy_1, \
                                         tg_y_xxxxxyz_0, tg_y_xxxxxyz_1, tg_y_xxxxxz_1, tg_y_xxxxxzz_0, tg_y_xxxxxzz_1, \
                                         tg_y_xxxxyy_1, tg_y_xxxxyyy_0, tg_y_xxxxyyy_1, tg_y_xxxxyyz_0, tg_y_xxxxyyz_1, \
                                         tg_y_xxxxyz_1, tg_y_xxxxyzz_0, tg_y_xxxxyzz_1, tg_y_xxxxzz_1, tg_y_xxxxzzz_0, \
                                         tg_y_xxxxzzz_1, tg_y_xxxyyy_1, tg_y_xxxyyyy_0, tg_y_xxxyyyy_1, tg_y_xxxyyyz_0, \
                                         tg_y_xxxyyyz_1, tg_y_xxxyyz_1, tg_y_xxxyyzz_0, tg_y_xxxyyzz_1, tg_y_xxxyzz_1, \
                                         tg_y_xxxyzzz_0, tg_y_xxxyzzz_1, tg_y_xxxzzz_1, tg_y_xxxzzzz_0, tg_y_xxxzzzz_1, \
                                         tg_y_xxyyyy_1, tg_y_xxyyyyy_0, tg_y_xxyyyyy_1, tg_y_xxyyyyz_0, tg_y_xxyyyyz_1, \
                                         tg_y_xxyyyz_1, tg_y_xxyyyzz_0, tg_y_xxyyyzz_1, tg_y_xxyyzz_1, tg_y_xxyyzzz_0, \
                                         tg_y_xxyyzzz_1, tg_y_xxyzzz_1, tg_y_xxyzzzz_0, tg_y_xxyzzzz_1, tg_y_xxzzzz_1, \
                                         tg_y_xxzzzzz_0, tg_y_xxzzzzz_1, tg_y_xyyyyy_1, tg_y_xyyyyyy_0, tg_y_xyyyyyy_1, \
                                         tg_y_xyyyyyz_0, tg_y_xyyyyyz_1, tg_y_xyyyyz_1, tg_y_xyyyyzz_0, tg_y_xyyyyzz_1, \
                                         tg_y_xyyyzz_1, tg_y_xyyyzzz_0, tg_y_xyyyzzz_1, tg_y_xyyzzz_1, tg_y_xyyzzzz_0, \
                                         tg_y_xyyzzzz_1, tg_y_xyzzzz_1, tg_y_xyzzzzz_0, tg_y_xyzzzzz_1, tg_y_xzzzzz_1, \
                                         tg_y_xzzzzzz_0, tg_y_xzzzzzz_1, tg_y_yyyyyy_1, tg_y_yyyyyyy_0, tg_y_yyyyyyy_1, \
                                         tg_y_yyyyyyz_0, tg_y_yyyyyyz_1, tg_y_yyyyyz_1, tg_y_yyyyyzz_0, tg_y_yyyyyzz_1, \
                                         tg_y_yyyyzz_1, tg_y_yyyyzzz_0, tg_y_yyyyzzz_1, tg_y_yyyzzz_1, tg_y_yyyzzzz_0, \
                                         tg_y_yyyzzzz_1, tg_y_yyzzzz_1, tg_y_yyzzzzz_0, tg_y_yyzzzzz_1, tg_y_yzzzzz_1, \
                                         tg_y_yzzzzzz_0, tg_y_yzzzzzz_1, tg_y_zzzzzz_1, tg_y_zzzzzzz_0, tg_y_zzzzzzz_1, \
                                         tg_yy_xxxxxxx_0, tg_yy_xxxxxxy_0, tg_yy_xxxxxxz_0, tg_yy_xxxxxyy_0, tg_yy_xxxxxyz_0, \
                                         tg_yy_xxxxxzz_0, tg_yy_xxxxyyy_0, tg_yy_xxxxyyz_0, tg_yy_xxxxyzz_0, tg_yy_xxxxzzz_0, \
                                         tg_yy_xxxyyyy_0, tg_yy_xxxyyyz_0, tg_yy_xxxyyzz_0, tg_yy_xxxyzzz_0, tg_yy_xxxzzzz_0, \
                                         tg_yy_xxyyyyy_0, tg_yy_xxyyyyz_0, tg_yy_xxyyyzz_0, tg_yy_xxyyzzz_0, tg_yy_xxyzzzz_0, \
                                         tg_yy_xxzzzzz_0, tg_yy_xyyyyyy_0, tg_yy_xyyyyyz_0, tg_yy_xyyyyzz_0, tg_yy_xyyyzzz_0, \
                                         tg_yy_xyyzzzz_0, tg_yy_xyzzzzz_0, tg_yy_xzzzzzz_0, tg_yy_yyyyyyy_0, tg_yy_yyyyyyz_0, \
                                         tg_yy_yyyyyzz_0, tg_yy_yyyyzzz_0, tg_yy_yyyzzzz_0, tg_yy_yyzzzzz_0, tg_yy_yzzzzzz_0, \
                                         tg_yy_zzzzzzz_0, tg_z_xxxxxx_1, tg_z_xxxxxxx_0, tg_z_xxxxxxx_1, tg_z_xxxxxxy_0, \
                                         tg_z_xxxxxxy_1, tg_z_xxxxxxz_0, tg_z_xxxxxxz_1, tg_z_xxxxxy_1, tg_z_xxxxxyy_0, \
                                         tg_z_xxxxxyy_1, tg_z_xxxxxyz_0, tg_z_xxxxxyz_1, tg_z_xxxxxz_1, tg_z_xxxxxzz_0, \
                                         tg_z_xxxxxzz_1, tg_z_xxxxyy_1, tg_z_xxxxyyy_0, tg_z_xxxxyyy_1, tg_z_xxxxyyz_0, \
                                         tg_z_xxxxyyz_1, tg_z_xxxxyz_1, tg_z_xxxxyzz_0, tg_z_xxxxyzz_1, tg_z_xxxxzz_1, \
                                         tg_z_xxxxzzz_0, tg_z_xxxxzzz_1, tg_z_xxxyyy_1, tg_z_xxxyyyy_0, tg_z_xxxyyyy_1, \
                                         tg_z_xxxyyyz_0, tg_z_xxxyyyz_1, tg_z_xxxyyz_1, tg_z_xxxyyzz_0, tg_z_xxxyyzz_1, \
                                         tg_z_xxxyzz_1, tg_z_xxxyzzz_0, tg_z_xxxyzzz_1, tg_z_xxxzzz_1, tg_z_xxxzzzz_0, \
                                         tg_z_xxxzzzz_1, tg_z_xxyyyy_1, tg_z_xxyyyyy_0, tg_z_xxyyyyy_1, tg_z_xxyyyyz_0, \
                                         tg_z_xxyyyyz_1, tg_z_xxyyyz_1, tg_z_xxyyyzz_0, tg_z_xxyyyzz_1, tg_z_xxyyzz_1, \
                                         tg_z_xxyyzzz_0, tg_z_xxyyzzz_1, tg_z_xxyzzz_1, tg_z_xxyzzzz_0, tg_z_xxyzzzz_1, \
                                         tg_z_xxzzzz_1, tg_z_xxzzzzz_0, tg_z_xxzzzzz_1, tg_z_xyyyyy_1, tg_z_xyyyyyy_0, \
                                         tg_z_xyyyyyy_1, tg_z_xyyyyyz_0, tg_z_xyyyyyz_1, tg_z_xyyyyz_1, tg_z_xyyyyzz_0, \
                                         tg_z_xyyyyzz_1, tg_z_xyyyzz_1, tg_z_xyyyzzz_0, tg_z_xyyyzzz_1, tg_z_xyyzzz_1, \
                                         tg_z_xyyzzzz_0, tg_z_xyyzzzz_1, tg_z_xyzzzz_1, tg_z_xyzzzzz_0, tg_z_xyzzzzz_1, \
                                         tg_z_xzzzzz_1, tg_z_xzzzzzz_0, tg_z_xzzzzzz_1, tg_z_yyyyyy_1, tg_z_yyyyyyy_0, \
                                         tg_z_yyyyyyy_1, tg_z_yyyyyyz_0, tg_z_yyyyyyz_1, tg_z_yyyyyz_1, tg_z_yyyyyzz_0, \
                                         tg_z_yyyyyzz_1, tg_z_yyyyzz_1, tg_z_yyyyzzz_0, tg_z_yyyyzzz_1, tg_z_yyyzzz_1, \
                                         tg_z_yyyzzzz_0, tg_z_yyyzzzz_1, tg_z_yyzzzz_1, tg_z_yyzzzzz_0, tg_z_yyzzzzz_1, \
                                         tg_z_yzzzzz_1, tg_z_yzzzzzz_0, tg_z_yzzzzzz_1, tg_z_zzzzzz_1, tg_z_zzzzzzz_0, \
                                         tg_z_zzzzzzz_1, wp_x, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xz_xxxxxxx_0[j] = pb_x * tg_z_xxxxxxx_0[j] + fr * tg_z_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_z_xxxxxx_1[j];

                    tg_xz_xxxxxxy_0[j] = pb_x * tg_z_xxxxxxy_0[j] + fr * tg_z_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_z_xxxxxy_1[j];

                    tg_xz_xxxxxxz_0[j] = pb_x * tg_z_xxxxxxz_0[j] + fr * tg_z_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_z_xxxxxz_1[j];

                    tg_xz_xxxxxyy_0[j] = pb_x * tg_z_xxxxxyy_0[j] + fr * tg_z_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_z_xxxxyy_1[j];

                    tg_xz_xxxxxyz_0[j] = pb_x * tg_z_xxxxxyz_0[j] + fr * tg_z_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxyz_1[j];

                    tg_xz_xxxxxzz_0[j] = pb_x * tg_z_xxxxxzz_0[j] + fr * tg_z_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxzz_1[j];

                    tg_xz_xxxxyyy_0[j] = pb_x * tg_z_xxxxyyy_0[j] + fr * tg_z_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyy_1[j];

                    tg_xz_xxxxyyz_0[j] = pb_x * tg_z_xxxxyyz_0[j] + fr * tg_z_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyz_1[j];

                    tg_xz_xxxxyzz_0[j] = pb_x * tg_z_xxxxyzz_0[j] + fr * tg_z_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyzz_1[j];

                    tg_xz_xxxxzzz_0[j] = pb_x * tg_z_xxxxzzz_0[j] + fr * tg_z_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxzzz_1[j];

                    tg_xz_xxxyyyy_0[j] = pb_x * tg_z_xxxyyyy_0[j] + fr * tg_z_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxyyyy_1[j];

                    tg_xz_xxxyyyz_0[j] = pb_x * tg_z_xxxyyyz_0[j] + fr * tg_z_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyyz_1[j];

                    tg_xz_xxxyyzz_0[j] = pb_x * tg_z_xxxyyzz_0[j] + fr * tg_z_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyzz_1[j];

                    tg_xz_xxxyzzz_0[j] = pb_x * tg_z_xxxyzzz_0[j] + fr * tg_z_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyzzz_1[j];

                    tg_xz_xxxzzzz_0[j] = pb_x * tg_z_xxxzzzz_0[j] + fr * tg_z_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxzzzz_1[j];

                    tg_xz_xxyyyyy_0[j] = pb_x * tg_z_xxyyyyy_0[j] + fr * tg_z_xxyyyyy_1[j] + fl1_fxn * tg_z_xyyyyy_1[j];

                    tg_xz_xxyyyyz_0[j] = pb_x * tg_z_xxyyyyz_0[j] + fr * tg_z_xxyyyyz_1[j] + fl1_fxn * tg_z_xyyyyz_1[j];

                    tg_xz_xxyyyzz_0[j] = pb_x * tg_z_xxyyyzz_0[j] + fr * tg_z_xxyyyzz_1[j] + fl1_fxn * tg_z_xyyyzz_1[j];

                    tg_xz_xxyyzzz_0[j] = pb_x * tg_z_xxyyzzz_0[j] + fr * tg_z_xxyyzzz_1[j] + fl1_fxn * tg_z_xyyzzz_1[j];

                    tg_xz_xxyzzzz_0[j] = pb_x * tg_z_xxyzzzz_0[j] + fr * tg_z_xxyzzzz_1[j] + fl1_fxn * tg_z_xyzzzz_1[j];

                    tg_xz_xxzzzzz_0[j] = pb_x * tg_z_xxzzzzz_0[j] + fr * tg_z_xxzzzzz_1[j] + fl1_fxn * tg_z_xzzzzz_1[j];

                    tg_xz_xyyyyyy_0[j] = pb_x * tg_z_xyyyyyy_0[j] + fr * tg_z_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_z_yyyyyy_1[j];

                    tg_xz_xyyyyyz_0[j] = pb_x * tg_z_xyyyyyz_0[j] + fr * tg_z_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyyz_1[j];

                    tg_xz_xyyyyzz_0[j] = pb_x * tg_z_xyyyyzz_0[j] + fr * tg_z_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyzz_1[j];

                    tg_xz_xyyyzzz_0[j] = pb_x * tg_z_xyyyzzz_0[j] + fr * tg_z_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyzzz_1[j];

                    tg_xz_xyyzzzz_0[j] = pb_x * tg_z_xyyzzzz_0[j] + fr * tg_z_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyzzzz_1[j];

                    tg_xz_xyzzzzz_0[j] = pb_x * tg_z_xyzzzzz_0[j] + fr * tg_z_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yzzzzz_1[j];

                    tg_xz_xzzzzzz_0[j] = pb_x * tg_z_xzzzzzz_0[j] + fr * tg_z_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzzz_1[j];

                    tg_xz_yyyyyyy_0[j] = pb_x * tg_z_yyyyyyy_0[j] + fr * tg_z_yyyyyyy_1[j];

                    tg_xz_yyyyyyz_0[j] = pb_x * tg_z_yyyyyyz_0[j] + fr * tg_z_yyyyyyz_1[j];

                    tg_xz_yyyyyzz_0[j] = pb_x * tg_z_yyyyyzz_0[j] + fr * tg_z_yyyyyzz_1[j];

                    tg_xz_yyyyzzz_0[j] = pb_x * tg_z_yyyyzzz_0[j] + fr * tg_z_yyyyzzz_1[j];

                    tg_xz_yyyzzzz_0[j] = pb_x * tg_z_yyyzzzz_0[j] + fr * tg_z_yyyzzzz_1[j];

                    tg_xz_yyzzzzz_0[j] = pb_x * tg_z_yyzzzzz_0[j] + fr * tg_z_yyzzzzz_1[j];

                    tg_xz_yzzzzzz_0[j] = pb_x * tg_z_yzzzzzz_0[j] + fr * tg_z_yzzzzzz_1[j];

                    tg_xz_zzzzzzz_0[j] = pb_x * tg_z_zzzzzzz_0[j] + fr * tg_z_zzzzzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yy_xxxxxxx_0[j] = pb_y * tg_y_xxxxxxx_0[j] + fr * tg_y_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxx_0[j] - tg_0_xxxxxxx_1[j] * fl1_fza);

                    tg_yy_xxxxxxy_0[j] = pb_y * tg_y_xxxxxxy_0[j] + fr * tg_y_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxy_0[j] - tg_0_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxxx_1[j];

                    tg_yy_xxxxxxz_0[j] = pb_y * tg_y_xxxxxxz_0[j] + fr * tg_y_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxz_0[j] - tg_0_xxxxxxz_1[j] * fl1_fza);

                    tg_yy_xxxxxyy_0[j] = pb_y * tg_y_xxxxxyy_0[j] + fr * tg_y_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyy_0[j] - tg_0_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxxy_1[j];

                    tg_yy_xxxxxyz_0[j] = pb_y * tg_y_xxxxxyz_0[j] + fr * tg_y_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyz_0[j] - tg_0_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxxz_1[j];

                    tg_yy_xxxxxzz_0[j] = pb_y * tg_y_xxxxxzz_0[j] + fr * tg_y_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzz_0[j] - tg_0_xxxxxzz_1[j] * fl1_fza);

                    tg_yy_xxxxyyy_0[j] = pb_y * tg_y_xxxxyyy_0[j] + fr * tg_y_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyy_0[j] - tg_0_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxxyy_1[j];

                    tg_yy_xxxxyyz_0[j] = pb_y * tg_y_xxxxyyz_0[j] + fr * tg_y_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyz_0[j] - tg_0_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxyz_1[j];

                    tg_yy_xxxxyzz_0[j] = pb_y * tg_y_xxxxyzz_0[j] + fr * tg_y_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzz_0[j] - tg_0_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxzz_1[j];

                    tg_yy_xxxxzzz_0[j] = pb_y * tg_y_xxxxzzz_0[j] + fr * tg_y_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzz_0[j] - tg_0_xxxxzzz_1[j] * fl1_fza);

                    tg_yy_xxxyyyy_0[j] = pb_y * tg_y_xxxyyyy_0[j] + fr * tg_y_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyy_0[j] - tg_0_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxxyyy_1[j];

                    tg_yy_xxxyyyz_0[j] = pb_y * tg_y_xxxyyyz_0[j] + fr * tg_y_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyz_0[j] - tg_0_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxyyz_1[j];

                    tg_yy_xxxyyzz_0[j] = pb_y * tg_y_xxxyyzz_0[j] + fr * tg_y_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzz_0[j] - tg_0_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxyzz_1[j];

                    tg_yy_xxxyzzz_0[j] = pb_y * tg_y_xxxyzzz_0[j] + fr * tg_y_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzz_0[j] - tg_0_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxzzz_1[j];

                    tg_yy_xxxzzzz_0[j] = pb_y * tg_y_xxxzzzz_0[j] + fr * tg_y_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzz_0[j] - tg_0_xxxzzzz_1[j] * fl1_fza);

                    tg_yy_xxyyyyy_0[j] = pb_y * tg_y_xxyyyyy_0[j] + fr * tg_y_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyy_0[j] - tg_0_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xxyyyy_1[j];

                    tg_yy_xxyyyyz_0[j] = pb_y * tg_y_xxyyyyz_0[j] + fr * tg_y_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyz_0[j] - tg_0_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxyyyz_1[j];

                    tg_yy_xxyyyzz_0[j] = pb_y * tg_y_xxyyyzz_0[j] + fr * tg_y_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzz_0[j] - tg_0_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxyyzz_1[j];

                    tg_yy_xxyyzzz_0[j] = pb_y * tg_y_xxyyzzz_0[j] + fr * tg_y_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzz_0[j] - tg_0_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxyzzz_1[j];

                    tg_yy_xxyzzzz_0[j] = pb_y * tg_y_xxyzzzz_0[j] + fr * tg_y_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzz_0[j] - tg_0_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxzzzz_1[j];

                    tg_yy_xxzzzzz_0[j] = pb_y * tg_y_xxzzzzz_0[j] + fr * tg_y_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzz_0[j] - tg_0_xxzzzzz_1[j] * fl1_fza);

                    tg_yy_xyyyyyy_0[j] = pb_y * tg_y_xyyyyyy_0[j] + fr * tg_y_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyy_0[j] - tg_0_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_xyyyyy_1[j];

                    tg_yy_xyyyyyz_0[j] = pb_y * tg_y_xyyyyyz_0[j] + fr * tg_y_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyz_0[j] - tg_0_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xyyyyz_1[j];

                    tg_yy_xyyyyzz_0[j] = pb_y * tg_y_xyyyyzz_0[j] + fr * tg_y_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzz_0[j] - tg_0_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xyyyzz_1[j];

                    tg_yy_xyyyzzz_0[j] = pb_y * tg_y_xyyyzzz_0[j] + fr * tg_y_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzz_0[j] - tg_0_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xyyzzz_1[j];

                    tg_yy_xyyzzzz_0[j] = pb_y * tg_y_xyyzzzz_0[j] + fr * tg_y_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzz_0[j] - tg_0_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xyzzzz_1[j];

                    tg_yy_xyzzzzz_0[j] = pb_y * tg_y_xyzzzzz_0[j] + fr * tg_y_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzz_0[j] - tg_0_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xzzzzz_1[j];

                    tg_yy_xzzzzzz_0[j] = pb_y * tg_y_xzzzzzz_0[j] + fr * tg_y_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzz_0[j] - tg_0_xzzzzzz_1[j] * fl1_fza);

                    tg_yy_yyyyyyy_0[j] = pb_y * tg_y_yyyyyyy_0[j] + fr * tg_y_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyy_0[j] - tg_0_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_y_yyyyyy_1[j];

                    tg_yy_yyyyyyz_0[j] = pb_y * tg_y_yyyyyyz_0[j] + fr * tg_y_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyz_0[j] - tg_0_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_yyyyyz_1[j];

                    tg_yy_yyyyyzz_0[j] = pb_y * tg_y_yyyyyzz_0[j] + fr * tg_y_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzz_0[j] - tg_0_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_yyyyzz_1[j];

                    tg_yy_yyyyzzz_0[j] = pb_y * tg_y_yyyyzzz_0[j] + fr * tg_y_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzz_0[j] - tg_0_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_yyyzzz_1[j];

                    tg_yy_yyyzzzz_0[j] = pb_y * tg_y_yyyzzzz_0[j] + fr * tg_y_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzz_0[j] - tg_0_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yyzzzz_1[j];

                    tg_yy_yyzzzzz_0[j] = pb_y * tg_y_yyzzzzz_0[j] + fr * tg_y_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzz_0[j] - tg_0_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_yzzzzz_1[j];

                    tg_yy_yzzzzzz_0[j] = pb_y * tg_y_yzzzzzz_0[j] + fr * tg_y_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzz_0[j] - tg_0_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zzzzzz_1[j];

                    tg_yy_zzzzzzz_0[j] = pb_y * tg_y_zzzzzzz_0[j] + fr * tg_y_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzz_0[j] - tg_0_zzzzzzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSK_144_216(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (144,216)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_z_xxxxxxx_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_0 = primBuffer[pidx_g_1_7_m0].data(108 * idx + 107); 

                auto tg_z_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 107); 

                auto tg_0_xxxxxxx_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx); 

                auto tg_0_xxxxxxy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_0 = primBuffer[pidx_g_0_7_m0].data(36 * idx + 35); 

                auto tg_0_xxxxxxx_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx); 

                auto tg_0_xxxxxxy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 1); 

                auto tg_0_xxxxxxz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 2); 

                auto tg_0_xxxxxyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 3); 

                auto tg_0_xxxxxyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 4); 

                auto tg_0_xxxxxzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 5); 

                auto tg_0_xxxxyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 6); 

                auto tg_0_xxxxyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 7); 

                auto tg_0_xxxxyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 8); 

                auto tg_0_xxxxzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 9); 

                auto tg_0_xxxyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 10); 

                auto tg_0_xxxyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 11); 

                auto tg_0_xxxyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 12); 

                auto tg_0_xxxyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 13); 

                auto tg_0_xxxzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 14); 

                auto tg_0_xxyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 15); 

                auto tg_0_xxyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 16); 

                auto tg_0_xxyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 17); 

                auto tg_0_xxyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 18); 

                auto tg_0_xxyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 19); 

                auto tg_0_xxzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 20); 

                auto tg_0_xyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 21); 

                auto tg_0_xyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 22); 

                auto tg_0_xyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 23); 

                auto tg_0_xyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 24); 

                auto tg_0_xyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 25); 

                auto tg_0_xyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 26); 

                auto tg_0_xzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 27); 

                auto tg_0_yyyyyyy_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 28); 

                auto tg_0_yyyyyyz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 29); 

                auto tg_0_yyyyyzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 30); 

                auto tg_0_yyyyzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 31); 

                auto tg_0_yyyzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 32); 

                auto tg_0_yyzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 33); 

                auto tg_0_yzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 34); 

                auto tg_0_zzzzzzz_1 = primBuffer[pidx_g_0_7_m1].data(36 * idx + 35); 

                auto tg_z_xxxxxx_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 56); 

                auto tg_z_xxxxxy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 57); 

                auto tg_z_xxxxxz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 58); 

                auto tg_z_xxxxyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 59); 

                auto tg_z_xxxxyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 60); 

                auto tg_z_xxxxzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 61); 

                auto tg_z_xxxyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 62); 

                auto tg_z_xxxyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 63); 

                auto tg_z_xxxyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 64); 

                auto tg_z_xxxzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 65); 

                auto tg_z_xxyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 66); 

                auto tg_z_xxyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 67); 

                auto tg_z_xxyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 68); 

                auto tg_z_xxyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 69); 

                auto tg_z_xxzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 70); 

                auto tg_z_xyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 71); 

                auto tg_z_xyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 72); 

                auto tg_z_xyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 73); 

                auto tg_z_xyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 74); 

                auto tg_z_xyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 75); 

                auto tg_z_xzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 76); 

                auto tg_z_yyyyyy_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 77); 

                auto tg_z_yyyyyz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 78); 

                auto tg_z_yyyyzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 79); 

                auto tg_z_yyyzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 80); 

                auto tg_z_yyzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 81); 

                auto tg_z_yzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 82); 

                auto tg_z_zzzzzz_1 = primBuffer[pidx_g_1_6_m1].data(84 * idx + 83); 

                // set up pointers to integrals

                auto tg_yz_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 144); 

                auto tg_yz_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 145); 

                auto tg_yz_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 146); 

                auto tg_yz_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 147); 

                auto tg_yz_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 148); 

                auto tg_yz_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 149); 

                auto tg_yz_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 150); 

                auto tg_yz_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 151); 

                auto tg_yz_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 152); 

                auto tg_yz_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 153); 

                auto tg_yz_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 154); 

                auto tg_yz_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 155); 

                auto tg_yz_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 156); 

                auto tg_yz_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 157); 

                auto tg_yz_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 158); 

                auto tg_yz_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 159); 

                auto tg_yz_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 160); 

                auto tg_yz_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 161); 

                auto tg_yz_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 162); 

                auto tg_yz_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 163); 

                auto tg_yz_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 164); 

                auto tg_yz_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 165); 

                auto tg_yz_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 166); 

                auto tg_yz_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 167); 

                auto tg_yz_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 168); 

                auto tg_yz_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 169); 

                auto tg_yz_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 170); 

                auto tg_yz_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 171); 

                auto tg_yz_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 172); 

                auto tg_yz_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 173); 

                auto tg_yz_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 174); 

                auto tg_yz_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 175); 

                auto tg_yz_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 176); 

                auto tg_yz_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 177); 

                auto tg_yz_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 178); 

                auto tg_yz_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 179); 

                auto tg_zz_xxxxxxx_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 180); 

                auto tg_zz_xxxxxxy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 181); 

                auto tg_zz_xxxxxxz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 182); 

                auto tg_zz_xxxxxyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 183); 

                auto tg_zz_xxxxxyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 184); 

                auto tg_zz_xxxxxzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 185); 

                auto tg_zz_xxxxyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 186); 

                auto tg_zz_xxxxyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 187); 

                auto tg_zz_xxxxyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 188); 

                auto tg_zz_xxxxzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 189); 

                auto tg_zz_xxxyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 190); 

                auto tg_zz_xxxyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 191); 

                auto tg_zz_xxxyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 192); 

                auto tg_zz_xxxyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 193); 

                auto tg_zz_xxxzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 194); 

                auto tg_zz_xxyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 195); 

                auto tg_zz_xxyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 196); 

                auto tg_zz_xxyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 197); 

                auto tg_zz_xxyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 198); 

                auto tg_zz_xxyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 199); 

                auto tg_zz_xxzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 200); 

                auto tg_zz_xyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 201); 

                auto tg_zz_xyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 202); 

                auto tg_zz_xyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 203); 

                auto tg_zz_xyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 204); 

                auto tg_zz_xyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 205); 

                auto tg_zz_xyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 206); 

                auto tg_zz_xzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 207); 

                auto tg_zz_yyyyyyy_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 208); 

                auto tg_zz_yyyyyyz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 209); 

                auto tg_zz_yyyyyzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 210); 

                auto tg_zz_yyyyzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 211); 

                auto tg_zz_yyyzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 212); 

                auto tg_zz_yyzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 213); 

                auto tg_zz_yzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 214); 

                auto tg_zz_zzzzzzz_0 = primBuffer[pidx_g_2_7_m0].data(216 * idx + 215); 

                // Batch of Integrals (144,216)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxx_0, tg_0_xxxxxxx_1, tg_0_xxxxxxy_0, \
                                         tg_0_xxxxxxy_1, tg_0_xxxxxxz_0, tg_0_xxxxxxz_1, tg_0_xxxxxyy_0, tg_0_xxxxxyy_1, \
                                         tg_0_xxxxxyz_0, tg_0_xxxxxyz_1, tg_0_xxxxxzz_0, tg_0_xxxxxzz_1, tg_0_xxxxyyy_0, \
                                         tg_0_xxxxyyy_1, tg_0_xxxxyyz_0, tg_0_xxxxyyz_1, tg_0_xxxxyzz_0, tg_0_xxxxyzz_1, \
                                         tg_0_xxxxzzz_0, tg_0_xxxxzzz_1, tg_0_xxxyyyy_0, tg_0_xxxyyyy_1, tg_0_xxxyyyz_0, \
                                         tg_0_xxxyyyz_1, tg_0_xxxyyzz_0, tg_0_xxxyyzz_1, tg_0_xxxyzzz_0, tg_0_xxxyzzz_1, \
                                         tg_0_xxxzzzz_0, tg_0_xxxzzzz_1, tg_0_xxyyyyy_0, tg_0_xxyyyyy_1, tg_0_xxyyyyz_0, \
                                         tg_0_xxyyyyz_1, tg_0_xxyyyzz_0, tg_0_xxyyyzz_1, tg_0_xxyyzzz_0, tg_0_xxyyzzz_1, \
                                         tg_0_xxyzzzz_0, tg_0_xxyzzzz_1, tg_0_xxzzzzz_0, tg_0_xxzzzzz_1, tg_0_xyyyyyy_0, \
                                         tg_0_xyyyyyy_1, tg_0_xyyyyyz_0, tg_0_xyyyyyz_1, tg_0_xyyyyzz_0, tg_0_xyyyyzz_1, \
                                         tg_0_xyyyzzz_0, tg_0_xyyyzzz_1, tg_0_xyyzzzz_0, tg_0_xyyzzzz_1, tg_0_xyzzzzz_0, \
                                         tg_0_xyzzzzz_1, tg_0_xzzzzzz_0, tg_0_xzzzzzz_1, tg_0_yyyyyyy_0, tg_0_yyyyyyy_1, \
                                         tg_0_yyyyyyz_0, tg_0_yyyyyyz_1, tg_0_yyyyyzz_0, tg_0_yyyyyzz_1, tg_0_yyyyzzz_0, \
                                         tg_0_yyyyzzz_1, tg_0_yyyzzzz_0, tg_0_yyyzzzz_1, tg_0_yyzzzzz_0, tg_0_yyzzzzz_1, \
                                         tg_0_yzzzzzz_0, tg_0_yzzzzzz_1, tg_0_zzzzzzz_0, tg_0_zzzzzzz_1, tg_yz_xxxxxxx_0, \
                                         tg_yz_xxxxxxy_0, tg_yz_xxxxxxz_0, tg_yz_xxxxxyy_0, tg_yz_xxxxxyz_0, tg_yz_xxxxxzz_0, \
                                         tg_yz_xxxxyyy_0, tg_yz_xxxxyyz_0, tg_yz_xxxxyzz_0, tg_yz_xxxxzzz_0, tg_yz_xxxyyyy_0, \
                                         tg_yz_xxxyyyz_0, tg_yz_xxxyyzz_0, tg_yz_xxxyzzz_0, tg_yz_xxxzzzz_0, tg_yz_xxyyyyy_0, \
                                         tg_yz_xxyyyyz_0, tg_yz_xxyyyzz_0, tg_yz_xxyyzzz_0, tg_yz_xxyzzzz_0, tg_yz_xxzzzzz_0, \
                                         tg_yz_xyyyyyy_0, tg_yz_xyyyyyz_0, tg_yz_xyyyyzz_0, tg_yz_xyyyzzz_0, tg_yz_xyyzzzz_0, \
                                         tg_yz_xyzzzzz_0, tg_yz_xzzzzzz_0, tg_yz_yyyyyyy_0, tg_yz_yyyyyyz_0, tg_yz_yyyyyzz_0, \
                                         tg_yz_yyyyzzz_0, tg_yz_yyyzzzz_0, tg_yz_yyzzzzz_0, tg_yz_yzzzzzz_0, tg_yz_zzzzzzz_0, \
                                         tg_z_xxxxxx_1, tg_z_xxxxxxx_0, tg_z_xxxxxxx_1, tg_z_xxxxxxy_0, tg_z_xxxxxxy_1, \
                                         tg_z_xxxxxxz_0, tg_z_xxxxxxz_1, tg_z_xxxxxy_1, tg_z_xxxxxyy_0, tg_z_xxxxxyy_1, \
                                         tg_z_xxxxxyz_0, tg_z_xxxxxyz_1, tg_z_xxxxxz_1, tg_z_xxxxxzz_0, tg_z_xxxxxzz_1, \
                                         tg_z_xxxxyy_1, tg_z_xxxxyyy_0, tg_z_xxxxyyy_1, tg_z_xxxxyyz_0, tg_z_xxxxyyz_1, \
                                         tg_z_xxxxyz_1, tg_z_xxxxyzz_0, tg_z_xxxxyzz_1, tg_z_xxxxzz_1, tg_z_xxxxzzz_0, \
                                         tg_z_xxxxzzz_1, tg_z_xxxyyy_1, tg_z_xxxyyyy_0, tg_z_xxxyyyy_1, tg_z_xxxyyyz_0, \
                                         tg_z_xxxyyyz_1, tg_z_xxxyyz_1, tg_z_xxxyyzz_0, tg_z_xxxyyzz_1, tg_z_xxxyzz_1, \
                                         tg_z_xxxyzzz_0, tg_z_xxxyzzz_1, tg_z_xxxzzz_1, tg_z_xxxzzzz_0, tg_z_xxxzzzz_1, \
                                         tg_z_xxyyyy_1, tg_z_xxyyyyy_0, tg_z_xxyyyyy_1, tg_z_xxyyyyz_0, tg_z_xxyyyyz_1, \
                                         tg_z_xxyyyz_1, tg_z_xxyyyzz_0, tg_z_xxyyyzz_1, tg_z_xxyyzz_1, tg_z_xxyyzzz_0, \
                                         tg_z_xxyyzzz_1, tg_z_xxyzzz_1, tg_z_xxyzzzz_0, tg_z_xxyzzzz_1, tg_z_xxzzzz_1, \
                                         tg_z_xxzzzzz_0, tg_z_xxzzzzz_1, tg_z_xyyyyy_1, tg_z_xyyyyyy_0, tg_z_xyyyyyy_1, \
                                         tg_z_xyyyyyz_0, tg_z_xyyyyyz_1, tg_z_xyyyyz_1, tg_z_xyyyyzz_0, tg_z_xyyyyzz_1, \
                                         tg_z_xyyyzz_1, tg_z_xyyyzzz_0, tg_z_xyyyzzz_1, tg_z_xyyzzz_1, tg_z_xyyzzzz_0, \
                                         tg_z_xyyzzzz_1, tg_z_xyzzzz_1, tg_z_xyzzzzz_0, tg_z_xyzzzzz_1, tg_z_xzzzzz_1, \
                                         tg_z_xzzzzzz_0, tg_z_xzzzzzz_1, tg_z_yyyyyy_1, tg_z_yyyyyyy_0, tg_z_yyyyyyy_1, \
                                         tg_z_yyyyyyz_0, tg_z_yyyyyyz_1, tg_z_yyyyyz_1, tg_z_yyyyyzz_0, tg_z_yyyyyzz_1, \
                                         tg_z_yyyyzz_1, tg_z_yyyyzzz_0, tg_z_yyyyzzz_1, tg_z_yyyzzz_1, tg_z_yyyzzzz_0, \
                                         tg_z_yyyzzzz_1, tg_z_yyzzzz_1, tg_z_yyzzzzz_0, tg_z_yyzzzzz_1, tg_z_yzzzzz_1, \
                                         tg_z_yzzzzzz_0, tg_z_yzzzzzz_1, tg_z_zzzzzz_1, tg_z_zzzzzzz_0, tg_z_zzzzzzz_1, \
                                         tg_zz_xxxxxxx_0, tg_zz_xxxxxxy_0, tg_zz_xxxxxxz_0, tg_zz_xxxxxyy_0, tg_zz_xxxxxyz_0, \
                                         tg_zz_xxxxxzz_0, tg_zz_xxxxyyy_0, tg_zz_xxxxyyz_0, tg_zz_xxxxyzz_0, tg_zz_xxxxzzz_0, \
                                         tg_zz_xxxyyyy_0, tg_zz_xxxyyyz_0, tg_zz_xxxyyzz_0, tg_zz_xxxyzzz_0, tg_zz_xxxzzzz_0, \
                                         tg_zz_xxyyyyy_0, tg_zz_xxyyyyz_0, tg_zz_xxyyyzz_0, tg_zz_xxyyzzz_0, tg_zz_xxyzzzz_0, \
                                         tg_zz_xxzzzzz_0, tg_zz_xyyyyyy_0, tg_zz_xyyyyyz_0, tg_zz_xyyyyzz_0, tg_zz_xyyyzzz_0, \
                                         tg_zz_xyyzzzz_0, tg_zz_xyzzzzz_0, tg_zz_xzzzzzz_0, tg_zz_yyyyyyy_0, tg_zz_yyyyyyz_0, \
                                         tg_zz_yyyyyzz_0, tg_zz_yyyyzzz_0, tg_zz_yyyzzzz_0, tg_zz_yyzzzzz_0, tg_zz_yzzzzzz_0, \
                                         tg_zz_zzzzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yz_xxxxxxx_0[j] = pb_y * tg_z_xxxxxxx_0[j] + fr * tg_z_xxxxxxx_1[j];

                    tg_yz_xxxxxxy_0[j] = pb_y * tg_z_xxxxxxy_0[j] + fr * tg_z_xxxxxxy_1[j] + 0.5 * fl1_fxn * tg_z_xxxxxx_1[j];

                    tg_yz_xxxxxxz_0[j] = pb_y * tg_z_xxxxxxz_0[j] + fr * tg_z_xxxxxxz_1[j];

                    tg_yz_xxxxxyy_0[j] = pb_y * tg_z_xxxxxyy_0[j] + fr * tg_z_xxxxxyy_1[j] + fl1_fxn * tg_z_xxxxxy_1[j];

                    tg_yz_xxxxxyz_0[j] = pb_y * tg_z_xxxxxyz_0[j] + fr * tg_z_xxxxxyz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxxz_1[j];

                    tg_yz_xxxxxzz_0[j] = pb_y * tg_z_xxxxxzz_0[j] + fr * tg_z_xxxxxzz_1[j];

                    tg_yz_xxxxyyy_0[j] = pb_y * tg_z_xxxxyyy_0[j] + fr * tg_z_xxxxyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxxxyy_1[j];

                    tg_yz_xxxxyyz_0[j] = pb_y * tg_z_xxxxyyz_0[j] + fr * tg_z_xxxxyyz_1[j] + fl1_fxn * tg_z_xxxxyz_1[j];

                    tg_yz_xxxxyzz_0[j] = pb_y * tg_z_xxxxyzz_0[j] + fr * tg_z_xxxxyzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxzz_1[j];

                    tg_yz_xxxxzzz_0[j] = pb_y * tg_z_xxxxzzz_0[j] + fr * tg_z_xxxxzzz_1[j];

                    tg_yz_xxxyyyy_0[j] = pb_y * tg_z_xxxyyyy_0[j] + fr * tg_z_xxxyyyy_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyy_1[j];

                    tg_yz_xxxyyyz_0[j] = pb_y * tg_z_xxxyyyz_0[j] + fr * tg_z_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxxyyz_1[j];

                    tg_yz_xxxyyzz_0[j] = pb_y * tg_z_xxxyyzz_0[j] + fr * tg_z_xxxyyzz_1[j] + fl1_fxn * tg_z_xxxyzz_1[j];

                    tg_yz_xxxyzzz_0[j] = pb_y * tg_z_xxxyzzz_0[j] + fr * tg_z_xxxyzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxzzz_1[j];

                    tg_yz_xxxzzzz_0[j] = pb_y * tg_z_xxxzzzz_0[j] + fr * tg_z_xxxzzzz_1[j];

                    tg_yz_xxyyyyy_0[j] = pb_y * tg_z_xxyyyyy_0[j] + fr * tg_z_xxyyyyy_1[j] + 2.5 * fl1_fxn * tg_z_xxyyyy_1[j];

                    tg_yz_xxyyyyz_0[j] = pb_y * tg_z_xxyyyyz_0[j] + fr * tg_z_xxyyyyz_1[j] + 2.0 * fl1_fxn * tg_z_xxyyyz_1[j];

                    tg_yz_xxyyyzz_0[j] = pb_y * tg_z_xxyyyzz_0[j] + fr * tg_z_xxyyyzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyzz_1[j];

                    tg_yz_xxyyzzz_0[j] = pb_y * tg_z_xxyyzzz_0[j] + fr * tg_z_xxyyzzz_1[j] + fl1_fxn * tg_z_xxyzzz_1[j];

                    tg_yz_xxyzzzz_0[j] = pb_y * tg_z_xxyzzzz_0[j] + fr * tg_z_xxyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxzzzz_1[j];

                    tg_yz_xxzzzzz_0[j] = pb_y * tg_z_xxzzzzz_0[j] + fr * tg_z_xxzzzzz_1[j];

                    tg_yz_xyyyyyy_0[j] = pb_y * tg_z_xyyyyyy_0[j] + fr * tg_z_xyyyyyy_1[j] + 3.0 * fl1_fxn * tg_z_xyyyyy_1[j];

                    tg_yz_xyyyyyz_0[j] = pb_y * tg_z_xyyyyyz_0[j] + fr * tg_z_xyyyyyz_1[j] + 2.5 * fl1_fxn * tg_z_xyyyyz_1[j];

                    tg_yz_xyyyyzz_0[j] = pb_y * tg_z_xyyyyzz_0[j] + fr * tg_z_xyyyyzz_1[j] + 2.0 * fl1_fxn * tg_z_xyyyzz_1[j];

                    tg_yz_xyyyzzz_0[j] = pb_y * tg_z_xyyyzzz_0[j] + fr * tg_z_xyyyzzz_1[j] + 1.5 * fl1_fxn * tg_z_xyyzzz_1[j];

                    tg_yz_xyyzzzz_0[j] = pb_y * tg_z_xyyzzzz_0[j] + fr * tg_z_xyyzzzz_1[j] + fl1_fxn * tg_z_xyzzzz_1[j];

                    tg_yz_xyzzzzz_0[j] = pb_y * tg_z_xyzzzzz_0[j] + fr * tg_z_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xzzzzz_1[j];

                    tg_yz_xzzzzzz_0[j] = pb_y * tg_z_xzzzzzz_0[j] + fr * tg_z_xzzzzzz_1[j];

                    tg_yz_yyyyyyy_0[j] = pb_y * tg_z_yyyyyyy_0[j] + fr * tg_z_yyyyyyy_1[j] + 3.5 * fl1_fxn * tg_z_yyyyyy_1[j];

                    tg_yz_yyyyyyz_0[j] = pb_y * tg_z_yyyyyyz_0[j] + fr * tg_z_yyyyyyz_1[j] + 3.0 * fl1_fxn * tg_z_yyyyyz_1[j];

                    tg_yz_yyyyyzz_0[j] = pb_y * tg_z_yyyyyzz_0[j] + fr * tg_z_yyyyyzz_1[j] + 2.5 * fl1_fxn * tg_z_yyyyzz_1[j];

                    tg_yz_yyyyzzz_0[j] = pb_y * tg_z_yyyyzzz_0[j] + fr * tg_z_yyyyzzz_1[j] + 2.0 * fl1_fxn * tg_z_yyyzzz_1[j];

                    tg_yz_yyyzzzz_0[j] = pb_y * tg_z_yyyzzzz_0[j] + fr * tg_z_yyyzzzz_1[j] + 1.5 * fl1_fxn * tg_z_yyzzzz_1[j];

                    tg_yz_yyzzzzz_0[j] = pb_y * tg_z_yyzzzzz_0[j] + fr * tg_z_yyzzzzz_1[j] + fl1_fxn * tg_z_yzzzzz_1[j];

                    tg_yz_yzzzzzz_0[j] = pb_y * tg_z_yzzzzzz_0[j] + fr * tg_z_yzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzzz_1[j];

                    tg_yz_zzzzzzz_0[j] = pb_y * tg_z_zzzzzzz_0[j] + fr * tg_z_zzzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxxxxxx_0[j] = pb_z * tg_z_xxxxxxx_0[j] + fr * tg_z_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxx_0[j] - tg_0_xxxxxxx_1[j] * fl1_fza);

                    tg_zz_xxxxxxy_0[j] = pb_z * tg_z_xxxxxxy_0[j] + fr * tg_z_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxy_0[j] - tg_0_xxxxxxy_1[j] * fl1_fza);

                    tg_zz_xxxxxxz_0[j] = pb_z * tg_z_xxxxxxz_0[j] + fr * tg_z_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxz_0[j] - tg_0_xxxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxxx_1[j];

                    tg_zz_xxxxxyy_0[j] = pb_z * tg_z_xxxxxyy_0[j] + fr * tg_z_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyy_0[j] - tg_0_xxxxxyy_1[j] * fl1_fza);

                    tg_zz_xxxxxyz_0[j] = pb_z * tg_z_xxxxxyz_0[j] + fr * tg_z_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyz_0[j] - tg_0_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxxy_1[j];

                    tg_zz_xxxxxzz_0[j] = pb_z * tg_z_xxxxxzz_0[j] + fr * tg_z_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzz_0[j] - tg_0_xxxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxxz_1[j];

                    tg_zz_xxxxyyy_0[j] = pb_z * tg_z_xxxxyyy_0[j] + fr * tg_z_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyy_0[j] - tg_0_xxxxyyy_1[j] * fl1_fza);

                    tg_zz_xxxxyyz_0[j] = pb_z * tg_z_xxxxyyz_0[j] + fr * tg_z_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyz_0[j] - tg_0_xxxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxyy_1[j];

                    tg_zz_xxxxyzz_0[j] = pb_z * tg_z_xxxxyzz_0[j] + fr * tg_z_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzz_0[j] - tg_0_xxxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxyz_1[j];

                    tg_zz_xxxxzzz_0[j] = pb_z * tg_z_xxxxzzz_0[j] + fr * tg_z_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzz_0[j] - tg_0_xxxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxxzz_1[j];

                    tg_zz_xxxyyyy_0[j] = pb_z * tg_z_xxxyyyy_0[j] + fr * tg_z_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyy_0[j] - tg_0_xxxyyyy_1[j] * fl1_fza);

                    tg_zz_xxxyyyz_0[j] = pb_z * tg_z_xxxyyyz_0[j] + fr * tg_z_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyz_0[j] - tg_0_xxxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxyyy_1[j];

                    tg_zz_xxxyyzz_0[j] = pb_z * tg_z_xxxyyzz_0[j] + fr * tg_z_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzz_0[j] - tg_0_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxyyz_1[j];

                    tg_zz_xxxyzzz_0[j] = pb_z * tg_z_xxxyzzz_0[j] + fr * tg_z_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzz_0[j] - tg_0_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxyzz_1[j];

                    tg_zz_xxxzzzz_0[j] = pb_z * tg_z_xxxzzzz_0[j] + fr * tg_z_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzz_0[j] - tg_0_xxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxxzzz_1[j];

                    tg_zz_xxyyyyy_0[j] = pb_z * tg_z_xxyyyyy_0[j] + fr * tg_z_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyy_0[j] - tg_0_xxyyyyy_1[j] * fl1_fza);

                    tg_zz_xxyyyyz_0[j] = pb_z * tg_z_xxyyyyz_0[j] + fr * tg_z_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyz_0[j] - tg_0_xxyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxyyyy_1[j];

                    tg_zz_xxyyyzz_0[j] = pb_z * tg_z_xxyyyzz_0[j] + fr * tg_z_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzz_0[j] - tg_0_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxyyyz_1[j];

                    tg_zz_xxyyzzz_0[j] = pb_z * tg_z_xxyyzzz_0[j] + fr * tg_z_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzz_0[j] - tg_0_xxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxyyzz_1[j];

                    tg_zz_xxyzzzz_0[j] = pb_z * tg_z_xxyzzzz_0[j] + fr * tg_z_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzz_0[j] - tg_0_xxyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxyzzz_1[j];

                    tg_zz_xxzzzzz_0[j] = pb_z * tg_z_xxzzzzz_0[j] + fr * tg_z_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzz_0[j] - tg_0_xxzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xxzzzz_1[j];

                    tg_zz_xyyyyyy_0[j] = pb_z * tg_z_xyyyyyy_0[j] + fr * tg_z_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyy_0[j] - tg_0_xyyyyyy_1[j] * fl1_fza);

                    tg_zz_xyyyyyz_0[j] = pb_z * tg_z_xyyyyyz_0[j] + fr * tg_z_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyz_0[j] - tg_0_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xyyyyy_1[j];

                    tg_zz_xyyyyzz_0[j] = pb_z * tg_z_xyyyyzz_0[j] + fr * tg_z_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzz_0[j] - tg_0_xyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xyyyyz_1[j];

                    tg_zz_xyyyzzz_0[j] = pb_z * tg_z_xyyyzzz_0[j] + fr * tg_z_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzz_0[j] - tg_0_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xyyyzz_1[j];

                    tg_zz_xyyzzzz_0[j] = pb_z * tg_z_xyyzzzz_0[j] + fr * tg_z_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzz_0[j] - tg_0_xyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xyyzzz_1[j];

                    tg_zz_xyzzzzz_0[j] = pb_z * tg_z_xyzzzzz_0[j] + fr * tg_z_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzz_0[j] - tg_0_xyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xyzzzz_1[j];

                    tg_zz_xzzzzzz_0[j] = pb_z * tg_z_xzzzzzz_0[j] + fr * tg_z_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzz_0[j] - tg_0_xzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_xzzzzz_1[j];

                    tg_zz_yyyyyyy_0[j] = pb_z * tg_z_yyyyyyy_0[j] + fr * tg_z_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyy_0[j] - tg_0_yyyyyyy_1[j] * fl1_fza);

                    tg_zz_yyyyyyz_0[j] = pb_z * tg_z_yyyyyyz_0[j] + fr * tg_z_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyz_0[j] - tg_0_yyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yyyyyy_1[j];

                    tg_zz_yyyyyzz_0[j] = pb_z * tg_z_yyyyyzz_0[j] + fr * tg_z_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzz_0[j] - tg_0_yyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yyyyyz_1[j];

                    tg_zz_yyyyzzz_0[j] = pb_z * tg_z_yyyyzzz_0[j] + fr * tg_z_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzz_0[j] - tg_0_yyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_yyyyzz_1[j];

                    tg_zz_yyyzzzz_0[j] = pb_z * tg_z_yyyzzzz_0[j] + fr * tg_z_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzz_0[j] - tg_0_yyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_yyyzzz_1[j];

                    tg_zz_yyzzzzz_0[j] = pb_z * tg_z_yyzzzzz_0[j] + fr * tg_z_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzz_0[j] - tg_0_yyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_yyzzzz_1[j];

                    tg_zz_yzzzzzz_0[j] = pb_z * tg_z_yzzzzzz_0[j] + fr * tg_z_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzz_0[j] - tg_0_yzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_yzzzzz_1[j];

                    tg_zz_zzzzzzz_0[j] = pb_z * tg_z_zzzzzzz_0[j] + fr * tg_z_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzz_0[j] - tg_0_zzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_z_zzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSKSD_0_72(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSKSD_72_144(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSKSD_144_216(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 
    }

    void
    compElectronRepulsionForSKSD_0_72(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,72)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxx_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx); 

                auto tg_xxxxxx_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 1); 

                auto tg_xxxxxx_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 2); 

                auto tg_xxxxxx_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 3); 

                auto tg_xxxxxx_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 4); 

                auto tg_xxxxxx_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 5); 

                auto tg_xxxxxy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 6); 

                auto tg_xxxxxy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 7); 

                auto tg_xxxxxy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 8); 

                auto tg_xxxxxy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 9); 

                auto tg_xxxxxy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 10); 

                auto tg_xxxxxy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 11); 

                auto tg_xxxxxz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 12); 

                auto tg_xxxxxz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 13); 

                auto tg_xxxxxz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 14); 

                auto tg_xxxxxz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 15); 

                auto tg_xxxxxz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 16); 

                auto tg_xxxxxz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 17); 

                auto tg_xxxxyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 18); 

                auto tg_xxxxyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 19); 

                auto tg_xxxxyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 20); 

                auto tg_xxxxyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 21); 

                auto tg_xxxxyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 22); 

                auto tg_xxxxyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 23); 

                auto tg_xxxxyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 24); 

                auto tg_xxxxyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 25); 

                auto tg_xxxxyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 26); 

                auto tg_xxxxyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 27); 

                auto tg_xxxxyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 28); 

                auto tg_xxxxyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 29); 

                auto tg_xxxxzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 30); 

                auto tg_xxxxzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 31); 

                auto tg_xxxxzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 32); 

                auto tg_xxxxzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 33); 

                auto tg_xxxxzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 34); 

                auto tg_xxxxzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 35); 

                auto tg_xxxyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 36); 

                auto tg_xxxyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 37); 

                auto tg_xxxyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 38); 

                auto tg_xxxyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 39); 

                auto tg_xxxyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 40); 

                auto tg_xxxyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 41); 

                auto tg_xxxyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 42); 

                auto tg_xxxyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 43); 

                auto tg_xxxyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 44); 

                auto tg_xxxyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 45); 

                auto tg_xxxyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 46); 

                auto tg_xxxyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 47); 

                auto tg_xxxyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 48); 

                auto tg_xxxyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 49); 

                auto tg_xxxyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 50); 

                auto tg_xxxyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 51); 

                auto tg_xxxyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 52); 

                auto tg_xxxyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 53); 

                auto tg_xxxzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 54); 

                auto tg_xxxzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 55); 

                auto tg_xxxzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 56); 

                auto tg_xxxzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 57); 

                auto tg_xxxzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 58); 

                auto tg_xxxzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 59); 

                auto tg_xxyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 60); 

                auto tg_xxyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 61); 

                auto tg_xxyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 62); 

                auto tg_xxyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 63); 

                auto tg_xxyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 64); 

                auto tg_xxyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 65); 

                auto tg_xxyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 66); 

                auto tg_xxyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 67); 

                auto tg_xxyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 68); 

                auto tg_xxyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 69); 

                auto tg_xxyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 70); 

                auto tg_xxyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 71); 

                auto tg_xxxxxx_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx); 

                auto tg_xxxxxx_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 1); 

                auto tg_xxxxxx_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 2); 

                auto tg_xxxxxx_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 3); 

                auto tg_xxxxxx_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 4); 

                auto tg_xxxxxx_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 5); 

                auto tg_xxxxxy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 6); 

                auto tg_xxxxxy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 7); 

                auto tg_xxxxxy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 8); 

                auto tg_xxxxxy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 9); 

                auto tg_xxxxxy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 10); 

                auto tg_xxxxxy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 11); 

                auto tg_xxxxxz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 12); 

                auto tg_xxxxxz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 13); 

                auto tg_xxxxxz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 14); 

                auto tg_xxxxxz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 15); 

                auto tg_xxxxxz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 16); 

                auto tg_xxxxxz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 17); 

                auto tg_xxxxyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 18); 

                auto tg_xxxxyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 19); 

                auto tg_xxxxyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 20); 

                auto tg_xxxxyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 21); 

                auto tg_xxxxyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 22); 

                auto tg_xxxxyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 23); 

                auto tg_xxxxyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 24); 

                auto tg_xxxxyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 25); 

                auto tg_xxxxyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 26); 

                auto tg_xxxxyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 27); 

                auto tg_xxxxyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 28); 

                auto tg_xxxxyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 29); 

                auto tg_xxxxzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 30); 

                auto tg_xxxxzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 31); 

                auto tg_xxxxzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 32); 

                auto tg_xxxxzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 33); 

                auto tg_xxxxzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 34); 

                auto tg_xxxxzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 35); 

                auto tg_xxxyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 36); 

                auto tg_xxxyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 37); 

                auto tg_xxxyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 38); 

                auto tg_xxxyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 39); 

                auto tg_xxxyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 40); 

                auto tg_xxxyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 41); 

                auto tg_xxxyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 42); 

                auto tg_xxxyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 43); 

                auto tg_xxxyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 44); 

                auto tg_xxxyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 45); 

                auto tg_xxxyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 46); 

                auto tg_xxxyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 47); 

                auto tg_xxxyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 48); 

                auto tg_xxxyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 49); 

                auto tg_xxxyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 50); 

                auto tg_xxxyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 51); 

                auto tg_xxxyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 52); 

                auto tg_xxxyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 53); 

                auto tg_xxxzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 54); 

                auto tg_xxxzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 55); 

                auto tg_xxxzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 56); 

                auto tg_xxxzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 57); 

                auto tg_xxxzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 58); 

                auto tg_xxxzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 59); 

                auto tg_xxyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 60); 

                auto tg_xxyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 61); 

                auto tg_xxyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 62); 

                auto tg_xxyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 63); 

                auto tg_xxyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 64); 

                auto tg_xxyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 65); 

                auto tg_xxyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 66); 

                auto tg_xxyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 67); 

                auto tg_xxyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 68); 

                auto tg_xxyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 69); 

                auto tg_xxyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 70); 

                auto tg_xxyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 71); 

                auto tg_xxxxx_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx); 

                auto tg_xxxxx_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 1); 

                auto tg_xxxxx_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 2); 

                auto tg_xxxxx_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 3); 

                auto tg_xxxxx_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 4); 

                auto tg_xxxxx_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 5); 

                auto tg_xxxxy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 6); 

                auto tg_xxxxy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 7); 

                auto tg_xxxxy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 8); 

                auto tg_xxxxy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 9); 

                auto tg_xxxxy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 10); 

                auto tg_xxxxy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 11); 

                auto tg_xxxxz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 12); 

                auto tg_xxxxz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 13); 

                auto tg_xxxxz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 14); 

                auto tg_xxxxz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 15); 

                auto tg_xxxxz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 16); 

                auto tg_xxxxz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 17); 

                auto tg_xxxyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 18); 

                auto tg_xxxyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 19); 

                auto tg_xxxyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 20); 

                auto tg_xxxyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 21); 

                auto tg_xxxyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 22); 

                auto tg_xxxyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 23); 

                auto tg_xxxyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 24); 

                auto tg_xxxyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 25); 

                auto tg_xxxyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 26); 

                auto tg_xxxyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 27); 

                auto tg_xxxyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 28); 

                auto tg_xxxyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 29); 

                auto tg_xxxzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 30); 

                auto tg_xxxzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 31); 

                auto tg_xxxzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 32); 

                auto tg_xxxzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 33); 

                auto tg_xxxzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 34); 

                auto tg_xxxzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 35); 

                auto tg_xxyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 36); 

                auto tg_xxyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 37); 

                auto tg_xxyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 38); 

                auto tg_xxyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 39); 

                auto tg_xxyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 40); 

                auto tg_xxyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 41); 

                auto tg_xxyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 42); 

                auto tg_xxyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 43); 

                auto tg_xxyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 44); 

                auto tg_xxyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 45); 

                auto tg_xxyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 46); 

                auto tg_xxyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 47); 

                auto tg_xxyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 48); 

                auto tg_xxyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 49); 

                auto tg_xxyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 50); 

                auto tg_xxyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 51); 

                auto tg_xxyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 52); 

                auto tg_xxyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 53); 

                auto tg_xxzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 54); 

                auto tg_xxzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 55); 

                auto tg_xxzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 56); 

                auto tg_xxzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 57); 

                auto tg_xxzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 58); 

                auto tg_xxzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 59); 

                auto tg_xyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 60); 

                auto tg_xyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 61); 

                auto tg_xyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 62); 

                auto tg_xyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 63); 

                auto tg_xyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 64); 

                auto tg_xyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 65); 

                auto tg_xyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 66); 

                auto tg_xyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 67); 

                auto tg_xyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 68); 

                auto tg_xyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 69); 

                auto tg_xyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 70); 

                auto tg_xyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 71); 

                auto tg_xxxxx_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx); 

                auto tg_xxxxx_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 1); 

                auto tg_xxxxx_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 2); 

                auto tg_xxxxx_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 3); 

                auto tg_xxxxx_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 4); 

                auto tg_xxxxx_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 5); 

                auto tg_xxxxy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 6); 

                auto tg_xxxxy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 7); 

                auto tg_xxxxy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 8); 

                auto tg_xxxxy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 9); 

                auto tg_xxxxy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 10); 

                auto tg_xxxxy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 11); 

                auto tg_xxxxz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 12); 

                auto tg_xxxxz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 13); 

                auto tg_xxxxz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 14); 

                auto tg_xxxxz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 15); 

                auto tg_xxxxz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 16); 

                auto tg_xxxxz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 17); 

                auto tg_xxxyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 18); 

                auto tg_xxxyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 19); 

                auto tg_xxxyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 20); 

                auto tg_xxxyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 21); 

                auto tg_xxxyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 22); 

                auto tg_xxxyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 23); 

                auto tg_xxxyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 24); 

                auto tg_xxxyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 25); 

                auto tg_xxxyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 26); 

                auto tg_xxxyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 27); 

                auto tg_xxxyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 28); 

                auto tg_xxxyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 29); 

                auto tg_xxxzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 30); 

                auto tg_xxxzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 31); 

                auto tg_xxxzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 32); 

                auto tg_xxxzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 33); 

                auto tg_xxxzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 34); 

                auto tg_xxxzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 35); 

                auto tg_xxyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 36); 

                auto tg_xxyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 37); 

                auto tg_xxyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 38); 

                auto tg_xxyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 39); 

                auto tg_xxyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 40); 

                auto tg_xxyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 41); 

                auto tg_xxyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 42); 

                auto tg_xxyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 43); 

                auto tg_xxyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 44); 

                auto tg_xxyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 45); 

                auto tg_xxyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 46); 

                auto tg_xxyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 47); 

                auto tg_xxyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 48); 

                auto tg_xxyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 49); 

                auto tg_xxyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 50); 

                auto tg_xxyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 51); 

                auto tg_xxyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 52); 

                auto tg_xxyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 53); 

                auto tg_xxzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 54); 

                auto tg_xxzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 55); 

                auto tg_xxzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 56); 

                auto tg_xxzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 57); 

                auto tg_xxzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 58); 

                auto tg_xxzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 59); 

                auto tg_xyyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 60); 

                auto tg_xyyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 61); 

                auto tg_xyyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 62); 

                auto tg_xyyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 63); 

                auto tg_xyyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 64); 

                auto tg_xyyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 65); 

                auto tg_xyyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 66); 

                auto tg_xyyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 67); 

                auto tg_xyyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 68); 

                auto tg_xyyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 69); 

                auto tg_xyyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 70); 

                auto tg_xyyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 71); 

                auto tg_xxxxxx_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx); 

                auto tg_xxxxxx_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 1); 

                auto tg_xxxxxx_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 2); 

                auto tg_xxxxxy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 3); 

                auto tg_xxxxxy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 4); 

                auto tg_xxxxxy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 5); 

                auto tg_xxxxxz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 6); 

                auto tg_xxxxxz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 7); 

                auto tg_xxxxxz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 8); 

                auto tg_xxxxyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 9); 

                auto tg_xxxxyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 10); 

                auto tg_xxxxyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 11); 

                auto tg_xxxxyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 12); 

                auto tg_xxxxyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 13); 

                auto tg_xxxxyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 14); 

                auto tg_xxxxzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 15); 

                auto tg_xxxxzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 16); 

                auto tg_xxxxzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 17); 

                auto tg_xxxyyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 18); 

                auto tg_xxxyyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 19); 

                auto tg_xxxyyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 20); 

                auto tg_xxxyyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 21); 

                auto tg_xxxyyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 22); 

                auto tg_xxxyyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 23); 

                auto tg_xxxyzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 24); 

                auto tg_xxxyzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 25); 

                auto tg_xxxyzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 26); 

                auto tg_xxxzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 27); 

                auto tg_xxxzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 28); 

                auto tg_xxxzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 29); 

                auto tg_xxyyyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 30); 

                auto tg_xxyyyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 31); 

                auto tg_xxyyyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 32); 

                auto tg_xxyyyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 33); 

                auto tg_xxyyyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 34); 

                auto tg_xxyyyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 35); 

                // set up pointers to integrals

                auto tg_xxxxxxx_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx); 

                auto tg_xxxxxxx_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 1); 

                auto tg_xxxxxxx_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 2); 

                auto tg_xxxxxxx_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 3); 

                auto tg_xxxxxxx_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 4); 

                auto tg_xxxxxxx_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 5); 

                auto tg_xxxxxxy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 6); 

                auto tg_xxxxxxy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 7); 

                auto tg_xxxxxxy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 8); 

                auto tg_xxxxxxy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 9); 

                auto tg_xxxxxxy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 10); 

                auto tg_xxxxxxy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 11); 

                auto tg_xxxxxxz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 12); 

                auto tg_xxxxxxz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 13); 

                auto tg_xxxxxxz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 14); 

                auto tg_xxxxxxz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 15); 

                auto tg_xxxxxxz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 16); 

                auto tg_xxxxxxz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 17); 

                auto tg_xxxxxyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 18); 

                auto tg_xxxxxyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 19); 

                auto tg_xxxxxyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 20); 

                auto tg_xxxxxyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 21); 

                auto tg_xxxxxyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 22); 

                auto tg_xxxxxyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 23); 

                auto tg_xxxxxyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 24); 

                auto tg_xxxxxyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 25); 

                auto tg_xxxxxyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 26); 

                auto tg_xxxxxyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 27); 

                auto tg_xxxxxyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 28); 

                auto tg_xxxxxyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 29); 

                auto tg_xxxxxzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 30); 

                auto tg_xxxxxzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 31); 

                auto tg_xxxxxzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 32); 

                auto tg_xxxxxzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 33); 

                auto tg_xxxxxzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 34); 

                auto tg_xxxxxzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 35); 

                auto tg_xxxxyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 36); 

                auto tg_xxxxyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 37); 

                auto tg_xxxxyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 38); 

                auto tg_xxxxyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 39); 

                auto tg_xxxxyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 40); 

                auto tg_xxxxyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 41); 

                auto tg_xxxxyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 42); 

                auto tg_xxxxyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 43); 

                auto tg_xxxxyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 44); 

                auto tg_xxxxyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 45); 

                auto tg_xxxxyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 46); 

                auto tg_xxxxyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 47); 

                auto tg_xxxxyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 48); 

                auto tg_xxxxyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 49); 

                auto tg_xxxxyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 50); 

                auto tg_xxxxyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 51); 

                auto tg_xxxxyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 52); 

                auto tg_xxxxyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 53); 

                auto tg_xxxxzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 54); 

                auto tg_xxxxzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 55); 

                auto tg_xxxxzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 56); 

                auto tg_xxxxzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 57); 

                auto tg_xxxxzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 58); 

                auto tg_xxxxzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 59); 

                auto tg_xxxyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 60); 

                auto tg_xxxyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 61); 

                auto tg_xxxyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 62); 

                auto tg_xxxyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 63); 

                auto tg_xxxyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 64); 

                auto tg_xxxyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 65); 

                auto tg_xxxyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 66); 

                auto tg_xxxyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 67); 

                auto tg_xxxyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 68); 

                auto tg_xxxyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 69); 

                auto tg_xxxyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 70); 

                auto tg_xxxyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 71); 

                // Batch of Integrals (0,72)

                #pragma omp simd aligned(fxn, fza, tg_xxxxx_xx_0, tg_xxxxx_xx_1, tg_xxxxx_xy_0, tg_xxxxx_xy_1, \
                                         tg_xxxxx_xz_0, tg_xxxxx_xz_1, tg_xxxxx_yy_0, tg_xxxxx_yy_1, tg_xxxxx_yz_0, \
                                         tg_xxxxx_yz_1, tg_xxxxx_zz_0, tg_xxxxx_zz_1, tg_xxxxxx_x_1, tg_xxxxxx_xx_0, \
                                         tg_xxxxxx_xx_1, tg_xxxxxx_xy_0, tg_xxxxxx_xy_1, tg_xxxxxx_xz_0, tg_xxxxxx_xz_1, \
                                         tg_xxxxxx_y_1, tg_xxxxxx_yy_0, tg_xxxxxx_yy_1, tg_xxxxxx_yz_0, tg_xxxxxx_yz_1, \
                                         tg_xxxxxx_z_1, tg_xxxxxx_zz_0, tg_xxxxxx_zz_1, tg_xxxxxxx_xx_0, tg_xxxxxxx_xy_0, \
                                         tg_xxxxxxx_xz_0, tg_xxxxxxx_yy_0, tg_xxxxxxx_yz_0, tg_xxxxxxx_zz_0, tg_xxxxxxy_xx_0, \
                                         tg_xxxxxxy_xy_0, tg_xxxxxxy_xz_0, tg_xxxxxxy_yy_0, tg_xxxxxxy_yz_0, tg_xxxxxxy_zz_0, \
                                         tg_xxxxxxz_xx_0, tg_xxxxxxz_xy_0, tg_xxxxxxz_xz_0, tg_xxxxxxz_yy_0, tg_xxxxxxz_yz_0, \
                                         tg_xxxxxxz_zz_0, tg_xxxxxy_x_1, tg_xxxxxy_xx_0, tg_xxxxxy_xx_1, tg_xxxxxy_xy_0, \
                                         tg_xxxxxy_xy_1, tg_xxxxxy_xz_0, tg_xxxxxy_xz_1, tg_xxxxxy_y_1, tg_xxxxxy_yy_0, \
                                         tg_xxxxxy_yy_1, tg_xxxxxy_yz_0, tg_xxxxxy_yz_1, tg_xxxxxy_z_1, tg_xxxxxy_zz_0, \
                                         tg_xxxxxy_zz_1, tg_xxxxxyy_xx_0, tg_xxxxxyy_xy_0, tg_xxxxxyy_xz_0, tg_xxxxxyy_yy_0, \
                                         tg_xxxxxyy_yz_0, tg_xxxxxyy_zz_0, tg_xxxxxyz_xx_0, tg_xxxxxyz_xy_0, tg_xxxxxyz_xz_0, \
                                         tg_xxxxxyz_yy_0, tg_xxxxxyz_yz_0, tg_xxxxxyz_zz_0, tg_xxxxxz_x_1, tg_xxxxxz_xx_0, \
                                         tg_xxxxxz_xx_1, tg_xxxxxz_xy_0, tg_xxxxxz_xy_1, tg_xxxxxz_xz_0, tg_xxxxxz_xz_1, \
                                         tg_xxxxxz_y_1, tg_xxxxxz_yy_0, tg_xxxxxz_yy_1, tg_xxxxxz_yz_0, tg_xxxxxz_yz_1, \
                                         tg_xxxxxz_z_1, tg_xxxxxz_zz_0, tg_xxxxxz_zz_1, tg_xxxxxzz_xx_0, tg_xxxxxzz_xy_0, \
                                         tg_xxxxxzz_xz_0, tg_xxxxxzz_yy_0, tg_xxxxxzz_yz_0, tg_xxxxxzz_zz_0, tg_xxxxy_xx_0, \
                                         tg_xxxxy_xx_1, tg_xxxxy_xy_0, tg_xxxxy_xy_1, tg_xxxxy_xz_0, tg_xxxxy_xz_1, \
                                         tg_xxxxy_yy_0, tg_xxxxy_yy_1, tg_xxxxy_yz_0, tg_xxxxy_yz_1, tg_xxxxy_zz_0, \
                                         tg_xxxxy_zz_1, tg_xxxxyy_x_1, tg_xxxxyy_xx_0, tg_xxxxyy_xx_1, tg_xxxxyy_xy_0, \
                                         tg_xxxxyy_xy_1, tg_xxxxyy_xz_0, tg_xxxxyy_xz_1, tg_xxxxyy_y_1, tg_xxxxyy_yy_0, \
                                         tg_xxxxyy_yy_1, tg_xxxxyy_yz_0, tg_xxxxyy_yz_1, tg_xxxxyy_z_1, tg_xxxxyy_zz_0, \
                                         tg_xxxxyy_zz_1, tg_xxxxyyy_xx_0, tg_xxxxyyy_xy_0, tg_xxxxyyy_xz_0, tg_xxxxyyy_yy_0, \
                                         tg_xxxxyyy_yz_0, tg_xxxxyyy_zz_0, tg_xxxxyyz_xx_0, tg_xxxxyyz_xy_0, tg_xxxxyyz_xz_0, \
                                         tg_xxxxyyz_yy_0, tg_xxxxyyz_yz_0, tg_xxxxyyz_zz_0, tg_xxxxyz_x_1, tg_xxxxyz_xx_0, \
                                         tg_xxxxyz_xx_1, tg_xxxxyz_xy_0, tg_xxxxyz_xy_1, tg_xxxxyz_xz_0, tg_xxxxyz_xz_1, \
                                         tg_xxxxyz_y_1, tg_xxxxyz_yy_0, tg_xxxxyz_yy_1, tg_xxxxyz_yz_0, tg_xxxxyz_yz_1, \
                                         tg_xxxxyz_z_1, tg_xxxxyz_zz_0, tg_xxxxyz_zz_1, tg_xxxxyzz_xx_0, tg_xxxxyzz_xy_0, \
                                         tg_xxxxyzz_xz_0, tg_xxxxyzz_yy_0, tg_xxxxyzz_yz_0, tg_xxxxyzz_zz_0, tg_xxxxz_xx_0, \
                                         tg_xxxxz_xx_1, tg_xxxxz_xy_0, tg_xxxxz_xy_1, tg_xxxxz_xz_0, tg_xxxxz_xz_1, \
                                         tg_xxxxz_yy_0, tg_xxxxz_yy_1, tg_xxxxz_yz_0, tg_xxxxz_yz_1, tg_xxxxz_zz_0, \
                                         tg_xxxxz_zz_1, tg_xxxxzz_x_1, tg_xxxxzz_xx_0, tg_xxxxzz_xx_1, tg_xxxxzz_xy_0, \
                                         tg_xxxxzz_xy_1, tg_xxxxzz_xz_0, tg_xxxxzz_xz_1, tg_xxxxzz_y_1, tg_xxxxzz_yy_0, \
                                         tg_xxxxzz_yy_1, tg_xxxxzz_yz_0, tg_xxxxzz_yz_1, tg_xxxxzz_z_1, tg_xxxxzz_zz_0, \
                                         tg_xxxxzz_zz_1, tg_xxxxzzz_xx_0, tg_xxxxzzz_xy_0, tg_xxxxzzz_xz_0, tg_xxxxzzz_yy_0, \
                                         tg_xxxxzzz_yz_0, tg_xxxxzzz_zz_0, tg_xxxyy_xx_0, tg_xxxyy_xx_1, tg_xxxyy_xy_0, \
                                         tg_xxxyy_xy_1, tg_xxxyy_xz_0, tg_xxxyy_xz_1, tg_xxxyy_yy_0, tg_xxxyy_yy_1, \
                                         tg_xxxyy_yz_0, tg_xxxyy_yz_1, tg_xxxyy_zz_0, tg_xxxyy_zz_1, tg_xxxyyy_x_1, \
                                         tg_xxxyyy_xx_0, tg_xxxyyy_xx_1, tg_xxxyyy_xy_0, tg_xxxyyy_xy_1, tg_xxxyyy_xz_0, \
                                         tg_xxxyyy_xz_1, tg_xxxyyy_y_1, tg_xxxyyy_yy_0, tg_xxxyyy_yy_1, tg_xxxyyy_yz_0, \
                                         tg_xxxyyy_yz_1, tg_xxxyyy_z_1, tg_xxxyyy_zz_0, tg_xxxyyy_zz_1, tg_xxxyyyy_xx_0, \
                                         tg_xxxyyyy_xy_0, tg_xxxyyyy_xz_0, tg_xxxyyyy_yy_0, tg_xxxyyyy_yz_0, tg_xxxyyyy_zz_0, \
                                         tg_xxxyyyz_xx_0, tg_xxxyyyz_xy_0, tg_xxxyyyz_xz_0, tg_xxxyyyz_yy_0, tg_xxxyyyz_yz_0, \
                                         tg_xxxyyyz_zz_0, tg_xxxyyz_x_1, tg_xxxyyz_xx_0, tg_xxxyyz_xx_1, tg_xxxyyz_xy_0, \
                                         tg_xxxyyz_xy_1, tg_xxxyyz_xz_0, tg_xxxyyz_xz_1, tg_xxxyyz_y_1, tg_xxxyyz_yy_0, \
                                         tg_xxxyyz_yy_1, tg_xxxyyz_yz_0, tg_xxxyyz_yz_1, tg_xxxyyz_z_1, tg_xxxyyz_zz_0, \
                                         tg_xxxyyz_zz_1, tg_xxxyz_xx_0, tg_xxxyz_xx_1, tg_xxxyz_xy_0, tg_xxxyz_xy_1, \
                                         tg_xxxyz_xz_0, tg_xxxyz_xz_1, tg_xxxyz_yy_0, tg_xxxyz_yy_1, tg_xxxyz_yz_0, \
                                         tg_xxxyz_yz_1, tg_xxxyz_zz_0, tg_xxxyz_zz_1, tg_xxxyzz_x_1, tg_xxxyzz_xx_0, \
                                         tg_xxxyzz_xx_1, tg_xxxyzz_xy_0, tg_xxxyzz_xy_1, tg_xxxyzz_xz_0, tg_xxxyzz_xz_1, \
                                         tg_xxxyzz_y_1, tg_xxxyzz_yy_0, tg_xxxyzz_yy_1, tg_xxxyzz_yz_0, tg_xxxyzz_yz_1, \
                                         tg_xxxyzz_z_1, tg_xxxyzz_zz_0, tg_xxxyzz_zz_1, tg_xxxzz_xx_0, tg_xxxzz_xx_1, \
                                         tg_xxxzz_xy_0, tg_xxxzz_xy_1, tg_xxxzz_xz_0, tg_xxxzz_xz_1, tg_xxxzz_yy_0, \
                                         tg_xxxzz_yy_1, tg_xxxzz_yz_0, tg_xxxzz_yz_1, tg_xxxzz_zz_0, tg_xxxzz_zz_1, \
                                         tg_xxxzzz_x_1, tg_xxxzzz_xx_0, tg_xxxzzz_xx_1, tg_xxxzzz_xy_0, tg_xxxzzz_xy_1, \
                                         tg_xxxzzz_xz_0, tg_xxxzzz_xz_1, tg_xxxzzz_y_1, tg_xxxzzz_yy_0, tg_xxxzzz_yy_1, \
                                         tg_xxxzzz_yz_0, tg_xxxzzz_yz_1, tg_xxxzzz_z_1, tg_xxxzzz_zz_0, tg_xxxzzz_zz_1, \
                                         tg_xxyyy_xx_0, tg_xxyyy_xx_1, tg_xxyyy_xy_0, tg_xxyyy_xy_1, tg_xxyyy_xz_0, \
                                         tg_xxyyy_xz_1, tg_xxyyy_yy_0, tg_xxyyy_yy_1, tg_xxyyy_yz_0, tg_xxyyy_yz_1, \
                                         tg_xxyyy_zz_0, tg_xxyyy_zz_1, tg_xxyyyy_x_1, tg_xxyyyy_xx_0, tg_xxyyyy_xx_1, \
                                         tg_xxyyyy_xy_0, tg_xxyyyy_xy_1, tg_xxyyyy_xz_0, tg_xxyyyy_xz_1, tg_xxyyyy_y_1, \
                                         tg_xxyyyy_yy_0, tg_xxyyyy_yy_1, tg_xxyyyy_yz_0, tg_xxyyyy_yz_1, tg_xxyyyy_z_1, \
                                         tg_xxyyyy_zz_0, tg_xxyyyy_zz_1, tg_xxyyyz_x_1, tg_xxyyyz_xx_0, tg_xxyyyz_xx_1, \
                                         tg_xxyyyz_xy_0, tg_xxyyyz_xy_1, tg_xxyyyz_xz_0, tg_xxyyyz_xz_1, tg_xxyyyz_y_1, \
                                         tg_xxyyyz_yy_0, tg_xxyyyz_yy_1, tg_xxyyyz_yz_0, tg_xxyyyz_yz_1, tg_xxyyyz_z_1, \
                                         tg_xxyyyz_zz_0, tg_xxyyyz_zz_1, tg_xxyyz_xx_0, tg_xxyyz_xx_1, tg_xxyyz_xy_0, \
                                         tg_xxyyz_xy_1, tg_xxyyz_xz_0, tg_xxyyz_xz_1, tg_xxyyz_yy_0, tg_xxyyz_yy_1, \
                                         tg_xxyyz_yz_0, tg_xxyyz_yz_1, tg_xxyyz_zz_0, tg_xxyyz_zz_1, tg_xxyzz_xx_0, \
                                         tg_xxyzz_xx_1, tg_xxyzz_xy_0, tg_xxyzz_xy_1, tg_xxyzz_xz_0, tg_xxyzz_xz_1, \
                                         tg_xxyzz_yy_0, tg_xxyzz_yy_1, tg_xxyzz_yz_0, tg_xxyzz_yz_1, tg_xxyzz_zz_0, \
                                         tg_xxyzz_zz_1, tg_xxzzz_xx_0, tg_xxzzz_xx_1, tg_xxzzz_xy_0, tg_xxzzz_xy_1, \
                                         tg_xxzzz_xz_0, tg_xxzzz_xz_1, tg_xxzzz_yy_0, tg_xxzzz_yy_1, tg_xxzzz_yz_0, \
                                         tg_xxzzz_yz_1, tg_xxzzz_zz_0, tg_xxzzz_zz_1, tg_xyyyy_xx_0, tg_xyyyy_xx_1, \
                                         tg_xyyyy_xy_0, tg_xyyyy_xy_1, tg_xyyyy_xz_0, tg_xyyyy_xz_1, tg_xyyyy_yy_0, \
                                         tg_xyyyy_yy_1, tg_xyyyy_yz_0, tg_xyyyy_yz_1, tg_xyyyy_zz_0, tg_xyyyy_zz_1, \
                                         tg_xyyyz_xx_0, tg_xyyyz_xx_1, tg_xyyyz_xy_0, tg_xyyyz_xy_1, tg_xyyyz_xz_0, \
                                         tg_xyyyz_xz_1, tg_xyyyz_yy_0, tg_xyyyz_yy_1, tg_xyyyz_yz_0, tg_xyyyz_yz_1, \
                                         tg_xyyyz_zz_0, tg_xyyyz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxx_xx_0[j] = pb_x * tg_xxxxxx_xx_0[j] + fr * tg_xxxxxx_xx_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xx_0[j] - tg_xxxxx_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_x_1[j];

                    tg_xxxxxxx_xy_0[j] = pb_x * tg_xxxxxx_xy_0[j] + fr * tg_xxxxxx_xy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xy_0[j] - tg_xxxxx_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_y_1[j];

                    tg_xxxxxxx_xz_0[j] = pb_x * tg_xxxxxx_xz_0[j] + fr * tg_xxxxxx_xz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xz_0[j] - tg_xxxxx_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_z_1[j];

                    tg_xxxxxxx_yy_0[j] = pb_x * tg_xxxxxx_yy_0[j] + fr * tg_xxxxxx_yy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yy_0[j] - tg_xxxxx_yy_1[j] * fl1_fza);

                    tg_xxxxxxx_yz_0[j] = pb_x * tg_xxxxxx_yz_0[j] + fr * tg_xxxxxx_yz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yz_0[j] - tg_xxxxx_yz_1[j] * fl1_fza);

                    tg_xxxxxxx_zz_0[j] = pb_x * tg_xxxxxx_zz_0[j] + fr * tg_xxxxxx_zz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_zz_0[j] - tg_xxxxx_zz_1[j] * fl1_fza);

                    tg_xxxxxxy_xx_0[j] = pb_x * tg_xxxxxy_xx_0[j] + fr * tg_xxxxxy_xx_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xx_0[j] - tg_xxxxy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_x_1[j];

                    tg_xxxxxxy_xy_0[j] = pb_x * tg_xxxxxy_xy_0[j] + fr * tg_xxxxxy_xy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xy_0[j] - tg_xxxxy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_y_1[j];

                    tg_xxxxxxy_xz_0[j] = pb_x * tg_xxxxxy_xz_0[j] + fr * tg_xxxxxy_xz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xz_0[j] - tg_xxxxy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_z_1[j];

                    tg_xxxxxxy_yy_0[j] = pb_x * tg_xxxxxy_yy_0[j] + fr * tg_xxxxxy_yy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yy_0[j] - tg_xxxxy_yy_1[j] * fl1_fza);

                    tg_xxxxxxy_yz_0[j] = pb_x * tg_xxxxxy_yz_0[j] + fr * tg_xxxxxy_yz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yz_0[j] - tg_xxxxy_yz_1[j] * fl1_fza);

                    tg_xxxxxxy_zz_0[j] = pb_x * tg_xxxxxy_zz_0[j] + fr * tg_xxxxxy_zz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_zz_0[j] - tg_xxxxy_zz_1[j] * fl1_fza);

                    tg_xxxxxxz_xx_0[j] = pb_x * tg_xxxxxz_xx_0[j] + fr * tg_xxxxxz_xx_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xx_0[j] - tg_xxxxz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_x_1[j];

                    tg_xxxxxxz_xy_0[j] = pb_x * tg_xxxxxz_xy_0[j] + fr * tg_xxxxxz_xy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xy_0[j] - tg_xxxxz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_y_1[j];

                    tg_xxxxxxz_xz_0[j] = pb_x * tg_xxxxxz_xz_0[j] + fr * tg_xxxxxz_xz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xz_0[j] - tg_xxxxz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_z_1[j];

                    tg_xxxxxxz_yy_0[j] = pb_x * tg_xxxxxz_yy_0[j] + fr * tg_xxxxxz_yy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yy_0[j] - tg_xxxxz_yy_1[j] * fl1_fza);

                    tg_xxxxxxz_yz_0[j] = pb_x * tg_xxxxxz_yz_0[j] + fr * tg_xxxxxz_yz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yz_0[j] - tg_xxxxz_yz_1[j] * fl1_fza);

                    tg_xxxxxxz_zz_0[j] = pb_x * tg_xxxxxz_zz_0[j] + fr * tg_xxxxxz_zz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_zz_0[j] - tg_xxxxz_zz_1[j] * fl1_fza);

                    tg_xxxxxyy_xx_0[j] = pb_x * tg_xxxxyy_xx_0[j] + fr * tg_xxxxyy_xx_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xx_0[j] - tg_xxxyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_x_1[j];

                    tg_xxxxxyy_xy_0[j] = pb_x * tg_xxxxyy_xy_0[j] + fr * tg_xxxxyy_xy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xy_0[j] - tg_xxxyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_y_1[j];

                    tg_xxxxxyy_xz_0[j] = pb_x * tg_xxxxyy_xz_0[j] + fr * tg_xxxxyy_xz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xz_0[j] - tg_xxxyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_z_1[j];

                    tg_xxxxxyy_yy_0[j] = pb_x * tg_xxxxyy_yy_0[j] + fr * tg_xxxxyy_yy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yy_0[j] - tg_xxxyy_yy_1[j] * fl1_fza);

                    tg_xxxxxyy_yz_0[j] = pb_x * tg_xxxxyy_yz_0[j] + fr * tg_xxxxyy_yz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yz_0[j] - tg_xxxyy_yz_1[j] * fl1_fza);

                    tg_xxxxxyy_zz_0[j] = pb_x * tg_xxxxyy_zz_0[j] + fr * tg_xxxxyy_zz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_zz_0[j] - tg_xxxyy_zz_1[j] * fl1_fza);

                    tg_xxxxxyz_xx_0[j] = pb_x * tg_xxxxyz_xx_0[j] + fr * tg_xxxxyz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xx_0[j] - tg_xxxyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_x_1[j];

                    tg_xxxxxyz_xy_0[j] = pb_x * tg_xxxxyz_xy_0[j] + fr * tg_xxxxyz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xy_0[j] - tg_xxxyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_y_1[j];

                    tg_xxxxxyz_xz_0[j] = pb_x * tg_xxxxyz_xz_0[j] + fr * tg_xxxxyz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xz_0[j] - tg_xxxyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_z_1[j];

                    tg_xxxxxyz_yy_0[j] = pb_x * tg_xxxxyz_yy_0[j] + fr * tg_xxxxyz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yy_0[j] - tg_xxxyz_yy_1[j] * fl1_fza);

                    tg_xxxxxyz_yz_0[j] = pb_x * tg_xxxxyz_yz_0[j] + fr * tg_xxxxyz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yz_0[j] - tg_xxxyz_yz_1[j] * fl1_fza);

                    tg_xxxxxyz_zz_0[j] = pb_x * tg_xxxxyz_zz_0[j] + fr * tg_xxxxyz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_zz_0[j] - tg_xxxyz_zz_1[j] * fl1_fza);

                    tg_xxxxxzz_xx_0[j] = pb_x * tg_xxxxzz_xx_0[j] + fr * tg_xxxxzz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xx_0[j] - tg_xxxzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_x_1[j];

                    tg_xxxxxzz_xy_0[j] = pb_x * tg_xxxxzz_xy_0[j] + fr * tg_xxxxzz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xy_0[j] - tg_xxxzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_y_1[j];

                    tg_xxxxxzz_xz_0[j] = pb_x * tg_xxxxzz_xz_0[j] + fr * tg_xxxxzz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xz_0[j] - tg_xxxzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_z_1[j];

                    tg_xxxxxzz_yy_0[j] = pb_x * tg_xxxxzz_yy_0[j] + fr * tg_xxxxzz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yy_0[j] - tg_xxxzz_yy_1[j] * fl1_fza);

                    tg_xxxxxzz_yz_0[j] = pb_x * tg_xxxxzz_yz_0[j] + fr * tg_xxxxzz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yz_0[j] - tg_xxxzz_yz_1[j] * fl1_fza);

                    tg_xxxxxzz_zz_0[j] = pb_x * tg_xxxxzz_zz_0[j] + fr * tg_xxxxzz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_zz_0[j] - tg_xxxzz_zz_1[j] * fl1_fza);

                    tg_xxxxyyy_xx_0[j] = pb_x * tg_xxxyyy_xx_0[j] + fr * tg_xxxyyy_xx_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xx_0[j] - tg_xxyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_x_1[j];

                    tg_xxxxyyy_xy_0[j] = pb_x * tg_xxxyyy_xy_0[j] + fr * tg_xxxyyy_xy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xy_0[j] - tg_xxyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_y_1[j];

                    tg_xxxxyyy_xz_0[j] = pb_x * tg_xxxyyy_xz_0[j] + fr * tg_xxxyyy_xz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xz_0[j] - tg_xxyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_z_1[j];

                    tg_xxxxyyy_yy_0[j] = pb_x * tg_xxxyyy_yy_0[j] + fr * tg_xxxyyy_yy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yy_0[j] - tg_xxyyy_yy_1[j] * fl1_fza);

                    tg_xxxxyyy_yz_0[j] = pb_x * tg_xxxyyy_yz_0[j] + fr * tg_xxxyyy_yz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yz_0[j] - tg_xxyyy_yz_1[j] * fl1_fza);

                    tg_xxxxyyy_zz_0[j] = pb_x * tg_xxxyyy_zz_0[j] + fr * tg_xxxyyy_zz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_zz_0[j] - tg_xxyyy_zz_1[j] * fl1_fza);

                    tg_xxxxyyz_xx_0[j] = pb_x * tg_xxxyyz_xx_0[j] + fr * tg_xxxyyz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xx_0[j] - tg_xxyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_x_1[j];

                    tg_xxxxyyz_xy_0[j] = pb_x * tg_xxxyyz_xy_0[j] + fr * tg_xxxyyz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xy_0[j] - tg_xxyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_y_1[j];

                    tg_xxxxyyz_xz_0[j] = pb_x * tg_xxxyyz_xz_0[j] + fr * tg_xxxyyz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xz_0[j] - tg_xxyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_z_1[j];

                    tg_xxxxyyz_yy_0[j] = pb_x * tg_xxxyyz_yy_0[j] + fr * tg_xxxyyz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yy_0[j] - tg_xxyyz_yy_1[j] * fl1_fza);

                    tg_xxxxyyz_yz_0[j] = pb_x * tg_xxxyyz_yz_0[j] + fr * tg_xxxyyz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yz_0[j] - tg_xxyyz_yz_1[j] * fl1_fza);

                    tg_xxxxyyz_zz_0[j] = pb_x * tg_xxxyyz_zz_0[j] + fr * tg_xxxyyz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_zz_0[j] - tg_xxyyz_zz_1[j] * fl1_fza);

                    tg_xxxxyzz_xx_0[j] = pb_x * tg_xxxyzz_xx_0[j] + fr * tg_xxxyzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xx_0[j] - tg_xxyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_x_1[j];

                    tg_xxxxyzz_xy_0[j] = pb_x * tg_xxxyzz_xy_0[j] + fr * tg_xxxyzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xy_0[j] - tg_xxyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_y_1[j];

                    tg_xxxxyzz_xz_0[j] = pb_x * tg_xxxyzz_xz_0[j] + fr * tg_xxxyzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xz_0[j] - tg_xxyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_z_1[j];

                    tg_xxxxyzz_yy_0[j] = pb_x * tg_xxxyzz_yy_0[j] + fr * tg_xxxyzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yy_0[j] - tg_xxyzz_yy_1[j] * fl1_fza);

                    tg_xxxxyzz_yz_0[j] = pb_x * tg_xxxyzz_yz_0[j] + fr * tg_xxxyzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yz_0[j] - tg_xxyzz_yz_1[j] * fl1_fza);

                    tg_xxxxyzz_zz_0[j] = pb_x * tg_xxxyzz_zz_0[j] + fr * tg_xxxyzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_zz_0[j] - tg_xxyzz_zz_1[j] * fl1_fza);

                    tg_xxxxzzz_xx_0[j] = pb_x * tg_xxxzzz_xx_0[j] + fr * tg_xxxzzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xx_0[j] - tg_xxzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_x_1[j];

                    tg_xxxxzzz_xy_0[j] = pb_x * tg_xxxzzz_xy_0[j] + fr * tg_xxxzzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xy_0[j] - tg_xxzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_y_1[j];

                    tg_xxxxzzz_xz_0[j] = pb_x * tg_xxxzzz_xz_0[j] + fr * tg_xxxzzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xz_0[j] - tg_xxzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_z_1[j];

                    tg_xxxxzzz_yy_0[j] = pb_x * tg_xxxzzz_yy_0[j] + fr * tg_xxxzzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yy_0[j] - tg_xxzzz_yy_1[j] * fl1_fza);

                    tg_xxxxzzz_yz_0[j] = pb_x * tg_xxxzzz_yz_0[j] + fr * tg_xxxzzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yz_0[j] - tg_xxzzz_yz_1[j] * fl1_fza);

                    tg_xxxxzzz_zz_0[j] = pb_x * tg_xxxzzz_zz_0[j] + fr * tg_xxxzzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_zz_0[j] - tg_xxzzz_zz_1[j] * fl1_fza);

                    tg_xxxyyyy_xx_0[j] = pb_x * tg_xxyyyy_xx_0[j] + fr * tg_xxyyyy_xx_1[j] + fl1_fx * (tg_xyyyy_xx_0[j] - tg_xyyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_x_1[j];

                    tg_xxxyyyy_xy_0[j] = pb_x * tg_xxyyyy_xy_0[j] + fr * tg_xxyyyy_xy_1[j] + fl1_fx * (tg_xyyyy_xy_0[j] - tg_xyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_y_1[j];

                    tg_xxxyyyy_xz_0[j] = pb_x * tg_xxyyyy_xz_0[j] + fr * tg_xxyyyy_xz_1[j] + fl1_fx * (tg_xyyyy_xz_0[j] - tg_xyyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_z_1[j];

                    tg_xxxyyyy_yy_0[j] = pb_x * tg_xxyyyy_yy_0[j] + fr * tg_xxyyyy_yy_1[j] + fl1_fx * (tg_xyyyy_yy_0[j] - tg_xyyyy_yy_1[j] * fl1_fza);

                    tg_xxxyyyy_yz_0[j] = pb_x * tg_xxyyyy_yz_0[j] + fr * tg_xxyyyy_yz_1[j] + fl1_fx * (tg_xyyyy_yz_0[j] - tg_xyyyy_yz_1[j] * fl1_fza);

                    tg_xxxyyyy_zz_0[j] = pb_x * tg_xxyyyy_zz_0[j] + fr * tg_xxyyyy_zz_1[j] + fl1_fx * (tg_xyyyy_zz_0[j] - tg_xyyyy_zz_1[j] * fl1_fza);

                    tg_xxxyyyz_xx_0[j] = pb_x * tg_xxyyyz_xx_0[j] + fr * tg_xxyyyz_xx_1[j] + fl1_fx * (tg_xyyyz_xx_0[j] - tg_xyyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_x_1[j];

                    tg_xxxyyyz_xy_0[j] = pb_x * tg_xxyyyz_xy_0[j] + fr * tg_xxyyyz_xy_1[j] + fl1_fx * (tg_xyyyz_xy_0[j] - tg_xyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_y_1[j];

                    tg_xxxyyyz_xz_0[j] = pb_x * tg_xxyyyz_xz_0[j] + fr * tg_xxyyyz_xz_1[j] + fl1_fx * (tg_xyyyz_xz_0[j] - tg_xyyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_z_1[j];

                    tg_xxxyyyz_yy_0[j] = pb_x * tg_xxyyyz_yy_0[j] + fr * tg_xxyyyz_yy_1[j] + fl1_fx * (tg_xyyyz_yy_0[j] - tg_xyyyz_yy_1[j] * fl1_fza);

                    tg_xxxyyyz_yz_0[j] = pb_x * tg_xxyyyz_yz_0[j] + fr * tg_xxyyyz_yz_1[j] + fl1_fx * (tg_xyyyz_yz_0[j] - tg_xyyyz_yz_1[j] * fl1_fza);

                    tg_xxxyyyz_zz_0[j] = pb_x * tg_xxyyyz_zz_0[j] + fr * tg_xxyyyz_zz_1[j] + fl1_fx * (tg_xyyyz_zz_0[j] - tg_xyyyz_zz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSD_72_144(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (72,144)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 72); 

                auto tg_xxyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 73); 

                auto tg_xxyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 74); 

                auto tg_xxyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 75); 

                auto tg_xxyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 76); 

                auto tg_xxyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 77); 

                auto tg_xxyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 78); 

                auto tg_xxyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 79); 

                auto tg_xxyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 80); 

                auto tg_xxyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 81); 

                auto tg_xxyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 82); 

                auto tg_xxyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 83); 

                auto tg_xxzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 84); 

                auto tg_xxzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 85); 

                auto tg_xxzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 86); 

                auto tg_xxzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 87); 

                auto tg_xxzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 88); 

                auto tg_xxzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 89); 

                auto tg_xyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 90); 

                auto tg_xyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 91); 

                auto tg_xyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 92); 

                auto tg_xyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 93); 

                auto tg_xyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 94); 

                auto tg_xyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 95); 

                auto tg_xyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 96); 

                auto tg_xyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 97); 

                auto tg_xyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 98); 

                auto tg_xyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 99); 

                auto tg_xyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 100); 

                auto tg_xyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 101); 

                auto tg_xyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 102); 

                auto tg_xyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 103); 

                auto tg_xyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 104); 

                auto tg_xyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 105); 

                auto tg_xyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 106); 

                auto tg_xyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 107); 

                auto tg_xyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 108); 

                auto tg_xyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 109); 

                auto tg_xyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 110); 

                auto tg_xyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 111); 

                auto tg_xyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 112); 

                auto tg_xyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 113); 

                auto tg_xyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 114); 

                auto tg_xyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 115); 

                auto tg_xyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 116); 

                auto tg_xyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 117); 

                auto tg_xyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 118); 

                auto tg_xyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 119); 

                auto tg_xzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 120); 

                auto tg_xzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 121); 

                auto tg_xzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 122); 

                auto tg_xzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 123); 

                auto tg_xzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 124); 

                auto tg_xzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 125); 

                auto tg_yyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 143); 

                auto tg_xxyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 72); 

                auto tg_xxyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 73); 

                auto tg_xxyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 74); 

                auto tg_xxyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 75); 

                auto tg_xxyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 76); 

                auto tg_xxyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 77); 

                auto tg_xxyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 78); 

                auto tg_xxyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 79); 

                auto tg_xxyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 80); 

                auto tg_xxyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 81); 

                auto tg_xxyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 82); 

                auto tg_xxyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 83); 

                auto tg_xxzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 84); 

                auto tg_xxzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 85); 

                auto tg_xxzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 86); 

                auto tg_xxzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 87); 

                auto tg_xxzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 88); 

                auto tg_xxzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 89); 

                auto tg_xyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 90); 

                auto tg_xyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 91); 

                auto tg_xyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 92); 

                auto tg_xyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 93); 

                auto tg_xyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 94); 

                auto tg_xyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 95); 

                auto tg_xyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 96); 

                auto tg_xyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 97); 

                auto tg_xyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 98); 

                auto tg_xyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 99); 

                auto tg_xyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 100); 

                auto tg_xyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 101); 

                auto tg_xyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 102); 

                auto tg_xyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 103); 

                auto tg_xyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 104); 

                auto tg_xyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 105); 

                auto tg_xyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 106); 

                auto tg_xyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 107); 

                auto tg_xyyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 108); 

                auto tg_xyyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 109); 

                auto tg_xyyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 110); 

                auto tg_xyyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 111); 

                auto tg_xyyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 112); 

                auto tg_xyyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 113); 

                auto tg_xyzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 114); 

                auto tg_xyzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 115); 

                auto tg_xyzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 116); 

                auto tg_xyzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 117); 

                auto tg_xyzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 118); 

                auto tg_xyzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 119); 

                auto tg_xzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 120); 

                auto tg_xzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 121); 

                auto tg_xzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 122); 

                auto tg_xzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 123); 

                auto tg_xzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 124); 

                auto tg_xzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 125); 

                auto tg_yyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 143); 

                auto tg_xyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 72); 

                auto tg_xyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 73); 

                auto tg_xyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 74); 

                auto tg_xyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 75); 

                auto tg_xyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 76); 

                auto tg_xyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 77); 

                auto tg_xyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 78); 

                auto tg_xyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 79); 

                auto tg_xyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 80); 

                auto tg_xyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 81); 

                auto tg_xyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 82); 

                auto tg_xyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 83); 

                auto tg_xzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 84); 

                auto tg_xzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 85); 

                auto tg_xzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 86); 

                auto tg_xzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 87); 

                auto tg_xzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 88); 

                auto tg_xzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 89); 

                auto tg_yyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 90); 

                auto tg_yyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 91); 

                auto tg_yyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 92); 

                auto tg_yyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 93); 

                auto tg_yyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 94); 

                auto tg_yyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 95); 

                auto tg_yyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 96); 

                auto tg_yyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 97); 

                auto tg_yyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 98); 

                auto tg_yyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 99); 

                auto tg_yyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 100); 

                auto tg_yyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 101); 

                auto tg_yyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 102); 

                auto tg_yyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 103); 

                auto tg_yyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 104); 

                auto tg_yyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 105); 

                auto tg_yyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 106); 

                auto tg_yyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 107); 

                auto tg_yyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 108); 

                auto tg_yyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 109); 

                auto tg_yyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 110); 

                auto tg_yyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 111); 

                auto tg_yyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 112); 

                auto tg_yyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 113); 

                auto tg_yzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 114); 

                auto tg_yzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 115); 

                auto tg_yzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 116); 

                auto tg_yzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 117); 

                auto tg_yzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 118); 

                auto tg_yzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 119); 

                auto tg_zzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 120); 

                auto tg_zzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 121); 

                auto tg_zzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 122); 

                auto tg_zzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 123); 

                auto tg_zzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 124); 

                auto tg_zzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 125); 

                auto tg_xyyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 72); 

                auto tg_xyyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 73); 

                auto tg_xyyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 74); 

                auto tg_xyyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 75); 

                auto tg_xyyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 76); 

                auto tg_xyyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 77); 

                auto tg_xyzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 78); 

                auto tg_xyzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 79); 

                auto tg_xyzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 80); 

                auto tg_xyzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 81); 

                auto tg_xyzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 82); 

                auto tg_xyzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 83); 

                auto tg_xzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 84); 

                auto tg_xzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 85); 

                auto tg_xzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 86); 

                auto tg_xzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 87); 

                auto tg_xzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 88); 

                auto tg_xzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 89); 

                auto tg_yyyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 90); 

                auto tg_yyyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 91); 

                auto tg_yyyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 92); 

                auto tg_yyyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 93); 

                auto tg_yyyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 94); 

                auto tg_yyyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 95); 

                auto tg_yyyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 96); 

                auto tg_yyyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 97); 

                auto tg_yyyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 98); 

                auto tg_yyyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 99); 

                auto tg_yyyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 100); 

                auto tg_yyyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 101); 

                auto tg_yyyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 102); 

                auto tg_yyyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 103); 

                auto tg_yyyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 104); 

                auto tg_yyyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 105); 

                auto tg_yyyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 106); 

                auto tg_yyyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 107); 

                auto tg_yyzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 108); 

                auto tg_yyzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 109); 

                auto tg_yyzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 110); 

                auto tg_yyzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 111); 

                auto tg_yyzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 112); 

                auto tg_yyzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 113); 

                auto tg_yzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 114); 

                auto tg_yzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 115); 

                auto tg_yzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 116); 

                auto tg_yzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 117); 

                auto tg_yzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 118); 

                auto tg_yzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 119); 

                auto tg_zzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 120); 

                auto tg_zzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 121); 

                auto tg_zzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 122); 

                auto tg_zzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 123); 

                auto tg_zzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 124); 

                auto tg_zzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 125); 

                auto tg_xxyyzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 36); 

                auto tg_xxyyzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 37); 

                auto tg_xxyyzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 38); 

                auto tg_xxyzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 39); 

                auto tg_xxyzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 40); 

                auto tg_xxyzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 41); 

                auto tg_xxzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 42); 

                auto tg_xxzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 43); 

                auto tg_xxzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 44); 

                auto tg_xyyyyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 45); 

                auto tg_xyyyyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 46); 

                auto tg_xyyyyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 47); 

                auto tg_xyyyyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 48); 

                auto tg_xyyyyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 49); 

                auto tg_xyyyyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 50); 

                auto tg_xyyyzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 51); 

                auto tg_xyyyzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 52); 

                auto tg_xyyyzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 53); 

                auto tg_xyyzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 54); 

                auto tg_xyyzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 55); 

                auto tg_xyyzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 56); 

                auto tg_xyzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 57); 

                auto tg_xyzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 58); 

                auto tg_xyzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 59); 

                auto tg_xzzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 60); 

                auto tg_xzzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 61); 

                auto tg_xzzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 62); 

                auto tg_yyyyyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 63); 

                auto tg_yyyyyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 64); 

                auto tg_yyyyyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 65); 

                auto tg_yyyyyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 66); 

                auto tg_yyyyyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 67); 

                auto tg_yyyyyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 68); 

                auto tg_yyyyzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 69); 

                auto tg_yyyyzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 70); 

                auto tg_yyyyzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 71); 

                // set up pointers to integrals

                auto tg_xxxyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 72); 

                auto tg_xxxyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 73); 

                auto tg_xxxyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 74); 

                auto tg_xxxyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 75); 

                auto tg_xxxyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 76); 

                auto tg_xxxyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 77); 

                auto tg_xxxyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 78); 

                auto tg_xxxyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 79); 

                auto tg_xxxyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 80); 

                auto tg_xxxyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 81); 

                auto tg_xxxyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 82); 

                auto tg_xxxyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 83); 

                auto tg_xxxzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 84); 

                auto tg_xxxzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 85); 

                auto tg_xxxzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 86); 

                auto tg_xxxzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 87); 

                auto tg_xxxzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 88); 

                auto tg_xxxzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 89); 

                auto tg_xxyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 90); 

                auto tg_xxyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 91); 

                auto tg_xxyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 92); 

                auto tg_xxyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 93); 

                auto tg_xxyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 94); 

                auto tg_xxyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 95); 

                auto tg_xxyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 96); 

                auto tg_xxyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 97); 

                auto tg_xxyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 98); 

                auto tg_xxyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 99); 

                auto tg_xxyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 100); 

                auto tg_xxyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 101); 

                auto tg_xxyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 102); 

                auto tg_xxyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 103); 

                auto tg_xxyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 104); 

                auto tg_xxyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 105); 

                auto tg_xxyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 106); 

                auto tg_xxyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 107); 

                auto tg_xxyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 108); 

                auto tg_xxyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 109); 

                auto tg_xxyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 110); 

                auto tg_xxyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 111); 

                auto tg_xxyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 112); 

                auto tg_xxyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 113); 

                auto tg_xxyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 114); 

                auto tg_xxyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 115); 

                auto tg_xxyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 116); 

                auto tg_xxyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 117); 

                auto tg_xxyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 118); 

                auto tg_xxyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 119); 

                auto tg_xxzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 120); 

                auto tg_xxzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 121); 

                auto tg_xxzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 122); 

                auto tg_xxzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 123); 

                auto tg_xxzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 124); 

                auto tg_xxzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 125); 

                auto tg_xyyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 126); 

                auto tg_xyyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 127); 

                auto tg_xyyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 128); 

                auto tg_xyyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 129); 

                auto tg_xyyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 130); 

                auto tg_xyyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 131); 

                auto tg_xyyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 132); 

                auto tg_xyyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 133); 

                auto tg_xyyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 134); 

                auto tg_xyyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 135); 

                auto tg_xyyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 136); 

                auto tg_xyyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 137); 

                auto tg_xyyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 138); 

                auto tg_xyyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 139); 

                auto tg_xyyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 140); 

                auto tg_xyyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 141); 

                auto tg_xyyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 142); 

                auto tg_xyyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 143); 

                // Batch of Integrals (72,144)

                #pragma omp simd aligned(fxn, fza, tg_xxxyyzz_xx_0, tg_xxxyyzz_xy_0, tg_xxxyyzz_xz_0, \
                                         tg_xxxyyzz_yy_0, tg_xxxyyzz_yz_0, tg_xxxyyzz_zz_0, tg_xxxyzzz_xx_0, tg_xxxyzzz_xy_0, \
                                         tg_xxxyzzz_xz_0, tg_xxxyzzz_yy_0, tg_xxxyzzz_yz_0, tg_xxxyzzz_zz_0, tg_xxxzzzz_xx_0, \
                                         tg_xxxzzzz_xy_0, tg_xxxzzzz_xz_0, tg_xxxzzzz_yy_0, tg_xxxzzzz_yz_0, tg_xxxzzzz_zz_0, \
                                         tg_xxyyyyy_xx_0, tg_xxyyyyy_xy_0, tg_xxyyyyy_xz_0, tg_xxyyyyy_yy_0, tg_xxyyyyy_yz_0, \
                                         tg_xxyyyyy_zz_0, tg_xxyyyyz_xx_0, tg_xxyyyyz_xy_0, tg_xxyyyyz_xz_0, tg_xxyyyyz_yy_0, \
                                         tg_xxyyyyz_yz_0, tg_xxyyyyz_zz_0, tg_xxyyyzz_xx_0, tg_xxyyyzz_xy_0, tg_xxyyyzz_xz_0, \
                                         tg_xxyyyzz_yy_0, tg_xxyyyzz_yz_0, tg_xxyyyzz_zz_0, tg_xxyyzz_x_1, tg_xxyyzz_xx_0, \
                                         tg_xxyyzz_xx_1, tg_xxyyzz_xy_0, tg_xxyyzz_xy_1, tg_xxyyzz_xz_0, tg_xxyyzz_xz_1, \
                                         tg_xxyyzz_y_1, tg_xxyyzz_yy_0, tg_xxyyzz_yy_1, tg_xxyyzz_yz_0, tg_xxyyzz_yz_1, \
                                         tg_xxyyzz_z_1, tg_xxyyzz_zz_0, tg_xxyyzz_zz_1, tg_xxyyzzz_xx_0, tg_xxyyzzz_xy_0, \
                                         tg_xxyyzzz_xz_0, tg_xxyyzzz_yy_0, tg_xxyyzzz_yz_0, tg_xxyyzzz_zz_0, tg_xxyzzz_x_1, \
                                         tg_xxyzzz_xx_0, tg_xxyzzz_xx_1, tg_xxyzzz_xy_0, tg_xxyzzz_xy_1, tg_xxyzzz_xz_0, \
                                         tg_xxyzzz_xz_1, tg_xxyzzz_y_1, tg_xxyzzz_yy_0, tg_xxyzzz_yy_1, tg_xxyzzz_yz_0, \
                                         tg_xxyzzz_yz_1, tg_xxyzzz_z_1, tg_xxyzzz_zz_0, tg_xxyzzz_zz_1, tg_xxyzzzz_xx_0, \
                                         tg_xxyzzzz_xy_0, tg_xxyzzzz_xz_0, tg_xxyzzzz_yy_0, tg_xxyzzzz_yz_0, tg_xxyzzzz_zz_0, \
                                         tg_xxzzzz_x_1, tg_xxzzzz_xx_0, tg_xxzzzz_xx_1, tg_xxzzzz_xy_0, tg_xxzzzz_xy_1, \
                                         tg_xxzzzz_xz_0, tg_xxzzzz_xz_1, tg_xxzzzz_y_1, tg_xxzzzz_yy_0, tg_xxzzzz_yy_1, \
                                         tg_xxzzzz_yz_0, tg_xxzzzz_yz_1, tg_xxzzzz_z_1, tg_xxzzzz_zz_0, tg_xxzzzz_zz_1, \
                                         tg_xxzzzzz_xx_0, tg_xxzzzzz_xy_0, tg_xxzzzzz_xz_0, tg_xxzzzzz_yy_0, tg_xxzzzzz_yz_0, \
                                         tg_xxzzzzz_zz_0, tg_xyyyyy_x_1, tg_xyyyyy_xx_0, tg_xyyyyy_xx_1, tg_xyyyyy_xy_0, \
                                         tg_xyyyyy_xy_1, tg_xyyyyy_xz_0, tg_xyyyyy_xz_1, tg_xyyyyy_y_1, tg_xyyyyy_yy_0, \
                                         tg_xyyyyy_yy_1, tg_xyyyyy_yz_0, tg_xyyyyy_yz_1, tg_xyyyyy_z_1, tg_xyyyyy_zz_0, \
                                         tg_xyyyyy_zz_1, tg_xyyyyyy_xx_0, tg_xyyyyyy_xy_0, tg_xyyyyyy_xz_0, tg_xyyyyyy_yy_0, \
                                         tg_xyyyyyy_yz_0, tg_xyyyyyy_zz_0, tg_xyyyyyz_xx_0, tg_xyyyyyz_xy_0, tg_xyyyyyz_xz_0, \
                                         tg_xyyyyyz_yy_0, tg_xyyyyyz_yz_0, tg_xyyyyyz_zz_0, tg_xyyyyz_x_1, tg_xyyyyz_xx_0, \
                                         tg_xyyyyz_xx_1, tg_xyyyyz_xy_0, tg_xyyyyz_xy_1, tg_xyyyyz_xz_0, tg_xyyyyz_xz_1, \
                                         tg_xyyyyz_y_1, tg_xyyyyz_yy_0, tg_xyyyyz_yy_1, tg_xyyyyz_yz_0, tg_xyyyyz_yz_1, \
                                         tg_xyyyyz_z_1, tg_xyyyyz_zz_0, tg_xyyyyz_zz_1, tg_xyyyyzz_xx_0, tg_xyyyyzz_xy_0, \
                                         tg_xyyyyzz_xz_0, tg_xyyyyzz_yy_0, tg_xyyyyzz_yz_0, tg_xyyyyzz_zz_0, tg_xyyyzz_x_1, \
                                         tg_xyyyzz_xx_0, tg_xyyyzz_xx_1, tg_xyyyzz_xy_0, tg_xyyyzz_xy_1, tg_xyyyzz_xz_0, \
                                         tg_xyyyzz_xz_1, tg_xyyyzz_y_1, tg_xyyyzz_yy_0, tg_xyyyzz_yy_1, tg_xyyyzz_yz_0, \
                                         tg_xyyyzz_yz_1, tg_xyyyzz_z_1, tg_xyyyzz_zz_0, tg_xyyyzz_zz_1, tg_xyyzz_xx_0, \
                                         tg_xyyzz_xx_1, tg_xyyzz_xy_0, tg_xyyzz_xy_1, tg_xyyzz_xz_0, tg_xyyzz_xz_1, \
                                         tg_xyyzz_yy_0, tg_xyyzz_yy_1, tg_xyyzz_yz_0, tg_xyyzz_yz_1, tg_xyyzz_zz_0, \
                                         tg_xyyzz_zz_1, tg_xyyzzz_x_1, tg_xyyzzz_xx_0, tg_xyyzzz_xx_1, tg_xyyzzz_xy_0, \
                                         tg_xyyzzz_xy_1, tg_xyyzzz_xz_0, tg_xyyzzz_xz_1, tg_xyyzzz_y_1, tg_xyyzzz_yy_0, \
                                         tg_xyyzzz_yy_1, tg_xyyzzz_yz_0, tg_xyyzzz_yz_1, tg_xyyzzz_z_1, tg_xyyzzz_zz_0, \
                                         tg_xyyzzz_zz_1, tg_xyzzz_xx_0, tg_xyzzz_xx_1, tg_xyzzz_xy_0, tg_xyzzz_xy_1, \
                                         tg_xyzzz_xz_0, tg_xyzzz_xz_1, tg_xyzzz_yy_0, tg_xyzzz_yy_1, tg_xyzzz_yz_0, \
                                         tg_xyzzz_yz_1, tg_xyzzz_zz_0, tg_xyzzz_zz_1, tg_xyzzzz_x_1, tg_xyzzzz_xx_0, \
                                         tg_xyzzzz_xx_1, tg_xyzzzz_xy_0, tg_xyzzzz_xy_1, tg_xyzzzz_xz_0, tg_xyzzzz_xz_1, \
                                         tg_xyzzzz_y_1, tg_xyzzzz_yy_0, tg_xyzzzz_yy_1, tg_xyzzzz_yz_0, tg_xyzzzz_yz_1, \
                                         tg_xyzzzz_z_1, tg_xyzzzz_zz_0, tg_xyzzzz_zz_1, tg_xzzzz_xx_0, tg_xzzzz_xx_1, \
                                         tg_xzzzz_xy_0, tg_xzzzz_xy_1, tg_xzzzz_xz_0, tg_xzzzz_xz_1, tg_xzzzz_yy_0, \
                                         tg_xzzzz_yy_1, tg_xzzzz_yz_0, tg_xzzzz_yz_1, tg_xzzzz_zz_0, tg_xzzzz_zz_1, \
                                         tg_xzzzzz_x_1, tg_xzzzzz_xx_0, tg_xzzzzz_xx_1, tg_xzzzzz_xy_0, tg_xzzzzz_xy_1, \
                                         tg_xzzzzz_xz_0, tg_xzzzzz_xz_1, tg_xzzzzz_y_1, tg_xzzzzz_yy_0, tg_xzzzzz_yy_1, \
                                         tg_xzzzzz_yz_0, tg_xzzzzz_yz_1, tg_xzzzzz_z_1, tg_xzzzzz_zz_0, tg_xzzzzz_zz_1, \
                                         tg_yyyyy_xx_0, tg_yyyyy_xx_1, tg_yyyyy_xy_0, tg_yyyyy_xy_1, tg_yyyyy_xz_0, \
                                         tg_yyyyy_xz_1, tg_yyyyy_yy_0, tg_yyyyy_yy_1, tg_yyyyy_yz_0, tg_yyyyy_yz_1, \
                                         tg_yyyyy_zz_0, tg_yyyyy_zz_1, tg_yyyyyy_x_1, tg_yyyyyy_xx_0, tg_yyyyyy_xx_1, \
                                         tg_yyyyyy_xy_0, tg_yyyyyy_xy_1, tg_yyyyyy_xz_0, tg_yyyyyy_xz_1, tg_yyyyyy_y_1, \
                                         tg_yyyyyy_yy_0, tg_yyyyyy_yy_1, tg_yyyyyy_yz_0, tg_yyyyyy_yz_1, tg_yyyyyy_z_1, \
                                         tg_yyyyyy_zz_0, tg_yyyyyy_zz_1, tg_yyyyyz_x_1, tg_yyyyyz_xx_0, tg_yyyyyz_xx_1, \
                                         tg_yyyyyz_xy_0, tg_yyyyyz_xy_1, tg_yyyyyz_xz_0, tg_yyyyyz_xz_1, tg_yyyyyz_y_1, \
                                         tg_yyyyyz_yy_0, tg_yyyyyz_yy_1, tg_yyyyyz_yz_0, tg_yyyyyz_yz_1, tg_yyyyyz_z_1, \
                                         tg_yyyyyz_zz_0, tg_yyyyyz_zz_1, tg_yyyyz_xx_0, tg_yyyyz_xx_1, tg_yyyyz_xy_0, \
                                         tg_yyyyz_xy_1, tg_yyyyz_xz_0, tg_yyyyz_xz_1, tg_yyyyz_yy_0, tg_yyyyz_yy_1, \
                                         tg_yyyyz_yz_0, tg_yyyyz_yz_1, tg_yyyyz_zz_0, tg_yyyyz_zz_1, tg_yyyyzz_x_1, \
                                         tg_yyyyzz_xx_0, tg_yyyyzz_xx_1, tg_yyyyzz_xy_0, tg_yyyyzz_xy_1, tg_yyyyzz_xz_0, \
                                         tg_yyyyzz_xz_1, tg_yyyyzz_y_1, tg_yyyyzz_yy_0, tg_yyyyzz_yy_1, tg_yyyyzz_yz_0, \
                                         tg_yyyyzz_yz_1, tg_yyyyzz_z_1, tg_yyyyzz_zz_0, tg_yyyyzz_zz_1, tg_yyyzz_xx_0, \
                                         tg_yyyzz_xx_1, tg_yyyzz_xy_0, tg_yyyzz_xy_1, tg_yyyzz_xz_0, tg_yyyzz_xz_1, \
                                         tg_yyyzz_yy_0, tg_yyyzz_yy_1, tg_yyyzz_yz_0, tg_yyyzz_yz_1, tg_yyyzz_zz_0, \
                                         tg_yyyzz_zz_1, tg_yyzzz_xx_0, tg_yyzzz_xx_1, tg_yyzzz_xy_0, tg_yyzzz_xy_1, \
                                         tg_yyzzz_xz_0, tg_yyzzz_xz_1, tg_yyzzz_yy_0, tg_yyzzz_yy_1, tg_yyzzz_yz_0, \
                                         tg_yyzzz_yz_1, tg_yyzzz_zz_0, tg_yyzzz_zz_1, tg_yzzzz_xx_0, tg_yzzzz_xx_1, \
                                         tg_yzzzz_xy_0, tg_yzzzz_xy_1, tg_yzzzz_xz_0, tg_yzzzz_xz_1, tg_yzzzz_yy_0, \
                                         tg_yzzzz_yy_1, tg_yzzzz_yz_0, tg_yzzzz_yz_1, tg_yzzzz_zz_0, tg_yzzzz_zz_1, \
                                         tg_zzzzz_xx_0, tg_zzzzz_xx_1, tg_zzzzz_xy_0, tg_zzzzz_xy_1, tg_zzzzz_xz_0, \
                                         tg_zzzzz_xz_1, tg_zzzzz_yy_0, tg_zzzzz_yy_1, tg_zzzzz_yz_0, tg_zzzzz_yz_1, \
                                         tg_zzzzz_zz_0, tg_zzzzz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyyzz_xx_0[j] = pb_x * tg_xxyyzz_xx_0[j] + fr * tg_xxyyzz_xx_1[j] + fl1_fx * (tg_xyyzz_xx_0[j] - tg_xyyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_x_1[j];

                    tg_xxxyyzz_xy_0[j] = pb_x * tg_xxyyzz_xy_0[j] + fr * tg_xxyyzz_xy_1[j] + fl1_fx * (tg_xyyzz_xy_0[j] - tg_xyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_y_1[j];

                    tg_xxxyyzz_xz_0[j] = pb_x * tg_xxyyzz_xz_0[j] + fr * tg_xxyyzz_xz_1[j] + fl1_fx * (tg_xyyzz_xz_0[j] - tg_xyyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_z_1[j];

                    tg_xxxyyzz_yy_0[j] = pb_x * tg_xxyyzz_yy_0[j] + fr * tg_xxyyzz_yy_1[j] + fl1_fx * (tg_xyyzz_yy_0[j] - tg_xyyzz_yy_1[j] * fl1_fza);

                    tg_xxxyyzz_yz_0[j] = pb_x * tg_xxyyzz_yz_0[j] + fr * tg_xxyyzz_yz_1[j] + fl1_fx * (tg_xyyzz_yz_0[j] - tg_xyyzz_yz_1[j] * fl1_fza);

                    tg_xxxyyzz_zz_0[j] = pb_x * tg_xxyyzz_zz_0[j] + fr * tg_xxyyzz_zz_1[j] + fl1_fx * (tg_xyyzz_zz_0[j] - tg_xyyzz_zz_1[j] * fl1_fza);

                    tg_xxxyzzz_xx_0[j] = pb_x * tg_xxyzzz_xx_0[j] + fr * tg_xxyzzz_xx_1[j] + fl1_fx * (tg_xyzzz_xx_0[j] - tg_xyzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_x_1[j];

                    tg_xxxyzzz_xy_0[j] = pb_x * tg_xxyzzz_xy_0[j] + fr * tg_xxyzzz_xy_1[j] + fl1_fx * (tg_xyzzz_xy_0[j] - tg_xyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_y_1[j];

                    tg_xxxyzzz_xz_0[j] = pb_x * tg_xxyzzz_xz_0[j] + fr * tg_xxyzzz_xz_1[j] + fl1_fx * (tg_xyzzz_xz_0[j] - tg_xyzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_z_1[j];

                    tg_xxxyzzz_yy_0[j] = pb_x * tg_xxyzzz_yy_0[j] + fr * tg_xxyzzz_yy_1[j] + fl1_fx * (tg_xyzzz_yy_0[j] - tg_xyzzz_yy_1[j] * fl1_fza);

                    tg_xxxyzzz_yz_0[j] = pb_x * tg_xxyzzz_yz_0[j] + fr * tg_xxyzzz_yz_1[j] + fl1_fx * (tg_xyzzz_yz_0[j] - tg_xyzzz_yz_1[j] * fl1_fza);

                    tg_xxxyzzz_zz_0[j] = pb_x * tg_xxyzzz_zz_0[j] + fr * tg_xxyzzz_zz_1[j] + fl1_fx * (tg_xyzzz_zz_0[j] - tg_xyzzz_zz_1[j] * fl1_fza);

                    tg_xxxzzzz_xx_0[j] = pb_x * tg_xxzzzz_xx_0[j] + fr * tg_xxzzzz_xx_1[j] + fl1_fx * (tg_xzzzz_xx_0[j] - tg_xzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_x_1[j];

                    tg_xxxzzzz_xy_0[j] = pb_x * tg_xxzzzz_xy_0[j] + fr * tg_xxzzzz_xy_1[j] + fl1_fx * (tg_xzzzz_xy_0[j] - tg_xzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_y_1[j];

                    tg_xxxzzzz_xz_0[j] = pb_x * tg_xxzzzz_xz_0[j] + fr * tg_xxzzzz_xz_1[j] + fl1_fx * (tg_xzzzz_xz_0[j] - tg_xzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_z_1[j];

                    tg_xxxzzzz_yy_0[j] = pb_x * tg_xxzzzz_yy_0[j] + fr * tg_xxzzzz_yy_1[j] + fl1_fx * (tg_xzzzz_yy_0[j] - tg_xzzzz_yy_1[j] * fl1_fza);

                    tg_xxxzzzz_yz_0[j] = pb_x * tg_xxzzzz_yz_0[j] + fr * tg_xxzzzz_yz_1[j] + fl1_fx * (tg_xzzzz_yz_0[j] - tg_xzzzz_yz_1[j] * fl1_fza);

                    tg_xxxzzzz_zz_0[j] = pb_x * tg_xxzzzz_zz_0[j] + fr * tg_xxzzzz_zz_1[j] + fl1_fx * (tg_xzzzz_zz_0[j] - tg_xzzzz_zz_1[j] * fl1_fza);

                    tg_xxyyyyy_xx_0[j] = pb_x * tg_xyyyyy_xx_0[j] + fr * tg_xyyyyy_xx_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xx_0[j] - tg_yyyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_x_1[j];

                    tg_xxyyyyy_xy_0[j] = pb_x * tg_xyyyyy_xy_0[j] + fr * tg_xyyyyy_xy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xy_0[j] - tg_yyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_y_1[j];

                    tg_xxyyyyy_xz_0[j] = pb_x * tg_xyyyyy_xz_0[j] + fr * tg_xyyyyy_xz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xz_0[j] - tg_yyyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_z_1[j];

                    tg_xxyyyyy_yy_0[j] = pb_x * tg_xyyyyy_yy_0[j] + fr * tg_xyyyyy_yy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yy_0[j] - tg_yyyyy_yy_1[j] * fl1_fza);

                    tg_xxyyyyy_yz_0[j] = pb_x * tg_xyyyyy_yz_0[j] + fr * tg_xyyyyy_yz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yz_0[j] - tg_yyyyy_yz_1[j] * fl1_fza);

                    tg_xxyyyyy_zz_0[j] = pb_x * tg_xyyyyy_zz_0[j] + fr * tg_xyyyyy_zz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_zz_0[j] - tg_yyyyy_zz_1[j] * fl1_fza);

                    tg_xxyyyyz_xx_0[j] = pb_x * tg_xyyyyz_xx_0[j] + fr * tg_xyyyyz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xx_0[j] - tg_yyyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_x_1[j];

                    tg_xxyyyyz_xy_0[j] = pb_x * tg_xyyyyz_xy_0[j] + fr * tg_xyyyyz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xy_0[j] - tg_yyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_y_1[j];

                    tg_xxyyyyz_xz_0[j] = pb_x * tg_xyyyyz_xz_0[j] + fr * tg_xyyyyz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xz_0[j] - tg_yyyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_z_1[j];

                    tg_xxyyyyz_yy_0[j] = pb_x * tg_xyyyyz_yy_0[j] + fr * tg_xyyyyz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yy_0[j] - tg_yyyyz_yy_1[j] * fl1_fza);

                    tg_xxyyyyz_yz_0[j] = pb_x * tg_xyyyyz_yz_0[j] + fr * tg_xyyyyz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yz_0[j] - tg_yyyyz_yz_1[j] * fl1_fza);

                    tg_xxyyyyz_zz_0[j] = pb_x * tg_xyyyyz_zz_0[j] + fr * tg_xyyyyz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_zz_0[j] - tg_yyyyz_zz_1[j] * fl1_fza);

                    tg_xxyyyzz_xx_0[j] = pb_x * tg_xyyyzz_xx_0[j] + fr * tg_xyyyzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xx_0[j] - tg_yyyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_x_1[j];

                    tg_xxyyyzz_xy_0[j] = pb_x * tg_xyyyzz_xy_0[j] + fr * tg_xyyyzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xy_0[j] - tg_yyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_y_1[j];

                    tg_xxyyyzz_xz_0[j] = pb_x * tg_xyyyzz_xz_0[j] + fr * tg_xyyyzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xz_0[j] - tg_yyyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_z_1[j];

                    tg_xxyyyzz_yy_0[j] = pb_x * tg_xyyyzz_yy_0[j] + fr * tg_xyyyzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yy_0[j] - tg_yyyzz_yy_1[j] * fl1_fza);

                    tg_xxyyyzz_yz_0[j] = pb_x * tg_xyyyzz_yz_0[j] + fr * tg_xyyyzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yz_0[j] - tg_yyyzz_yz_1[j] * fl1_fza);

                    tg_xxyyyzz_zz_0[j] = pb_x * tg_xyyyzz_zz_0[j] + fr * tg_xyyyzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_zz_0[j] - tg_yyyzz_zz_1[j] * fl1_fza);

                    tg_xxyyzzz_xx_0[j] = pb_x * tg_xyyzzz_xx_0[j] + fr * tg_xyyzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xx_0[j] - tg_yyzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_x_1[j];

                    tg_xxyyzzz_xy_0[j] = pb_x * tg_xyyzzz_xy_0[j] + fr * tg_xyyzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xy_0[j] - tg_yyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_y_1[j];

                    tg_xxyyzzz_xz_0[j] = pb_x * tg_xyyzzz_xz_0[j] + fr * tg_xyyzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xz_0[j] - tg_yyzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_z_1[j];

                    tg_xxyyzzz_yy_0[j] = pb_x * tg_xyyzzz_yy_0[j] + fr * tg_xyyzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yy_0[j] - tg_yyzzz_yy_1[j] * fl1_fza);

                    tg_xxyyzzz_yz_0[j] = pb_x * tg_xyyzzz_yz_0[j] + fr * tg_xyyzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yz_0[j] - tg_yyzzz_yz_1[j] * fl1_fza);

                    tg_xxyyzzz_zz_0[j] = pb_x * tg_xyyzzz_zz_0[j] + fr * tg_xyyzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_zz_0[j] - tg_yyzzz_zz_1[j] * fl1_fza);

                    tg_xxyzzzz_xx_0[j] = pb_x * tg_xyzzzz_xx_0[j] + fr * tg_xyzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xx_0[j] - tg_yzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_x_1[j];

                    tg_xxyzzzz_xy_0[j] = pb_x * tg_xyzzzz_xy_0[j] + fr * tg_xyzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xy_0[j] - tg_yzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_y_1[j];

                    tg_xxyzzzz_xz_0[j] = pb_x * tg_xyzzzz_xz_0[j] + fr * tg_xyzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xz_0[j] - tg_yzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_z_1[j];

                    tg_xxyzzzz_yy_0[j] = pb_x * tg_xyzzzz_yy_0[j] + fr * tg_xyzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yy_0[j] - tg_yzzzz_yy_1[j] * fl1_fza);

                    tg_xxyzzzz_yz_0[j] = pb_x * tg_xyzzzz_yz_0[j] + fr * tg_xyzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yz_0[j] - tg_yzzzz_yz_1[j] * fl1_fza);

                    tg_xxyzzzz_zz_0[j] = pb_x * tg_xyzzzz_zz_0[j] + fr * tg_xyzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_zz_0[j] - tg_yzzzz_zz_1[j] * fl1_fza);

                    tg_xxzzzzz_xx_0[j] = pb_x * tg_xzzzzz_xx_0[j] + fr * tg_xzzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xx_0[j] - tg_zzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_x_1[j];

                    tg_xxzzzzz_xy_0[j] = pb_x * tg_xzzzzz_xy_0[j] + fr * tg_xzzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xy_0[j] - tg_zzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_y_1[j];

                    tg_xxzzzzz_xz_0[j] = pb_x * tg_xzzzzz_xz_0[j] + fr * tg_xzzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xz_0[j] - tg_zzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_z_1[j];

                    tg_xxzzzzz_yy_0[j] = pb_x * tg_xzzzzz_yy_0[j] + fr * tg_xzzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yy_0[j] - tg_zzzzz_yy_1[j] * fl1_fza);

                    tg_xxzzzzz_yz_0[j] = pb_x * tg_xzzzzz_yz_0[j] + fr * tg_xzzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yz_0[j] - tg_zzzzz_yz_1[j] * fl1_fza);

                    tg_xxzzzzz_zz_0[j] = pb_x * tg_xzzzzz_zz_0[j] + fr * tg_xzzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_zz_0[j] - tg_zzzzz_zz_1[j] * fl1_fza);

                    tg_xyyyyyy_xx_0[j] = pb_x * tg_yyyyyy_xx_0[j] + fr * tg_yyyyyy_xx_1[j] + fl1_fxn * tg_yyyyyy_x_1[j];

                    tg_xyyyyyy_xy_0[j] = pb_x * tg_yyyyyy_xy_0[j] + fr * tg_yyyyyy_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_y_1[j];

                    tg_xyyyyyy_xz_0[j] = pb_x * tg_yyyyyy_xz_0[j] + fr * tg_yyyyyy_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_z_1[j];

                    tg_xyyyyyy_yy_0[j] = pb_x * tg_yyyyyy_yy_0[j] + fr * tg_yyyyyy_yy_1[j];

                    tg_xyyyyyy_yz_0[j] = pb_x * tg_yyyyyy_yz_0[j] + fr * tg_yyyyyy_yz_1[j];

                    tg_xyyyyyy_zz_0[j] = pb_x * tg_yyyyyy_zz_0[j] + fr * tg_yyyyyy_zz_1[j];

                    tg_xyyyyyz_xx_0[j] = pb_x * tg_yyyyyz_xx_0[j] + fr * tg_yyyyyz_xx_1[j] + fl1_fxn * tg_yyyyyz_x_1[j];

                    tg_xyyyyyz_xy_0[j] = pb_x * tg_yyyyyz_xy_0[j] + fr * tg_yyyyyz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_y_1[j];

                    tg_xyyyyyz_xz_0[j] = pb_x * tg_yyyyyz_xz_0[j] + fr * tg_yyyyyz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_z_1[j];

                    tg_xyyyyyz_yy_0[j] = pb_x * tg_yyyyyz_yy_0[j] + fr * tg_yyyyyz_yy_1[j];

                    tg_xyyyyyz_yz_0[j] = pb_x * tg_yyyyyz_yz_0[j] + fr * tg_yyyyyz_yz_1[j];

                    tg_xyyyyyz_zz_0[j] = pb_x * tg_yyyyyz_zz_0[j] + fr * tg_yyyyyz_zz_1[j];

                    tg_xyyyyzz_xx_0[j] = pb_x * tg_yyyyzz_xx_0[j] + fr * tg_yyyyzz_xx_1[j] + fl1_fxn * tg_yyyyzz_x_1[j];

                    tg_xyyyyzz_xy_0[j] = pb_x * tg_yyyyzz_xy_0[j] + fr * tg_yyyyzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_y_1[j];

                    tg_xyyyyzz_xz_0[j] = pb_x * tg_yyyyzz_xz_0[j] + fr * tg_yyyyzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_z_1[j];

                    tg_xyyyyzz_yy_0[j] = pb_x * tg_yyyyzz_yy_0[j] + fr * tg_yyyyzz_yy_1[j];

                    tg_xyyyyzz_yz_0[j] = pb_x * tg_yyyyzz_yz_0[j] + fr * tg_yyyyzz_yz_1[j];

                    tg_xyyyyzz_zz_0[j] = pb_x * tg_yyyyzz_zz_0[j] + fr * tg_yyyyzz_zz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSD_144_216(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (144,216)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 167); 

                auto tg_yyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 167); 

                auto tg_yyyyy_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 90); 

                auto tg_yyyyy_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 91); 

                auto tg_yyyyy_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 92); 

                auto tg_yyyyy_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 93); 

                auto tg_yyyyy_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 94); 

                auto tg_yyyyy_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 95); 

                auto tg_yyyyz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 96); 

                auto tg_yyyyz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 97); 

                auto tg_yyyyz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 98); 

                auto tg_yyyyz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 99); 

                auto tg_yyyyz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 100); 

                auto tg_yyyyz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 101); 

                auto tg_yyyzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 102); 

                auto tg_yyyzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 103); 

                auto tg_yyyzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 104); 

                auto tg_yyyzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 105); 

                auto tg_yyyzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 106); 

                auto tg_yyyzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 107); 

                auto tg_yyzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 108); 

                auto tg_yyzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 109); 

                auto tg_yyzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 110); 

                auto tg_yyzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 111); 

                auto tg_yyzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 112); 

                auto tg_yyzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 113); 

                auto tg_yzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 114); 

                auto tg_yzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 115); 

                auto tg_yzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 116); 

                auto tg_yzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 117); 

                auto tg_yzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 118); 

                auto tg_yzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 119); 

                auto tg_zzzzz_xx_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 120); 

                auto tg_zzzzz_xy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 121); 

                auto tg_zzzzz_xz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 122); 

                auto tg_zzzzz_yy_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 123); 

                auto tg_zzzzz_yz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 124); 

                auto tg_zzzzz_zz_0 = primBuffer[pidx_g_5_2_m0].data(126 * idx + 125); 

                auto tg_yyyyy_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 90); 

                auto tg_yyyyy_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 91); 

                auto tg_yyyyy_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 92); 

                auto tg_yyyyy_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 93); 

                auto tg_yyyyy_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 94); 

                auto tg_yyyyy_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 95); 

                auto tg_yyyyz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 96); 

                auto tg_yyyyz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 97); 

                auto tg_yyyyz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 98); 

                auto tg_yyyyz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 99); 

                auto tg_yyyyz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 100); 

                auto tg_yyyyz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 101); 

                auto tg_yyyzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 102); 

                auto tg_yyyzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 103); 

                auto tg_yyyzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 104); 

                auto tg_yyyzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 105); 

                auto tg_yyyzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 106); 

                auto tg_yyyzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 107); 

                auto tg_yyzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 108); 

                auto tg_yyzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 109); 

                auto tg_yyzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 110); 

                auto tg_yyzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 111); 

                auto tg_yyzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 112); 

                auto tg_yyzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 113); 

                auto tg_yzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 114); 

                auto tg_yzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 115); 

                auto tg_yzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 116); 

                auto tg_yzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 117); 

                auto tg_yzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 118); 

                auto tg_yzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 119); 

                auto tg_zzzzz_xx_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 120); 

                auto tg_zzzzz_xy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 121); 

                auto tg_zzzzz_xz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 122); 

                auto tg_zzzzz_yy_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 123); 

                auto tg_zzzzz_yz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 124); 

                auto tg_zzzzz_zz_1 = primBuffer[pidx_g_5_2_m1].data(126 * idx + 125); 

                auto tg_yyyyyy_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 63); 

                auto tg_yyyyyy_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 64); 

                auto tg_yyyyyy_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 65); 

                auto tg_yyyyyz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 66); 

                auto tg_yyyyyz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 67); 

                auto tg_yyyyyz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 68); 

                auto tg_yyyyzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 69); 

                auto tg_yyyyzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 70); 

                auto tg_yyyyzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 71); 

                auto tg_yyyzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 72); 

                auto tg_yyyzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 73); 

                auto tg_yyyzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 74); 

                auto tg_yyzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 75); 

                auto tg_yyzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 76); 

                auto tg_yyzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 77); 

                auto tg_yzzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 78); 

                auto tg_yzzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 79); 

                auto tg_yzzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 80); 

                auto tg_zzzzzz_x_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 81); 

                auto tg_zzzzzz_y_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 82); 

                auto tg_zzzzzz_z_1 = primBuffer[pidx_g_6_1_m1].data(84 * idx + 83); 

                // set up pointers to integrals

                auto tg_xyyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 144); 

                auto tg_xyyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 145); 

                auto tg_xyyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 146); 

                auto tg_xyyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 147); 

                auto tg_xyyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 148); 

                auto tg_xyyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 149); 

                auto tg_xyyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 150); 

                auto tg_xyyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 151); 

                auto tg_xyyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 152); 

                auto tg_xyyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 153); 

                auto tg_xyyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 154); 

                auto tg_xyyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 155); 

                auto tg_xyzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 156); 

                auto tg_xyzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 157); 

                auto tg_xyzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 158); 

                auto tg_xyzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 159); 

                auto tg_xyzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 160); 

                auto tg_xyzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 161); 

                auto tg_xzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 162); 

                auto tg_xzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 163); 

                auto tg_xzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 164); 

                auto tg_xzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 165); 

                auto tg_xzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 166); 

                auto tg_xzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 167); 

                auto tg_yyyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 168); 

                auto tg_yyyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 169); 

                auto tg_yyyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 170); 

                auto tg_yyyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 171); 

                auto tg_yyyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 172); 

                auto tg_yyyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 173); 

                auto tg_yyyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 174); 

                auto tg_yyyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 175); 

                auto tg_yyyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 176); 

                auto tg_yyyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 177); 

                auto tg_yyyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 178); 

                auto tg_yyyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 179); 

                auto tg_yyyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 180); 

                auto tg_yyyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 181); 

                auto tg_yyyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 182); 

                auto tg_yyyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 183); 

                auto tg_yyyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 184); 

                auto tg_yyyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 185); 

                auto tg_yyyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 186); 

                auto tg_yyyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 187); 

                auto tg_yyyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 188); 

                auto tg_yyyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 189); 

                auto tg_yyyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 190); 

                auto tg_yyyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 191); 

                auto tg_yyyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 192); 

                auto tg_yyyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 193); 

                auto tg_yyyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 194); 

                auto tg_yyyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 195); 

                auto tg_yyyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 196); 

                auto tg_yyyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 197); 

                auto tg_yyzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 198); 

                auto tg_yyzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 199); 

                auto tg_yyzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 200); 

                auto tg_yyzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 201); 

                auto tg_yyzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 202); 

                auto tg_yyzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 203); 

                auto tg_yzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 204); 

                auto tg_yzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 205); 

                auto tg_yzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 206); 

                auto tg_yzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 207); 

                auto tg_yzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 208); 

                auto tg_yzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 209); 

                auto tg_zzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 210); 

                auto tg_zzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 211); 

                auto tg_zzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 212); 

                auto tg_zzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 213); 

                auto tg_zzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 214); 

                auto tg_zzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 215); 

                // Batch of Integrals (144,216)

                #pragma omp simd aligned(fxn, fza, tg_xyyyzzz_xx_0, tg_xyyyzzz_xy_0, tg_xyyyzzz_xz_0, \
                                         tg_xyyyzzz_yy_0, tg_xyyyzzz_yz_0, tg_xyyyzzz_zz_0, tg_xyyzzzz_xx_0, tg_xyyzzzz_xy_0, \
                                         tg_xyyzzzz_xz_0, tg_xyyzzzz_yy_0, tg_xyyzzzz_yz_0, tg_xyyzzzz_zz_0, tg_xyzzzzz_xx_0, \
                                         tg_xyzzzzz_xy_0, tg_xyzzzzz_xz_0, tg_xyzzzzz_yy_0, tg_xyzzzzz_yz_0, tg_xyzzzzz_zz_0, \
                                         tg_xzzzzzz_xx_0, tg_xzzzzzz_xy_0, tg_xzzzzzz_xz_0, tg_xzzzzzz_yy_0, tg_xzzzzzz_yz_0, \
                                         tg_xzzzzzz_zz_0, tg_yyyyy_xx_0, tg_yyyyy_xx_1, tg_yyyyy_xy_0, tg_yyyyy_xy_1, \
                                         tg_yyyyy_xz_0, tg_yyyyy_xz_1, tg_yyyyy_yy_0, tg_yyyyy_yy_1, tg_yyyyy_yz_0, \
                                         tg_yyyyy_yz_1, tg_yyyyy_zz_0, tg_yyyyy_zz_1, tg_yyyyyy_x_1, tg_yyyyyy_xx_0, \
                                         tg_yyyyyy_xx_1, tg_yyyyyy_xy_0, tg_yyyyyy_xy_1, tg_yyyyyy_xz_0, tg_yyyyyy_xz_1, \
                                         tg_yyyyyy_y_1, tg_yyyyyy_yy_0, tg_yyyyyy_yy_1, tg_yyyyyy_yz_0, tg_yyyyyy_yz_1, \
                                         tg_yyyyyy_z_1, tg_yyyyyy_zz_0, tg_yyyyyy_zz_1, tg_yyyyyyy_xx_0, tg_yyyyyyy_xy_0, \
                                         tg_yyyyyyy_xz_0, tg_yyyyyyy_yy_0, tg_yyyyyyy_yz_0, tg_yyyyyyy_zz_0, tg_yyyyyyz_xx_0, \
                                         tg_yyyyyyz_xy_0, tg_yyyyyyz_xz_0, tg_yyyyyyz_yy_0, tg_yyyyyyz_yz_0, tg_yyyyyyz_zz_0, \
                                         tg_yyyyyz_x_1, tg_yyyyyz_xx_0, tg_yyyyyz_xx_1, tg_yyyyyz_xy_0, tg_yyyyyz_xy_1, \
                                         tg_yyyyyz_xz_0, tg_yyyyyz_xz_1, tg_yyyyyz_y_1, tg_yyyyyz_yy_0, tg_yyyyyz_yy_1, \
                                         tg_yyyyyz_yz_0, tg_yyyyyz_yz_1, tg_yyyyyz_z_1, tg_yyyyyz_zz_0, tg_yyyyyz_zz_1, \
                                         tg_yyyyyzz_xx_0, tg_yyyyyzz_xy_0, tg_yyyyyzz_xz_0, tg_yyyyyzz_yy_0, tg_yyyyyzz_yz_0, \
                                         tg_yyyyyzz_zz_0, tg_yyyyz_xx_0, tg_yyyyz_xx_1, tg_yyyyz_xy_0, tg_yyyyz_xy_1, \
                                         tg_yyyyz_xz_0, tg_yyyyz_xz_1, tg_yyyyz_yy_0, tg_yyyyz_yy_1, tg_yyyyz_yz_0, \
                                         tg_yyyyz_yz_1, tg_yyyyz_zz_0, tg_yyyyz_zz_1, tg_yyyyzz_x_1, tg_yyyyzz_xx_0, \
                                         tg_yyyyzz_xx_1, tg_yyyyzz_xy_0, tg_yyyyzz_xy_1, tg_yyyyzz_xz_0, tg_yyyyzz_xz_1, \
                                         tg_yyyyzz_y_1, tg_yyyyzz_yy_0, tg_yyyyzz_yy_1, tg_yyyyzz_yz_0, tg_yyyyzz_yz_1, \
                                         tg_yyyyzz_z_1, tg_yyyyzz_zz_0, tg_yyyyzz_zz_1, tg_yyyyzzz_xx_0, tg_yyyyzzz_xy_0, \
                                         tg_yyyyzzz_xz_0, tg_yyyyzzz_yy_0, tg_yyyyzzz_yz_0, tg_yyyyzzz_zz_0, tg_yyyzz_xx_0, \
                                         tg_yyyzz_xx_1, tg_yyyzz_xy_0, tg_yyyzz_xy_1, tg_yyyzz_xz_0, tg_yyyzz_xz_1, \
                                         tg_yyyzz_yy_0, tg_yyyzz_yy_1, tg_yyyzz_yz_0, tg_yyyzz_yz_1, tg_yyyzz_zz_0, \
                                         tg_yyyzz_zz_1, tg_yyyzzz_x_1, tg_yyyzzz_xx_0, tg_yyyzzz_xx_1, tg_yyyzzz_xy_0, \
                                         tg_yyyzzz_xy_1, tg_yyyzzz_xz_0, tg_yyyzzz_xz_1, tg_yyyzzz_y_1, tg_yyyzzz_yy_0, \
                                         tg_yyyzzz_yy_1, tg_yyyzzz_yz_0, tg_yyyzzz_yz_1, tg_yyyzzz_z_1, tg_yyyzzz_zz_0, \
                                         tg_yyyzzz_zz_1, tg_yyyzzzz_xx_0, tg_yyyzzzz_xy_0, tg_yyyzzzz_xz_0, tg_yyyzzzz_yy_0, \
                                         tg_yyyzzzz_yz_0, tg_yyyzzzz_zz_0, tg_yyzzz_xx_0, tg_yyzzz_xx_1, tg_yyzzz_xy_0, \
                                         tg_yyzzz_xy_1, tg_yyzzz_xz_0, tg_yyzzz_xz_1, tg_yyzzz_yy_0, tg_yyzzz_yy_1, \
                                         tg_yyzzz_yz_0, tg_yyzzz_yz_1, tg_yyzzz_zz_0, tg_yyzzz_zz_1, tg_yyzzzz_x_1, \
                                         tg_yyzzzz_xx_0, tg_yyzzzz_xx_1, tg_yyzzzz_xy_0, tg_yyzzzz_xy_1, tg_yyzzzz_xz_0, \
                                         tg_yyzzzz_xz_1, tg_yyzzzz_y_1, tg_yyzzzz_yy_0, tg_yyzzzz_yy_1, tg_yyzzzz_yz_0, \
                                         tg_yyzzzz_yz_1, tg_yyzzzz_z_1, tg_yyzzzz_zz_0, tg_yyzzzz_zz_1, tg_yyzzzzz_xx_0, \
                                         tg_yyzzzzz_xy_0, tg_yyzzzzz_xz_0, tg_yyzzzzz_yy_0, tg_yyzzzzz_yz_0, tg_yyzzzzz_zz_0, \
                                         tg_yzzzz_xx_0, tg_yzzzz_xx_1, tg_yzzzz_xy_0, tg_yzzzz_xy_1, tg_yzzzz_xz_0, \
                                         tg_yzzzz_xz_1, tg_yzzzz_yy_0, tg_yzzzz_yy_1, tg_yzzzz_yz_0, tg_yzzzz_yz_1, \
                                         tg_yzzzz_zz_0, tg_yzzzz_zz_1, tg_yzzzzz_x_1, tg_yzzzzz_xx_0, tg_yzzzzz_xx_1, \
                                         tg_yzzzzz_xy_0, tg_yzzzzz_xy_1, tg_yzzzzz_xz_0, tg_yzzzzz_xz_1, tg_yzzzzz_y_1, \
                                         tg_yzzzzz_yy_0, tg_yzzzzz_yy_1, tg_yzzzzz_yz_0, tg_yzzzzz_yz_1, tg_yzzzzz_z_1, \
                                         tg_yzzzzz_zz_0, tg_yzzzzz_zz_1, tg_yzzzzzz_xx_0, tg_yzzzzzz_xy_0, tg_yzzzzzz_xz_0, \
                                         tg_yzzzzzz_yy_0, tg_yzzzzzz_yz_0, tg_yzzzzzz_zz_0, tg_zzzzz_xx_0, tg_zzzzz_xx_1, \
                                         tg_zzzzz_xy_0, tg_zzzzz_xy_1, tg_zzzzz_xz_0, tg_zzzzz_xz_1, tg_zzzzz_yy_0, \
                                         tg_zzzzz_yy_1, tg_zzzzz_yz_0, tg_zzzzz_yz_1, tg_zzzzz_zz_0, tg_zzzzz_zz_1, \
                                         tg_zzzzzz_x_1, tg_zzzzzz_xx_0, tg_zzzzzz_xx_1, tg_zzzzzz_xy_0, tg_zzzzzz_xy_1, \
                                         tg_zzzzzz_xz_0, tg_zzzzzz_xz_1, tg_zzzzzz_y_1, tg_zzzzzz_yy_0, tg_zzzzzz_yy_1, \
                                         tg_zzzzzz_yz_0, tg_zzzzzz_yz_1, tg_zzzzzz_z_1, tg_zzzzzz_zz_0, tg_zzzzzz_zz_1, \
                                         tg_zzzzzzz_xx_0, tg_zzzzzzz_xy_0, tg_zzzzzzz_xz_0, tg_zzzzzzz_yy_0, tg_zzzzzzz_yz_0, \
                                         tg_zzzzzzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xyyyzzz_xx_0[j] = pb_x * tg_yyyzzz_xx_0[j] + fr * tg_yyyzzz_xx_1[j] + fl1_fxn * tg_yyyzzz_x_1[j];

                    tg_xyyyzzz_xy_0[j] = pb_x * tg_yyyzzz_xy_0[j] + fr * tg_yyyzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_y_1[j];

                    tg_xyyyzzz_xz_0[j] = pb_x * tg_yyyzzz_xz_0[j] + fr * tg_yyyzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_z_1[j];

                    tg_xyyyzzz_yy_0[j] = pb_x * tg_yyyzzz_yy_0[j] + fr * tg_yyyzzz_yy_1[j];

                    tg_xyyyzzz_yz_0[j] = pb_x * tg_yyyzzz_yz_0[j] + fr * tg_yyyzzz_yz_1[j];

                    tg_xyyyzzz_zz_0[j] = pb_x * tg_yyyzzz_zz_0[j] + fr * tg_yyyzzz_zz_1[j];

                    tg_xyyzzzz_xx_0[j] = pb_x * tg_yyzzzz_xx_0[j] + fr * tg_yyzzzz_xx_1[j] + fl1_fxn * tg_yyzzzz_x_1[j];

                    tg_xyyzzzz_xy_0[j] = pb_x * tg_yyzzzz_xy_0[j] + fr * tg_yyzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_y_1[j];

                    tg_xyyzzzz_xz_0[j] = pb_x * tg_yyzzzz_xz_0[j] + fr * tg_yyzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_z_1[j];

                    tg_xyyzzzz_yy_0[j] = pb_x * tg_yyzzzz_yy_0[j] + fr * tg_yyzzzz_yy_1[j];

                    tg_xyyzzzz_yz_0[j] = pb_x * tg_yyzzzz_yz_0[j] + fr * tg_yyzzzz_yz_1[j];

                    tg_xyyzzzz_zz_0[j] = pb_x * tg_yyzzzz_zz_0[j] + fr * tg_yyzzzz_zz_1[j];

                    tg_xyzzzzz_xx_0[j] = pb_x * tg_yzzzzz_xx_0[j] + fr * tg_yzzzzz_xx_1[j] + fl1_fxn * tg_yzzzzz_x_1[j];

                    tg_xyzzzzz_xy_0[j] = pb_x * tg_yzzzzz_xy_0[j] + fr * tg_yzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_y_1[j];

                    tg_xyzzzzz_xz_0[j] = pb_x * tg_yzzzzz_xz_0[j] + fr * tg_yzzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_z_1[j];

                    tg_xyzzzzz_yy_0[j] = pb_x * tg_yzzzzz_yy_0[j] + fr * tg_yzzzzz_yy_1[j];

                    tg_xyzzzzz_yz_0[j] = pb_x * tg_yzzzzz_yz_0[j] + fr * tg_yzzzzz_yz_1[j];

                    tg_xyzzzzz_zz_0[j] = pb_x * tg_yzzzzz_zz_0[j] + fr * tg_yzzzzz_zz_1[j];

                    tg_xzzzzzz_xx_0[j] = pb_x * tg_zzzzzz_xx_0[j] + fr * tg_zzzzzz_xx_1[j] + fl1_fxn * tg_zzzzzz_x_1[j];

                    tg_xzzzzzz_xy_0[j] = pb_x * tg_zzzzzz_xy_0[j] + fr * tg_zzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_y_1[j];

                    tg_xzzzzzz_xz_0[j] = pb_x * tg_zzzzzz_xz_0[j] + fr * tg_zzzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_z_1[j];

                    tg_xzzzzzz_yy_0[j] = pb_x * tg_zzzzzz_yy_0[j] + fr * tg_zzzzzz_yy_1[j];

                    tg_xzzzzzz_yz_0[j] = pb_x * tg_zzzzzz_yz_0[j] + fr * tg_zzzzzz_yz_1[j];

                    tg_xzzzzzz_zz_0[j] = pb_x * tg_zzzzzz_zz_0[j] + fr * tg_zzzzzz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyyy_xx_0[j] = pb_y * tg_yyyyyy_xx_0[j] + fr * tg_yyyyyy_xx_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xx_0[j] - tg_yyyyy_xx_1[j] * fl1_fza);

                    tg_yyyyyyy_xy_0[j] = pb_y * tg_yyyyyy_xy_0[j] + fr * tg_yyyyyy_xy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xy_0[j] - tg_yyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_x_1[j];

                    tg_yyyyyyy_xz_0[j] = pb_y * tg_yyyyyy_xz_0[j] + fr * tg_yyyyyy_xz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xz_0[j] - tg_yyyyy_xz_1[j] * fl1_fza);

                    tg_yyyyyyy_yy_0[j] = pb_y * tg_yyyyyy_yy_0[j] + fr * tg_yyyyyy_yy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yy_0[j] - tg_yyyyy_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_y_1[j];

                    tg_yyyyyyy_yz_0[j] = pb_y * tg_yyyyyy_yz_0[j] + fr * tg_yyyyyy_yz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yz_0[j] - tg_yyyyy_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_z_1[j];

                    tg_yyyyyyy_zz_0[j] = pb_y * tg_yyyyyy_zz_0[j] + fr * tg_yyyyyy_zz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_zz_0[j] - tg_yyyyy_zz_1[j] * fl1_fza);

                    tg_yyyyyyz_xx_0[j] = pb_y * tg_yyyyyz_xx_0[j] + fr * tg_yyyyyz_xx_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xx_0[j] - tg_yyyyz_xx_1[j] * fl1_fza);

                    tg_yyyyyyz_xy_0[j] = pb_y * tg_yyyyyz_xy_0[j] + fr * tg_yyyyyz_xy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xy_0[j] - tg_yyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_x_1[j];

                    tg_yyyyyyz_xz_0[j] = pb_y * tg_yyyyyz_xz_0[j] + fr * tg_yyyyyz_xz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xz_0[j] - tg_yyyyz_xz_1[j] * fl1_fza);

                    tg_yyyyyyz_yy_0[j] = pb_y * tg_yyyyyz_yy_0[j] + fr * tg_yyyyyz_yy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yy_0[j] - tg_yyyyz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_y_1[j];

                    tg_yyyyyyz_yz_0[j] = pb_y * tg_yyyyyz_yz_0[j] + fr * tg_yyyyyz_yz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yz_0[j] - tg_yyyyz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_z_1[j];

                    tg_yyyyyyz_zz_0[j] = pb_y * tg_yyyyyz_zz_0[j] + fr * tg_yyyyyz_zz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_zz_0[j] - tg_yyyyz_zz_1[j] * fl1_fza);

                    tg_yyyyyzz_xx_0[j] = pb_y * tg_yyyyzz_xx_0[j] + fr * tg_yyyyzz_xx_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xx_0[j] - tg_yyyzz_xx_1[j] * fl1_fza);

                    tg_yyyyyzz_xy_0[j] = pb_y * tg_yyyyzz_xy_0[j] + fr * tg_yyyyzz_xy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xy_0[j] - tg_yyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_x_1[j];

                    tg_yyyyyzz_xz_0[j] = pb_y * tg_yyyyzz_xz_0[j] + fr * tg_yyyyzz_xz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xz_0[j] - tg_yyyzz_xz_1[j] * fl1_fza);

                    tg_yyyyyzz_yy_0[j] = pb_y * tg_yyyyzz_yy_0[j] + fr * tg_yyyyzz_yy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yy_0[j] - tg_yyyzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_y_1[j];

                    tg_yyyyyzz_yz_0[j] = pb_y * tg_yyyyzz_yz_0[j] + fr * tg_yyyyzz_yz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yz_0[j] - tg_yyyzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_z_1[j];

                    tg_yyyyyzz_zz_0[j] = pb_y * tg_yyyyzz_zz_0[j] + fr * tg_yyyyzz_zz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_zz_0[j] - tg_yyyzz_zz_1[j] * fl1_fza);

                    tg_yyyyzzz_xx_0[j] = pb_y * tg_yyyzzz_xx_0[j] + fr * tg_yyyzzz_xx_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xx_0[j] - tg_yyzzz_xx_1[j] * fl1_fza);

                    tg_yyyyzzz_xy_0[j] = pb_y * tg_yyyzzz_xy_0[j] + fr * tg_yyyzzz_xy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xy_0[j] - tg_yyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_x_1[j];

                    tg_yyyyzzz_xz_0[j] = pb_y * tg_yyyzzz_xz_0[j] + fr * tg_yyyzzz_xz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xz_0[j] - tg_yyzzz_xz_1[j] * fl1_fza);

                    tg_yyyyzzz_yy_0[j] = pb_y * tg_yyyzzz_yy_0[j] + fr * tg_yyyzzz_yy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yy_0[j] - tg_yyzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_y_1[j];

                    tg_yyyyzzz_yz_0[j] = pb_y * tg_yyyzzz_yz_0[j] + fr * tg_yyyzzz_yz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yz_0[j] - tg_yyzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_z_1[j];

                    tg_yyyyzzz_zz_0[j] = pb_y * tg_yyyzzz_zz_0[j] + fr * tg_yyyzzz_zz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_zz_0[j] - tg_yyzzz_zz_1[j] * fl1_fza);

                    tg_yyyzzzz_xx_0[j] = pb_y * tg_yyzzzz_xx_0[j] + fr * tg_yyzzzz_xx_1[j] + fl1_fx * (tg_yzzzz_xx_0[j] - tg_yzzzz_xx_1[j] * fl1_fza);

                    tg_yyyzzzz_xy_0[j] = pb_y * tg_yyzzzz_xy_0[j] + fr * tg_yyzzzz_xy_1[j] + fl1_fx * (tg_yzzzz_xy_0[j] - tg_yzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_x_1[j];

                    tg_yyyzzzz_xz_0[j] = pb_y * tg_yyzzzz_xz_0[j] + fr * tg_yyzzzz_xz_1[j] + fl1_fx * (tg_yzzzz_xz_0[j] - tg_yzzzz_xz_1[j] * fl1_fza);

                    tg_yyyzzzz_yy_0[j] = pb_y * tg_yyzzzz_yy_0[j] + fr * tg_yyzzzz_yy_1[j] + fl1_fx * (tg_yzzzz_yy_0[j] - tg_yzzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_y_1[j];

                    tg_yyyzzzz_yz_0[j] = pb_y * tg_yyzzzz_yz_0[j] + fr * tg_yyzzzz_yz_1[j] + fl1_fx * (tg_yzzzz_yz_0[j] - tg_yzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_z_1[j];

                    tg_yyyzzzz_zz_0[j] = pb_y * tg_yyzzzz_zz_0[j] + fr * tg_yyzzzz_zz_1[j] + fl1_fx * (tg_yzzzz_zz_0[j] - tg_yzzzz_zz_1[j] * fl1_fza);

                    tg_yyzzzzz_xx_0[j] = pb_y * tg_yzzzzz_xx_0[j] + fr * tg_yzzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xx_0[j] - tg_zzzzz_xx_1[j] * fl1_fza);

                    tg_yyzzzzz_xy_0[j] = pb_y * tg_yzzzzz_xy_0[j] + fr * tg_yzzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xy_0[j] - tg_zzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_x_1[j];

                    tg_yyzzzzz_xz_0[j] = pb_y * tg_yzzzzz_xz_0[j] + fr * tg_yzzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xz_0[j] - tg_zzzzz_xz_1[j] * fl1_fza);

                    tg_yyzzzzz_yy_0[j] = pb_y * tg_yzzzzz_yy_0[j] + fr * tg_yzzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yy_0[j] - tg_zzzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_y_1[j];

                    tg_yyzzzzz_yz_0[j] = pb_y * tg_yzzzzz_yz_0[j] + fr * tg_yzzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yz_0[j] - tg_zzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_z_1[j];

                    tg_yyzzzzz_zz_0[j] = pb_y * tg_yzzzzz_zz_0[j] + fr * tg_yzzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_zz_0[j] - tg_zzzzz_zz_1[j] * fl1_fza);

                    tg_yzzzzzz_xx_0[j] = pb_y * tg_zzzzzz_xx_0[j] + fr * tg_zzzzzz_xx_1[j];

                    tg_yzzzzzz_xy_0[j] = pb_y * tg_zzzzzz_xy_0[j] + fr * tg_zzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_x_1[j];

                    tg_yzzzzzz_xz_0[j] = pb_y * tg_zzzzzz_xz_0[j] + fr * tg_zzzzzz_xz_1[j];

                    tg_yzzzzzz_yy_0[j] = pb_y * tg_zzzzzz_yy_0[j] + fr * tg_zzzzzz_yy_1[j] + fl1_fxn * tg_zzzzzz_y_1[j];

                    tg_yzzzzzz_yz_0[j] = pb_y * tg_zzzzzz_yz_0[j] + fr * tg_zzzzzz_yz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_z_1[j];

                    tg_yzzzzzz_zz_0[j] = pb_y * tg_zzzzzz_zz_0[j] + fr * tg_zzzzzz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzzz_xx_0[j] = pb_z * tg_zzzzzz_xx_0[j] + fr * tg_zzzzzz_xx_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xx_0[j] - tg_zzzzz_xx_1[j] * fl1_fza);

                    tg_zzzzzzz_xy_0[j] = pb_z * tg_zzzzzz_xy_0[j] + fr * tg_zzzzzz_xy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xy_0[j] - tg_zzzzz_xy_1[j] * fl1_fza);

                    tg_zzzzzzz_xz_0[j] = pb_z * tg_zzzzzz_xz_0[j] + fr * tg_zzzzzz_xz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xz_0[j] - tg_zzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_x_1[j];

                    tg_zzzzzzz_yy_0[j] = pb_z * tg_zzzzzz_yy_0[j] + fr * tg_zzzzzz_yy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yy_0[j] - tg_zzzzz_yy_1[j] * fl1_fza);

                    tg_zzzzzzz_yz_0[j] = pb_z * tg_zzzzzz_yz_0[j] + fr * tg_zzzzzz_yz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yz_0[j] - tg_zzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_y_1[j];

                    tg_zzzzzzz_zz_0[j] = pb_z * tg_zzzzzz_zz_0[j] + fr * tg_zzzzzz_zz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_zz_0[j] - tg_zzzzz_zz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_z_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSL(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSDSL_0_90(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSDSL_90_180(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSDSL_180_270(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 
    }

    void
    compElectronRepulsionForSDSL_0_90(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,90)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_x_xxxxxxxx_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx); 

                auto tg_x_xxxxxxxy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 1); 

                auto tg_x_xxxxxxxz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 2); 

                auto tg_x_xxxxxxyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 3); 

                auto tg_x_xxxxxxyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 4); 

                auto tg_x_xxxxxxzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 5); 

                auto tg_x_xxxxxyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 6); 

                auto tg_x_xxxxxyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 7); 

                auto tg_x_xxxxxyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 8); 

                auto tg_x_xxxxxzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 9); 

                auto tg_x_xxxxyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 10); 

                auto tg_x_xxxxyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 11); 

                auto tg_x_xxxxyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 12); 

                auto tg_x_xxxxyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 13); 

                auto tg_x_xxxxzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 14); 

                auto tg_x_xxxyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 15); 

                auto tg_x_xxxyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 16); 

                auto tg_x_xxxyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 17); 

                auto tg_x_xxxyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 18); 

                auto tg_x_xxxyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 19); 

                auto tg_x_xxxzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 20); 

                auto tg_x_xxyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 21); 

                auto tg_x_xxyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 22); 

                auto tg_x_xxyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 23); 

                auto tg_x_xxyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 24); 

                auto tg_x_xxyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 25); 

                auto tg_x_xxyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 26); 

                auto tg_x_xxzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 27); 

                auto tg_x_xyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 28); 

                auto tg_x_xyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 29); 

                auto tg_x_xyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 30); 

                auto tg_x_xyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 31); 

                auto tg_x_xyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 32); 

                auto tg_x_xyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 33); 

                auto tg_x_xyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 34); 

                auto tg_x_xzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 35); 

                auto tg_x_yyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 36); 

                auto tg_x_yyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 37); 

                auto tg_x_yyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 38); 

                auto tg_x_yyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 39); 

                auto tg_x_yyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 40); 

                auto tg_x_yyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 41); 

                auto tg_x_yyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 42); 

                auto tg_x_yzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 43); 

                auto tg_x_zzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 44); 

                auto tg_y_xxxxxxxx_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 45); 

                auto tg_y_xxxxxxxy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 46); 

                auto tg_y_xxxxxxxz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 47); 

                auto tg_y_xxxxxxyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 48); 

                auto tg_y_xxxxxxyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 49); 

                auto tg_y_xxxxxxzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 50); 

                auto tg_y_xxxxxyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 51); 

                auto tg_y_xxxxxyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 52); 

                auto tg_y_xxxxxyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 53); 

                auto tg_y_xxxxxzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 54); 

                auto tg_y_xxxxyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 55); 

                auto tg_y_xxxxyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 56); 

                auto tg_y_xxxxyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 57); 

                auto tg_y_xxxxyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 58); 

                auto tg_y_xxxxzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 59); 

                auto tg_y_xxxyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 60); 

                auto tg_y_xxxyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 61); 

                auto tg_y_xxxyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 62); 

                auto tg_y_xxxyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 63); 

                auto tg_y_xxxyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 64); 

                auto tg_y_xxxzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 65); 

                auto tg_y_xxyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 66); 

                auto tg_y_xxyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 67); 

                auto tg_y_xxyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 68); 

                auto tg_y_xxyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 69); 

                auto tg_y_xxyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 70); 

                auto tg_y_xxyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 71); 

                auto tg_y_xxzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 72); 

                auto tg_y_xyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 73); 

                auto tg_y_xyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 74); 

                auto tg_y_xyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 75); 

                auto tg_y_xyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 76); 

                auto tg_y_xyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 77); 

                auto tg_y_xyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 78); 

                auto tg_y_xyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 79); 

                auto tg_y_xzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 80); 

                auto tg_y_yyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 81); 

                auto tg_y_yyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 82); 

                auto tg_y_yyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 83); 

                auto tg_y_yyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 84); 

                auto tg_y_yyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 85); 

                auto tg_y_yyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 86); 

                auto tg_y_yyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 87); 

                auto tg_y_yzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 88); 

                auto tg_y_zzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 89); 

                auto tg_x_xxxxxxxx_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx); 

                auto tg_x_xxxxxxxy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 1); 

                auto tg_x_xxxxxxxz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 2); 

                auto tg_x_xxxxxxyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 3); 

                auto tg_x_xxxxxxyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 4); 

                auto tg_x_xxxxxxzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 5); 

                auto tg_x_xxxxxyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 6); 

                auto tg_x_xxxxxyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 7); 

                auto tg_x_xxxxxyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 8); 

                auto tg_x_xxxxxzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 9); 

                auto tg_x_xxxxyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 10); 

                auto tg_x_xxxxyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 11); 

                auto tg_x_xxxxyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 12); 

                auto tg_x_xxxxyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 13); 

                auto tg_x_xxxxzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 14); 

                auto tg_x_xxxyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 15); 

                auto tg_x_xxxyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 16); 

                auto tg_x_xxxyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 17); 

                auto tg_x_xxxyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 18); 

                auto tg_x_xxxyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 19); 

                auto tg_x_xxxzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 20); 

                auto tg_x_xxyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 21); 

                auto tg_x_xxyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 22); 

                auto tg_x_xxyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 23); 

                auto tg_x_xxyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 24); 

                auto tg_x_xxyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 25); 

                auto tg_x_xxyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 26); 

                auto tg_x_xxzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 27); 

                auto tg_x_xyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 28); 

                auto tg_x_xyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 29); 

                auto tg_x_xyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 30); 

                auto tg_x_xyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 31); 

                auto tg_x_xyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 32); 

                auto tg_x_xyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 33); 

                auto tg_x_xyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 34); 

                auto tg_x_xzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 35); 

                auto tg_x_yyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 36); 

                auto tg_x_yyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 37); 

                auto tg_x_yyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 38); 

                auto tg_x_yyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 39); 

                auto tg_x_yyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 40); 

                auto tg_x_yyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 41); 

                auto tg_x_yyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 42); 

                auto tg_x_yzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 43); 

                auto tg_x_zzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 44); 

                auto tg_y_xxxxxxxx_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 45); 

                auto tg_y_xxxxxxxy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 46); 

                auto tg_y_xxxxxxxz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 47); 

                auto tg_y_xxxxxxyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 48); 

                auto tg_y_xxxxxxyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 49); 

                auto tg_y_xxxxxxzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 50); 

                auto tg_y_xxxxxyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 51); 

                auto tg_y_xxxxxyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 52); 

                auto tg_y_xxxxxyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 53); 

                auto tg_y_xxxxxzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 54); 

                auto tg_y_xxxxyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 55); 

                auto tg_y_xxxxyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 56); 

                auto tg_y_xxxxyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 57); 

                auto tg_y_xxxxyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 58); 

                auto tg_y_xxxxzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 59); 

                auto tg_y_xxxyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 60); 

                auto tg_y_xxxyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 61); 

                auto tg_y_xxxyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 62); 

                auto tg_y_xxxyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 63); 

                auto tg_y_xxxyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 64); 

                auto tg_y_xxxzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 65); 

                auto tg_y_xxyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 66); 

                auto tg_y_xxyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 67); 

                auto tg_y_xxyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 68); 

                auto tg_y_xxyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 69); 

                auto tg_y_xxyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 70); 

                auto tg_y_xxyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 71); 

                auto tg_y_xxzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 72); 

                auto tg_y_xyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 73); 

                auto tg_y_xyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 74); 

                auto tg_y_xyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 75); 

                auto tg_y_xyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 76); 

                auto tg_y_xyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 77); 

                auto tg_y_xyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 78); 

                auto tg_y_xyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 79); 

                auto tg_y_xzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 80); 

                auto tg_y_yyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 81); 

                auto tg_y_yyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 82); 

                auto tg_y_yyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 83); 

                auto tg_y_yyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 84); 

                auto tg_y_yyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 85); 

                auto tg_y_yyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 86); 

                auto tg_y_yyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 87); 

                auto tg_y_yzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 88); 

                auto tg_y_zzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 89); 

                auto tg_0_xxxxxxxx_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx); 

                auto tg_0_xxxxxxxy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 44); 

                auto tg_0_xxxxxxxx_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx); 

                auto tg_0_xxxxxxxy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 44); 

                auto tg_x_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx); 

                auto tg_x_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 1); 

                auto tg_x_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 2); 

                auto tg_x_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 3); 

                auto tg_x_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 4); 

                auto tg_x_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 5); 

                auto tg_x_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 6); 

                auto tg_x_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 7); 

                auto tg_x_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 8); 

                auto tg_x_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 9); 

                auto tg_x_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 10); 

                auto tg_x_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 11); 

                auto tg_x_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 12); 

                auto tg_x_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 13); 

                auto tg_x_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 14); 

                auto tg_x_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 15); 

                auto tg_x_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 16); 

                auto tg_x_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 17); 

                auto tg_x_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 18); 

                auto tg_x_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 19); 

                auto tg_x_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 20); 

                auto tg_x_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 21); 

                auto tg_x_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 22); 

                auto tg_x_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 23); 

                auto tg_x_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 24); 

                auto tg_x_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 25); 

                auto tg_x_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 26); 

                auto tg_x_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 27); 

                auto tg_x_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 28); 

                auto tg_x_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 29); 

                auto tg_x_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 30); 

                auto tg_x_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 31); 

                auto tg_x_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 32); 

                auto tg_x_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 33); 

                auto tg_x_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 34); 

                auto tg_x_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 35); 

                auto tg_y_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 71); 

                // set up pointers to integrals

                auto tg_xx_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx); 

                auto tg_xx_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 1); 

                auto tg_xx_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 2); 

                auto tg_xx_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 3); 

                auto tg_xx_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 4); 

                auto tg_xx_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 5); 

                auto tg_xx_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 6); 

                auto tg_xx_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 7); 

                auto tg_xx_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 8); 

                auto tg_xx_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 9); 

                auto tg_xx_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 10); 

                auto tg_xx_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 11); 

                auto tg_xx_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 12); 

                auto tg_xx_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 13); 

                auto tg_xx_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 14); 

                auto tg_xx_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 15); 

                auto tg_xx_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 16); 

                auto tg_xx_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 17); 

                auto tg_xx_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 18); 

                auto tg_xx_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 19); 

                auto tg_xx_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 20); 

                auto tg_xx_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 21); 

                auto tg_xx_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 22); 

                auto tg_xx_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 23); 

                auto tg_xx_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 24); 

                auto tg_xx_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 25); 

                auto tg_xx_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 26); 

                auto tg_xx_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 27); 

                auto tg_xx_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 28); 

                auto tg_xx_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 29); 

                auto tg_xx_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 30); 

                auto tg_xx_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 31); 

                auto tg_xx_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 32); 

                auto tg_xx_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 33); 

                auto tg_xx_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 34); 

                auto tg_xx_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 35); 

                auto tg_xx_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 36); 

                auto tg_xx_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 37); 

                auto tg_xx_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 38); 

                auto tg_xx_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 39); 

                auto tg_xx_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 40); 

                auto tg_xx_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 41); 

                auto tg_xx_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 42); 

                auto tg_xx_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 43); 

                auto tg_xx_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 44); 

                auto tg_xy_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 45); 

                auto tg_xy_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 46); 

                auto tg_xy_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 47); 

                auto tg_xy_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 48); 

                auto tg_xy_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 49); 

                auto tg_xy_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 50); 

                auto tg_xy_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 51); 

                auto tg_xy_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 52); 

                auto tg_xy_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 53); 

                auto tg_xy_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 54); 

                auto tg_xy_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 55); 

                auto tg_xy_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 56); 

                auto tg_xy_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 57); 

                auto tg_xy_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 58); 

                auto tg_xy_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 59); 

                auto tg_xy_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 60); 

                auto tg_xy_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 61); 

                auto tg_xy_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 62); 

                auto tg_xy_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 63); 

                auto tg_xy_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 64); 

                auto tg_xy_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 65); 

                auto tg_xy_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 66); 

                auto tg_xy_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 67); 

                auto tg_xy_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 68); 

                auto tg_xy_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 69); 

                auto tg_xy_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 70); 

                auto tg_xy_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 71); 

                auto tg_xy_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 72); 

                auto tg_xy_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 73); 

                auto tg_xy_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 74); 

                auto tg_xy_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 75); 

                auto tg_xy_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 76); 

                auto tg_xy_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 77); 

                auto tg_xy_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 78); 

                auto tg_xy_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 79); 

                auto tg_xy_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 80); 

                auto tg_xy_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 81); 

                auto tg_xy_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 82); 

                auto tg_xy_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 83); 

                auto tg_xy_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 84); 

                auto tg_xy_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 85); 

                auto tg_xy_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 86); 

                auto tg_xy_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 87); 

                auto tg_xy_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 88); 

                auto tg_xy_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 89); 

                // Batch of Integrals (0,90)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxxx_0, tg_0_xxxxxxxx_1, tg_0_xxxxxxxy_0, \
                                         tg_0_xxxxxxxy_1, tg_0_xxxxxxxz_0, tg_0_xxxxxxxz_1, tg_0_xxxxxxyy_0, tg_0_xxxxxxyy_1, \
                                         tg_0_xxxxxxyz_0, tg_0_xxxxxxyz_1, tg_0_xxxxxxzz_0, tg_0_xxxxxxzz_1, tg_0_xxxxxyyy_0, \
                                         tg_0_xxxxxyyy_1, tg_0_xxxxxyyz_0, tg_0_xxxxxyyz_1, tg_0_xxxxxyzz_0, tg_0_xxxxxyzz_1, \
                                         tg_0_xxxxxzzz_0, tg_0_xxxxxzzz_1, tg_0_xxxxyyyy_0, tg_0_xxxxyyyy_1, tg_0_xxxxyyyz_0, \
                                         tg_0_xxxxyyyz_1, tg_0_xxxxyyzz_0, tg_0_xxxxyyzz_1, tg_0_xxxxyzzz_0, tg_0_xxxxyzzz_1, \
                                         tg_0_xxxxzzzz_0, tg_0_xxxxzzzz_1, tg_0_xxxyyyyy_0, tg_0_xxxyyyyy_1, tg_0_xxxyyyyz_0, \
                                         tg_0_xxxyyyyz_1, tg_0_xxxyyyzz_0, tg_0_xxxyyyzz_1, tg_0_xxxyyzzz_0, tg_0_xxxyyzzz_1, \
                                         tg_0_xxxyzzzz_0, tg_0_xxxyzzzz_1, tg_0_xxxzzzzz_0, tg_0_xxxzzzzz_1, tg_0_xxyyyyyy_0, \
                                         tg_0_xxyyyyyy_1, tg_0_xxyyyyyz_0, tg_0_xxyyyyyz_1, tg_0_xxyyyyzz_0, tg_0_xxyyyyzz_1, \
                                         tg_0_xxyyyzzz_0, tg_0_xxyyyzzz_1, tg_0_xxyyzzzz_0, tg_0_xxyyzzzz_1, tg_0_xxyzzzzz_0, \
                                         tg_0_xxyzzzzz_1, tg_0_xxzzzzzz_0, tg_0_xxzzzzzz_1, tg_0_xyyyyyyy_0, tg_0_xyyyyyyy_1, \
                                         tg_0_xyyyyyyz_0, tg_0_xyyyyyyz_1, tg_0_xyyyyyzz_0, tg_0_xyyyyyzz_1, tg_0_xyyyyzzz_0, \
                                         tg_0_xyyyyzzz_1, tg_0_xyyyzzzz_0, tg_0_xyyyzzzz_1, tg_0_xyyzzzzz_0, tg_0_xyyzzzzz_1, \
                                         tg_0_xyzzzzzz_0, tg_0_xyzzzzzz_1, tg_0_xzzzzzzz_0, tg_0_xzzzzzzz_1, tg_0_yyyyyyyy_0, \
                                         tg_0_yyyyyyyy_1, tg_0_yyyyyyyz_0, tg_0_yyyyyyyz_1, tg_0_yyyyyyzz_0, tg_0_yyyyyyzz_1, \
                                         tg_0_yyyyyzzz_0, tg_0_yyyyyzzz_1, tg_0_yyyyzzzz_0, tg_0_yyyyzzzz_1, tg_0_yyyzzzzz_0, \
                                         tg_0_yyyzzzzz_1, tg_0_yyzzzzzz_0, tg_0_yyzzzzzz_1, tg_0_yzzzzzzz_0, tg_0_yzzzzzzz_1, \
                                         tg_0_zzzzzzzz_0, tg_0_zzzzzzzz_1, tg_x_xxxxxxx_1, tg_x_xxxxxxxx_0, tg_x_xxxxxxxx_1, \
                                         tg_x_xxxxxxxy_0, tg_x_xxxxxxxy_1, tg_x_xxxxxxxz_0, tg_x_xxxxxxxz_1, tg_x_xxxxxxy_1, \
                                         tg_x_xxxxxxyy_0, tg_x_xxxxxxyy_1, tg_x_xxxxxxyz_0, tg_x_xxxxxxyz_1, tg_x_xxxxxxz_1, \
                                         tg_x_xxxxxxzz_0, tg_x_xxxxxxzz_1, tg_x_xxxxxyy_1, tg_x_xxxxxyyy_0, tg_x_xxxxxyyy_1, \
                                         tg_x_xxxxxyyz_0, tg_x_xxxxxyyz_1, tg_x_xxxxxyz_1, tg_x_xxxxxyzz_0, tg_x_xxxxxyzz_1, \
                                         tg_x_xxxxxzz_1, tg_x_xxxxxzzz_0, tg_x_xxxxxzzz_1, tg_x_xxxxyyy_1, tg_x_xxxxyyyy_0, \
                                         tg_x_xxxxyyyy_1, tg_x_xxxxyyyz_0, tg_x_xxxxyyyz_1, tg_x_xxxxyyz_1, tg_x_xxxxyyzz_0, \
                                         tg_x_xxxxyyzz_1, tg_x_xxxxyzz_1, tg_x_xxxxyzzz_0, tg_x_xxxxyzzz_1, tg_x_xxxxzzz_1, \
                                         tg_x_xxxxzzzz_0, tg_x_xxxxzzzz_1, tg_x_xxxyyyy_1, tg_x_xxxyyyyy_0, tg_x_xxxyyyyy_1, \
                                         tg_x_xxxyyyyz_0, tg_x_xxxyyyyz_1, tg_x_xxxyyyz_1, tg_x_xxxyyyzz_0, tg_x_xxxyyyzz_1, \
                                         tg_x_xxxyyzz_1, tg_x_xxxyyzzz_0, tg_x_xxxyyzzz_1, tg_x_xxxyzzz_1, tg_x_xxxyzzzz_0, \
                                         tg_x_xxxyzzzz_1, tg_x_xxxzzzz_1, tg_x_xxxzzzzz_0, tg_x_xxxzzzzz_1, tg_x_xxyyyyy_1, \
                                         tg_x_xxyyyyyy_0, tg_x_xxyyyyyy_1, tg_x_xxyyyyyz_0, tg_x_xxyyyyyz_1, tg_x_xxyyyyz_1, \
                                         tg_x_xxyyyyzz_0, tg_x_xxyyyyzz_1, tg_x_xxyyyzz_1, tg_x_xxyyyzzz_0, tg_x_xxyyyzzz_1, \
                                         tg_x_xxyyzzz_1, tg_x_xxyyzzzz_0, tg_x_xxyyzzzz_1, tg_x_xxyzzzz_1, tg_x_xxyzzzzz_0, \
                                         tg_x_xxyzzzzz_1, tg_x_xxzzzzz_1, tg_x_xxzzzzzz_0, tg_x_xxzzzzzz_1, tg_x_xyyyyyy_1, \
                                         tg_x_xyyyyyyy_0, tg_x_xyyyyyyy_1, tg_x_xyyyyyyz_0, tg_x_xyyyyyyz_1, tg_x_xyyyyyz_1, \
                                         tg_x_xyyyyyzz_0, tg_x_xyyyyyzz_1, tg_x_xyyyyzz_1, tg_x_xyyyyzzz_0, tg_x_xyyyyzzz_1, \
                                         tg_x_xyyyzzz_1, tg_x_xyyyzzzz_0, tg_x_xyyyzzzz_1, tg_x_xyyzzzz_1, tg_x_xyyzzzzz_0, \
                                         tg_x_xyyzzzzz_1, tg_x_xyzzzzz_1, tg_x_xyzzzzzz_0, tg_x_xyzzzzzz_1, tg_x_xzzzzzz_1, \
                                         tg_x_xzzzzzzz_0, tg_x_xzzzzzzz_1, tg_x_yyyyyyy_1, tg_x_yyyyyyyy_0, tg_x_yyyyyyyy_1, \
                                         tg_x_yyyyyyyz_0, tg_x_yyyyyyyz_1, tg_x_yyyyyyz_1, tg_x_yyyyyyzz_0, tg_x_yyyyyyzz_1, \
                                         tg_x_yyyyyzz_1, tg_x_yyyyyzzz_0, tg_x_yyyyyzzz_1, tg_x_yyyyzzz_1, tg_x_yyyyzzzz_0, \
                                         tg_x_yyyyzzzz_1, tg_x_yyyzzzz_1, tg_x_yyyzzzzz_0, tg_x_yyyzzzzz_1, tg_x_yyzzzzz_1, \
                                         tg_x_yyzzzzzz_0, tg_x_yyzzzzzz_1, tg_x_yzzzzzz_1, tg_x_yzzzzzzz_0, tg_x_yzzzzzzz_1, \
                                         tg_x_zzzzzzz_1, tg_x_zzzzzzzz_0, tg_x_zzzzzzzz_1, tg_xx_xxxxxxxx_0, \
                                         tg_xx_xxxxxxxy_0, tg_xx_xxxxxxxz_0, tg_xx_xxxxxxyy_0, tg_xx_xxxxxxyz_0, \
                                         tg_xx_xxxxxxzz_0, tg_xx_xxxxxyyy_0, tg_xx_xxxxxyyz_0, tg_xx_xxxxxyzz_0, \
                                         tg_xx_xxxxxzzz_0, tg_xx_xxxxyyyy_0, tg_xx_xxxxyyyz_0, tg_xx_xxxxyyzz_0, \
                                         tg_xx_xxxxyzzz_0, tg_xx_xxxxzzzz_0, tg_xx_xxxyyyyy_0, tg_xx_xxxyyyyz_0, \
                                         tg_xx_xxxyyyzz_0, tg_xx_xxxyyzzz_0, tg_xx_xxxyzzzz_0, tg_xx_xxxzzzzz_0, \
                                         tg_xx_xxyyyyyy_0, tg_xx_xxyyyyyz_0, tg_xx_xxyyyyzz_0, tg_xx_xxyyyzzz_0, \
                                         tg_xx_xxyyzzzz_0, tg_xx_xxyzzzzz_0, tg_xx_xxzzzzzz_0, tg_xx_xyyyyyyy_0, \
                                         tg_xx_xyyyyyyz_0, tg_xx_xyyyyyzz_0, tg_xx_xyyyyzzz_0, tg_xx_xyyyzzzz_0, \
                                         tg_xx_xyyzzzzz_0, tg_xx_xyzzzzzz_0, tg_xx_xzzzzzzz_0, tg_xx_yyyyyyyy_0, \
                                         tg_xx_yyyyyyyz_0, tg_xx_yyyyyyzz_0, tg_xx_yyyyyzzz_0, tg_xx_yyyyzzzz_0, \
                                         tg_xx_yyyzzzzz_0, tg_xx_yyzzzzzz_0, tg_xx_yzzzzzzz_0, tg_xx_zzzzzzzz_0, \
                                         tg_xy_xxxxxxxx_0, tg_xy_xxxxxxxy_0, tg_xy_xxxxxxxz_0, tg_xy_xxxxxxyy_0, \
                                         tg_xy_xxxxxxyz_0, tg_xy_xxxxxxzz_0, tg_xy_xxxxxyyy_0, tg_xy_xxxxxyyz_0, \
                                         tg_xy_xxxxxyzz_0, tg_xy_xxxxxzzz_0, tg_xy_xxxxyyyy_0, tg_xy_xxxxyyyz_0, \
                                         tg_xy_xxxxyyzz_0, tg_xy_xxxxyzzz_0, tg_xy_xxxxzzzz_0, tg_xy_xxxyyyyy_0, \
                                         tg_xy_xxxyyyyz_0, tg_xy_xxxyyyzz_0, tg_xy_xxxyyzzz_0, tg_xy_xxxyzzzz_0, \
                                         tg_xy_xxxzzzzz_0, tg_xy_xxyyyyyy_0, tg_xy_xxyyyyyz_0, tg_xy_xxyyyyzz_0, \
                                         tg_xy_xxyyyzzz_0, tg_xy_xxyyzzzz_0, tg_xy_xxyzzzzz_0, tg_xy_xxzzzzzz_0, \
                                         tg_xy_xyyyyyyy_0, tg_xy_xyyyyyyz_0, tg_xy_xyyyyyzz_0, tg_xy_xyyyyzzz_0, \
                                         tg_xy_xyyyzzzz_0, tg_xy_xyyzzzzz_0, tg_xy_xyzzzzzz_0, tg_xy_xzzzzzzz_0, \
                                         tg_xy_yyyyyyyy_0, tg_xy_yyyyyyyz_0, tg_xy_yyyyyyzz_0, tg_xy_yyyyyzzz_0, \
                                         tg_xy_yyyyzzzz_0, tg_xy_yyyzzzzz_0, tg_xy_yyzzzzzz_0, tg_xy_yzzzzzzz_0, \
                                         tg_xy_zzzzzzzz_0, tg_y_xxxxxxx_1, tg_y_xxxxxxxx_0, tg_y_xxxxxxxx_1, tg_y_xxxxxxxy_0, \
                                         tg_y_xxxxxxxy_1, tg_y_xxxxxxxz_0, tg_y_xxxxxxxz_1, tg_y_xxxxxxy_1, tg_y_xxxxxxyy_0, \
                                         tg_y_xxxxxxyy_1, tg_y_xxxxxxyz_0, tg_y_xxxxxxyz_1, tg_y_xxxxxxz_1, tg_y_xxxxxxzz_0, \
                                         tg_y_xxxxxxzz_1, tg_y_xxxxxyy_1, tg_y_xxxxxyyy_0, tg_y_xxxxxyyy_1, tg_y_xxxxxyyz_0, \
                                         tg_y_xxxxxyyz_1, tg_y_xxxxxyz_1, tg_y_xxxxxyzz_0, tg_y_xxxxxyzz_1, tg_y_xxxxxzz_1, \
                                         tg_y_xxxxxzzz_0, tg_y_xxxxxzzz_1, tg_y_xxxxyyy_1, tg_y_xxxxyyyy_0, tg_y_xxxxyyyy_1, \
                                         tg_y_xxxxyyyz_0, tg_y_xxxxyyyz_1, tg_y_xxxxyyz_1, tg_y_xxxxyyzz_0, tg_y_xxxxyyzz_1, \
                                         tg_y_xxxxyzz_1, tg_y_xxxxyzzz_0, tg_y_xxxxyzzz_1, tg_y_xxxxzzz_1, tg_y_xxxxzzzz_0, \
                                         tg_y_xxxxzzzz_1, tg_y_xxxyyyy_1, tg_y_xxxyyyyy_0, tg_y_xxxyyyyy_1, tg_y_xxxyyyyz_0, \
                                         tg_y_xxxyyyyz_1, tg_y_xxxyyyz_1, tg_y_xxxyyyzz_0, tg_y_xxxyyyzz_1, tg_y_xxxyyzz_1, \
                                         tg_y_xxxyyzzz_0, tg_y_xxxyyzzz_1, tg_y_xxxyzzz_1, tg_y_xxxyzzzz_0, tg_y_xxxyzzzz_1, \
                                         tg_y_xxxzzzz_1, tg_y_xxxzzzzz_0, tg_y_xxxzzzzz_1, tg_y_xxyyyyy_1, tg_y_xxyyyyyy_0, \
                                         tg_y_xxyyyyyy_1, tg_y_xxyyyyyz_0, tg_y_xxyyyyyz_1, tg_y_xxyyyyz_1, tg_y_xxyyyyzz_0, \
                                         tg_y_xxyyyyzz_1, tg_y_xxyyyzz_1, tg_y_xxyyyzzz_0, tg_y_xxyyyzzz_1, tg_y_xxyyzzz_1, \
                                         tg_y_xxyyzzzz_0, tg_y_xxyyzzzz_1, tg_y_xxyzzzz_1, tg_y_xxyzzzzz_0, tg_y_xxyzzzzz_1, \
                                         tg_y_xxzzzzz_1, tg_y_xxzzzzzz_0, tg_y_xxzzzzzz_1, tg_y_xyyyyyy_1, tg_y_xyyyyyyy_0, \
                                         tg_y_xyyyyyyy_1, tg_y_xyyyyyyz_0, tg_y_xyyyyyyz_1, tg_y_xyyyyyz_1, tg_y_xyyyyyzz_0, \
                                         tg_y_xyyyyyzz_1, tg_y_xyyyyzz_1, tg_y_xyyyyzzz_0, tg_y_xyyyyzzz_1, tg_y_xyyyzzz_1, \
                                         tg_y_xyyyzzzz_0, tg_y_xyyyzzzz_1, tg_y_xyyzzzz_1, tg_y_xyyzzzzz_0, tg_y_xyyzzzzz_1, \
                                         tg_y_xyzzzzz_1, tg_y_xyzzzzzz_0, tg_y_xyzzzzzz_1, tg_y_xzzzzzz_1, tg_y_xzzzzzzz_0, \
                                         tg_y_xzzzzzzz_1, tg_y_yyyyyyy_1, tg_y_yyyyyyyy_0, tg_y_yyyyyyyy_1, tg_y_yyyyyyyz_0, \
                                         tg_y_yyyyyyyz_1, tg_y_yyyyyyz_1, tg_y_yyyyyyzz_0, tg_y_yyyyyyzz_1, tg_y_yyyyyzz_1, \
                                         tg_y_yyyyyzzz_0, tg_y_yyyyyzzz_1, tg_y_yyyyzzz_1, tg_y_yyyyzzzz_0, tg_y_yyyyzzzz_1, \
                                         tg_y_yyyzzzz_1, tg_y_yyyzzzzz_0, tg_y_yyyzzzzz_1, tg_y_yyzzzzz_1, tg_y_yyzzzzzz_0, \
                                         tg_y_yyzzzzzz_1, tg_y_yzzzzzz_1, tg_y_yzzzzzzz_0, tg_y_yzzzzzzz_1, tg_y_zzzzzzz_1, \
                                         tg_y_zzzzzzzz_0, tg_y_zzzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xx_xxxxxxxx_0[j] = pb_x * tg_x_xxxxxxxx_0[j] + fr * tg_x_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxx_0[j] - tg_0_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_x_xxxxxxx_1[j];

                    tg_xx_xxxxxxxy_0[j] = pb_x * tg_x_xxxxxxxy_0[j] + fr * tg_x_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxy_0[j] - tg_0_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_x_xxxxxxy_1[j];

                    tg_xx_xxxxxxxz_0[j] = pb_x * tg_x_xxxxxxxz_0[j] + fr * tg_x_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxz_0[j] - tg_0_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_x_xxxxxxz_1[j];

                    tg_xx_xxxxxxyy_0[j] = pb_x * tg_x_xxxxxxyy_0[j] + fr * tg_x_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyy_0[j] - tg_0_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxxyy_1[j];

                    tg_xx_xxxxxxyz_0[j] = pb_x * tg_x_xxxxxxyz_0[j] + fr * tg_x_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyz_0[j] - tg_0_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxxyz_1[j];

                    tg_xx_xxxxxxzz_0[j] = pb_x * tg_x_xxxxxxzz_0[j] + fr * tg_x_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxzz_0[j] - tg_0_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_x_xxxxxzz_1[j];

                    tg_xx_xxxxxyyy_0[j] = pb_x * tg_x_xxxxxyyy_0[j] + fr * tg_x_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyy_0[j] - tg_0_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxyyy_1[j];

                    tg_xx_xxxxxyyz_0[j] = pb_x * tg_x_xxxxxyyz_0[j] + fr * tg_x_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyz_0[j] - tg_0_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxyyz_1[j];

                    tg_xx_xxxxxyzz_0[j] = pb_x * tg_x_xxxxxyzz_0[j] + fr * tg_x_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyzz_0[j] - tg_0_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxyzz_1[j];

                    tg_xx_xxxxxzzz_0[j] = pb_x * tg_x_xxxxxzzz_0[j] + fr * tg_x_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzzz_0[j] - tg_0_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_x_xxxxzzz_1[j];

                    tg_xx_xxxxyyyy_0[j] = pb_x * tg_x_xxxxyyyy_0[j] + fr * tg_x_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyy_0[j] - tg_0_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyyyy_1[j];

                    tg_xx_xxxxyyyz_0[j] = pb_x * tg_x_xxxxyyyz_0[j] + fr * tg_x_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyz_0[j] - tg_0_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyyyz_1[j];

                    tg_xx_xxxxyyzz_0[j] = pb_x * tg_x_xxxxyyzz_0[j] + fr * tg_x_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyzz_0[j] - tg_0_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyyzz_1[j];

                    tg_xx_xxxxyzzz_0[j] = pb_x * tg_x_xxxxyzzz_0[j] + fr * tg_x_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzzz_0[j] - tg_0_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxyzzz_1[j];

                    tg_xx_xxxxzzzz_0[j] = pb_x * tg_x_xxxxzzzz_0[j] + fr * tg_x_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzzz_0[j] - tg_0_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_x_xxxzzzz_1[j];

                    tg_xx_xxxyyyyy_0[j] = pb_x * tg_x_xxxyyyyy_0[j] + fr * tg_x_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyy_0[j] - tg_0_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyyyy_1[j];

                    tg_xx_xxxyyyyz_0[j] = pb_x * tg_x_xxxyyyyz_0[j] + fr * tg_x_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyz_0[j] - tg_0_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyyyz_1[j];

                    tg_xx_xxxyyyzz_0[j] = pb_x * tg_x_xxxyyyzz_0[j] + fr * tg_x_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyzz_0[j] - tg_0_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyyzz_1[j];

                    tg_xx_xxxyyzzz_0[j] = pb_x * tg_x_xxxyyzzz_0[j] + fr * tg_x_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzzz_0[j] - tg_0_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyyzzz_1[j];

                    tg_xx_xxxyzzzz_0[j] = pb_x * tg_x_xxxyzzzz_0[j] + fr * tg_x_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzzz_0[j] - tg_0_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxyzzzz_1[j];

                    tg_xx_xxxzzzzz_0[j] = pb_x * tg_x_xxxzzzzz_0[j] + fr * tg_x_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzzz_0[j] - tg_0_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_x_xxzzzzz_1[j];

                    tg_xx_xxyyyyyy_0[j] = pb_x * tg_x_xxyyyyyy_0[j] + fr * tg_x_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyy_0[j] - tg_0_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyyyy_1[j];

                    tg_xx_xxyyyyyz_0[j] = pb_x * tg_x_xxyyyyyz_0[j] + fr * tg_x_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyz_0[j] - tg_0_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyyyz_1[j];

                    tg_xx_xxyyyyzz_0[j] = pb_x * tg_x_xxyyyyzz_0[j] + fr * tg_x_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyzz_0[j] - tg_0_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyyzz_1[j];

                    tg_xx_xxyyyzzz_0[j] = pb_x * tg_x_xxyyyzzz_0[j] + fr * tg_x_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzzz_0[j] - tg_0_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyyzzz_1[j];

                    tg_xx_xxyyzzzz_0[j] = pb_x * tg_x_xxyyzzzz_0[j] + fr * tg_x_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzzz_0[j] - tg_0_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyyzzzz_1[j];

                    tg_xx_xxyzzzzz_0[j] = pb_x * tg_x_xxyzzzzz_0[j] + fr * tg_x_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzzz_0[j] - tg_0_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xyzzzzz_1[j];

                    tg_xx_xxzzzzzz_0[j] = pb_x * tg_x_xxzzzzzz_0[j] + fr * tg_x_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzzz_0[j] - tg_0_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_x_xzzzzzz_1[j];

                    tg_xx_xyyyyyyy_0[j] = pb_x * tg_x_xyyyyyyy_0[j] + fr * tg_x_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyy_0[j] - tg_0_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyyyy_1[j];

                    tg_xx_xyyyyyyz_0[j] = pb_x * tg_x_xyyyyyyz_0[j] + fr * tg_x_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyz_0[j] - tg_0_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyyyz_1[j];

                    tg_xx_xyyyyyzz_0[j] = pb_x * tg_x_xyyyyyzz_0[j] + fr * tg_x_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyzz_0[j] - tg_0_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyyzz_1[j];

                    tg_xx_xyyyyzzz_0[j] = pb_x * tg_x_xyyyyzzz_0[j] + fr * tg_x_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzzz_0[j] - tg_0_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyyzzz_1[j];

                    tg_xx_xyyyzzzz_0[j] = pb_x * tg_x_xyyyzzzz_0[j] + fr * tg_x_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzzz_0[j] - tg_0_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyyzzzz_1[j];

                    tg_xx_xyyzzzzz_0[j] = pb_x * tg_x_xyyzzzzz_0[j] + fr * tg_x_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzzz_0[j] - tg_0_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yyzzzzz_1[j];

                    tg_xx_xyzzzzzz_0[j] = pb_x * tg_x_xyzzzzzz_0[j] + fr * tg_x_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzzz_0[j] - tg_0_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_yzzzzzz_1[j];

                    tg_xx_xzzzzzzz_0[j] = pb_x * tg_x_xzzzzzzz_0[j] + fr * tg_x_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzzz_0[j] - tg_0_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_x_zzzzzzz_1[j];

                    tg_xx_yyyyyyyy_0[j] = pb_x * tg_x_yyyyyyyy_0[j] + fr * tg_x_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyy_0[j] - tg_0_yyyyyyyy_1[j] * fl1_fza);

                    tg_xx_yyyyyyyz_0[j] = pb_x * tg_x_yyyyyyyz_0[j] + fr * tg_x_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyz_0[j] - tg_0_yyyyyyyz_1[j] * fl1_fza);

                    tg_xx_yyyyyyzz_0[j] = pb_x * tg_x_yyyyyyzz_0[j] + fr * tg_x_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyzz_0[j] - tg_0_yyyyyyzz_1[j] * fl1_fza);

                    tg_xx_yyyyyzzz_0[j] = pb_x * tg_x_yyyyyzzz_0[j] + fr * tg_x_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzzz_0[j] - tg_0_yyyyyzzz_1[j] * fl1_fza);

                    tg_xx_yyyyzzzz_0[j] = pb_x * tg_x_yyyyzzzz_0[j] + fr * tg_x_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzzz_0[j] - tg_0_yyyyzzzz_1[j] * fl1_fza);

                    tg_xx_yyyzzzzz_0[j] = pb_x * tg_x_yyyzzzzz_0[j] + fr * tg_x_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzzz_0[j] - tg_0_yyyzzzzz_1[j] * fl1_fza);

                    tg_xx_yyzzzzzz_0[j] = pb_x * tg_x_yyzzzzzz_0[j] + fr * tg_x_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzzz_0[j] - tg_0_yyzzzzzz_1[j] * fl1_fza);

                    tg_xx_yzzzzzzz_0[j] = pb_x * tg_x_yzzzzzzz_0[j] + fr * tg_x_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzzz_0[j] - tg_0_yzzzzzzz_1[j] * fl1_fza);

                    tg_xx_zzzzzzzz_0[j] = pb_x * tg_x_zzzzzzzz_0[j] + fr * tg_x_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzzz_0[j] - tg_0_zzzzzzzz_1[j] * fl1_fza);

                    tg_xy_xxxxxxxx_0[j] = pb_x * tg_y_xxxxxxxx_0[j] + fr * tg_y_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_y_xxxxxxx_1[j];

                    tg_xy_xxxxxxxy_0[j] = pb_x * tg_y_xxxxxxxy_0[j] + fr * tg_y_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_y_xxxxxxy_1[j];

                    tg_xy_xxxxxxxz_0[j] = pb_x * tg_y_xxxxxxxz_0[j] + fr * tg_y_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_y_xxxxxxz_1[j];

                    tg_xy_xxxxxxyy_0[j] = pb_x * tg_y_xxxxxxyy_0[j] + fr * tg_y_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_y_xxxxxyy_1[j];

                    tg_xy_xxxxxxyz_0[j] = pb_x * tg_y_xxxxxxyz_0[j] + fr * tg_y_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_y_xxxxxyz_1[j];

                    tg_xy_xxxxxxzz_0[j] = pb_x * tg_y_xxxxxxzz_0[j] + fr * tg_y_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_y_xxxxxzz_1[j];

                    tg_xy_xxxxxyyy_0[j] = pb_x * tg_y_xxxxxyyy_0[j] + fr * tg_y_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_y_xxxxyyy_1[j];

                    tg_xy_xxxxxyyz_0[j] = pb_x * tg_y_xxxxxyyz_0[j] + fr * tg_y_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxyyz_1[j];

                    tg_xy_xxxxxyzz_0[j] = pb_x * tg_y_xxxxxyzz_0[j] + fr * tg_y_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxyzz_1[j];

                    tg_xy_xxxxxzzz_0[j] = pb_x * tg_y_xxxxxzzz_0[j] + fr * tg_y_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_y_xxxxzzz_1[j];

                    tg_xy_xxxxyyyy_0[j] = pb_x * tg_y_xxxxyyyy_0[j] + fr * tg_y_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_y_xxxyyyy_1[j];

                    tg_xy_xxxxyyyz_0[j] = pb_x * tg_y_xxxxyyyz_0[j] + fr * tg_y_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyyyz_1[j];

                    tg_xy_xxxxyyzz_0[j] = pb_x * tg_y_xxxxyyzz_0[j] + fr * tg_y_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyyzz_1[j];

                    tg_xy_xxxxyzzz_0[j] = pb_x * tg_y_xxxxyzzz_0[j] + fr * tg_y_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxyzzz_1[j];

                    tg_xy_xxxxzzzz_0[j] = pb_x * tg_y_xxxxzzzz_0[j] + fr * tg_y_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_y_xxxzzzz_1[j];

                    tg_xy_xxxyyyyy_0[j] = pb_x * tg_y_xxxyyyyy_0[j] + fr * tg_y_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_y_xxyyyyy_1[j];

                    tg_xy_xxxyyyyz_0[j] = pb_x * tg_y_xxxyyyyz_0[j] + fr * tg_y_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyyyz_1[j];

                    tg_xy_xxxyyyzz_0[j] = pb_x * tg_y_xxxyyyzz_0[j] + fr * tg_y_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyyzz_1[j];

                    tg_xy_xxxyyzzz_0[j] = pb_x * tg_y_xxxyyzzz_0[j] + fr * tg_y_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyyzzz_1[j];

                    tg_xy_xxxyzzzz_0[j] = pb_x * tg_y_xxxyzzzz_0[j] + fr * tg_y_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxyzzzz_1[j];

                    tg_xy_xxxzzzzz_0[j] = pb_x * tg_y_xxxzzzzz_0[j] + fr * tg_y_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_y_xxzzzzz_1[j];

                    tg_xy_xxyyyyyy_0[j] = pb_x * tg_y_xxyyyyyy_0[j] + fr * tg_y_xxyyyyyy_1[j] + fl1_fxn * tg_y_xyyyyyy_1[j];

                    tg_xy_xxyyyyyz_0[j] = pb_x * tg_y_xxyyyyyz_0[j] + fr * tg_y_xxyyyyyz_1[j] + fl1_fxn * tg_y_xyyyyyz_1[j];

                    tg_xy_xxyyyyzz_0[j] = pb_x * tg_y_xxyyyyzz_0[j] + fr * tg_y_xxyyyyzz_1[j] + fl1_fxn * tg_y_xyyyyzz_1[j];

                    tg_xy_xxyyyzzz_0[j] = pb_x * tg_y_xxyyyzzz_0[j] + fr * tg_y_xxyyyzzz_1[j] + fl1_fxn * tg_y_xyyyzzz_1[j];

                    tg_xy_xxyyzzzz_0[j] = pb_x * tg_y_xxyyzzzz_0[j] + fr * tg_y_xxyyzzzz_1[j] + fl1_fxn * tg_y_xyyzzzz_1[j];

                    tg_xy_xxyzzzzz_0[j] = pb_x * tg_y_xxyzzzzz_0[j] + fr * tg_y_xxyzzzzz_1[j] + fl1_fxn * tg_y_xyzzzzz_1[j];

                    tg_xy_xxzzzzzz_0[j] = pb_x * tg_y_xxzzzzzz_0[j] + fr * tg_y_xxzzzzzz_1[j] + fl1_fxn * tg_y_xzzzzzz_1[j];

                    tg_xy_xyyyyyyy_0[j] = pb_x * tg_y_xyyyyyyy_0[j] + fr * tg_y_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_y_yyyyyyy_1[j];

                    tg_xy_xyyyyyyz_0[j] = pb_x * tg_y_xyyyyyyz_0[j] + fr * tg_y_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyyyz_1[j];

                    tg_xy_xyyyyyzz_0[j] = pb_x * tg_y_xyyyyyzz_0[j] + fr * tg_y_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyyzz_1[j];

                    tg_xy_xyyyyzzz_0[j] = pb_x * tg_y_xyyyyzzz_0[j] + fr * tg_y_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyyzzz_1[j];

                    tg_xy_xyyyzzzz_0[j] = pb_x * tg_y_xyyyzzzz_0[j] + fr * tg_y_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyyzzzz_1[j];

                    tg_xy_xyyzzzzz_0[j] = pb_x * tg_y_xyyzzzzz_0[j] + fr * tg_y_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yyzzzzz_1[j];

                    tg_xy_xyzzzzzz_0[j] = pb_x * tg_y_xyzzzzzz_0[j] + fr * tg_y_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_yzzzzzz_1[j];

                    tg_xy_xzzzzzzz_0[j] = pb_x * tg_y_xzzzzzzz_0[j] + fr * tg_y_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_y_zzzzzzz_1[j];

                    tg_xy_yyyyyyyy_0[j] = pb_x * tg_y_yyyyyyyy_0[j] + fr * tg_y_yyyyyyyy_1[j];

                    tg_xy_yyyyyyyz_0[j] = pb_x * tg_y_yyyyyyyz_0[j] + fr * tg_y_yyyyyyyz_1[j];

                    tg_xy_yyyyyyzz_0[j] = pb_x * tg_y_yyyyyyzz_0[j] + fr * tg_y_yyyyyyzz_1[j];

                    tg_xy_yyyyyzzz_0[j] = pb_x * tg_y_yyyyyzzz_0[j] + fr * tg_y_yyyyyzzz_1[j];

                    tg_xy_yyyyzzzz_0[j] = pb_x * tg_y_yyyyzzzz_0[j] + fr * tg_y_yyyyzzzz_1[j];

                    tg_xy_yyyzzzzz_0[j] = pb_x * tg_y_yyyzzzzz_0[j] + fr * tg_y_yyyzzzzz_1[j];

                    tg_xy_yyzzzzzz_0[j] = pb_x * tg_y_yyzzzzzz_0[j] + fr * tg_y_yyzzzzzz_1[j];

                    tg_xy_yzzzzzzz_0[j] = pb_x * tg_y_yzzzzzzz_0[j] + fr * tg_y_yzzzzzzz_1[j];

                    tg_xy_zzzzzzzz_0[j] = pb_x * tg_y_zzzzzzzz_0[j] + fr * tg_y_zzzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSL_90_180(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (90,180)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_y_xxxxxxxx_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 45); 

                auto tg_y_xxxxxxxy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 46); 

                auto tg_y_xxxxxxxz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 47); 

                auto tg_y_xxxxxxyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 48); 

                auto tg_y_xxxxxxyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 49); 

                auto tg_y_xxxxxxzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 50); 

                auto tg_y_xxxxxyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 51); 

                auto tg_y_xxxxxyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 52); 

                auto tg_y_xxxxxyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 53); 

                auto tg_y_xxxxxzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 54); 

                auto tg_y_xxxxyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 55); 

                auto tg_y_xxxxyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 56); 

                auto tg_y_xxxxyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 57); 

                auto tg_y_xxxxyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 58); 

                auto tg_y_xxxxzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 59); 

                auto tg_y_xxxyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 60); 

                auto tg_y_xxxyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 61); 

                auto tg_y_xxxyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 62); 

                auto tg_y_xxxyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 63); 

                auto tg_y_xxxyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 64); 

                auto tg_y_xxxzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 65); 

                auto tg_y_xxyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 66); 

                auto tg_y_xxyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 67); 

                auto tg_y_xxyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 68); 

                auto tg_y_xxyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 69); 

                auto tg_y_xxyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 70); 

                auto tg_y_xxyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 71); 

                auto tg_y_xxzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 72); 

                auto tg_y_xyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 73); 

                auto tg_y_xyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 74); 

                auto tg_y_xyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 75); 

                auto tg_y_xyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 76); 

                auto tg_y_xyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 77); 

                auto tg_y_xyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 78); 

                auto tg_y_xyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 79); 

                auto tg_y_xzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 80); 

                auto tg_y_yyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 81); 

                auto tg_y_yyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 82); 

                auto tg_y_yyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 83); 

                auto tg_y_yyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 84); 

                auto tg_y_yyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 85); 

                auto tg_y_yyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 86); 

                auto tg_y_yyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 87); 

                auto tg_y_yzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 88); 

                auto tg_y_zzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 89); 

                auto tg_z_xxxxxxxx_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 90); 

                auto tg_z_xxxxxxxy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 91); 

                auto tg_z_xxxxxxxz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 92); 

                auto tg_z_xxxxxxyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 93); 

                auto tg_z_xxxxxxyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 94); 

                auto tg_z_xxxxxxzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 95); 

                auto tg_z_xxxxxyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 96); 

                auto tg_z_xxxxxyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 97); 

                auto tg_z_xxxxxyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 98); 

                auto tg_z_xxxxxzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 99); 

                auto tg_z_xxxxyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 100); 

                auto tg_z_xxxxyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 101); 

                auto tg_z_xxxxyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 102); 

                auto tg_z_xxxxyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 103); 

                auto tg_z_xxxxzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 104); 

                auto tg_z_xxxyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 105); 

                auto tg_z_xxxyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 106); 

                auto tg_z_xxxyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 107); 

                auto tg_z_xxxyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 108); 

                auto tg_z_xxxyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 109); 

                auto tg_z_xxxzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 110); 

                auto tg_z_xxyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 111); 

                auto tg_z_xxyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 112); 

                auto tg_z_xxyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 113); 

                auto tg_z_xxyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 114); 

                auto tg_z_xxyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 115); 

                auto tg_z_xxyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 116); 

                auto tg_z_xxzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 117); 

                auto tg_z_xyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 118); 

                auto tg_z_xyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 119); 

                auto tg_z_xyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 120); 

                auto tg_z_xyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 121); 

                auto tg_z_xyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 122); 

                auto tg_z_xyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 123); 

                auto tg_z_xyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 124); 

                auto tg_z_xzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 125); 

                auto tg_z_yyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 126); 

                auto tg_z_yyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 127); 

                auto tg_z_yyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 128); 

                auto tg_z_yyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 129); 

                auto tg_z_yyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 130); 

                auto tg_z_yyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 131); 

                auto tg_z_yyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 132); 

                auto tg_z_yzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 133); 

                auto tg_z_zzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 134); 

                auto tg_y_xxxxxxxx_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 45); 

                auto tg_y_xxxxxxxy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 46); 

                auto tg_y_xxxxxxxz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 47); 

                auto tg_y_xxxxxxyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 48); 

                auto tg_y_xxxxxxyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 49); 

                auto tg_y_xxxxxxzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 50); 

                auto tg_y_xxxxxyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 51); 

                auto tg_y_xxxxxyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 52); 

                auto tg_y_xxxxxyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 53); 

                auto tg_y_xxxxxzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 54); 

                auto tg_y_xxxxyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 55); 

                auto tg_y_xxxxyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 56); 

                auto tg_y_xxxxyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 57); 

                auto tg_y_xxxxyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 58); 

                auto tg_y_xxxxzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 59); 

                auto tg_y_xxxyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 60); 

                auto tg_y_xxxyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 61); 

                auto tg_y_xxxyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 62); 

                auto tg_y_xxxyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 63); 

                auto tg_y_xxxyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 64); 

                auto tg_y_xxxzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 65); 

                auto tg_y_xxyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 66); 

                auto tg_y_xxyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 67); 

                auto tg_y_xxyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 68); 

                auto tg_y_xxyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 69); 

                auto tg_y_xxyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 70); 

                auto tg_y_xxyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 71); 

                auto tg_y_xxzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 72); 

                auto tg_y_xyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 73); 

                auto tg_y_xyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 74); 

                auto tg_y_xyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 75); 

                auto tg_y_xyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 76); 

                auto tg_y_xyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 77); 

                auto tg_y_xyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 78); 

                auto tg_y_xyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 79); 

                auto tg_y_xzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 80); 

                auto tg_y_yyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 81); 

                auto tg_y_yyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 82); 

                auto tg_y_yyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 83); 

                auto tg_y_yyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 84); 

                auto tg_y_yyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 85); 

                auto tg_y_yyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 86); 

                auto tg_y_yyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 87); 

                auto tg_y_yzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 88); 

                auto tg_y_zzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 89); 

                auto tg_z_xxxxxxxx_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 90); 

                auto tg_z_xxxxxxxy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 91); 

                auto tg_z_xxxxxxxz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 92); 

                auto tg_z_xxxxxxyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 93); 

                auto tg_z_xxxxxxyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 94); 

                auto tg_z_xxxxxxzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 95); 

                auto tg_z_xxxxxyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 96); 

                auto tg_z_xxxxxyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 97); 

                auto tg_z_xxxxxyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 98); 

                auto tg_z_xxxxxzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 99); 

                auto tg_z_xxxxyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 100); 

                auto tg_z_xxxxyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 101); 

                auto tg_z_xxxxyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 102); 

                auto tg_z_xxxxyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 103); 

                auto tg_z_xxxxzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 104); 

                auto tg_z_xxxyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 105); 

                auto tg_z_xxxyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 106); 

                auto tg_z_xxxyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 107); 

                auto tg_z_xxxyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 108); 

                auto tg_z_xxxyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 109); 

                auto tg_z_xxxzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 110); 

                auto tg_z_xxyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 111); 

                auto tg_z_xxyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 112); 

                auto tg_z_xxyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 113); 

                auto tg_z_xxyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 114); 

                auto tg_z_xxyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 115); 

                auto tg_z_xxyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 116); 

                auto tg_z_xxzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 117); 

                auto tg_z_xyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 118); 

                auto tg_z_xyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 119); 

                auto tg_z_xyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 120); 

                auto tg_z_xyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 121); 

                auto tg_z_xyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 122); 

                auto tg_z_xyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 123); 

                auto tg_z_xyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 124); 

                auto tg_z_xzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 125); 

                auto tg_z_yyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 126); 

                auto tg_z_yyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 127); 

                auto tg_z_yyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 128); 

                auto tg_z_yyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 129); 

                auto tg_z_yyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 130); 

                auto tg_z_yyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 131); 

                auto tg_z_yyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 132); 

                auto tg_z_yzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 133); 

                auto tg_z_zzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 134); 

                auto tg_0_xxxxxxxx_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx); 

                auto tg_0_xxxxxxxy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 44); 

                auto tg_0_xxxxxxxx_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx); 

                auto tg_0_xxxxxxxy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 44); 

                auto tg_y_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 36); 

                auto tg_y_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 37); 

                auto tg_y_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 38); 

                auto tg_y_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 39); 

                auto tg_y_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 40); 

                auto tg_y_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 41); 

                auto tg_y_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 42); 

                auto tg_y_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 43); 

                auto tg_y_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 44); 

                auto tg_y_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 45); 

                auto tg_y_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 46); 

                auto tg_y_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 47); 

                auto tg_y_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 48); 

                auto tg_y_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 49); 

                auto tg_y_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 50); 

                auto tg_y_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 51); 

                auto tg_y_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 52); 

                auto tg_y_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 53); 

                auto tg_y_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 54); 

                auto tg_y_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 55); 

                auto tg_y_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 56); 

                auto tg_y_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 57); 

                auto tg_y_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 58); 

                auto tg_y_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 59); 

                auto tg_y_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 60); 

                auto tg_y_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 61); 

                auto tg_y_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 62); 

                auto tg_y_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 63); 

                auto tg_y_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 64); 

                auto tg_y_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 65); 

                auto tg_y_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 66); 

                auto tg_y_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 67); 

                auto tg_y_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 68); 

                auto tg_y_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 69); 

                auto tg_y_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 70); 

                auto tg_y_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 71); 

                auto tg_z_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 107); 

                // set up pointers to integrals

                auto tg_xz_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 90); 

                auto tg_xz_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 91); 

                auto tg_xz_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 92); 

                auto tg_xz_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 93); 

                auto tg_xz_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 94); 

                auto tg_xz_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 95); 

                auto tg_xz_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 96); 

                auto tg_xz_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 97); 

                auto tg_xz_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 98); 

                auto tg_xz_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 99); 

                auto tg_xz_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 100); 

                auto tg_xz_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 101); 

                auto tg_xz_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 102); 

                auto tg_xz_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 103); 

                auto tg_xz_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 104); 

                auto tg_xz_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 105); 

                auto tg_xz_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 106); 

                auto tg_xz_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 107); 

                auto tg_xz_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 108); 

                auto tg_xz_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 109); 

                auto tg_xz_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 110); 

                auto tg_xz_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 111); 

                auto tg_xz_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 112); 

                auto tg_xz_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 113); 

                auto tg_xz_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 114); 

                auto tg_xz_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 115); 

                auto tg_xz_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 116); 

                auto tg_xz_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 117); 

                auto tg_xz_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 118); 

                auto tg_xz_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 119); 

                auto tg_xz_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 120); 

                auto tg_xz_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 121); 

                auto tg_xz_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 122); 

                auto tg_xz_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 123); 

                auto tg_xz_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 124); 

                auto tg_xz_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 125); 

                auto tg_xz_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 126); 

                auto tg_xz_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 127); 

                auto tg_xz_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 128); 

                auto tg_xz_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 129); 

                auto tg_xz_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 130); 

                auto tg_xz_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 131); 

                auto tg_xz_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 132); 

                auto tg_xz_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 133); 

                auto tg_xz_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 134); 

                auto tg_yy_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 135); 

                auto tg_yy_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 136); 

                auto tg_yy_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 137); 

                auto tg_yy_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 138); 

                auto tg_yy_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 139); 

                auto tg_yy_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 140); 

                auto tg_yy_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 141); 

                auto tg_yy_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 142); 

                auto tg_yy_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 143); 

                auto tg_yy_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 144); 

                auto tg_yy_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 145); 

                auto tg_yy_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 146); 

                auto tg_yy_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 147); 

                auto tg_yy_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 148); 

                auto tg_yy_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 149); 

                auto tg_yy_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 150); 

                auto tg_yy_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 151); 

                auto tg_yy_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 152); 

                auto tg_yy_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 153); 

                auto tg_yy_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 154); 

                auto tg_yy_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 155); 

                auto tg_yy_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 156); 

                auto tg_yy_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 157); 

                auto tg_yy_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 158); 

                auto tg_yy_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 159); 

                auto tg_yy_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 160); 

                auto tg_yy_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 161); 

                auto tg_yy_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 162); 

                auto tg_yy_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 163); 

                auto tg_yy_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 164); 

                auto tg_yy_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 165); 

                auto tg_yy_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 166); 

                auto tg_yy_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 167); 

                auto tg_yy_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 168); 

                auto tg_yy_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 169); 

                auto tg_yy_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 170); 

                auto tg_yy_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 171); 

                auto tg_yy_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 172); 

                auto tg_yy_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 173); 

                auto tg_yy_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 174); 

                auto tg_yy_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 175); 

                auto tg_yy_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 176); 

                auto tg_yy_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 177); 

                auto tg_yy_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 178); 

                auto tg_yy_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 179); 

                // Batch of Integrals (90,180)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxxx_0, tg_0_xxxxxxxx_1, tg_0_xxxxxxxy_0, \
                                         tg_0_xxxxxxxy_1, tg_0_xxxxxxxz_0, tg_0_xxxxxxxz_1, tg_0_xxxxxxyy_0, tg_0_xxxxxxyy_1, \
                                         tg_0_xxxxxxyz_0, tg_0_xxxxxxyz_1, tg_0_xxxxxxzz_0, tg_0_xxxxxxzz_1, tg_0_xxxxxyyy_0, \
                                         tg_0_xxxxxyyy_1, tg_0_xxxxxyyz_0, tg_0_xxxxxyyz_1, tg_0_xxxxxyzz_0, tg_0_xxxxxyzz_1, \
                                         tg_0_xxxxxzzz_0, tg_0_xxxxxzzz_1, tg_0_xxxxyyyy_0, tg_0_xxxxyyyy_1, tg_0_xxxxyyyz_0, \
                                         tg_0_xxxxyyyz_1, tg_0_xxxxyyzz_0, tg_0_xxxxyyzz_1, tg_0_xxxxyzzz_0, tg_0_xxxxyzzz_1, \
                                         tg_0_xxxxzzzz_0, tg_0_xxxxzzzz_1, tg_0_xxxyyyyy_0, tg_0_xxxyyyyy_1, tg_0_xxxyyyyz_0, \
                                         tg_0_xxxyyyyz_1, tg_0_xxxyyyzz_0, tg_0_xxxyyyzz_1, tg_0_xxxyyzzz_0, tg_0_xxxyyzzz_1, \
                                         tg_0_xxxyzzzz_0, tg_0_xxxyzzzz_1, tg_0_xxxzzzzz_0, tg_0_xxxzzzzz_1, tg_0_xxyyyyyy_0, \
                                         tg_0_xxyyyyyy_1, tg_0_xxyyyyyz_0, tg_0_xxyyyyyz_1, tg_0_xxyyyyzz_0, tg_0_xxyyyyzz_1, \
                                         tg_0_xxyyyzzz_0, tg_0_xxyyyzzz_1, tg_0_xxyyzzzz_0, tg_0_xxyyzzzz_1, tg_0_xxyzzzzz_0, \
                                         tg_0_xxyzzzzz_1, tg_0_xxzzzzzz_0, tg_0_xxzzzzzz_1, tg_0_xyyyyyyy_0, tg_0_xyyyyyyy_1, \
                                         tg_0_xyyyyyyz_0, tg_0_xyyyyyyz_1, tg_0_xyyyyyzz_0, tg_0_xyyyyyzz_1, tg_0_xyyyyzzz_0, \
                                         tg_0_xyyyyzzz_1, tg_0_xyyyzzzz_0, tg_0_xyyyzzzz_1, tg_0_xyyzzzzz_0, tg_0_xyyzzzzz_1, \
                                         tg_0_xyzzzzzz_0, tg_0_xyzzzzzz_1, tg_0_xzzzzzzz_0, tg_0_xzzzzzzz_1, tg_0_yyyyyyyy_0, \
                                         tg_0_yyyyyyyy_1, tg_0_yyyyyyyz_0, tg_0_yyyyyyyz_1, tg_0_yyyyyyzz_0, tg_0_yyyyyyzz_1, \
                                         tg_0_yyyyyzzz_0, tg_0_yyyyyzzz_1, tg_0_yyyyzzzz_0, tg_0_yyyyzzzz_1, tg_0_yyyzzzzz_0, \
                                         tg_0_yyyzzzzz_1, tg_0_yyzzzzzz_0, tg_0_yyzzzzzz_1, tg_0_yzzzzzzz_0, tg_0_yzzzzzzz_1, \
                                         tg_0_zzzzzzzz_0, tg_0_zzzzzzzz_1, tg_xz_xxxxxxxx_0, tg_xz_xxxxxxxy_0, \
                                         tg_xz_xxxxxxxz_0, tg_xz_xxxxxxyy_0, tg_xz_xxxxxxyz_0, tg_xz_xxxxxxzz_0, \
                                         tg_xz_xxxxxyyy_0, tg_xz_xxxxxyyz_0, tg_xz_xxxxxyzz_0, tg_xz_xxxxxzzz_0, \
                                         tg_xz_xxxxyyyy_0, tg_xz_xxxxyyyz_0, tg_xz_xxxxyyzz_0, tg_xz_xxxxyzzz_0, \
                                         tg_xz_xxxxzzzz_0, tg_xz_xxxyyyyy_0, tg_xz_xxxyyyyz_0, tg_xz_xxxyyyzz_0, \
                                         tg_xz_xxxyyzzz_0, tg_xz_xxxyzzzz_0, tg_xz_xxxzzzzz_0, tg_xz_xxyyyyyy_0, \
                                         tg_xz_xxyyyyyz_0, tg_xz_xxyyyyzz_0, tg_xz_xxyyyzzz_0, tg_xz_xxyyzzzz_0, \
                                         tg_xz_xxyzzzzz_0, tg_xz_xxzzzzzz_0, tg_xz_xyyyyyyy_0, tg_xz_xyyyyyyz_0, \
                                         tg_xz_xyyyyyzz_0, tg_xz_xyyyyzzz_0, tg_xz_xyyyzzzz_0, tg_xz_xyyzzzzz_0, \
                                         tg_xz_xyzzzzzz_0, tg_xz_xzzzzzzz_0, tg_xz_yyyyyyyy_0, tg_xz_yyyyyyyz_0, \
                                         tg_xz_yyyyyyzz_0, tg_xz_yyyyyzzz_0, tg_xz_yyyyzzzz_0, tg_xz_yyyzzzzz_0, \
                                         tg_xz_yyzzzzzz_0, tg_xz_yzzzzzzz_0, tg_xz_zzzzzzzz_0, tg_y_xxxxxxx_1, \
                                         tg_y_xxxxxxxx_0, tg_y_xxxxxxxx_1, tg_y_xxxxxxxy_0, tg_y_xxxxxxxy_1, tg_y_xxxxxxxz_0, \
                                         tg_y_xxxxxxxz_1, tg_y_xxxxxxy_1, tg_y_xxxxxxyy_0, tg_y_xxxxxxyy_1, tg_y_xxxxxxyz_0, \
                                         tg_y_xxxxxxyz_1, tg_y_xxxxxxz_1, tg_y_xxxxxxzz_0, tg_y_xxxxxxzz_1, tg_y_xxxxxyy_1, \
                                         tg_y_xxxxxyyy_0, tg_y_xxxxxyyy_1, tg_y_xxxxxyyz_0, tg_y_xxxxxyyz_1, tg_y_xxxxxyz_1, \
                                         tg_y_xxxxxyzz_0, tg_y_xxxxxyzz_1, tg_y_xxxxxzz_1, tg_y_xxxxxzzz_0, tg_y_xxxxxzzz_1, \
                                         tg_y_xxxxyyy_1, tg_y_xxxxyyyy_0, tg_y_xxxxyyyy_1, tg_y_xxxxyyyz_0, tg_y_xxxxyyyz_1, \
                                         tg_y_xxxxyyz_1, tg_y_xxxxyyzz_0, tg_y_xxxxyyzz_1, tg_y_xxxxyzz_1, tg_y_xxxxyzzz_0, \
                                         tg_y_xxxxyzzz_1, tg_y_xxxxzzz_1, tg_y_xxxxzzzz_0, tg_y_xxxxzzzz_1, tg_y_xxxyyyy_1, \
                                         tg_y_xxxyyyyy_0, tg_y_xxxyyyyy_1, tg_y_xxxyyyyz_0, tg_y_xxxyyyyz_1, tg_y_xxxyyyz_1, \
                                         tg_y_xxxyyyzz_0, tg_y_xxxyyyzz_1, tg_y_xxxyyzz_1, tg_y_xxxyyzzz_0, tg_y_xxxyyzzz_1, \
                                         tg_y_xxxyzzz_1, tg_y_xxxyzzzz_0, tg_y_xxxyzzzz_1, tg_y_xxxzzzz_1, tg_y_xxxzzzzz_0, \
                                         tg_y_xxxzzzzz_1, tg_y_xxyyyyy_1, tg_y_xxyyyyyy_0, tg_y_xxyyyyyy_1, tg_y_xxyyyyyz_0, \
                                         tg_y_xxyyyyyz_1, tg_y_xxyyyyz_1, tg_y_xxyyyyzz_0, tg_y_xxyyyyzz_1, tg_y_xxyyyzz_1, \
                                         tg_y_xxyyyzzz_0, tg_y_xxyyyzzz_1, tg_y_xxyyzzz_1, tg_y_xxyyzzzz_0, tg_y_xxyyzzzz_1, \
                                         tg_y_xxyzzzz_1, tg_y_xxyzzzzz_0, tg_y_xxyzzzzz_1, tg_y_xxzzzzz_1, tg_y_xxzzzzzz_0, \
                                         tg_y_xxzzzzzz_1, tg_y_xyyyyyy_1, tg_y_xyyyyyyy_0, tg_y_xyyyyyyy_1, tg_y_xyyyyyyz_0, \
                                         tg_y_xyyyyyyz_1, tg_y_xyyyyyz_1, tg_y_xyyyyyzz_0, tg_y_xyyyyyzz_1, tg_y_xyyyyzz_1, \
                                         tg_y_xyyyyzzz_0, tg_y_xyyyyzzz_1, tg_y_xyyyzzz_1, tg_y_xyyyzzzz_0, tg_y_xyyyzzzz_1, \
                                         tg_y_xyyzzzz_1, tg_y_xyyzzzzz_0, tg_y_xyyzzzzz_1, tg_y_xyzzzzz_1, tg_y_xyzzzzzz_0, \
                                         tg_y_xyzzzzzz_1, tg_y_xzzzzzz_1, tg_y_xzzzzzzz_0, tg_y_xzzzzzzz_1, tg_y_yyyyyyy_1, \
                                         tg_y_yyyyyyyy_0, tg_y_yyyyyyyy_1, tg_y_yyyyyyyz_0, tg_y_yyyyyyyz_1, tg_y_yyyyyyz_1, \
                                         tg_y_yyyyyyzz_0, tg_y_yyyyyyzz_1, tg_y_yyyyyzz_1, tg_y_yyyyyzzz_0, tg_y_yyyyyzzz_1, \
                                         tg_y_yyyyzzz_1, tg_y_yyyyzzzz_0, tg_y_yyyyzzzz_1, tg_y_yyyzzzz_1, tg_y_yyyzzzzz_0, \
                                         tg_y_yyyzzzzz_1, tg_y_yyzzzzz_1, tg_y_yyzzzzzz_0, tg_y_yyzzzzzz_1, tg_y_yzzzzzz_1, \
                                         tg_y_yzzzzzzz_0, tg_y_yzzzzzzz_1, tg_y_zzzzzzz_1, tg_y_zzzzzzzz_0, tg_y_zzzzzzzz_1, \
                                         tg_yy_xxxxxxxx_0, tg_yy_xxxxxxxy_0, tg_yy_xxxxxxxz_0, tg_yy_xxxxxxyy_0, \
                                         tg_yy_xxxxxxyz_0, tg_yy_xxxxxxzz_0, tg_yy_xxxxxyyy_0, tg_yy_xxxxxyyz_0, \
                                         tg_yy_xxxxxyzz_0, tg_yy_xxxxxzzz_0, tg_yy_xxxxyyyy_0, tg_yy_xxxxyyyz_0, \
                                         tg_yy_xxxxyyzz_0, tg_yy_xxxxyzzz_0, tg_yy_xxxxzzzz_0, tg_yy_xxxyyyyy_0, \
                                         tg_yy_xxxyyyyz_0, tg_yy_xxxyyyzz_0, tg_yy_xxxyyzzz_0, tg_yy_xxxyzzzz_0, \
                                         tg_yy_xxxzzzzz_0, tg_yy_xxyyyyyy_0, tg_yy_xxyyyyyz_0, tg_yy_xxyyyyzz_0, \
                                         tg_yy_xxyyyzzz_0, tg_yy_xxyyzzzz_0, tg_yy_xxyzzzzz_0, tg_yy_xxzzzzzz_0, \
                                         tg_yy_xyyyyyyy_0, tg_yy_xyyyyyyz_0, tg_yy_xyyyyyzz_0, tg_yy_xyyyyzzz_0, \
                                         tg_yy_xyyyzzzz_0, tg_yy_xyyzzzzz_0, tg_yy_xyzzzzzz_0, tg_yy_xzzzzzzz_0, \
                                         tg_yy_yyyyyyyy_0, tg_yy_yyyyyyyz_0, tg_yy_yyyyyyzz_0, tg_yy_yyyyyzzz_0, \
                                         tg_yy_yyyyzzzz_0, tg_yy_yyyzzzzz_0, tg_yy_yyzzzzzz_0, tg_yy_yzzzzzzz_0, \
                                         tg_yy_zzzzzzzz_0, tg_z_xxxxxxx_1, tg_z_xxxxxxxx_0, tg_z_xxxxxxxx_1, tg_z_xxxxxxxy_0, \
                                         tg_z_xxxxxxxy_1, tg_z_xxxxxxxz_0, tg_z_xxxxxxxz_1, tg_z_xxxxxxy_1, tg_z_xxxxxxyy_0, \
                                         tg_z_xxxxxxyy_1, tg_z_xxxxxxyz_0, tg_z_xxxxxxyz_1, tg_z_xxxxxxz_1, tg_z_xxxxxxzz_0, \
                                         tg_z_xxxxxxzz_1, tg_z_xxxxxyy_1, tg_z_xxxxxyyy_0, tg_z_xxxxxyyy_1, tg_z_xxxxxyyz_0, \
                                         tg_z_xxxxxyyz_1, tg_z_xxxxxyz_1, tg_z_xxxxxyzz_0, tg_z_xxxxxyzz_1, tg_z_xxxxxzz_1, \
                                         tg_z_xxxxxzzz_0, tg_z_xxxxxzzz_1, tg_z_xxxxyyy_1, tg_z_xxxxyyyy_0, tg_z_xxxxyyyy_1, \
                                         tg_z_xxxxyyyz_0, tg_z_xxxxyyyz_1, tg_z_xxxxyyz_1, tg_z_xxxxyyzz_0, tg_z_xxxxyyzz_1, \
                                         tg_z_xxxxyzz_1, tg_z_xxxxyzzz_0, tg_z_xxxxyzzz_1, tg_z_xxxxzzz_1, tg_z_xxxxzzzz_0, \
                                         tg_z_xxxxzzzz_1, tg_z_xxxyyyy_1, tg_z_xxxyyyyy_0, tg_z_xxxyyyyy_1, tg_z_xxxyyyyz_0, \
                                         tg_z_xxxyyyyz_1, tg_z_xxxyyyz_1, tg_z_xxxyyyzz_0, tg_z_xxxyyyzz_1, tg_z_xxxyyzz_1, \
                                         tg_z_xxxyyzzz_0, tg_z_xxxyyzzz_1, tg_z_xxxyzzz_1, tg_z_xxxyzzzz_0, tg_z_xxxyzzzz_1, \
                                         tg_z_xxxzzzz_1, tg_z_xxxzzzzz_0, tg_z_xxxzzzzz_1, tg_z_xxyyyyy_1, tg_z_xxyyyyyy_0, \
                                         tg_z_xxyyyyyy_1, tg_z_xxyyyyyz_0, tg_z_xxyyyyyz_1, tg_z_xxyyyyz_1, tg_z_xxyyyyzz_0, \
                                         tg_z_xxyyyyzz_1, tg_z_xxyyyzz_1, tg_z_xxyyyzzz_0, tg_z_xxyyyzzz_1, tg_z_xxyyzzz_1, \
                                         tg_z_xxyyzzzz_0, tg_z_xxyyzzzz_1, tg_z_xxyzzzz_1, tg_z_xxyzzzzz_0, tg_z_xxyzzzzz_1, \
                                         tg_z_xxzzzzz_1, tg_z_xxzzzzzz_0, tg_z_xxzzzzzz_1, tg_z_xyyyyyy_1, tg_z_xyyyyyyy_0, \
                                         tg_z_xyyyyyyy_1, tg_z_xyyyyyyz_0, tg_z_xyyyyyyz_1, tg_z_xyyyyyz_1, tg_z_xyyyyyzz_0, \
                                         tg_z_xyyyyyzz_1, tg_z_xyyyyzz_1, tg_z_xyyyyzzz_0, tg_z_xyyyyzzz_1, tg_z_xyyyzzz_1, \
                                         tg_z_xyyyzzzz_0, tg_z_xyyyzzzz_1, tg_z_xyyzzzz_1, tg_z_xyyzzzzz_0, tg_z_xyyzzzzz_1, \
                                         tg_z_xyzzzzz_1, tg_z_xyzzzzzz_0, tg_z_xyzzzzzz_1, tg_z_xzzzzzz_1, tg_z_xzzzzzzz_0, \
                                         tg_z_xzzzzzzz_1, tg_z_yyyyyyy_1, tg_z_yyyyyyyy_0, tg_z_yyyyyyyy_1, tg_z_yyyyyyyz_0, \
                                         tg_z_yyyyyyyz_1, tg_z_yyyyyyz_1, tg_z_yyyyyyzz_0, tg_z_yyyyyyzz_1, tg_z_yyyyyzz_1, \
                                         tg_z_yyyyyzzz_0, tg_z_yyyyyzzz_1, tg_z_yyyyzzz_1, tg_z_yyyyzzzz_0, tg_z_yyyyzzzz_1, \
                                         tg_z_yyyzzzz_1, tg_z_yyyzzzzz_0, tg_z_yyyzzzzz_1, tg_z_yyzzzzz_1, tg_z_yyzzzzzz_0, \
                                         tg_z_yyzzzzzz_1, tg_z_yzzzzzz_1, tg_z_yzzzzzzz_0, tg_z_yzzzzzzz_1, tg_z_zzzzzzz_1, \
                                         tg_z_zzzzzzzz_0, tg_z_zzzzzzzz_1, wp_x, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xz_xxxxxxxx_0[j] = pb_x * tg_z_xxxxxxxx_0[j] + fr * tg_z_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_z_xxxxxxx_1[j];

                    tg_xz_xxxxxxxy_0[j] = pb_x * tg_z_xxxxxxxy_0[j] + fr * tg_z_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_z_xxxxxxy_1[j];

                    tg_xz_xxxxxxxz_0[j] = pb_x * tg_z_xxxxxxxz_0[j] + fr * tg_z_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_z_xxxxxxz_1[j];

                    tg_xz_xxxxxxyy_0[j] = pb_x * tg_z_xxxxxxyy_0[j] + fr * tg_z_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_z_xxxxxyy_1[j];

                    tg_xz_xxxxxxyz_0[j] = pb_x * tg_z_xxxxxxyz_0[j] + fr * tg_z_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_z_xxxxxyz_1[j];

                    tg_xz_xxxxxxzz_0[j] = pb_x * tg_z_xxxxxxzz_0[j] + fr * tg_z_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_z_xxxxxzz_1[j];

                    tg_xz_xxxxxyyy_0[j] = pb_x * tg_z_xxxxxyyy_0[j] + fr * tg_z_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_z_xxxxyyy_1[j];

                    tg_xz_xxxxxyyz_0[j] = pb_x * tg_z_xxxxxyyz_0[j] + fr * tg_z_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxyyz_1[j];

                    tg_xz_xxxxxyzz_0[j] = pb_x * tg_z_xxxxxyzz_0[j] + fr * tg_z_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxyzz_1[j];

                    tg_xz_xxxxxzzz_0[j] = pb_x * tg_z_xxxxxzzz_0[j] + fr * tg_z_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_z_xxxxzzz_1[j];

                    tg_xz_xxxxyyyy_0[j] = pb_x * tg_z_xxxxyyyy_0[j] + fr * tg_z_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyyy_1[j];

                    tg_xz_xxxxyyyz_0[j] = pb_x * tg_z_xxxxyyyz_0[j] + fr * tg_z_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyyz_1[j];

                    tg_xz_xxxxyyzz_0[j] = pb_x * tg_z_xxxxyyzz_0[j] + fr * tg_z_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyzz_1[j];

                    tg_xz_xxxxyzzz_0[j] = pb_x * tg_z_xxxxyzzz_0[j] + fr * tg_z_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyzzz_1[j];

                    tg_xz_xxxxzzzz_0[j] = pb_x * tg_z_xxxxzzzz_0[j] + fr * tg_z_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_z_xxxzzzz_1[j];

                    tg_xz_xxxyyyyy_0[j] = pb_x * tg_z_xxxyyyyy_0[j] + fr * tg_z_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxyyyyy_1[j];

                    tg_xz_xxxyyyyz_0[j] = pb_x * tg_z_xxxyyyyz_0[j] + fr * tg_z_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyyyz_1[j];

                    tg_xz_xxxyyyzz_0[j] = pb_x * tg_z_xxxyyyzz_0[j] + fr * tg_z_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyyzz_1[j];

                    tg_xz_xxxyyzzz_0[j] = pb_x * tg_z_xxxyyzzz_0[j] + fr * tg_z_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyzzz_1[j];

                    tg_xz_xxxyzzzz_0[j] = pb_x * tg_z_xxxyzzzz_0[j] + fr * tg_z_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyzzzz_1[j];

                    tg_xz_xxxzzzzz_0[j] = pb_x * tg_z_xxxzzzzz_0[j] + fr * tg_z_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxzzzzz_1[j];

                    tg_xz_xxyyyyyy_0[j] = pb_x * tg_z_xxyyyyyy_0[j] + fr * tg_z_xxyyyyyy_1[j] + fl1_fxn * tg_z_xyyyyyy_1[j];

                    tg_xz_xxyyyyyz_0[j] = pb_x * tg_z_xxyyyyyz_0[j] + fr * tg_z_xxyyyyyz_1[j] + fl1_fxn * tg_z_xyyyyyz_1[j];

                    tg_xz_xxyyyyzz_0[j] = pb_x * tg_z_xxyyyyzz_0[j] + fr * tg_z_xxyyyyzz_1[j] + fl1_fxn * tg_z_xyyyyzz_1[j];

                    tg_xz_xxyyyzzz_0[j] = pb_x * tg_z_xxyyyzzz_0[j] + fr * tg_z_xxyyyzzz_1[j] + fl1_fxn * tg_z_xyyyzzz_1[j];

                    tg_xz_xxyyzzzz_0[j] = pb_x * tg_z_xxyyzzzz_0[j] + fr * tg_z_xxyyzzzz_1[j] + fl1_fxn * tg_z_xyyzzzz_1[j];

                    tg_xz_xxyzzzzz_0[j] = pb_x * tg_z_xxyzzzzz_0[j] + fr * tg_z_xxyzzzzz_1[j] + fl1_fxn * tg_z_xyzzzzz_1[j];

                    tg_xz_xxzzzzzz_0[j] = pb_x * tg_z_xxzzzzzz_0[j] + fr * tg_z_xxzzzzzz_1[j] + fl1_fxn * tg_z_xzzzzzz_1[j];

                    tg_xz_xyyyyyyy_0[j] = pb_x * tg_z_xyyyyyyy_0[j] + fr * tg_z_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_z_yyyyyyy_1[j];

                    tg_xz_xyyyyyyz_0[j] = pb_x * tg_z_xyyyyyyz_0[j] + fr * tg_z_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyyyz_1[j];

                    tg_xz_xyyyyyzz_0[j] = pb_x * tg_z_xyyyyyzz_0[j] + fr * tg_z_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyyzz_1[j];

                    tg_xz_xyyyyzzz_0[j] = pb_x * tg_z_xyyyyzzz_0[j] + fr * tg_z_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyyzzz_1[j];

                    tg_xz_xyyyzzzz_0[j] = pb_x * tg_z_xyyyzzzz_0[j] + fr * tg_z_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyyzzzz_1[j];

                    tg_xz_xyyzzzzz_0[j] = pb_x * tg_z_xyyzzzzz_0[j] + fr * tg_z_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yyzzzzz_1[j];

                    tg_xz_xyzzzzzz_0[j] = pb_x * tg_z_xyzzzzzz_0[j] + fr * tg_z_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_yzzzzzz_1[j];

                    tg_xz_xzzzzzzz_0[j] = pb_x * tg_z_xzzzzzzz_0[j] + fr * tg_z_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzzzz_1[j];

                    tg_xz_yyyyyyyy_0[j] = pb_x * tg_z_yyyyyyyy_0[j] + fr * tg_z_yyyyyyyy_1[j];

                    tg_xz_yyyyyyyz_0[j] = pb_x * tg_z_yyyyyyyz_0[j] + fr * tg_z_yyyyyyyz_1[j];

                    tg_xz_yyyyyyzz_0[j] = pb_x * tg_z_yyyyyyzz_0[j] + fr * tg_z_yyyyyyzz_1[j];

                    tg_xz_yyyyyzzz_0[j] = pb_x * tg_z_yyyyyzzz_0[j] + fr * tg_z_yyyyyzzz_1[j];

                    tg_xz_yyyyzzzz_0[j] = pb_x * tg_z_yyyyzzzz_0[j] + fr * tg_z_yyyyzzzz_1[j];

                    tg_xz_yyyzzzzz_0[j] = pb_x * tg_z_yyyzzzzz_0[j] + fr * tg_z_yyyzzzzz_1[j];

                    tg_xz_yyzzzzzz_0[j] = pb_x * tg_z_yyzzzzzz_0[j] + fr * tg_z_yyzzzzzz_1[j];

                    tg_xz_yzzzzzzz_0[j] = pb_x * tg_z_yzzzzzzz_0[j] + fr * tg_z_yzzzzzzz_1[j];

                    tg_xz_zzzzzzzz_0[j] = pb_x * tg_z_zzzzzzzz_0[j] + fr * tg_z_zzzzzzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yy_xxxxxxxx_0[j] = pb_y * tg_y_xxxxxxxx_0[j] + fr * tg_y_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxx_0[j] - tg_0_xxxxxxxx_1[j] * fl1_fza);

                    tg_yy_xxxxxxxy_0[j] = pb_y * tg_y_xxxxxxxy_0[j] + fr * tg_y_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxy_0[j] - tg_0_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxxxx_1[j];

                    tg_yy_xxxxxxxz_0[j] = pb_y * tg_y_xxxxxxxz_0[j] + fr * tg_y_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxz_0[j] - tg_0_xxxxxxxz_1[j] * fl1_fza);

                    tg_yy_xxxxxxyy_0[j] = pb_y * tg_y_xxxxxxyy_0[j] + fr * tg_y_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyy_0[j] - tg_0_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxxxy_1[j];

                    tg_yy_xxxxxxyz_0[j] = pb_y * tg_y_xxxxxxyz_0[j] + fr * tg_y_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyz_0[j] - tg_0_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxxxz_1[j];

                    tg_yy_xxxxxxzz_0[j] = pb_y * tg_y_xxxxxxzz_0[j] + fr * tg_y_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxzz_0[j] - tg_0_xxxxxxzz_1[j] * fl1_fza);

                    tg_yy_xxxxxyyy_0[j] = pb_y * tg_y_xxxxxyyy_0[j] + fr * tg_y_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyy_0[j] - tg_0_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxxxyy_1[j];

                    tg_yy_xxxxxyyz_0[j] = pb_y * tg_y_xxxxxyyz_0[j] + fr * tg_y_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyz_0[j] - tg_0_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxxyz_1[j];

                    tg_yy_xxxxxyzz_0[j] = pb_y * tg_y_xxxxxyzz_0[j] + fr * tg_y_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyzz_0[j] - tg_0_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxxzz_1[j];

                    tg_yy_xxxxxzzz_0[j] = pb_y * tg_y_xxxxxzzz_0[j] + fr * tg_y_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzzz_0[j] - tg_0_xxxxxzzz_1[j] * fl1_fza);

                    tg_yy_xxxxyyyy_0[j] = pb_y * tg_y_xxxxyyyy_0[j] + fr * tg_y_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyy_0[j] - tg_0_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxxxyyy_1[j];

                    tg_yy_xxxxyyyz_0[j] = pb_y * tg_y_xxxxyyyz_0[j] + fr * tg_y_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyz_0[j] - tg_0_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxxyyz_1[j];

                    tg_yy_xxxxyyzz_0[j] = pb_y * tg_y_xxxxyyzz_0[j] + fr * tg_y_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyzz_0[j] - tg_0_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxxyzz_1[j];

                    tg_yy_xxxxyzzz_0[j] = pb_y * tg_y_xxxxyzzz_0[j] + fr * tg_y_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzzz_0[j] - tg_0_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxxzzz_1[j];

                    tg_yy_xxxxzzzz_0[j] = pb_y * tg_y_xxxxzzzz_0[j] + fr * tg_y_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzzz_0[j] - tg_0_xxxxzzzz_1[j] * fl1_fza);

                    tg_yy_xxxyyyyy_0[j] = pb_y * tg_y_xxxyyyyy_0[j] + fr * tg_y_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyy_0[j] - tg_0_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xxxyyyy_1[j];

                    tg_yy_xxxyyyyz_0[j] = pb_y * tg_y_xxxyyyyz_0[j] + fr * tg_y_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyz_0[j] - tg_0_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxxyyyz_1[j];

                    tg_yy_xxxyyyzz_0[j] = pb_y * tg_y_xxxyyyzz_0[j] + fr * tg_y_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyzz_0[j] - tg_0_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxxyyzz_1[j];

                    tg_yy_xxxyyzzz_0[j] = pb_y * tg_y_xxxyyzzz_0[j] + fr * tg_y_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzzz_0[j] - tg_0_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxxyzzz_1[j];

                    tg_yy_xxxyzzzz_0[j] = pb_y * tg_y_xxxyzzzz_0[j] + fr * tg_y_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzzz_0[j] - tg_0_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxxzzzz_1[j];

                    tg_yy_xxxzzzzz_0[j] = pb_y * tg_y_xxxzzzzz_0[j] + fr * tg_y_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzzz_0[j] - tg_0_xxxzzzzz_1[j] * fl1_fza);

                    tg_yy_xxyyyyyy_0[j] = pb_y * tg_y_xxyyyyyy_0[j] + fr * tg_y_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyy_0[j] - tg_0_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_xxyyyyy_1[j];

                    tg_yy_xxyyyyyz_0[j] = pb_y * tg_y_xxyyyyyz_0[j] + fr * tg_y_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyz_0[j] - tg_0_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xxyyyyz_1[j];

                    tg_yy_xxyyyyzz_0[j] = pb_y * tg_y_xxyyyyzz_0[j] + fr * tg_y_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyzz_0[j] - tg_0_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xxyyyzz_1[j];

                    tg_yy_xxyyyzzz_0[j] = pb_y * tg_y_xxyyyzzz_0[j] + fr * tg_y_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzzz_0[j] - tg_0_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xxyyzzz_1[j];

                    tg_yy_xxyyzzzz_0[j] = pb_y * tg_y_xxyyzzzz_0[j] + fr * tg_y_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzzz_0[j] - tg_0_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xxyzzzz_1[j];

                    tg_yy_xxyzzzzz_0[j] = pb_y * tg_y_xxyzzzzz_0[j] + fr * tg_y_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzzz_0[j] - tg_0_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xxzzzzz_1[j];

                    tg_yy_xxzzzzzz_0[j] = pb_y * tg_y_xxzzzzzz_0[j] + fr * tg_y_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzzz_0[j] - tg_0_xxzzzzzz_1[j] * fl1_fza);

                    tg_yy_xyyyyyyy_0[j] = pb_y * tg_y_xyyyyyyy_0[j] + fr * tg_y_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyy_0[j] - tg_0_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_y_xyyyyyy_1[j];

                    tg_yy_xyyyyyyz_0[j] = pb_y * tg_y_xyyyyyyz_0[j] + fr * tg_y_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyz_0[j] - tg_0_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_xyyyyyz_1[j];

                    tg_yy_xyyyyyzz_0[j] = pb_y * tg_y_xyyyyyzz_0[j] + fr * tg_y_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyzz_0[j] - tg_0_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_xyyyyzz_1[j];

                    tg_yy_xyyyyzzz_0[j] = pb_y * tg_y_xyyyyzzz_0[j] + fr * tg_y_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzzz_0[j] - tg_0_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_xyyyzzz_1[j];

                    tg_yy_xyyyzzzz_0[j] = pb_y * tg_y_xyyyzzzz_0[j] + fr * tg_y_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzzz_0[j] - tg_0_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_xyyzzzz_1[j];

                    tg_yy_xyyzzzzz_0[j] = pb_y * tg_y_xyyzzzzz_0[j] + fr * tg_y_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzzz_0[j] - tg_0_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_xyzzzzz_1[j];

                    tg_yy_xyzzzzzz_0[j] = pb_y * tg_y_xyzzzzzz_0[j] + fr * tg_y_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzzz_0[j] - tg_0_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_xzzzzzz_1[j];

                    tg_yy_xzzzzzzz_0[j] = pb_y * tg_y_xzzzzzzz_0[j] + fr * tg_y_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzzz_0[j] - tg_0_xzzzzzzz_1[j] * fl1_fza);

                    tg_yy_yyyyyyyy_0[j] = pb_y * tg_y_yyyyyyyy_0[j] + fr * tg_y_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyy_0[j] - tg_0_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_y_yyyyyyy_1[j];

                    tg_yy_yyyyyyyz_0[j] = pb_y * tg_y_yyyyyyyz_0[j] + fr * tg_y_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyz_0[j] - tg_0_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_y_yyyyyyz_1[j];

                    tg_yy_yyyyyyzz_0[j] = pb_y * tg_y_yyyyyyzz_0[j] + fr * tg_y_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyzz_0[j] - tg_0_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_y_yyyyyzz_1[j];

                    tg_yy_yyyyyzzz_0[j] = pb_y * tg_y_yyyyyzzz_0[j] + fr * tg_y_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzzz_0[j] - tg_0_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_y_yyyyzzz_1[j];

                    tg_yy_yyyyzzzz_0[j] = pb_y * tg_y_yyyyzzzz_0[j] + fr * tg_y_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzzz_0[j] - tg_0_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_y_yyyzzzz_1[j];

                    tg_yy_yyyzzzzz_0[j] = pb_y * tg_y_yyyzzzzz_0[j] + fr * tg_y_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzzz_0[j] - tg_0_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_y_yyzzzzz_1[j];

                    tg_yy_yyzzzzzz_0[j] = pb_y * tg_y_yyzzzzzz_0[j] + fr * tg_y_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzzz_0[j] - tg_0_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_y_yzzzzzz_1[j];

                    tg_yy_yzzzzzzz_0[j] = pb_y * tg_y_yzzzzzzz_0[j] + fr * tg_y_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzzz_0[j] - tg_0_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_y_zzzzzzz_1[j];

                    tg_yy_zzzzzzzz_0[j] = pb_y * tg_y_zzzzzzzz_0[j] + fr * tg_y_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzzz_0[j] - tg_0_zzzzzzzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSDSL_180_270(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (180,270)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {2, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_2_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {2, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_2_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_1_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_1_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_1_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {1, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_0_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_0_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {0, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_z_xxxxxxxx_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 90); 

                auto tg_z_xxxxxxxy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 91); 

                auto tg_z_xxxxxxxz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 92); 

                auto tg_z_xxxxxxyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 93); 

                auto tg_z_xxxxxxyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 94); 

                auto tg_z_xxxxxxzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 95); 

                auto tg_z_xxxxxyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 96); 

                auto tg_z_xxxxxyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 97); 

                auto tg_z_xxxxxyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 98); 

                auto tg_z_xxxxxzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 99); 

                auto tg_z_xxxxyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 100); 

                auto tg_z_xxxxyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 101); 

                auto tg_z_xxxxyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 102); 

                auto tg_z_xxxxyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 103); 

                auto tg_z_xxxxzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 104); 

                auto tg_z_xxxyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 105); 

                auto tg_z_xxxyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 106); 

                auto tg_z_xxxyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 107); 

                auto tg_z_xxxyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 108); 

                auto tg_z_xxxyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 109); 

                auto tg_z_xxxzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 110); 

                auto tg_z_xxyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 111); 

                auto tg_z_xxyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 112); 

                auto tg_z_xxyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 113); 

                auto tg_z_xxyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 114); 

                auto tg_z_xxyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 115); 

                auto tg_z_xxyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 116); 

                auto tg_z_xxzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 117); 

                auto tg_z_xyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 118); 

                auto tg_z_xyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 119); 

                auto tg_z_xyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 120); 

                auto tg_z_xyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 121); 

                auto tg_z_xyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 122); 

                auto tg_z_xyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 123); 

                auto tg_z_xyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 124); 

                auto tg_z_xzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 125); 

                auto tg_z_yyyyyyyy_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 126); 

                auto tg_z_yyyyyyyz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 127); 

                auto tg_z_yyyyyyzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 128); 

                auto tg_z_yyyyyzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 129); 

                auto tg_z_yyyyzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 130); 

                auto tg_z_yyyzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 131); 

                auto tg_z_yyzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 132); 

                auto tg_z_yzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 133); 

                auto tg_z_zzzzzzzz_0 = primBuffer[pidx_g_1_8_m0].data(135 * idx + 134); 

                auto tg_z_xxxxxxxx_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 90); 

                auto tg_z_xxxxxxxy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 91); 

                auto tg_z_xxxxxxxz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 92); 

                auto tg_z_xxxxxxyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 93); 

                auto tg_z_xxxxxxyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 94); 

                auto tg_z_xxxxxxzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 95); 

                auto tg_z_xxxxxyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 96); 

                auto tg_z_xxxxxyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 97); 

                auto tg_z_xxxxxyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 98); 

                auto tg_z_xxxxxzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 99); 

                auto tg_z_xxxxyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 100); 

                auto tg_z_xxxxyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 101); 

                auto tg_z_xxxxyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 102); 

                auto tg_z_xxxxyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 103); 

                auto tg_z_xxxxzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 104); 

                auto tg_z_xxxyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 105); 

                auto tg_z_xxxyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 106); 

                auto tg_z_xxxyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 107); 

                auto tg_z_xxxyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 108); 

                auto tg_z_xxxyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 109); 

                auto tg_z_xxxzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 110); 

                auto tg_z_xxyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 111); 

                auto tg_z_xxyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 112); 

                auto tg_z_xxyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 113); 

                auto tg_z_xxyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 114); 

                auto tg_z_xxyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 115); 

                auto tg_z_xxyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 116); 

                auto tg_z_xxzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 117); 

                auto tg_z_xyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 118); 

                auto tg_z_xyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 119); 

                auto tg_z_xyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 120); 

                auto tg_z_xyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 121); 

                auto tg_z_xyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 122); 

                auto tg_z_xyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 123); 

                auto tg_z_xyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 124); 

                auto tg_z_xzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 125); 

                auto tg_z_yyyyyyyy_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 126); 

                auto tg_z_yyyyyyyz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 127); 

                auto tg_z_yyyyyyzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 128); 

                auto tg_z_yyyyyzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 129); 

                auto tg_z_yyyyzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 130); 

                auto tg_z_yyyzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 131); 

                auto tg_z_yyzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 132); 

                auto tg_z_yzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 133); 

                auto tg_z_zzzzzzzz_1 = primBuffer[pidx_g_1_8_m1].data(135 * idx + 134); 

                auto tg_0_xxxxxxxx_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx); 

                auto tg_0_xxxxxxxy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_0 = primBuffer[pidx_g_0_8_m0].data(45 * idx + 44); 

                auto tg_0_xxxxxxxx_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx); 

                auto tg_0_xxxxxxxy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 1); 

                auto tg_0_xxxxxxxz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 2); 

                auto tg_0_xxxxxxyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 3); 

                auto tg_0_xxxxxxyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 4); 

                auto tg_0_xxxxxxzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 5); 

                auto tg_0_xxxxxyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 6); 

                auto tg_0_xxxxxyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 7); 

                auto tg_0_xxxxxyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 8); 

                auto tg_0_xxxxxzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 9); 

                auto tg_0_xxxxyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 10); 

                auto tg_0_xxxxyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 11); 

                auto tg_0_xxxxyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 12); 

                auto tg_0_xxxxyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 13); 

                auto tg_0_xxxxzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 14); 

                auto tg_0_xxxyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 15); 

                auto tg_0_xxxyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 16); 

                auto tg_0_xxxyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 17); 

                auto tg_0_xxxyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 18); 

                auto tg_0_xxxyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 19); 

                auto tg_0_xxxzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 20); 

                auto tg_0_xxyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 21); 

                auto tg_0_xxyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 22); 

                auto tg_0_xxyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 23); 

                auto tg_0_xxyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 24); 

                auto tg_0_xxyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 25); 

                auto tg_0_xxyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 26); 

                auto tg_0_xxzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 27); 

                auto tg_0_xyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 28); 

                auto tg_0_xyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 29); 

                auto tg_0_xyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 30); 

                auto tg_0_xyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 31); 

                auto tg_0_xyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 32); 

                auto tg_0_xyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 33); 

                auto tg_0_xyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 34); 

                auto tg_0_xzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 35); 

                auto tg_0_yyyyyyyy_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 36); 

                auto tg_0_yyyyyyyz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 37); 

                auto tg_0_yyyyyyzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 38); 

                auto tg_0_yyyyyzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 39); 

                auto tg_0_yyyyzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 40); 

                auto tg_0_yyyzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 41); 

                auto tg_0_yyzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 42); 

                auto tg_0_yzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 43); 

                auto tg_0_zzzzzzzz_1 = primBuffer[pidx_g_0_8_m1].data(45 * idx + 44); 

                auto tg_z_xxxxxxx_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 72); 

                auto tg_z_xxxxxxy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 73); 

                auto tg_z_xxxxxxz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 74); 

                auto tg_z_xxxxxyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 75); 

                auto tg_z_xxxxxyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 76); 

                auto tg_z_xxxxxzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 77); 

                auto tg_z_xxxxyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 78); 

                auto tg_z_xxxxyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 79); 

                auto tg_z_xxxxyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 80); 

                auto tg_z_xxxxzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 81); 

                auto tg_z_xxxyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 82); 

                auto tg_z_xxxyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 83); 

                auto tg_z_xxxyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 84); 

                auto tg_z_xxxyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 85); 

                auto tg_z_xxxzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 86); 

                auto tg_z_xxyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 87); 

                auto tg_z_xxyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 88); 

                auto tg_z_xxyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 89); 

                auto tg_z_xxyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 90); 

                auto tg_z_xxyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 91); 

                auto tg_z_xxzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 92); 

                auto tg_z_xyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 93); 

                auto tg_z_xyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 94); 

                auto tg_z_xyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 95); 

                auto tg_z_xyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 96); 

                auto tg_z_xyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 97); 

                auto tg_z_xyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 98); 

                auto tg_z_xzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 99); 

                auto tg_z_yyyyyyy_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 100); 

                auto tg_z_yyyyyyz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 101); 

                auto tg_z_yyyyyzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 102); 

                auto tg_z_yyyyzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 103); 

                auto tg_z_yyyzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 104); 

                auto tg_z_yyzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 105); 

                auto tg_z_yzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 106); 

                auto tg_z_zzzzzzz_1 = primBuffer[pidx_g_1_7_m1].data(108 * idx + 107); 

                // set up pointers to integrals

                auto tg_yz_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 180); 

                auto tg_yz_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 181); 

                auto tg_yz_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 182); 

                auto tg_yz_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 183); 

                auto tg_yz_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 184); 

                auto tg_yz_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 185); 

                auto tg_yz_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 186); 

                auto tg_yz_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 187); 

                auto tg_yz_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 188); 

                auto tg_yz_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 189); 

                auto tg_yz_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 190); 

                auto tg_yz_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 191); 

                auto tg_yz_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 192); 

                auto tg_yz_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 193); 

                auto tg_yz_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 194); 

                auto tg_yz_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 195); 

                auto tg_yz_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 196); 

                auto tg_yz_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 197); 

                auto tg_yz_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 198); 

                auto tg_yz_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 199); 

                auto tg_yz_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 200); 

                auto tg_yz_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 201); 

                auto tg_yz_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 202); 

                auto tg_yz_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 203); 

                auto tg_yz_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 204); 

                auto tg_yz_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 205); 

                auto tg_yz_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 206); 

                auto tg_yz_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 207); 

                auto tg_yz_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 208); 

                auto tg_yz_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 209); 

                auto tg_yz_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 210); 

                auto tg_yz_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 211); 

                auto tg_yz_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 212); 

                auto tg_yz_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 213); 

                auto tg_yz_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 214); 

                auto tg_yz_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 215); 

                auto tg_yz_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 216); 

                auto tg_yz_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 217); 

                auto tg_yz_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 218); 

                auto tg_yz_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 219); 

                auto tg_yz_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 220); 

                auto tg_yz_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 221); 

                auto tg_yz_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 222); 

                auto tg_yz_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 223); 

                auto tg_yz_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 224); 

                auto tg_zz_xxxxxxxx_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 225); 

                auto tg_zz_xxxxxxxy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 226); 

                auto tg_zz_xxxxxxxz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 227); 

                auto tg_zz_xxxxxxyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 228); 

                auto tg_zz_xxxxxxyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 229); 

                auto tg_zz_xxxxxxzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 230); 

                auto tg_zz_xxxxxyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 231); 

                auto tg_zz_xxxxxyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 232); 

                auto tg_zz_xxxxxyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 233); 

                auto tg_zz_xxxxxzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 234); 

                auto tg_zz_xxxxyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 235); 

                auto tg_zz_xxxxyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 236); 

                auto tg_zz_xxxxyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 237); 

                auto tg_zz_xxxxyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 238); 

                auto tg_zz_xxxxzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 239); 

                auto tg_zz_xxxyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 240); 

                auto tg_zz_xxxyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 241); 

                auto tg_zz_xxxyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 242); 

                auto tg_zz_xxxyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 243); 

                auto tg_zz_xxxyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 244); 

                auto tg_zz_xxxzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 245); 

                auto tg_zz_xxyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 246); 

                auto tg_zz_xxyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 247); 

                auto tg_zz_xxyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 248); 

                auto tg_zz_xxyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 249); 

                auto tg_zz_xxyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 250); 

                auto tg_zz_xxyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 251); 

                auto tg_zz_xxzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 252); 

                auto tg_zz_xyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 253); 

                auto tg_zz_xyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 254); 

                auto tg_zz_xyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 255); 

                auto tg_zz_xyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 256); 

                auto tg_zz_xyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 257); 

                auto tg_zz_xyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 258); 

                auto tg_zz_xyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 259); 

                auto tg_zz_xzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 260); 

                auto tg_zz_yyyyyyyy_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 261); 

                auto tg_zz_yyyyyyyz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 262); 

                auto tg_zz_yyyyyyzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 263); 

                auto tg_zz_yyyyyzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 264); 

                auto tg_zz_yyyyzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 265); 

                auto tg_zz_yyyzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 266); 

                auto tg_zz_yyzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 267); 

                auto tg_zz_yzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 268); 

                auto tg_zz_zzzzzzzz_0 = primBuffer[pidx_g_2_8_m0].data(270 * idx + 269); 

                // Batch of Integrals (180,270)

                #pragma omp simd aligned(fxn, fza, tg_0_xxxxxxxx_0, tg_0_xxxxxxxx_1, tg_0_xxxxxxxy_0, \
                                         tg_0_xxxxxxxy_1, tg_0_xxxxxxxz_0, tg_0_xxxxxxxz_1, tg_0_xxxxxxyy_0, tg_0_xxxxxxyy_1, \
                                         tg_0_xxxxxxyz_0, tg_0_xxxxxxyz_1, tg_0_xxxxxxzz_0, tg_0_xxxxxxzz_1, tg_0_xxxxxyyy_0, \
                                         tg_0_xxxxxyyy_1, tg_0_xxxxxyyz_0, tg_0_xxxxxyyz_1, tg_0_xxxxxyzz_0, tg_0_xxxxxyzz_1, \
                                         tg_0_xxxxxzzz_0, tg_0_xxxxxzzz_1, tg_0_xxxxyyyy_0, tg_0_xxxxyyyy_1, tg_0_xxxxyyyz_0, \
                                         tg_0_xxxxyyyz_1, tg_0_xxxxyyzz_0, tg_0_xxxxyyzz_1, tg_0_xxxxyzzz_0, tg_0_xxxxyzzz_1, \
                                         tg_0_xxxxzzzz_0, tg_0_xxxxzzzz_1, tg_0_xxxyyyyy_0, tg_0_xxxyyyyy_1, tg_0_xxxyyyyz_0, \
                                         tg_0_xxxyyyyz_1, tg_0_xxxyyyzz_0, tg_0_xxxyyyzz_1, tg_0_xxxyyzzz_0, tg_0_xxxyyzzz_1, \
                                         tg_0_xxxyzzzz_0, tg_0_xxxyzzzz_1, tg_0_xxxzzzzz_0, tg_0_xxxzzzzz_1, tg_0_xxyyyyyy_0, \
                                         tg_0_xxyyyyyy_1, tg_0_xxyyyyyz_0, tg_0_xxyyyyyz_1, tg_0_xxyyyyzz_0, tg_0_xxyyyyzz_1, \
                                         tg_0_xxyyyzzz_0, tg_0_xxyyyzzz_1, tg_0_xxyyzzzz_0, tg_0_xxyyzzzz_1, tg_0_xxyzzzzz_0, \
                                         tg_0_xxyzzzzz_1, tg_0_xxzzzzzz_0, tg_0_xxzzzzzz_1, tg_0_xyyyyyyy_0, tg_0_xyyyyyyy_1, \
                                         tg_0_xyyyyyyz_0, tg_0_xyyyyyyz_1, tg_0_xyyyyyzz_0, tg_0_xyyyyyzz_1, tg_0_xyyyyzzz_0, \
                                         tg_0_xyyyyzzz_1, tg_0_xyyyzzzz_0, tg_0_xyyyzzzz_1, tg_0_xyyzzzzz_0, tg_0_xyyzzzzz_1, \
                                         tg_0_xyzzzzzz_0, tg_0_xyzzzzzz_1, tg_0_xzzzzzzz_0, tg_0_xzzzzzzz_1, tg_0_yyyyyyyy_0, \
                                         tg_0_yyyyyyyy_1, tg_0_yyyyyyyz_0, tg_0_yyyyyyyz_1, tg_0_yyyyyyzz_0, tg_0_yyyyyyzz_1, \
                                         tg_0_yyyyyzzz_0, tg_0_yyyyyzzz_1, tg_0_yyyyzzzz_0, tg_0_yyyyzzzz_1, tg_0_yyyzzzzz_0, \
                                         tg_0_yyyzzzzz_1, tg_0_yyzzzzzz_0, tg_0_yyzzzzzz_1, tg_0_yzzzzzzz_0, tg_0_yzzzzzzz_1, \
                                         tg_0_zzzzzzzz_0, tg_0_zzzzzzzz_1, tg_yz_xxxxxxxx_0, tg_yz_xxxxxxxy_0, \
                                         tg_yz_xxxxxxxz_0, tg_yz_xxxxxxyy_0, tg_yz_xxxxxxyz_0, tg_yz_xxxxxxzz_0, \
                                         tg_yz_xxxxxyyy_0, tg_yz_xxxxxyyz_0, tg_yz_xxxxxyzz_0, tg_yz_xxxxxzzz_0, \
                                         tg_yz_xxxxyyyy_0, tg_yz_xxxxyyyz_0, tg_yz_xxxxyyzz_0, tg_yz_xxxxyzzz_0, \
                                         tg_yz_xxxxzzzz_0, tg_yz_xxxyyyyy_0, tg_yz_xxxyyyyz_0, tg_yz_xxxyyyzz_0, \
                                         tg_yz_xxxyyzzz_0, tg_yz_xxxyzzzz_0, tg_yz_xxxzzzzz_0, tg_yz_xxyyyyyy_0, \
                                         tg_yz_xxyyyyyz_0, tg_yz_xxyyyyzz_0, tg_yz_xxyyyzzz_0, tg_yz_xxyyzzzz_0, \
                                         tg_yz_xxyzzzzz_0, tg_yz_xxzzzzzz_0, tg_yz_xyyyyyyy_0, tg_yz_xyyyyyyz_0, \
                                         tg_yz_xyyyyyzz_0, tg_yz_xyyyyzzz_0, tg_yz_xyyyzzzz_0, tg_yz_xyyzzzzz_0, \
                                         tg_yz_xyzzzzzz_0, tg_yz_xzzzzzzz_0, tg_yz_yyyyyyyy_0, tg_yz_yyyyyyyz_0, \
                                         tg_yz_yyyyyyzz_0, tg_yz_yyyyyzzz_0, tg_yz_yyyyzzzz_0, tg_yz_yyyzzzzz_0, \
                                         tg_yz_yyzzzzzz_0, tg_yz_yzzzzzzz_0, tg_yz_zzzzzzzz_0, tg_z_xxxxxxx_1, \
                                         tg_z_xxxxxxxx_0, tg_z_xxxxxxxx_1, tg_z_xxxxxxxy_0, tg_z_xxxxxxxy_1, tg_z_xxxxxxxz_0, \
                                         tg_z_xxxxxxxz_1, tg_z_xxxxxxy_1, tg_z_xxxxxxyy_0, tg_z_xxxxxxyy_1, tg_z_xxxxxxyz_0, \
                                         tg_z_xxxxxxyz_1, tg_z_xxxxxxz_1, tg_z_xxxxxxzz_0, tg_z_xxxxxxzz_1, tg_z_xxxxxyy_1, \
                                         tg_z_xxxxxyyy_0, tg_z_xxxxxyyy_1, tg_z_xxxxxyyz_0, tg_z_xxxxxyyz_1, tg_z_xxxxxyz_1, \
                                         tg_z_xxxxxyzz_0, tg_z_xxxxxyzz_1, tg_z_xxxxxzz_1, tg_z_xxxxxzzz_0, tg_z_xxxxxzzz_1, \
                                         tg_z_xxxxyyy_1, tg_z_xxxxyyyy_0, tg_z_xxxxyyyy_1, tg_z_xxxxyyyz_0, tg_z_xxxxyyyz_1, \
                                         tg_z_xxxxyyz_1, tg_z_xxxxyyzz_0, tg_z_xxxxyyzz_1, tg_z_xxxxyzz_1, tg_z_xxxxyzzz_0, \
                                         tg_z_xxxxyzzz_1, tg_z_xxxxzzz_1, tg_z_xxxxzzzz_0, tg_z_xxxxzzzz_1, tg_z_xxxyyyy_1, \
                                         tg_z_xxxyyyyy_0, tg_z_xxxyyyyy_1, tg_z_xxxyyyyz_0, tg_z_xxxyyyyz_1, tg_z_xxxyyyz_1, \
                                         tg_z_xxxyyyzz_0, tg_z_xxxyyyzz_1, tg_z_xxxyyzz_1, tg_z_xxxyyzzz_0, tg_z_xxxyyzzz_1, \
                                         tg_z_xxxyzzz_1, tg_z_xxxyzzzz_0, tg_z_xxxyzzzz_1, tg_z_xxxzzzz_1, tg_z_xxxzzzzz_0, \
                                         tg_z_xxxzzzzz_1, tg_z_xxyyyyy_1, tg_z_xxyyyyyy_0, tg_z_xxyyyyyy_1, tg_z_xxyyyyyz_0, \
                                         tg_z_xxyyyyyz_1, tg_z_xxyyyyz_1, tg_z_xxyyyyzz_0, tg_z_xxyyyyzz_1, tg_z_xxyyyzz_1, \
                                         tg_z_xxyyyzzz_0, tg_z_xxyyyzzz_1, tg_z_xxyyzzz_1, tg_z_xxyyzzzz_0, tg_z_xxyyzzzz_1, \
                                         tg_z_xxyzzzz_1, tg_z_xxyzzzzz_0, tg_z_xxyzzzzz_1, tg_z_xxzzzzz_1, tg_z_xxzzzzzz_0, \
                                         tg_z_xxzzzzzz_1, tg_z_xyyyyyy_1, tg_z_xyyyyyyy_0, tg_z_xyyyyyyy_1, tg_z_xyyyyyyz_0, \
                                         tg_z_xyyyyyyz_1, tg_z_xyyyyyz_1, tg_z_xyyyyyzz_0, tg_z_xyyyyyzz_1, tg_z_xyyyyzz_1, \
                                         tg_z_xyyyyzzz_0, tg_z_xyyyyzzz_1, tg_z_xyyyzzz_1, tg_z_xyyyzzzz_0, tg_z_xyyyzzzz_1, \
                                         tg_z_xyyzzzz_1, tg_z_xyyzzzzz_0, tg_z_xyyzzzzz_1, tg_z_xyzzzzz_1, tg_z_xyzzzzzz_0, \
                                         tg_z_xyzzzzzz_1, tg_z_xzzzzzz_1, tg_z_xzzzzzzz_0, tg_z_xzzzzzzz_1, tg_z_yyyyyyy_1, \
                                         tg_z_yyyyyyyy_0, tg_z_yyyyyyyy_1, tg_z_yyyyyyyz_0, tg_z_yyyyyyyz_1, tg_z_yyyyyyz_1, \
                                         tg_z_yyyyyyzz_0, tg_z_yyyyyyzz_1, tg_z_yyyyyzz_1, tg_z_yyyyyzzz_0, tg_z_yyyyyzzz_1, \
                                         tg_z_yyyyzzz_1, tg_z_yyyyzzzz_0, tg_z_yyyyzzzz_1, tg_z_yyyzzzz_1, tg_z_yyyzzzzz_0, \
                                         tg_z_yyyzzzzz_1, tg_z_yyzzzzz_1, tg_z_yyzzzzzz_0, tg_z_yyzzzzzz_1, tg_z_yzzzzzz_1, \
                                         tg_z_yzzzzzzz_0, tg_z_yzzzzzzz_1, tg_z_zzzzzzz_1, tg_z_zzzzzzzz_0, tg_z_zzzzzzzz_1, \
                                         tg_zz_xxxxxxxx_0, tg_zz_xxxxxxxy_0, tg_zz_xxxxxxxz_0, tg_zz_xxxxxxyy_0, \
                                         tg_zz_xxxxxxyz_0, tg_zz_xxxxxxzz_0, tg_zz_xxxxxyyy_0, tg_zz_xxxxxyyz_0, \
                                         tg_zz_xxxxxyzz_0, tg_zz_xxxxxzzz_0, tg_zz_xxxxyyyy_0, tg_zz_xxxxyyyz_0, \
                                         tg_zz_xxxxyyzz_0, tg_zz_xxxxyzzz_0, tg_zz_xxxxzzzz_0, tg_zz_xxxyyyyy_0, \
                                         tg_zz_xxxyyyyz_0, tg_zz_xxxyyyzz_0, tg_zz_xxxyyzzz_0, tg_zz_xxxyzzzz_0, \
                                         tg_zz_xxxzzzzz_0, tg_zz_xxyyyyyy_0, tg_zz_xxyyyyyz_0, tg_zz_xxyyyyzz_0, \
                                         tg_zz_xxyyyzzz_0, tg_zz_xxyyzzzz_0, tg_zz_xxyzzzzz_0, tg_zz_xxzzzzzz_0, \
                                         tg_zz_xyyyyyyy_0, tg_zz_xyyyyyyz_0, tg_zz_xyyyyyzz_0, tg_zz_xyyyyzzz_0, \
                                         tg_zz_xyyyzzzz_0, tg_zz_xyyzzzzz_0, tg_zz_xyzzzzzz_0, tg_zz_xzzzzzzz_0, \
                                         tg_zz_yyyyyyyy_0, tg_zz_yyyyyyyz_0, tg_zz_yyyyyyzz_0, tg_zz_yyyyyzzz_0, \
                                         tg_zz_yyyyzzzz_0, tg_zz_yyyzzzzz_0, tg_zz_yyzzzzzz_0, tg_zz_yzzzzzzz_0, \
                                         tg_zz_zzzzzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yz_xxxxxxxx_0[j] = pb_y * tg_z_xxxxxxxx_0[j] + fr * tg_z_xxxxxxxx_1[j];

                    tg_yz_xxxxxxxy_0[j] = pb_y * tg_z_xxxxxxxy_0[j] + fr * tg_z_xxxxxxxy_1[j] + 0.5 * fl1_fxn * tg_z_xxxxxxx_1[j];

                    tg_yz_xxxxxxxz_0[j] = pb_y * tg_z_xxxxxxxz_0[j] + fr * tg_z_xxxxxxxz_1[j];

                    tg_yz_xxxxxxyy_0[j] = pb_y * tg_z_xxxxxxyy_0[j] + fr * tg_z_xxxxxxyy_1[j] + fl1_fxn * tg_z_xxxxxxy_1[j];

                    tg_yz_xxxxxxyz_0[j] = pb_y * tg_z_xxxxxxyz_0[j] + fr * tg_z_xxxxxxyz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxxxz_1[j];

                    tg_yz_xxxxxxzz_0[j] = pb_y * tg_z_xxxxxxzz_0[j] + fr * tg_z_xxxxxxzz_1[j];

                    tg_yz_xxxxxyyy_0[j] = pb_y * tg_z_xxxxxyyy_0[j] + fr * tg_z_xxxxxyyy_1[j] + 1.5 * fl1_fxn * tg_z_xxxxxyy_1[j];

                    tg_yz_xxxxxyyz_0[j] = pb_y * tg_z_xxxxxyyz_0[j] + fr * tg_z_xxxxxyyz_1[j] + fl1_fxn * tg_z_xxxxxyz_1[j];

                    tg_yz_xxxxxyzz_0[j] = pb_y * tg_z_xxxxxyzz_0[j] + fr * tg_z_xxxxxyzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxxzz_1[j];

                    tg_yz_xxxxxzzz_0[j] = pb_y * tg_z_xxxxxzzz_0[j] + fr * tg_z_xxxxxzzz_1[j];

                    tg_yz_xxxxyyyy_0[j] = pb_y * tg_z_xxxxyyyy_0[j] + fr * tg_z_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_z_xxxxyyy_1[j];

                    tg_yz_xxxxyyyz_0[j] = pb_y * tg_z_xxxxyyyz_0[j] + fr * tg_z_xxxxyyyz_1[j] + 1.5 * fl1_fxn * tg_z_xxxxyyz_1[j];

                    tg_yz_xxxxyyzz_0[j] = pb_y * tg_z_xxxxyyzz_0[j] + fr * tg_z_xxxxyyzz_1[j] + fl1_fxn * tg_z_xxxxyzz_1[j];

                    tg_yz_xxxxyzzz_0[j] = pb_y * tg_z_xxxxyzzz_0[j] + fr * tg_z_xxxxyzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxxzzz_1[j];

                    tg_yz_xxxxzzzz_0[j] = pb_y * tg_z_xxxxzzzz_0[j] + fr * tg_z_xxxxzzzz_1[j];

                    tg_yz_xxxyyyyy_0[j] = pb_y * tg_z_xxxyyyyy_0[j] + fr * tg_z_xxxyyyyy_1[j] + 2.5 * fl1_fxn * tg_z_xxxyyyy_1[j];

                    tg_yz_xxxyyyyz_0[j] = pb_y * tg_z_xxxyyyyz_0[j] + fr * tg_z_xxxyyyyz_1[j] + 2.0 * fl1_fxn * tg_z_xxxyyyz_1[j];

                    tg_yz_xxxyyyzz_0[j] = pb_y * tg_z_xxxyyyzz_0[j] + fr * tg_z_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_z_xxxyyzz_1[j];

                    tg_yz_xxxyyzzz_0[j] = pb_y * tg_z_xxxyyzzz_0[j] + fr * tg_z_xxxyyzzz_1[j] + fl1_fxn * tg_z_xxxyzzz_1[j];

                    tg_yz_xxxyzzzz_0[j] = pb_y * tg_z_xxxyzzzz_0[j] + fr * tg_z_xxxyzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxxzzzz_1[j];

                    tg_yz_xxxzzzzz_0[j] = pb_y * tg_z_xxxzzzzz_0[j] + fr * tg_z_xxxzzzzz_1[j];

                    tg_yz_xxyyyyyy_0[j] = pb_y * tg_z_xxyyyyyy_0[j] + fr * tg_z_xxyyyyyy_1[j] + 3.0 * fl1_fxn * tg_z_xxyyyyy_1[j];

                    tg_yz_xxyyyyyz_0[j] = pb_y * tg_z_xxyyyyyz_0[j] + fr * tg_z_xxyyyyyz_1[j] + 2.5 * fl1_fxn * tg_z_xxyyyyz_1[j];

                    tg_yz_xxyyyyzz_0[j] = pb_y * tg_z_xxyyyyzz_0[j] + fr * tg_z_xxyyyyzz_1[j] + 2.0 * fl1_fxn * tg_z_xxyyyzz_1[j];

                    tg_yz_xxyyyzzz_0[j] = pb_y * tg_z_xxyyyzzz_0[j] + fr * tg_z_xxyyyzzz_1[j] + 1.5 * fl1_fxn * tg_z_xxyyzzz_1[j];

                    tg_yz_xxyyzzzz_0[j] = pb_y * tg_z_xxyyzzzz_0[j] + fr * tg_z_xxyyzzzz_1[j] + fl1_fxn * tg_z_xxyzzzz_1[j];

                    tg_yz_xxyzzzzz_0[j] = pb_y * tg_z_xxyzzzzz_0[j] + fr * tg_z_xxyzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xxzzzzz_1[j];

                    tg_yz_xxzzzzzz_0[j] = pb_y * tg_z_xxzzzzzz_0[j] + fr * tg_z_xxzzzzzz_1[j];

                    tg_yz_xyyyyyyy_0[j] = pb_y * tg_z_xyyyyyyy_0[j] + fr * tg_z_xyyyyyyy_1[j] + 3.5 * fl1_fxn * tg_z_xyyyyyy_1[j];

                    tg_yz_xyyyyyyz_0[j] = pb_y * tg_z_xyyyyyyz_0[j] + fr * tg_z_xyyyyyyz_1[j] + 3.0 * fl1_fxn * tg_z_xyyyyyz_1[j];

                    tg_yz_xyyyyyzz_0[j] = pb_y * tg_z_xyyyyyzz_0[j] + fr * tg_z_xyyyyyzz_1[j] + 2.5 * fl1_fxn * tg_z_xyyyyzz_1[j];

                    tg_yz_xyyyyzzz_0[j] = pb_y * tg_z_xyyyyzzz_0[j] + fr * tg_z_xyyyyzzz_1[j] + 2.0 * fl1_fxn * tg_z_xyyyzzz_1[j];

                    tg_yz_xyyyzzzz_0[j] = pb_y * tg_z_xyyyzzzz_0[j] + fr * tg_z_xyyyzzzz_1[j] + 1.5 * fl1_fxn * tg_z_xyyzzzz_1[j];

                    tg_yz_xyyzzzzz_0[j] = pb_y * tg_z_xyyzzzzz_0[j] + fr * tg_z_xyyzzzzz_1[j] + fl1_fxn * tg_z_xyzzzzz_1[j];

                    tg_yz_xyzzzzzz_0[j] = pb_y * tg_z_xyzzzzzz_0[j] + fr * tg_z_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_xzzzzzz_1[j];

                    tg_yz_xzzzzzzz_0[j] = pb_y * tg_z_xzzzzzzz_0[j] + fr * tg_z_xzzzzzzz_1[j];

                    tg_yz_yyyyyyyy_0[j] = pb_y * tg_z_yyyyyyyy_0[j] + fr * tg_z_yyyyyyyy_1[j] + 4.0 * fl1_fxn * tg_z_yyyyyyy_1[j];

                    tg_yz_yyyyyyyz_0[j] = pb_y * tg_z_yyyyyyyz_0[j] + fr * tg_z_yyyyyyyz_1[j] + 3.5 * fl1_fxn * tg_z_yyyyyyz_1[j];

                    tg_yz_yyyyyyzz_0[j] = pb_y * tg_z_yyyyyyzz_0[j] + fr * tg_z_yyyyyyzz_1[j] + 3.0 * fl1_fxn * tg_z_yyyyyzz_1[j];

                    tg_yz_yyyyyzzz_0[j] = pb_y * tg_z_yyyyyzzz_0[j] + fr * tg_z_yyyyyzzz_1[j] + 2.5 * fl1_fxn * tg_z_yyyyzzz_1[j];

                    tg_yz_yyyyzzzz_0[j] = pb_y * tg_z_yyyyzzzz_0[j] + fr * tg_z_yyyyzzzz_1[j] + 2.0 * fl1_fxn * tg_z_yyyzzzz_1[j];

                    tg_yz_yyyzzzzz_0[j] = pb_y * tg_z_yyyzzzzz_0[j] + fr * tg_z_yyyzzzzz_1[j] + 1.5 * fl1_fxn * tg_z_yyzzzzz_1[j];

                    tg_yz_yyzzzzzz_0[j] = pb_y * tg_z_yyzzzzzz_0[j] + fr * tg_z_yyzzzzzz_1[j] + fl1_fxn * tg_z_yzzzzzz_1[j];

                    tg_yz_yzzzzzzz_0[j] = pb_y * tg_z_yzzzzzzz_0[j] + fr * tg_z_yzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_z_zzzzzzz_1[j];

                    tg_yz_zzzzzzzz_0[j] = pb_y * tg_z_zzzzzzzz_0[j] + fr * tg_z_zzzzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zz_xxxxxxxx_0[j] = pb_z * tg_z_xxxxxxxx_0[j] + fr * tg_z_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxx_0[j] - tg_0_xxxxxxxx_1[j] * fl1_fza);

                    tg_zz_xxxxxxxy_0[j] = pb_z * tg_z_xxxxxxxy_0[j] + fr * tg_z_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxy_0[j] - tg_0_xxxxxxxy_1[j] * fl1_fza);

                    tg_zz_xxxxxxxz_0[j] = pb_z * tg_z_xxxxxxxz_0[j] + fr * tg_z_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxxz_0[j] - tg_0_xxxxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxxxx_1[j];

                    tg_zz_xxxxxxyy_0[j] = pb_z * tg_z_xxxxxxyy_0[j] + fr * tg_z_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyy_0[j] - tg_0_xxxxxxyy_1[j] * fl1_fza);

                    tg_zz_xxxxxxyz_0[j] = pb_z * tg_z_xxxxxxyz_0[j] + fr * tg_z_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxyz_0[j] - tg_0_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxxxy_1[j];

                    tg_zz_xxxxxxzz_0[j] = pb_z * tg_z_xxxxxxzz_0[j] + fr * tg_z_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxxzz_0[j] - tg_0_xxxxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxxxz_1[j];

                    tg_zz_xxxxxyyy_0[j] = pb_z * tg_z_xxxxxyyy_0[j] + fr * tg_z_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyy_0[j] - tg_0_xxxxxyyy_1[j] * fl1_fza);

                    tg_zz_xxxxxyyz_0[j] = pb_z * tg_z_xxxxxyyz_0[j] + fr * tg_z_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyyz_0[j] - tg_0_xxxxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxxyy_1[j];

                    tg_zz_xxxxxyzz_0[j] = pb_z * tg_z_xxxxxyzz_0[j] + fr * tg_z_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxyzz_0[j] - tg_0_xxxxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxxyz_1[j];

                    tg_zz_xxxxxzzz_0[j] = pb_z * tg_z_xxxxxzzz_0[j] + fr * tg_z_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxxzzz_0[j] - tg_0_xxxxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxxxzz_1[j];

                    tg_zz_xxxxyyyy_0[j] = pb_z * tg_z_xxxxyyyy_0[j] + fr * tg_z_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyy_0[j] - tg_0_xxxxyyyy_1[j] * fl1_fza);

                    tg_zz_xxxxyyyz_0[j] = pb_z * tg_z_xxxxyyyz_0[j] + fr * tg_z_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyyz_0[j] - tg_0_xxxxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxxyyy_1[j];

                    tg_zz_xxxxyyzz_0[j] = pb_z * tg_z_xxxxyyzz_0[j] + fr * tg_z_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyyzz_0[j] - tg_0_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxxyyz_1[j];

                    tg_zz_xxxxyzzz_0[j] = pb_z * tg_z_xxxxyzzz_0[j] + fr * tg_z_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxyzzz_0[j] - tg_0_xxxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxxyzz_1[j];

                    tg_zz_xxxxzzzz_0[j] = pb_z * tg_z_xxxxzzzz_0[j] + fr * tg_z_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxxzzzz_0[j] - tg_0_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxxxzzz_1[j];

                    tg_zz_xxxyyyyy_0[j] = pb_z * tg_z_xxxyyyyy_0[j] + fr * tg_z_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyy_0[j] - tg_0_xxxyyyyy_1[j] * fl1_fza);

                    tg_zz_xxxyyyyz_0[j] = pb_z * tg_z_xxxyyyyz_0[j] + fr * tg_z_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyyz_0[j] - tg_0_xxxyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxxyyyy_1[j];

                    tg_zz_xxxyyyzz_0[j] = pb_z * tg_z_xxxyyyzz_0[j] + fr * tg_z_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyyzz_0[j] - tg_0_xxxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxxyyyz_1[j];

                    tg_zz_xxxyyzzz_0[j] = pb_z * tg_z_xxxyyzzz_0[j] + fr * tg_z_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyyzzz_0[j] - tg_0_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxxyyzz_1[j];

                    tg_zz_xxxyzzzz_0[j] = pb_z * tg_z_xxxyzzzz_0[j] + fr * tg_z_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxyzzzz_0[j] - tg_0_xxxyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxxyzzz_1[j];

                    tg_zz_xxxzzzzz_0[j] = pb_z * tg_z_xxxzzzzz_0[j] + fr * tg_z_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxxzzzzz_0[j] - tg_0_xxxzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xxxzzzz_1[j];

                    tg_zz_xxyyyyyy_0[j] = pb_z * tg_z_xxyyyyyy_0[j] + fr * tg_z_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyy_0[j] - tg_0_xxyyyyyy_1[j] * fl1_fza);

                    tg_zz_xxyyyyyz_0[j] = pb_z * tg_z_xxyyyyyz_0[j] + fr * tg_z_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyyz_0[j] - tg_0_xxyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xxyyyyy_1[j];

                    tg_zz_xxyyyyzz_0[j] = pb_z * tg_z_xxyyyyzz_0[j] + fr * tg_z_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyyzz_0[j] - tg_0_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xxyyyyz_1[j];

                    tg_zz_xxyyyzzz_0[j] = pb_z * tg_z_xxyyyzzz_0[j] + fr * tg_z_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyyzzz_0[j] - tg_0_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xxyyyzz_1[j];

                    tg_zz_xxyyzzzz_0[j] = pb_z * tg_z_xxyyzzzz_0[j] + fr * tg_z_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyyzzzz_0[j] - tg_0_xxyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xxyyzzz_1[j];

                    tg_zz_xxyzzzzz_0[j] = pb_z * tg_z_xxyzzzzz_0[j] + fr * tg_z_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxyzzzzz_0[j] - tg_0_xxyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xxyzzzz_1[j];

                    tg_zz_xxzzzzzz_0[j] = pb_z * tg_z_xxzzzzzz_0[j] + fr * tg_z_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xxzzzzzz_0[j] - tg_0_xxzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_xxzzzzz_1[j];

                    tg_zz_xyyyyyyy_0[j] = pb_z * tg_z_xyyyyyyy_0[j] + fr * tg_z_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyy_0[j] - tg_0_xyyyyyyy_1[j] * fl1_fza);

                    tg_zz_xyyyyyyz_0[j] = pb_z * tg_z_xyyyyyyz_0[j] + fr * tg_z_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyyz_0[j] - tg_0_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_xyyyyyy_1[j];

                    tg_zz_xyyyyyzz_0[j] = pb_z * tg_z_xyyyyyzz_0[j] + fr * tg_z_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyyzz_0[j] - tg_0_xyyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_xyyyyyz_1[j];

                    tg_zz_xyyyyzzz_0[j] = pb_z * tg_z_xyyyyzzz_0[j] + fr * tg_z_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyyzzz_0[j] - tg_0_xyyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_xyyyyzz_1[j];

                    tg_zz_xyyyzzzz_0[j] = pb_z * tg_z_xyyyzzzz_0[j] + fr * tg_z_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyyzzzz_0[j] - tg_0_xyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_xyyyzzz_1[j];

                    tg_zz_xyyzzzzz_0[j] = pb_z * tg_z_xyyzzzzz_0[j] + fr * tg_z_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyyzzzzz_0[j] - tg_0_xyyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_xyyzzzz_1[j];

                    tg_zz_xyzzzzzz_0[j] = pb_z * tg_z_xyzzzzzz_0[j] + fr * tg_z_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xyzzzzzz_0[j] - tg_0_xyzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_xyzzzzz_1[j];

                    tg_zz_xzzzzzzz_0[j] = pb_z * tg_z_xzzzzzzz_0[j] + fr * tg_z_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_xzzzzzzz_0[j] - tg_0_xzzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_z_xzzzzzz_1[j];

                    tg_zz_yyyyyyyy_0[j] = pb_z * tg_z_yyyyyyyy_0[j] + fr * tg_z_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyy_0[j] - tg_0_yyyyyyyy_1[j] * fl1_fza);

                    tg_zz_yyyyyyyz_0[j] = pb_z * tg_z_yyyyyyyz_0[j] + fr * tg_z_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyyz_0[j] - tg_0_yyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_z_yyyyyyy_1[j];

                    tg_zz_yyyyyyzz_0[j] = pb_z * tg_z_yyyyyyzz_0[j] + fr * tg_z_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyyzz_0[j] - tg_0_yyyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_z_yyyyyyz_1[j];

                    tg_zz_yyyyyzzz_0[j] = pb_z * tg_z_yyyyyzzz_0[j] + fr * tg_z_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyyzzz_0[j] - tg_0_yyyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_z_yyyyyzz_1[j];

                    tg_zz_yyyyzzzz_0[j] = pb_z * tg_z_yyyyzzzz_0[j] + fr * tg_z_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyyzzzz_0[j] - tg_0_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_z_yyyyzzz_1[j];

                    tg_zz_yyyzzzzz_0[j] = pb_z * tg_z_yyyzzzzz_0[j] + fr * tg_z_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyyzzzzz_0[j] - tg_0_yyyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_z_yyyzzzz_1[j];

                    tg_zz_yyzzzzzz_0[j] = pb_z * tg_z_yyzzzzzz_0[j] + fr * tg_z_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yyzzzzzz_0[j] - tg_0_yyzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_z_yyzzzzz_1[j];

                    tg_zz_yzzzzzzz_0[j] = pb_z * tg_z_yzzzzzzz_0[j] + fr * tg_z_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_yzzzzzzz_0[j] - tg_0_yzzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_z_yzzzzzz_1[j];

                    tg_zz_zzzzzzzz_0[j] = pb_z * tg_z_zzzzzzzz_0[j] + fr * tg_z_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_0_zzzzzzzz_0[j] - tg_0_zzzzzzzz_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_z_zzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSD(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSLSD_0_90(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSLSD_90_180(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSLSD_180_270(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 
    }

    void
    compElectronRepulsionForSLSD_0_90(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,90)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxxx_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx); 

                auto tg_xxxxxxx_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 1); 

                auto tg_xxxxxxx_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 2); 

                auto tg_xxxxxxx_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 3); 

                auto tg_xxxxxxx_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 4); 

                auto tg_xxxxxxx_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 5); 

                auto tg_xxxxxxy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 6); 

                auto tg_xxxxxxy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 7); 

                auto tg_xxxxxxy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 8); 

                auto tg_xxxxxxy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 9); 

                auto tg_xxxxxxy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 10); 

                auto tg_xxxxxxy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 11); 

                auto tg_xxxxxxz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 12); 

                auto tg_xxxxxxz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 13); 

                auto tg_xxxxxxz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 14); 

                auto tg_xxxxxxz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 15); 

                auto tg_xxxxxxz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 16); 

                auto tg_xxxxxxz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 17); 

                auto tg_xxxxxyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 18); 

                auto tg_xxxxxyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 19); 

                auto tg_xxxxxyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 20); 

                auto tg_xxxxxyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 21); 

                auto tg_xxxxxyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 22); 

                auto tg_xxxxxyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 23); 

                auto tg_xxxxxyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 24); 

                auto tg_xxxxxyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 25); 

                auto tg_xxxxxyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 26); 

                auto tg_xxxxxyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 27); 

                auto tg_xxxxxyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 28); 

                auto tg_xxxxxyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 29); 

                auto tg_xxxxxzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 30); 

                auto tg_xxxxxzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 31); 

                auto tg_xxxxxzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 32); 

                auto tg_xxxxxzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 33); 

                auto tg_xxxxxzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 34); 

                auto tg_xxxxxzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 35); 

                auto tg_xxxxyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 36); 

                auto tg_xxxxyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 37); 

                auto tg_xxxxyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 38); 

                auto tg_xxxxyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 39); 

                auto tg_xxxxyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 40); 

                auto tg_xxxxyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 41); 

                auto tg_xxxxyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 42); 

                auto tg_xxxxyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 43); 

                auto tg_xxxxyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 44); 

                auto tg_xxxxyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 45); 

                auto tg_xxxxyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 46); 

                auto tg_xxxxyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 47); 

                auto tg_xxxxyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 48); 

                auto tg_xxxxyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 49); 

                auto tg_xxxxyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 50); 

                auto tg_xxxxyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 51); 

                auto tg_xxxxyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 52); 

                auto tg_xxxxyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 53); 

                auto tg_xxxxzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 54); 

                auto tg_xxxxzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 55); 

                auto tg_xxxxzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 56); 

                auto tg_xxxxzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 57); 

                auto tg_xxxxzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 58); 

                auto tg_xxxxzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 59); 

                auto tg_xxxyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 60); 

                auto tg_xxxyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 61); 

                auto tg_xxxyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 62); 

                auto tg_xxxyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 63); 

                auto tg_xxxyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 64); 

                auto tg_xxxyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 65); 

                auto tg_xxxyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 66); 

                auto tg_xxxyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 67); 

                auto tg_xxxyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 68); 

                auto tg_xxxyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 69); 

                auto tg_xxxyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 70); 

                auto tg_xxxyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 71); 

                auto tg_xxxyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 72); 

                auto tg_xxxyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 73); 

                auto tg_xxxyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 74); 

                auto tg_xxxyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 75); 

                auto tg_xxxyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 76); 

                auto tg_xxxyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 77); 

                auto tg_xxxyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 78); 

                auto tg_xxxyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 79); 

                auto tg_xxxyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 80); 

                auto tg_xxxyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 81); 

                auto tg_xxxyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 82); 

                auto tg_xxxyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 83); 

                auto tg_xxxzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 84); 

                auto tg_xxxzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 85); 

                auto tg_xxxzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 86); 

                auto tg_xxxzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 87); 

                auto tg_xxxzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 88); 

                auto tg_xxxzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 89); 

                auto tg_xxxxxxx_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx); 

                auto tg_xxxxxxx_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 1); 

                auto tg_xxxxxxx_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 2); 

                auto tg_xxxxxxx_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 3); 

                auto tg_xxxxxxx_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 4); 

                auto tg_xxxxxxx_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 5); 

                auto tg_xxxxxxy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 6); 

                auto tg_xxxxxxy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 7); 

                auto tg_xxxxxxy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 8); 

                auto tg_xxxxxxy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 9); 

                auto tg_xxxxxxy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 10); 

                auto tg_xxxxxxy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 11); 

                auto tg_xxxxxxz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 12); 

                auto tg_xxxxxxz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 13); 

                auto tg_xxxxxxz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 14); 

                auto tg_xxxxxxz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 15); 

                auto tg_xxxxxxz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 16); 

                auto tg_xxxxxxz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 17); 

                auto tg_xxxxxyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 18); 

                auto tg_xxxxxyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 19); 

                auto tg_xxxxxyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 20); 

                auto tg_xxxxxyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 21); 

                auto tg_xxxxxyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 22); 

                auto tg_xxxxxyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 23); 

                auto tg_xxxxxyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 24); 

                auto tg_xxxxxyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 25); 

                auto tg_xxxxxyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 26); 

                auto tg_xxxxxyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 27); 

                auto tg_xxxxxyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 28); 

                auto tg_xxxxxyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 29); 

                auto tg_xxxxxzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 30); 

                auto tg_xxxxxzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 31); 

                auto tg_xxxxxzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 32); 

                auto tg_xxxxxzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 33); 

                auto tg_xxxxxzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 34); 

                auto tg_xxxxxzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 35); 

                auto tg_xxxxyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 36); 

                auto tg_xxxxyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 37); 

                auto tg_xxxxyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 38); 

                auto tg_xxxxyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 39); 

                auto tg_xxxxyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 40); 

                auto tg_xxxxyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 41); 

                auto tg_xxxxyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 42); 

                auto tg_xxxxyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 43); 

                auto tg_xxxxyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 44); 

                auto tg_xxxxyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 45); 

                auto tg_xxxxyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 46); 

                auto tg_xxxxyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 47); 

                auto tg_xxxxyzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 48); 

                auto tg_xxxxyzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 49); 

                auto tg_xxxxyzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 50); 

                auto tg_xxxxyzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 51); 

                auto tg_xxxxyzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 52); 

                auto tg_xxxxyzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 53); 

                auto tg_xxxxzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 54); 

                auto tg_xxxxzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 55); 

                auto tg_xxxxzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 56); 

                auto tg_xxxxzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 57); 

                auto tg_xxxxzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 58); 

                auto tg_xxxxzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 59); 

                auto tg_xxxyyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 60); 

                auto tg_xxxyyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 61); 

                auto tg_xxxyyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 62); 

                auto tg_xxxyyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 63); 

                auto tg_xxxyyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 64); 

                auto tg_xxxyyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 65); 

                auto tg_xxxyyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 66); 

                auto tg_xxxyyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 67); 

                auto tg_xxxyyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 68); 

                auto tg_xxxyyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 69); 

                auto tg_xxxyyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 70); 

                auto tg_xxxyyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 71); 

                auto tg_xxxyyzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 72); 

                auto tg_xxxyyzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 73); 

                auto tg_xxxyyzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 74); 

                auto tg_xxxyyzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 75); 

                auto tg_xxxyyzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 76); 

                auto tg_xxxyyzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 77); 

                auto tg_xxxyzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 78); 

                auto tg_xxxyzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 79); 

                auto tg_xxxyzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 80); 

                auto tg_xxxyzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 81); 

                auto tg_xxxyzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 82); 

                auto tg_xxxyzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 83); 

                auto tg_xxxzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 84); 

                auto tg_xxxzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 85); 

                auto tg_xxxzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 86); 

                auto tg_xxxzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 87); 

                auto tg_xxxzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 88); 

                auto tg_xxxzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 89); 

                auto tg_xxxxxx_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx); 

                auto tg_xxxxxx_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 1); 

                auto tg_xxxxxx_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 2); 

                auto tg_xxxxxx_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 3); 

                auto tg_xxxxxx_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 4); 

                auto tg_xxxxxx_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 5); 

                auto tg_xxxxxy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 6); 

                auto tg_xxxxxy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 7); 

                auto tg_xxxxxy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 8); 

                auto tg_xxxxxy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 9); 

                auto tg_xxxxxy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 10); 

                auto tg_xxxxxy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 11); 

                auto tg_xxxxxz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 12); 

                auto tg_xxxxxz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 13); 

                auto tg_xxxxxz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 14); 

                auto tg_xxxxxz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 15); 

                auto tg_xxxxxz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 16); 

                auto tg_xxxxxz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 17); 

                auto tg_xxxxyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 18); 

                auto tg_xxxxyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 19); 

                auto tg_xxxxyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 20); 

                auto tg_xxxxyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 21); 

                auto tg_xxxxyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 22); 

                auto tg_xxxxyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 23); 

                auto tg_xxxxyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 24); 

                auto tg_xxxxyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 25); 

                auto tg_xxxxyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 26); 

                auto tg_xxxxyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 27); 

                auto tg_xxxxyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 28); 

                auto tg_xxxxyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 29); 

                auto tg_xxxxzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 30); 

                auto tg_xxxxzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 31); 

                auto tg_xxxxzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 32); 

                auto tg_xxxxzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 33); 

                auto tg_xxxxzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 34); 

                auto tg_xxxxzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 35); 

                auto tg_xxxyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 36); 

                auto tg_xxxyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 37); 

                auto tg_xxxyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 38); 

                auto tg_xxxyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 39); 

                auto tg_xxxyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 40); 

                auto tg_xxxyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 41); 

                auto tg_xxxyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 42); 

                auto tg_xxxyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 43); 

                auto tg_xxxyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 44); 

                auto tg_xxxyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 45); 

                auto tg_xxxyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 46); 

                auto tg_xxxyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 47); 

                auto tg_xxxyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 48); 

                auto tg_xxxyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 49); 

                auto tg_xxxyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 50); 

                auto tg_xxxyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 51); 

                auto tg_xxxyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 52); 

                auto tg_xxxyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 53); 

                auto tg_xxxzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 54); 

                auto tg_xxxzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 55); 

                auto tg_xxxzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 56); 

                auto tg_xxxzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 57); 

                auto tg_xxxzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 58); 

                auto tg_xxxzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 59); 

                auto tg_xxyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 60); 

                auto tg_xxyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 61); 

                auto tg_xxyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 62); 

                auto tg_xxyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 63); 

                auto tg_xxyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 64); 

                auto tg_xxyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 65); 

                auto tg_xxyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 66); 

                auto tg_xxyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 67); 

                auto tg_xxyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 68); 

                auto tg_xxyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 69); 

                auto tg_xxyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 70); 

                auto tg_xxyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 71); 

                auto tg_xxyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 72); 

                auto tg_xxyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 73); 

                auto tg_xxyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 74); 

                auto tg_xxyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 75); 

                auto tg_xxyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 76); 

                auto tg_xxyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 77); 

                auto tg_xxyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 78); 

                auto tg_xxyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 79); 

                auto tg_xxyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 80); 

                auto tg_xxyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 81); 

                auto tg_xxyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 82); 

                auto tg_xxyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 83); 

                auto tg_xxzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 84); 

                auto tg_xxzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 85); 

                auto tg_xxzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 86); 

                auto tg_xxzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 87); 

                auto tg_xxzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 88); 

                auto tg_xxzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 89); 

                auto tg_xxxxxx_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx); 

                auto tg_xxxxxx_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 1); 

                auto tg_xxxxxx_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 2); 

                auto tg_xxxxxx_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 3); 

                auto tg_xxxxxx_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 4); 

                auto tg_xxxxxx_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 5); 

                auto tg_xxxxxy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 6); 

                auto tg_xxxxxy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 7); 

                auto tg_xxxxxy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 8); 

                auto tg_xxxxxy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 9); 

                auto tg_xxxxxy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 10); 

                auto tg_xxxxxy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 11); 

                auto tg_xxxxxz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 12); 

                auto tg_xxxxxz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 13); 

                auto tg_xxxxxz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 14); 

                auto tg_xxxxxz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 15); 

                auto tg_xxxxxz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 16); 

                auto tg_xxxxxz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 17); 

                auto tg_xxxxyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 18); 

                auto tg_xxxxyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 19); 

                auto tg_xxxxyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 20); 

                auto tg_xxxxyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 21); 

                auto tg_xxxxyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 22); 

                auto tg_xxxxyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 23); 

                auto tg_xxxxyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 24); 

                auto tg_xxxxyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 25); 

                auto tg_xxxxyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 26); 

                auto tg_xxxxyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 27); 

                auto tg_xxxxyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 28); 

                auto tg_xxxxyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 29); 

                auto tg_xxxxzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 30); 

                auto tg_xxxxzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 31); 

                auto tg_xxxxzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 32); 

                auto tg_xxxxzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 33); 

                auto tg_xxxxzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 34); 

                auto tg_xxxxzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 35); 

                auto tg_xxxyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 36); 

                auto tg_xxxyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 37); 

                auto tg_xxxyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 38); 

                auto tg_xxxyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 39); 

                auto tg_xxxyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 40); 

                auto tg_xxxyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 41); 

                auto tg_xxxyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 42); 

                auto tg_xxxyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 43); 

                auto tg_xxxyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 44); 

                auto tg_xxxyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 45); 

                auto tg_xxxyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 46); 

                auto tg_xxxyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 47); 

                auto tg_xxxyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 48); 

                auto tg_xxxyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 49); 

                auto tg_xxxyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 50); 

                auto tg_xxxyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 51); 

                auto tg_xxxyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 52); 

                auto tg_xxxyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 53); 

                auto tg_xxxzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 54); 

                auto tg_xxxzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 55); 

                auto tg_xxxzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 56); 

                auto tg_xxxzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 57); 

                auto tg_xxxzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 58); 

                auto tg_xxxzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 59); 

                auto tg_xxyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 60); 

                auto tg_xxyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 61); 

                auto tg_xxyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 62); 

                auto tg_xxyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 63); 

                auto tg_xxyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 64); 

                auto tg_xxyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 65); 

                auto tg_xxyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 66); 

                auto tg_xxyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 67); 

                auto tg_xxyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 68); 

                auto tg_xxyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 69); 

                auto tg_xxyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 70); 

                auto tg_xxyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 71); 

                auto tg_xxyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 72); 

                auto tg_xxyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 73); 

                auto tg_xxyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 74); 

                auto tg_xxyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 75); 

                auto tg_xxyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 76); 

                auto tg_xxyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 77); 

                auto tg_xxyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 78); 

                auto tg_xxyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 79); 

                auto tg_xxyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 80); 

                auto tg_xxyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 81); 

                auto tg_xxyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 82); 

                auto tg_xxyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 83); 

                auto tg_xxzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 84); 

                auto tg_xxzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 85); 

                auto tg_xxzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 86); 

                auto tg_xxzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 87); 

                auto tg_xxzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 88); 

                auto tg_xxzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 89); 

                auto tg_xxxxxxx_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx); 

                auto tg_xxxxxxx_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 1); 

                auto tg_xxxxxxx_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 2); 

                auto tg_xxxxxxy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 3); 

                auto tg_xxxxxxy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 4); 

                auto tg_xxxxxxy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 5); 

                auto tg_xxxxxxz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 6); 

                auto tg_xxxxxxz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 7); 

                auto tg_xxxxxxz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 8); 

                auto tg_xxxxxyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 9); 

                auto tg_xxxxxyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 10); 

                auto tg_xxxxxyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 11); 

                auto tg_xxxxxyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 12); 

                auto tg_xxxxxyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 13); 

                auto tg_xxxxxyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 14); 

                auto tg_xxxxxzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 15); 

                auto tg_xxxxxzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 16); 

                auto tg_xxxxxzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 17); 

                auto tg_xxxxyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 18); 

                auto tg_xxxxyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 19); 

                auto tg_xxxxyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 20); 

                auto tg_xxxxyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 21); 

                auto tg_xxxxyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 22); 

                auto tg_xxxxyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 23); 

                auto tg_xxxxyzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 24); 

                auto tg_xxxxyzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 25); 

                auto tg_xxxxyzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 26); 

                auto tg_xxxxzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 27); 

                auto tg_xxxxzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 28); 

                auto tg_xxxxzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 29); 

                auto tg_xxxyyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 30); 

                auto tg_xxxyyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 31); 

                auto tg_xxxyyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 32); 

                auto tg_xxxyyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 33); 

                auto tg_xxxyyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 34); 

                auto tg_xxxyyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 35); 

                auto tg_xxxyyzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 36); 

                auto tg_xxxyyzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 37); 

                auto tg_xxxyyzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 38); 

                auto tg_xxxyzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 39); 

                auto tg_xxxyzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 40); 

                auto tg_xxxyzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 41); 

                auto tg_xxxzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 42); 

                auto tg_xxxzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 43); 

                auto tg_xxxzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 44); 

                // set up pointers to integrals

                auto tg_xxxxxxxx_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx); 

                auto tg_xxxxxxxx_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 1); 

                auto tg_xxxxxxxx_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 2); 

                auto tg_xxxxxxxx_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 3); 

                auto tg_xxxxxxxx_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 4); 

                auto tg_xxxxxxxx_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 5); 

                auto tg_xxxxxxxy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 6); 

                auto tg_xxxxxxxy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 7); 

                auto tg_xxxxxxxy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 8); 

                auto tg_xxxxxxxy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 9); 

                auto tg_xxxxxxxy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 10); 

                auto tg_xxxxxxxy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 11); 

                auto tg_xxxxxxxz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 12); 

                auto tg_xxxxxxxz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 13); 

                auto tg_xxxxxxxz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 14); 

                auto tg_xxxxxxxz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 15); 

                auto tg_xxxxxxxz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 16); 

                auto tg_xxxxxxxz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 17); 

                auto tg_xxxxxxyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 18); 

                auto tg_xxxxxxyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 19); 

                auto tg_xxxxxxyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 20); 

                auto tg_xxxxxxyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 21); 

                auto tg_xxxxxxyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 22); 

                auto tg_xxxxxxyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 23); 

                auto tg_xxxxxxyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 24); 

                auto tg_xxxxxxyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 25); 

                auto tg_xxxxxxyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 26); 

                auto tg_xxxxxxyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 27); 

                auto tg_xxxxxxyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 28); 

                auto tg_xxxxxxyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 29); 

                auto tg_xxxxxxzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 30); 

                auto tg_xxxxxxzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 31); 

                auto tg_xxxxxxzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 32); 

                auto tg_xxxxxxzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 33); 

                auto tg_xxxxxxzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 34); 

                auto tg_xxxxxxzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 35); 

                auto tg_xxxxxyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 36); 

                auto tg_xxxxxyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 37); 

                auto tg_xxxxxyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 38); 

                auto tg_xxxxxyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 39); 

                auto tg_xxxxxyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 40); 

                auto tg_xxxxxyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 41); 

                auto tg_xxxxxyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 42); 

                auto tg_xxxxxyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 43); 

                auto tg_xxxxxyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 44); 

                auto tg_xxxxxyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 45); 

                auto tg_xxxxxyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 46); 

                auto tg_xxxxxyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 47); 

                auto tg_xxxxxyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 48); 

                auto tg_xxxxxyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 49); 

                auto tg_xxxxxyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 50); 

                auto tg_xxxxxyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 51); 

                auto tg_xxxxxyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 52); 

                auto tg_xxxxxyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 53); 

                auto tg_xxxxxzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 54); 

                auto tg_xxxxxzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 55); 

                auto tg_xxxxxzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 56); 

                auto tg_xxxxxzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 57); 

                auto tg_xxxxxzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 58); 

                auto tg_xxxxxzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 59); 

                auto tg_xxxxyyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 60); 

                auto tg_xxxxyyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 61); 

                auto tg_xxxxyyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 62); 

                auto tg_xxxxyyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 63); 

                auto tg_xxxxyyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 64); 

                auto tg_xxxxyyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 65); 

                auto tg_xxxxyyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 66); 

                auto tg_xxxxyyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 67); 

                auto tg_xxxxyyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 68); 

                auto tg_xxxxyyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 69); 

                auto tg_xxxxyyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 70); 

                auto tg_xxxxyyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 71); 

                auto tg_xxxxyyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 72); 

                auto tg_xxxxyyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 73); 

                auto tg_xxxxyyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 74); 

                auto tg_xxxxyyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 75); 

                auto tg_xxxxyyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 76); 

                auto tg_xxxxyyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 77); 

                auto tg_xxxxyzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 78); 

                auto tg_xxxxyzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 79); 

                auto tg_xxxxyzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 80); 

                auto tg_xxxxyzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 81); 

                auto tg_xxxxyzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 82); 

                auto tg_xxxxyzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 83); 

                auto tg_xxxxzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 84); 

                auto tg_xxxxzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 85); 

                auto tg_xxxxzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 86); 

                auto tg_xxxxzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 87); 

                auto tg_xxxxzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 88); 

                auto tg_xxxxzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 89); 

                // Batch of Integrals (0,90)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxx_xx_0, tg_xxxxxx_xx_1, tg_xxxxxx_xy_0, \
                                         tg_xxxxxx_xy_1, tg_xxxxxx_xz_0, tg_xxxxxx_xz_1, tg_xxxxxx_yy_0, tg_xxxxxx_yy_1, \
                                         tg_xxxxxx_yz_0, tg_xxxxxx_yz_1, tg_xxxxxx_zz_0, tg_xxxxxx_zz_1, tg_xxxxxxx_x_1, \
                                         tg_xxxxxxx_xx_0, tg_xxxxxxx_xx_1, tg_xxxxxxx_xy_0, tg_xxxxxxx_xy_1, tg_xxxxxxx_xz_0, \
                                         tg_xxxxxxx_xz_1, tg_xxxxxxx_y_1, tg_xxxxxxx_yy_0, tg_xxxxxxx_yy_1, tg_xxxxxxx_yz_0, \
                                         tg_xxxxxxx_yz_1, tg_xxxxxxx_z_1, tg_xxxxxxx_zz_0, tg_xxxxxxx_zz_1, tg_xxxxxxxx_xx_0, \
                                         tg_xxxxxxxx_xy_0, tg_xxxxxxxx_xz_0, tg_xxxxxxxx_yy_0, tg_xxxxxxxx_yz_0, \
                                         tg_xxxxxxxx_zz_0, tg_xxxxxxxy_xx_0, tg_xxxxxxxy_xy_0, tg_xxxxxxxy_xz_0, \
                                         tg_xxxxxxxy_yy_0, tg_xxxxxxxy_yz_0, tg_xxxxxxxy_zz_0, tg_xxxxxxxz_xx_0, \
                                         tg_xxxxxxxz_xy_0, tg_xxxxxxxz_xz_0, tg_xxxxxxxz_yy_0, tg_xxxxxxxz_yz_0, \
                                         tg_xxxxxxxz_zz_0, tg_xxxxxxy_x_1, tg_xxxxxxy_xx_0, tg_xxxxxxy_xx_1, tg_xxxxxxy_xy_0, \
                                         tg_xxxxxxy_xy_1, tg_xxxxxxy_xz_0, tg_xxxxxxy_xz_1, tg_xxxxxxy_y_1, tg_xxxxxxy_yy_0, \
                                         tg_xxxxxxy_yy_1, tg_xxxxxxy_yz_0, tg_xxxxxxy_yz_1, tg_xxxxxxy_z_1, tg_xxxxxxy_zz_0, \
                                         tg_xxxxxxy_zz_1, tg_xxxxxxyy_xx_0, tg_xxxxxxyy_xy_0, tg_xxxxxxyy_xz_0, \
                                         tg_xxxxxxyy_yy_0, tg_xxxxxxyy_yz_0, tg_xxxxxxyy_zz_0, tg_xxxxxxyz_xx_0, \
                                         tg_xxxxxxyz_xy_0, tg_xxxxxxyz_xz_0, tg_xxxxxxyz_yy_0, tg_xxxxxxyz_yz_0, \
                                         tg_xxxxxxyz_zz_0, tg_xxxxxxz_x_1, tg_xxxxxxz_xx_0, tg_xxxxxxz_xx_1, tg_xxxxxxz_xy_0, \
                                         tg_xxxxxxz_xy_1, tg_xxxxxxz_xz_0, tg_xxxxxxz_xz_1, tg_xxxxxxz_y_1, tg_xxxxxxz_yy_0, \
                                         tg_xxxxxxz_yy_1, tg_xxxxxxz_yz_0, tg_xxxxxxz_yz_1, tg_xxxxxxz_z_1, tg_xxxxxxz_zz_0, \
                                         tg_xxxxxxz_zz_1, tg_xxxxxxzz_xx_0, tg_xxxxxxzz_xy_0, tg_xxxxxxzz_xz_0, \
                                         tg_xxxxxxzz_yy_0, tg_xxxxxxzz_yz_0, tg_xxxxxxzz_zz_0, tg_xxxxxy_xx_0, tg_xxxxxy_xx_1, \
                                         tg_xxxxxy_xy_0, tg_xxxxxy_xy_1, tg_xxxxxy_xz_0, tg_xxxxxy_xz_1, tg_xxxxxy_yy_0, \
                                         tg_xxxxxy_yy_1, tg_xxxxxy_yz_0, tg_xxxxxy_yz_1, tg_xxxxxy_zz_0, tg_xxxxxy_zz_1, \
                                         tg_xxxxxyy_x_1, tg_xxxxxyy_xx_0, tg_xxxxxyy_xx_1, tg_xxxxxyy_xy_0, tg_xxxxxyy_xy_1, \
                                         tg_xxxxxyy_xz_0, tg_xxxxxyy_xz_1, tg_xxxxxyy_y_1, tg_xxxxxyy_yy_0, tg_xxxxxyy_yy_1, \
                                         tg_xxxxxyy_yz_0, tg_xxxxxyy_yz_1, tg_xxxxxyy_z_1, tg_xxxxxyy_zz_0, tg_xxxxxyy_zz_1, \
                                         tg_xxxxxyyy_xx_0, tg_xxxxxyyy_xy_0, tg_xxxxxyyy_xz_0, tg_xxxxxyyy_yy_0, \
                                         tg_xxxxxyyy_yz_0, tg_xxxxxyyy_zz_0, tg_xxxxxyyz_xx_0, tg_xxxxxyyz_xy_0, \
                                         tg_xxxxxyyz_xz_0, tg_xxxxxyyz_yy_0, tg_xxxxxyyz_yz_0, tg_xxxxxyyz_zz_0, \
                                         tg_xxxxxyz_x_1, tg_xxxxxyz_xx_0, tg_xxxxxyz_xx_1, tg_xxxxxyz_xy_0, tg_xxxxxyz_xy_1, \
                                         tg_xxxxxyz_xz_0, tg_xxxxxyz_xz_1, tg_xxxxxyz_y_1, tg_xxxxxyz_yy_0, tg_xxxxxyz_yy_1, \
                                         tg_xxxxxyz_yz_0, tg_xxxxxyz_yz_1, tg_xxxxxyz_z_1, tg_xxxxxyz_zz_0, tg_xxxxxyz_zz_1, \
                                         tg_xxxxxyzz_xx_0, tg_xxxxxyzz_xy_0, tg_xxxxxyzz_xz_0, tg_xxxxxyzz_yy_0, \
                                         tg_xxxxxyzz_yz_0, tg_xxxxxyzz_zz_0, tg_xxxxxz_xx_0, tg_xxxxxz_xx_1, tg_xxxxxz_xy_0, \
                                         tg_xxxxxz_xy_1, tg_xxxxxz_xz_0, tg_xxxxxz_xz_1, tg_xxxxxz_yy_0, tg_xxxxxz_yy_1, \
                                         tg_xxxxxz_yz_0, tg_xxxxxz_yz_1, tg_xxxxxz_zz_0, tg_xxxxxz_zz_1, tg_xxxxxzz_x_1, \
                                         tg_xxxxxzz_xx_0, tg_xxxxxzz_xx_1, tg_xxxxxzz_xy_0, tg_xxxxxzz_xy_1, tg_xxxxxzz_xz_0, \
                                         tg_xxxxxzz_xz_1, tg_xxxxxzz_y_1, tg_xxxxxzz_yy_0, tg_xxxxxzz_yy_1, tg_xxxxxzz_yz_0, \
                                         tg_xxxxxzz_yz_1, tg_xxxxxzz_z_1, tg_xxxxxzz_zz_0, tg_xxxxxzz_zz_1, tg_xxxxxzzz_xx_0, \
                                         tg_xxxxxzzz_xy_0, tg_xxxxxzzz_xz_0, tg_xxxxxzzz_yy_0, tg_xxxxxzzz_yz_0, \
                                         tg_xxxxxzzz_zz_0, tg_xxxxyy_xx_0, tg_xxxxyy_xx_1, tg_xxxxyy_xy_0, tg_xxxxyy_xy_1, \
                                         tg_xxxxyy_xz_0, tg_xxxxyy_xz_1, tg_xxxxyy_yy_0, tg_xxxxyy_yy_1, tg_xxxxyy_yz_0, \
                                         tg_xxxxyy_yz_1, tg_xxxxyy_zz_0, tg_xxxxyy_zz_1, tg_xxxxyyy_x_1, tg_xxxxyyy_xx_0, \
                                         tg_xxxxyyy_xx_1, tg_xxxxyyy_xy_0, tg_xxxxyyy_xy_1, tg_xxxxyyy_xz_0, tg_xxxxyyy_xz_1, \
                                         tg_xxxxyyy_y_1, tg_xxxxyyy_yy_0, tg_xxxxyyy_yy_1, tg_xxxxyyy_yz_0, tg_xxxxyyy_yz_1, \
                                         tg_xxxxyyy_z_1, tg_xxxxyyy_zz_0, tg_xxxxyyy_zz_1, tg_xxxxyyyy_xx_0, \
                                         tg_xxxxyyyy_xy_0, tg_xxxxyyyy_xz_0, tg_xxxxyyyy_yy_0, tg_xxxxyyyy_yz_0, \
                                         tg_xxxxyyyy_zz_0, tg_xxxxyyyz_xx_0, tg_xxxxyyyz_xy_0, tg_xxxxyyyz_xz_0, \
                                         tg_xxxxyyyz_yy_0, tg_xxxxyyyz_yz_0, tg_xxxxyyyz_zz_0, tg_xxxxyyz_x_1, \
                                         tg_xxxxyyz_xx_0, tg_xxxxyyz_xx_1, tg_xxxxyyz_xy_0, tg_xxxxyyz_xy_1, tg_xxxxyyz_xz_0, \
                                         tg_xxxxyyz_xz_1, tg_xxxxyyz_y_1, tg_xxxxyyz_yy_0, tg_xxxxyyz_yy_1, tg_xxxxyyz_yz_0, \
                                         tg_xxxxyyz_yz_1, tg_xxxxyyz_z_1, tg_xxxxyyz_zz_0, tg_xxxxyyz_zz_1, tg_xxxxyyzz_xx_0, \
                                         tg_xxxxyyzz_xy_0, tg_xxxxyyzz_xz_0, tg_xxxxyyzz_yy_0, tg_xxxxyyzz_yz_0, \
                                         tg_xxxxyyzz_zz_0, tg_xxxxyz_xx_0, tg_xxxxyz_xx_1, tg_xxxxyz_xy_0, tg_xxxxyz_xy_1, \
                                         tg_xxxxyz_xz_0, tg_xxxxyz_xz_1, tg_xxxxyz_yy_0, tg_xxxxyz_yy_1, tg_xxxxyz_yz_0, \
                                         tg_xxxxyz_yz_1, tg_xxxxyz_zz_0, tg_xxxxyz_zz_1, tg_xxxxyzz_x_1, tg_xxxxyzz_xx_0, \
                                         tg_xxxxyzz_xx_1, tg_xxxxyzz_xy_0, tg_xxxxyzz_xy_1, tg_xxxxyzz_xz_0, tg_xxxxyzz_xz_1, \
                                         tg_xxxxyzz_y_1, tg_xxxxyzz_yy_0, tg_xxxxyzz_yy_1, tg_xxxxyzz_yz_0, tg_xxxxyzz_yz_1, \
                                         tg_xxxxyzz_z_1, tg_xxxxyzz_zz_0, tg_xxxxyzz_zz_1, tg_xxxxyzzz_xx_0, \
                                         tg_xxxxyzzz_xy_0, tg_xxxxyzzz_xz_0, tg_xxxxyzzz_yy_0, tg_xxxxyzzz_yz_0, \
                                         tg_xxxxyzzz_zz_0, tg_xxxxzz_xx_0, tg_xxxxzz_xx_1, tg_xxxxzz_xy_0, tg_xxxxzz_xy_1, \
                                         tg_xxxxzz_xz_0, tg_xxxxzz_xz_1, tg_xxxxzz_yy_0, tg_xxxxzz_yy_1, tg_xxxxzz_yz_0, \
                                         tg_xxxxzz_yz_1, tg_xxxxzz_zz_0, tg_xxxxzz_zz_1, tg_xxxxzzz_x_1, tg_xxxxzzz_xx_0, \
                                         tg_xxxxzzz_xx_1, tg_xxxxzzz_xy_0, tg_xxxxzzz_xy_1, tg_xxxxzzz_xz_0, tg_xxxxzzz_xz_1, \
                                         tg_xxxxzzz_y_1, tg_xxxxzzz_yy_0, tg_xxxxzzz_yy_1, tg_xxxxzzz_yz_0, tg_xxxxzzz_yz_1, \
                                         tg_xxxxzzz_z_1, tg_xxxxzzz_zz_0, tg_xxxxzzz_zz_1, tg_xxxxzzzz_xx_0, \
                                         tg_xxxxzzzz_xy_0, tg_xxxxzzzz_xz_0, tg_xxxxzzzz_yy_0, tg_xxxxzzzz_yz_0, \
                                         tg_xxxxzzzz_zz_0, tg_xxxyyy_xx_0, tg_xxxyyy_xx_1, tg_xxxyyy_xy_0, tg_xxxyyy_xy_1, \
                                         tg_xxxyyy_xz_0, tg_xxxyyy_xz_1, tg_xxxyyy_yy_0, tg_xxxyyy_yy_1, tg_xxxyyy_yz_0, \
                                         tg_xxxyyy_yz_1, tg_xxxyyy_zz_0, tg_xxxyyy_zz_1, tg_xxxyyyy_x_1, tg_xxxyyyy_xx_0, \
                                         tg_xxxyyyy_xx_1, tg_xxxyyyy_xy_0, tg_xxxyyyy_xy_1, tg_xxxyyyy_xz_0, tg_xxxyyyy_xz_1, \
                                         tg_xxxyyyy_y_1, tg_xxxyyyy_yy_0, tg_xxxyyyy_yy_1, tg_xxxyyyy_yz_0, tg_xxxyyyy_yz_1, \
                                         tg_xxxyyyy_z_1, tg_xxxyyyy_zz_0, tg_xxxyyyy_zz_1, tg_xxxyyyz_x_1, tg_xxxyyyz_xx_0, \
                                         tg_xxxyyyz_xx_1, tg_xxxyyyz_xy_0, tg_xxxyyyz_xy_1, tg_xxxyyyz_xz_0, tg_xxxyyyz_xz_1, \
                                         tg_xxxyyyz_y_1, tg_xxxyyyz_yy_0, tg_xxxyyyz_yy_1, tg_xxxyyyz_yz_0, tg_xxxyyyz_yz_1, \
                                         tg_xxxyyyz_z_1, tg_xxxyyyz_zz_0, tg_xxxyyyz_zz_1, tg_xxxyyz_xx_0, tg_xxxyyz_xx_1, \
                                         tg_xxxyyz_xy_0, tg_xxxyyz_xy_1, tg_xxxyyz_xz_0, tg_xxxyyz_xz_1, tg_xxxyyz_yy_0, \
                                         tg_xxxyyz_yy_1, tg_xxxyyz_yz_0, tg_xxxyyz_yz_1, tg_xxxyyz_zz_0, tg_xxxyyz_zz_1, \
                                         tg_xxxyyzz_x_1, tg_xxxyyzz_xx_0, tg_xxxyyzz_xx_1, tg_xxxyyzz_xy_0, tg_xxxyyzz_xy_1, \
                                         tg_xxxyyzz_xz_0, tg_xxxyyzz_xz_1, tg_xxxyyzz_y_1, tg_xxxyyzz_yy_0, tg_xxxyyzz_yy_1, \
                                         tg_xxxyyzz_yz_0, tg_xxxyyzz_yz_1, tg_xxxyyzz_z_1, tg_xxxyyzz_zz_0, tg_xxxyyzz_zz_1, \
                                         tg_xxxyzz_xx_0, tg_xxxyzz_xx_1, tg_xxxyzz_xy_0, tg_xxxyzz_xy_1, tg_xxxyzz_xz_0, \
                                         tg_xxxyzz_xz_1, tg_xxxyzz_yy_0, tg_xxxyzz_yy_1, tg_xxxyzz_yz_0, tg_xxxyzz_yz_1, \
                                         tg_xxxyzz_zz_0, tg_xxxyzz_zz_1, tg_xxxyzzz_x_1, tg_xxxyzzz_xx_0, tg_xxxyzzz_xx_1, \
                                         tg_xxxyzzz_xy_0, tg_xxxyzzz_xy_1, tg_xxxyzzz_xz_0, tg_xxxyzzz_xz_1, tg_xxxyzzz_y_1, \
                                         tg_xxxyzzz_yy_0, tg_xxxyzzz_yy_1, tg_xxxyzzz_yz_0, tg_xxxyzzz_yz_1, tg_xxxyzzz_z_1, \
                                         tg_xxxyzzz_zz_0, tg_xxxyzzz_zz_1, tg_xxxzzz_xx_0, tg_xxxzzz_xx_1, tg_xxxzzz_xy_0, \
                                         tg_xxxzzz_xy_1, tg_xxxzzz_xz_0, tg_xxxzzz_xz_1, tg_xxxzzz_yy_0, tg_xxxzzz_yy_1, \
                                         tg_xxxzzz_yz_0, tg_xxxzzz_yz_1, tg_xxxzzz_zz_0, tg_xxxzzz_zz_1, tg_xxxzzzz_x_1, \
                                         tg_xxxzzzz_xx_0, tg_xxxzzzz_xx_1, tg_xxxzzzz_xy_0, tg_xxxzzzz_xy_1, tg_xxxzzzz_xz_0, \
                                         tg_xxxzzzz_xz_1, tg_xxxzzzz_y_1, tg_xxxzzzz_yy_0, tg_xxxzzzz_yy_1, tg_xxxzzzz_yz_0, \
                                         tg_xxxzzzz_yz_1, tg_xxxzzzz_z_1, tg_xxxzzzz_zz_0, tg_xxxzzzz_zz_1, tg_xxyyyy_xx_0, \
                                         tg_xxyyyy_xx_1, tg_xxyyyy_xy_0, tg_xxyyyy_xy_1, tg_xxyyyy_xz_0, tg_xxyyyy_xz_1, \
                                         tg_xxyyyy_yy_0, tg_xxyyyy_yy_1, tg_xxyyyy_yz_0, tg_xxyyyy_yz_1, tg_xxyyyy_zz_0, \
                                         tg_xxyyyy_zz_1, tg_xxyyyz_xx_0, tg_xxyyyz_xx_1, tg_xxyyyz_xy_0, tg_xxyyyz_xy_1, \
                                         tg_xxyyyz_xz_0, tg_xxyyyz_xz_1, tg_xxyyyz_yy_0, tg_xxyyyz_yy_1, tg_xxyyyz_yz_0, \
                                         tg_xxyyyz_yz_1, tg_xxyyyz_zz_0, tg_xxyyyz_zz_1, tg_xxyyzz_xx_0, tg_xxyyzz_xx_1, \
                                         tg_xxyyzz_xy_0, tg_xxyyzz_xy_1, tg_xxyyzz_xz_0, tg_xxyyzz_xz_1, tg_xxyyzz_yy_0, \
                                         tg_xxyyzz_yy_1, tg_xxyyzz_yz_0, tg_xxyyzz_yz_1, tg_xxyyzz_zz_0, tg_xxyyzz_zz_1, \
                                         tg_xxyzzz_xx_0, tg_xxyzzz_xx_1, tg_xxyzzz_xy_0, tg_xxyzzz_xy_1, tg_xxyzzz_xz_0, \
                                         tg_xxyzzz_xz_1, tg_xxyzzz_yy_0, tg_xxyzzz_yy_1, tg_xxyzzz_yz_0, tg_xxyzzz_yz_1, \
                                         tg_xxyzzz_zz_0, tg_xxyzzz_zz_1, tg_xxzzzz_xx_0, tg_xxzzzz_xx_1, tg_xxzzzz_xy_0, \
                                         tg_xxzzzz_xy_1, tg_xxzzzz_xz_0, tg_xxzzzz_xz_1, tg_xxzzzz_yy_0, tg_xxzzzz_yy_1, \
                                         tg_xxzzzz_yz_0, tg_xxzzzz_yz_1, tg_xxzzzz_zz_0, tg_xxzzzz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxxx_xx_0[j] = pb_x * tg_xxxxxxx_xx_0[j] + fr * tg_xxxxxxx_xx_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xx_0[j] - tg_xxxxxx_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_x_1[j];

                    tg_xxxxxxxx_xy_0[j] = pb_x * tg_xxxxxxx_xy_0[j] + fr * tg_xxxxxxx_xy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xy_0[j] - tg_xxxxxx_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_y_1[j];

                    tg_xxxxxxxx_xz_0[j] = pb_x * tg_xxxxxxx_xz_0[j] + fr * tg_xxxxxxx_xz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xz_0[j] - tg_xxxxxx_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_z_1[j];

                    tg_xxxxxxxx_yy_0[j] = pb_x * tg_xxxxxxx_yy_0[j] + fr * tg_xxxxxxx_yy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yy_0[j] - tg_xxxxxx_yy_1[j] * fl1_fza);

                    tg_xxxxxxxx_yz_0[j] = pb_x * tg_xxxxxxx_yz_0[j] + fr * tg_xxxxxxx_yz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yz_0[j] - tg_xxxxxx_yz_1[j] * fl1_fza);

                    tg_xxxxxxxx_zz_0[j] = pb_x * tg_xxxxxxx_zz_0[j] + fr * tg_xxxxxxx_zz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_zz_0[j] - tg_xxxxxx_zz_1[j] * fl1_fza);

                    tg_xxxxxxxy_xx_0[j] = pb_x * tg_xxxxxxy_xx_0[j] + fr * tg_xxxxxxy_xx_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xx_0[j] - tg_xxxxxy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_x_1[j];

                    tg_xxxxxxxy_xy_0[j] = pb_x * tg_xxxxxxy_xy_0[j] + fr * tg_xxxxxxy_xy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xy_0[j] - tg_xxxxxy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_y_1[j];

                    tg_xxxxxxxy_xz_0[j] = pb_x * tg_xxxxxxy_xz_0[j] + fr * tg_xxxxxxy_xz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xz_0[j] - tg_xxxxxy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_z_1[j];

                    tg_xxxxxxxy_yy_0[j] = pb_x * tg_xxxxxxy_yy_0[j] + fr * tg_xxxxxxy_yy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yy_0[j] - tg_xxxxxy_yy_1[j] * fl1_fza);

                    tg_xxxxxxxy_yz_0[j] = pb_x * tg_xxxxxxy_yz_0[j] + fr * tg_xxxxxxy_yz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yz_0[j] - tg_xxxxxy_yz_1[j] * fl1_fza);

                    tg_xxxxxxxy_zz_0[j] = pb_x * tg_xxxxxxy_zz_0[j] + fr * tg_xxxxxxy_zz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_zz_0[j] - tg_xxxxxy_zz_1[j] * fl1_fza);

                    tg_xxxxxxxz_xx_0[j] = pb_x * tg_xxxxxxz_xx_0[j] + fr * tg_xxxxxxz_xx_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xx_0[j] - tg_xxxxxz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_x_1[j];

                    tg_xxxxxxxz_xy_0[j] = pb_x * tg_xxxxxxz_xy_0[j] + fr * tg_xxxxxxz_xy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xy_0[j] - tg_xxxxxz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_y_1[j];

                    tg_xxxxxxxz_xz_0[j] = pb_x * tg_xxxxxxz_xz_0[j] + fr * tg_xxxxxxz_xz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xz_0[j] - tg_xxxxxz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_z_1[j];

                    tg_xxxxxxxz_yy_0[j] = pb_x * tg_xxxxxxz_yy_0[j] + fr * tg_xxxxxxz_yy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yy_0[j] - tg_xxxxxz_yy_1[j] * fl1_fza);

                    tg_xxxxxxxz_yz_0[j] = pb_x * tg_xxxxxxz_yz_0[j] + fr * tg_xxxxxxz_yz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yz_0[j] - tg_xxxxxz_yz_1[j] * fl1_fza);

                    tg_xxxxxxxz_zz_0[j] = pb_x * tg_xxxxxxz_zz_0[j] + fr * tg_xxxxxxz_zz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_zz_0[j] - tg_xxxxxz_zz_1[j] * fl1_fza);

                    tg_xxxxxxyy_xx_0[j] = pb_x * tg_xxxxxyy_xx_0[j] + fr * tg_xxxxxyy_xx_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xx_0[j] - tg_xxxxyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_x_1[j];

                    tg_xxxxxxyy_xy_0[j] = pb_x * tg_xxxxxyy_xy_0[j] + fr * tg_xxxxxyy_xy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xy_0[j] - tg_xxxxyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_y_1[j];

                    tg_xxxxxxyy_xz_0[j] = pb_x * tg_xxxxxyy_xz_0[j] + fr * tg_xxxxxyy_xz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xz_0[j] - tg_xxxxyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_z_1[j];

                    tg_xxxxxxyy_yy_0[j] = pb_x * tg_xxxxxyy_yy_0[j] + fr * tg_xxxxxyy_yy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yy_0[j] - tg_xxxxyy_yy_1[j] * fl1_fza);

                    tg_xxxxxxyy_yz_0[j] = pb_x * tg_xxxxxyy_yz_0[j] + fr * tg_xxxxxyy_yz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yz_0[j] - tg_xxxxyy_yz_1[j] * fl1_fza);

                    tg_xxxxxxyy_zz_0[j] = pb_x * tg_xxxxxyy_zz_0[j] + fr * tg_xxxxxyy_zz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_zz_0[j] - tg_xxxxyy_zz_1[j] * fl1_fza);

                    tg_xxxxxxyz_xx_0[j] = pb_x * tg_xxxxxyz_xx_0[j] + fr * tg_xxxxxyz_xx_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xx_0[j] - tg_xxxxyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_x_1[j];

                    tg_xxxxxxyz_xy_0[j] = pb_x * tg_xxxxxyz_xy_0[j] + fr * tg_xxxxxyz_xy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xy_0[j] - tg_xxxxyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_y_1[j];

                    tg_xxxxxxyz_xz_0[j] = pb_x * tg_xxxxxyz_xz_0[j] + fr * tg_xxxxxyz_xz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xz_0[j] - tg_xxxxyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_z_1[j];

                    tg_xxxxxxyz_yy_0[j] = pb_x * tg_xxxxxyz_yy_0[j] + fr * tg_xxxxxyz_yy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yy_0[j] - tg_xxxxyz_yy_1[j] * fl1_fza);

                    tg_xxxxxxyz_yz_0[j] = pb_x * tg_xxxxxyz_yz_0[j] + fr * tg_xxxxxyz_yz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yz_0[j] - tg_xxxxyz_yz_1[j] * fl1_fza);

                    tg_xxxxxxyz_zz_0[j] = pb_x * tg_xxxxxyz_zz_0[j] + fr * tg_xxxxxyz_zz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_zz_0[j] - tg_xxxxyz_zz_1[j] * fl1_fza);

                    tg_xxxxxxzz_xx_0[j] = pb_x * tg_xxxxxzz_xx_0[j] + fr * tg_xxxxxzz_xx_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xx_0[j] - tg_xxxxzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_x_1[j];

                    tg_xxxxxxzz_xy_0[j] = pb_x * tg_xxxxxzz_xy_0[j] + fr * tg_xxxxxzz_xy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xy_0[j] - tg_xxxxzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_y_1[j];

                    tg_xxxxxxzz_xz_0[j] = pb_x * tg_xxxxxzz_xz_0[j] + fr * tg_xxxxxzz_xz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xz_0[j] - tg_xxxxzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_z_1[j];

                    tg_xxxxxxzz_yy_0[j] = pb_x * tg_xxxxxzz_yy_0[j] + fr * tg_xxxxxzz_yy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yy_0[j] - tg_xxxxzz_yy_1[j] * fl1_fza);

                    tg_xxxxxxzz_yz_0[j] = pb_x * tg_xxxxxzz_yz_0[j] + fr * tg_xxxxxzz_yz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yz_0[j] - tg_xxxxzz_yz_1[j] * fl1_fza);

                    tg_xxxxxxzz_zz_0[j] = pb_x * tg_xxxxxzz_zz_0[j] + fr * tg_xxxxxzz_zz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_zz_0[j] - tg_xxxxzz_zz_1[j] * fl1_fza);

                    tg_xxxxxyyy_xx_0[j] = pb_x * tg_xxxxyyy_xx_0[j] + fr * tg_xxxxyyy_xx_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xx_0[j] - tg_xxxyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_x_1[j];

                    tg_xxxxxyyy_xy_0[j] = pb_x * tg_xxxxyyy_xy_0[j] + fr * tg_xxxxyyy_xy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xy_0[j] - tg_xxxyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_y_1[j];

                    tg_xxxxxyyy_xz_0[j] = pb_x * tg_xxxxyyy_xz_0[j] + fr * tg_xxxxyyy_xz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xz_0[j] - tg_xxxyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_z_1[j];

                    tg_xxxxxyyy_yy_0[j] = pb_x * tg_xxxxyyy_yy_0[j] + fr * tg_xxxxyyy_yy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yy_0[j] - tg_xxxyyy_yy_1[j] * fl1_fza);

                    tg_xxxxxyyy_yz_0[j] = pb_x * tg_xxxxyyy_yz_0[j] + fr * tg_xxxxyyy_yz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yz_0[j] - tg_xxxyyy_yz_1[j] * fl1_fza);

                    tg_xxxxxyyy_zz_0[j] = pb_x * tg_xxxxyyy_zz_0[j] + fr * tg_xxxxyyy_zz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_zz_0[j] - tg_xxxyyy_zz_1[j] * fl1_fza);

                    tg_xxxxxyyz_xx_0[j] = pb_x * tg_xxxxyyz_xx_0[j] + fr * tg_xxxxyyz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xx_0[j] - tg_xxxyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_x_1[j];

                    tg_xxxxxyyz_xy_0[j] = pb_x * tg_xxxxyyz_xy_0[j] + fr * tg_xxxxyyz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xy_0[j] - tg_xxxyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_y_1[j];

                    tg_xxxxxyyz_xz_0[j] = pb_x * tg_xxxxyyz_xz_0[j] + fr * tg_xxxxyyz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xz_0[j] - tg_xxxyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_z_1[j];

                    tg_xxxxxyyz_yy_0[j] = pb_x * tg_xxxxyyz_yy_0[j] + fr * tg_xxxxyyz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yy_0[j] - tg_xxxyyz_yy_1[j] * fl1_fza);

                    tg_xxxxxyyz_yz_0[j] = pb_x * tg_xxxxyyz_yz_0[j] + fr * tg_xxxxyyz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yz_0[j] - tg_xxxyyz_yz_1[j] * fl1_fza);

                    tg_xxxxxyyz_zz_0[j] = pb_x * tg_xxxxyyz_zz_0[j] + fr * tg_xxxxyyz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_zz_0[j] - tg_xxxyyz_zz_1[j] * fl1_fza);

                    tg_xxxxxyzz_xx_0[j] = pb_x * tg_xxxxyzz_xx_0[j] + fr * tg_xxxxyzz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xx_0[j] - tg_xxxyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_x_1[j];

                    tg_xxxxxyzz_xy_0[j] = pb_x * tg_xxxxyzz_xy_0[j] + fr * tg_xxxxyzz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xy_0[j] - tg_xxxyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_y_1[j];

                    tg_xxxxxyzz_xz_0[j] = pb_x * tg_xxxxyzz_xz_0[j] + fr * tg_xxxxyzz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xz_0[j] - tg_xxxyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_z_1[j];

                    tg_xxxxxyzz_yy_0[j] = pb_x * tg_xxxxyzz_yy_0[j] + fr * tg_xxxxyzz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yy_0[j] - tg_xxxyzz_yy_1[j] * fl1_fza);

                    tg_xxxxxyzz_yz_0[j] = pb_x * tg_xxxxyzz_yz_0[j] + fr * tg_xxxxyzz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yz_0[j] - tg_xxxyzz_yz_1[j] * fl1_fza);

                    tg_xxxxxyzz_zz_0[j] = pb_x * tg_xxxxyzz_zz_0[j] + fr * tg_xxxxyzz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_zz_0[j] - tg_xxxyzz_zz_1[j] * fl1_fza);

                    tg_xxxxxzzz_xx_0[j] = pb_x * tg_xxxxzzz_xx_0[j] + fr * tg_xxxxzzz_xx_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xx_0[j] - tg_xxxzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_x_1[j];

                    tg_xxxxxzzz_xy_0[j] = pb_x * tg_xxxxzzz_xy_0[j] + fr * tg_xxxxzzz_xy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xy_0[j] - tg_xxxzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_y_1[j];

                    tg_xxxxxzzz_xz_0[j] = pb_x * tg_xxxxzzz_xz_0[j] + fr * tg_xxxxzzz_xz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xz_0[j] - tg_xxxzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_z_1[j];

                    tg_xxxxxzzz_yy_0[j] = pb_x * tg_xxxxzzz_yy_0[j] + fr * tg_xxxxzzz_yy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yy_0[j] - tg_xxxzzz_yy_1[j] * fl1_fza);

                    tg_xxxxxzzz_yz_0[j] = pb_x * tg_xxxxzzz_yz_0[j] + fr * tg_xxxxzzz_yz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yz_0[j] - tg_xxxzzz_yz_1[j] * fl1_fza);

                    tg_xxxxxzzz_zz_0[j] = pb_x * tg_xxxxzzz_zz_0[j] + fr * tg_xxxxzzz_zz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_zz_0[j] - tg_xxxzzz_zz_1[j] * fl1_fza);

                    tg_xxxxyyyy_xx_0[j] = pb_x * tg_xxxyyyy_xx_0[j] + fr * tg_xxxyyyy_xx_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xx_0[j] - tg_xxyyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_x_1[j];

                    tg_xxxxyyyy_xy_0[j] = pb_x * tg_xxxyyyy_xy_0[j] + fr * tg_xxxyyyy_xy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xy_0[j] - tg_xxyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_y_1[j];

                    tg_xxxxyyyy_xz_0[j] = pb_x * tg_xxxyyyy_xz_0[j] + fr * tg_xxxyyyy_xz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xz_0[j] - tg_xxyyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_z_1[j];

                    tg_xxxxyyyy_yy_0[j] = pb_x * tg_xxxyyyy_yy_0[j] + fr * tg_xxxyyyy_yy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yy_0[j] - tg_xxyyyy_yy_1[j] * fl1_fza);

                    tg_xxxxyyyy_yz_0[j] = pb_x * tg_xxxyyyy_yz_0[j] + fr * tg_xxxyyyy_yz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yz_0[j] - tg_xxyyyy_yz_1[j] * fl1_fza);

                    tg_xxxxyyyy_zz_0[j] = pb_x * tg_xxxyyyy_zz_0[j] + fr * tg_xxxyyyy_zz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_zz_0[j] - tg_xxyyyy_zz_1[j] * fl1_fza);

                    tg_xxxxyyyz_xx_0[j] = pb_x * tg_xxxyyyz_xx_0[j] + fr * tg_xxxyyyz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xx_0[j] - tg_xxyyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_x_1[j];

                    tg_xxxxyyyz_xy_0[j] = pb_x * tg_xxxyyyz_xy_0[j] + fr * tg_xxxyyyz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xy_0[j] - tg_xxyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_y_1[j];

                    tg_xxxxyyyz_xz_0[j] = pb_x * tg_xxxyyyz_xz_0[j] + fr * tg_xxxyyyz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xz_0[j] - tg_xxyyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_z_1[j];

                    tg_xxxxyyyz_yy_0[j] = pb_x * tg_xxxyyyz_yy_0[j] + fr * tg_xxxyyyz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yy_0[j] - tg_xxyyyz_yy_1[j] * fl1_fza);

                    tg_xxxxyyyz_yz_0[j] = pb_x * tg_xxxyyyz_yz_0[j] + fr * tg_xxxyyyz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yz_0[j] - tg_xxyyyz_yz_1[j] * fl1_fza);

                    tg_xxxxyyyz_zz_0[j] = pb_x * tg_xxxyyyz_zz_0[j] + fr * tg_xxxyyyz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_zz_0[j] - tg_xxyyyz_zz_1[j] * fl1_fza);

                    tg_xxxxyyzz_xx_0[j] = pb_x * tg_xxxyyzz_xx_0[j] + fr * tg_xxxyyzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xx_0[j] - tg_xxyyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_x_1[j];

                    tg_xxxxyyzz_xy_0[j] = pb_x * tg_xxxyyzz_xy_0[j] + fr * tg_xxxyyzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xy_0[j] - tg_xxyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_y_1[j];

                    tg_xxxxyyzz_xz_0[j] = pb_x * tg_xxxyyzz_xz_0[j] + fr * tg_xxxyyzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xz_0[j] - tg_xxyyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_z_1[j];

                    tg_xxxxyyzz_yy_0[j] = pb_x * tg_xxxyyzz_yy_0[j] + fr * tg_xxxyyzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yy_0[j] - tg_xxyyzz_yy_1[j] * fl1_fza);

                    tg_xxxxyyzz_yz_0[j] = pb_x * tg_xxxyyzz_yz_0[j] + fr * tg_xxxyyzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yz_0[j] - tg_xxyyzz_yz_1[j] * fl1_fza);

                    tg_xxxxyyzz_zz_0[j] = pb_x * tg_xxxyyzz_zz_0[j] + fr * tg_xxxyyzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_zz_0[j] - tg_xxyyzz_zz_1[j] * fl1_fza);

                    tg_xxxxyzzz_xx_0[j] = pb_x * tg_xxxyzzz_xx_0[j] + fr * tg_xxxyzzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xx_0[j] - tg_xxyzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_x_1[j];

                    tg_xxxxyzzz_xy_0[j] = pb_x * tg_xxxyzzz_xy_0[j] + fr * tg_xxxyzzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xy_0[j] - tg_xxyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_y_1[j];

                    tg_xxxxyzzz_xz_0[j] = pb_x * tg_xxxyzzz_xz_0[j] + fr * tg_xxxyzzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xz_0[j] - tg_xxyzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_z_1[j];

                    tg_xxxxyzzz_yy_0[j] = pb_x * tg_xxxyzzz_yy_0[j] + fr * tg_xxxyzzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yy_0[j] - tg_xxyzzz_yy_1[j] * fl1_fza);

                    tg_xxxxyzzz_yz_0[j] = pb_x * tg_xxxyzzz_yz_0[j] + fr * tg_xxxyzzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yz_0[j] - tg_xxyzzz_yz_1[j] * fl1_fza);

                    tg_xxxxyzzz_zz_0[j] = pb_x * tg_xxxyzzz_zz_0[j] + fr * tg_xxxyzzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_zz_0[j] - tg_xxyzzz_zz_1[j] * fl1_fza);

                    tg_xxxxzzzz_xx_0[j] = pb_x * tg_xxxzzzz_xx_0[j] + fr * tg_xxxzzzz_xx_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xx_0[j] - tg_xxzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_x_1[j];

                    tg_xxxxzzzz_xy_0[j] = pb_x * tg_xxxzzzz_xy_0[j] + fr * tg_xxxzzzz_xy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xy_0[j] - tg_xxzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_y_1[j];

                    tg_xxxxzzzz_xz_0[j] = pb_x * tg_xxxzzzz_xz_0[j] + fr * tg_xxxzzzz_xz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xz_0[j] - tg_xxzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_z_1[j];

                    tg_xxxxzzzz_yy_0[j] = pb_x * tg_xxxzzzz_yy_0[j] + fr * tg_xxxzzzz_yy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yy_0[j] - tg_xxzzzz_yy_1[j] * fl1_fza);

                    tg_xxxxzzzz_yz_0[j] = pb_x * tg_xxxzzzz_yz_0[j] + fr * tg_xxxzzzz_yz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yz_0[j] - tg_xxzzzz_yz_1[j] * fl1_fza);

                    tg_xxxxzzzz_zz_0[j] = pb_x * tg_xxxzzzz_zz_0[j] + fr * tg_xxxzzzz_zz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_zz_0[j] - tg_xxzzzz_zz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSD_90_180(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (90,180)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 90); 

                auto tg_xxyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 91); 

                auto tg_xxyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 92); 

                auto tg_xxyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 93); 

                auto tg_xxyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 94); 

                auto tg_xxyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 95); 

                auto tg_xxyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 96); 

                auto tg_xxyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 97); 

                auto tg_xxyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 98); 

                auto tg_xxyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 99); 

                auto tg_xxyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 100); 

                auto tg_xxyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 101); 

                auto tg_xxyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 102); 

                auto tg_xxyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 103); 

                auto tg_xxyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 104); 

                auto tg_xxyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 105); 

                auto tg_xxyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 106); 

                auto tg_xxyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 107); 

                auto tg_xxyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 108); 

                auto tg_xxyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 109); 

                auto tg_xxyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 110); 

                auto tg_xxyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 111); 

                auto tg_xxyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 112); 

                auto tg_xxyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 113); 

                auto tg_xxyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 114); 

                auto tg_xxyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 115); 

                auto tg_xxyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 116); 

                auto tg_xxyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 117); 

                auto tg_xxyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 118); 

                auto tg_xxyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 119); 

                auto tg_xxzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 120); 

                auto tg_xxzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 121); 

                auto tg_xxzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 122); 

                auto tg_xxzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 123); 

                auto tg_xxzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 124); 

                auto tg_xxzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 125); 

                auto tg_xyyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 126); 

                auto tg_xyyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 127); 

                auto tg_xyyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 128); 

                auto tg_xyyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 129); 

                auto tg_xyyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 130); 

                auto tg_xyyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 131); 

                auto tg_xyyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 132); 

                auto tg_xyyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 133); 

                auto tg_xyyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 134); 

                auto tg_xyyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 135); 

                auto tg_xyyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 136); 

                auto tg_xyyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 137); 

                auto tg_xyyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 138); 

                auto tg_xyyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 139); 

                auto tg_xyyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 140); 

                auto tg_xyyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 141); 

                auto tg_xyyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 142); 

                auto tg_xyyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 143); 

                auto tg_xyyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 144); 

                auto tg_xyyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 145); 

                auto tg_xyyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 146); 

                auto tg_xyyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 147); 

                auto tg_xyyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 148); 

                auto tg_xyyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 149); 

                auto tg_xyyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 150); 

                auto tg_xyyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 151); 

                auto tg_xyyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 152); 

                auto tg_xyyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 153); 

                auto tg_xyyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 154); 

                auto tg_xyyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 155); 

                auto tg_xyzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 156); 

                auto tg_xyzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 157); 

                auto tg_xyzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 158); 

                auto tg_xyzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 159); 

                auto tg_xyzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 160); 

                auto tg_xyzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 161); 

                auto tg_xzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 162); 

                auto tg_xzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 163); 

                auto tg_xzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 164); 

                auto tg_xzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 165); 

                auto tg_xzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 166); 

                auto tg_xzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 167); 

                auto tg_yyyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 168); 

                auto tg_yyyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 169); 

                auto tg_yyyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 170); 

                auto tg_yyyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 171); 

                auto tg_yyyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 172); 

                auto tg_yyyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 173); 

                auto tg_yyyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 174); 

                auto tg_yyyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 175); 

                auto tg_yyyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 176); 

                auto tg_yyyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 177); 

                auto tg_yyyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 178); 

                auto tg_yyyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 179); 

                auto tg_xxyyyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 90); 

                auto tg_xxyyyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 91); 

                auto tg_xxyyyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 92); 

                auto tg_xxyyyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 93); 

                auto tg_xxyyyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 94); 

                auto tg_xxyyyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 95); 

                auto tg_xxyyyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 96); 

                auto tg_xxyyyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 97); 

                auto tg_xxyyyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 98); 

                auto tg_xxyyyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 99); 

                auto tg_xxyyyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 100); 

                auto tg_xxyyyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 101); 

                auto tg_xxyyyzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 102); 

                auto tg_xxyyyzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 103); 

                auto tg_xxyyyzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 104); 

                auto tg_xxyyyzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 105); 

                auto tg_xxyyyzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 106); 

                auto tg_xxyyyzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 107); 

                auto tg_xxyyzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 108); 

                auto tg_xxyyzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 109); 

                auto tg_xxyyzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 110); 

                auto tg_xxyyzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 111); 

                auto tg_xxyyzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 112); 

                auto tg_xxyyzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 113); 

                auto tg_xxyzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 114); 

                auto tg_xxyzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 115); 

                auto tg_xxyzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 116); 

                auto tg_xxyzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 117); 

                auto tg_xxyzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 118); 

                auto tg_xxyzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 119); 

                auto tg_xxzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 120); 

                auto tg_xxzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 121); 

                auto tg_xxzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 122); 

                auto tg_xxzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 123); 

                auto tg_xxzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 124); 

                auto tg_xxzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 125); 

                auto tg_xyyyyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 126); 

                auto tg_xyyyyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 127); 

                auto tg_xyyyyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 128); 

                auto tg_xyyyyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 129); 

                auto tg_xyyyyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 130); 

                auto tg_xyyyyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 131); 

                auto tg_xyyyyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 132); 

                auto tg_xyyyyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 133); 

                auto tg_xyyyyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 134); 

                auto tg_xyyyyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 135); 

                auto tg_xyyyyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 136); 

                auto tg_xyyyyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 137); 

                auto tg_xyyyyzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 138); 

                auto tg_xyyyyzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 139); 

                auto tg_xyyyyzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 140); 

                auto tg_xyyyyzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 141); 

                auto tg_xyyyyzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 142); 

                auto tg_xyyyyzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 143); 

                auto tg_xyyyzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 144); 

                auto tg_xyyyzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 145); 

                auto tg_xyyyzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 146); 

                auto tg_xyyyzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 147); 

                auto tg_xyyyzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 148); 

                auto tg_xyyyzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 149); 

                auto tg_xyyzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 150); 

                auto tg_xyyzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 151); 

                auto tg_xyyzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 152); 

                auto tg_xyyzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 153); 

                auto tg_xyyzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 154); 

                auto tg_xyyzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 155); 

                auto tg_xyzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 156); 

                auto tg_xyzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 157); 

                auto tg_xyzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 158); 

                auto tg_xyzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 159); 

                auto tg_xyzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 160); 

                auto tg_xyzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 161); 

                auto tg_xzzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 162); 

                auto tg_xzzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 163); 

                auto tg_xzzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 164); 

                auto tg_xzzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 165); 

                auto tg_xzzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 166); 

                auto tg_xzzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 167); 

                auto tg_yyyyyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 168); 

                auto tg_yyyyyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 169); 

                auto tg_yyyyyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 170); 

                auto tg_yyyyyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 171); 

                auto tg_yyyyyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 172); 

                auto tg_yyyyyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 173); 

                auto tg_yyyyyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 174); 

                auto tg_yyyyyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 175); 

                auto tg_yyyyyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 176); 

                auto tg_yyyyyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 177); 

                auto tg_yyyyyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 178); 

                auto tg_yyyyyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 179); 

                auto tg_xyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 90); 

                auto tg_xyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 91); 

                auto tg_xyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 92); 

                auto tg_xyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 93); 

                auto tg_xyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 94); 

                auto tg_xyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 95); 

                auto tg_xyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 96); 

                auto tg_xyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 97); 

                auto tg_xyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 98); 

                auto tg_xyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 99); 

                auto tg_xyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 100); 

                auto tg_xyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 101); 

                auto tg_xyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 102); 

                auto tg_xyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 103); 

                auto tg_xyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 104); 

                auto tg_xyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 105); 

                auto tg_xyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 106); 

                auto tg_xyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 107); 

                auto tg_xyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 108); 

                auto tg_xyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 109); 

                auto tg_xyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 110); 

                auto tg_xyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 111); 

                auto tg_xyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 112); 

                auto tg_xyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 113); 

                auto tg_xyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 114); 

                auto tg_xyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 115); 

                auto tg_xyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 116); 

                auto tg_xyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 117); 

                auto tg_xyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 118); 

                auto tg_xyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 119); 

                auto tg_xzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 120); 

                auto tg_xzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 121); 

                auto tg_xzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 122); 

                auto tg_xzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 123); 

                auto tg_xzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 124); 

                auto tg_xzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 125); 

                auto tg_yyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 167); 

                auto tg_xyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 90); 

                auto tg_xyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 91); 

                auto tg_xyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 92); 

                auto tg_xyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 93); 

                auto tg_xyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 94); 

                auto tg_xyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 95); 

                auto tg_xyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 96); 

                auto tg_xyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 97); 

                auto tg_xyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 98); 

                auto tg_xyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 99); 

                auto tg_xyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 100); 

                auto tg_xyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 101); 

                auto tg_xyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 102); 

                auto tg_xyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 103); 

                auto tg_xyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 104); 

                auto tg_xyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 105); 

                auto tg_xyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 106); 

                auto tg_xyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 107); 

                auto tg_xyyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 108); 

                auto tg_xyyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 109); 

                auto tg_xyyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 110); 

                auto tg_xyyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 111); 

                auto tg_xyyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 112); 

                auto tg_xyyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 113); 

                auto tg_xyzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 114); 

                auto tg_xyzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 115); 

                auto tg_xyzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 116); 

                auto tg_xyzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 117); 

                auto tg_xyzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 118); 

                auto tg_xyzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 119); 

                auto tg_xzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 120); 

                auto tg_xzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 121); 

                auto tg_xzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 122); 

                auto tg_xzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 123); 

                auto tg_xzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 124); 

                auto tg_xzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 125); 

                auto tg_yyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 167); 

                auto tg_xxyyyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 45); 

                auto tg_xxyyyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 46); 

                auto tg_xxyyyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 47); 

                auto tg_xxyyyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 48); 

                auto tg_xxyyyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 49); 

                auto tg_xxyyyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 50); 

                auto tg_xxyyyzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 51); 

                auto tg_xxyyyzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 52); 

                auto tg_xxyyyzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 53); 

                auto tg_xxyyzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 54); 

                auto tg_xxyyzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 55); 

                auto tg_xxyyzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 56); 

                auto tg_xxyzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 57); 

                auto tg_xxyzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 58); 

                auto tg_xxyzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 59); 

                auto tg_xxzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 60); 

                auto tg_xxzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 61); 

                auto tg_xxzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 62); 

                auto tg_xyyyyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 63); 

                auto tg_xyyyyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 64); 

                auto tg_xyyyyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 65); 

                auto tg_xyyyyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 66); 

                auto tg_xyyyyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 67); 

                auto tg_xyyyyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 68); 

                auto tg_xyyyyzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 69); 

                auto tg_xyyyyzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 70); 

                auto tg_xyyyyzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 71); 

                auto tg_xyyyzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 72); 

                auto tg_xyyyzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 73); 

                auto tg_xyyyzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 74); 

                auto tg_xyyzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 75); 

                auto tg_xyyzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 76); 

                auto tg_xyyzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 77); 

                auto tg_xyzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 78); 

                auto tg_xyzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 79); 

                auto tg_xyzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 80); 

                auto tg_xzzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 81); 

                auto tg_xzzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 82); 

                auto tg_xzzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 83); 

                auto tg_yyyyyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 84); 

                auto tg_yyyyyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 85); 

                auto tg_yyyyyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 86); 

                auto tg_yyyyyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 87); 

                auto tg_yyyyyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 88); 

                auto tg_yyyyyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 89); 

                // set up pointers to integrals

                auto tg_xxxyyyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 90); 

                auto tg_xxxyyyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 91); 

                auto tg_xxxyyyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 92); 

                auto tg_xxxyyyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 93); 

                auto tg_xxxyyyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 94); 

                auto tg_xxxyyyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 95); 

                auto tg_xxxyyyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 96); 

                auto tg_xxxyyyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 97); 

                auto tg_xxxyyyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 98); 

                auto tg_xxxyyyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 99); 

                auto tg_xxxyyyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 100); 

                auto tg_xxxyyyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 101); 

                auto tg_xxxyyyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 102); 

                auto tg_xxxyyyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 103); 

                auto tg_xxxyyyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 104); 

                auto tg_xxxyyyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 105); 

                auto tg_xxxyyyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 106); 

                auto tg_xxxyyyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 107); 

                auto tg_xxxyyzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 108); 

                auto tg_xxxyyzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 109); 

                auto tg_xxxyyzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 110); 

                auto tg_xxxyyzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 111); 

                auto tg_xxxyyzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 112); 

                auto tg_xxxyyzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 113); 

                auto tg_xxxyzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 114); 

                auto tg_xxxyzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 115); 

                auto tg_xxxyzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 116); 

                auto tg_xxxyzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 117); 

                auto tg_xxxyzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 118); 

                auto tg_xxxyzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 119); 

                auto tg_xxxzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 120); 

                auto tg_xxxzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 121); 

                auto tg_xxxzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 122); 

                auto tg_xxxzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 123); 

                auto tg_xxxzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 124); 

                auto tg_xxxzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 125); 

                auto tg_xxyyyyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 126); 

                auto tg_xxyyyyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 127); 

                auto tg_xxyyyyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 128); 

                auto tg_xxyyyyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 129); 

                auto tg_xxyyyyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 130); 

                auto tg_xxyyyyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 131); 

                auto tg_xxyyyyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 132); 

                auto tg_xxyyyyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 133); 

                auto tg_xxyyyyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 134); 

                auto tg_xxyyyyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 135); 

                auto tg_xxyyyyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 136); 

                auto tg_xxyyyyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 137); 

                auto tg_xxyyyyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 138); 

                auto tg_xxyyyyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 139); 

                auto tg_xxyyyyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 140); 

                auto tg_xxyyyyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 141); 

                auto tg_xxyyyyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 142); 

                auto tg_xxyyyyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 143); 

                auto tg_xxyyyzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 144); 

                auto tg_xxyyyzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 145); 

                auto tg_xxyyyzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 146); 

                auto tg_xxyyyzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 147); 

                auto tg_xxyyyzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 148); 

                auto tg_xxyyyzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 149); 

                auto tg_xxyyzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 150); 

                auto tg_xxyyzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 151); 

                auto tg_xxyyzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 152); 

                auto tg_xxyyzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 153); 

                auto tg_xxyyzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 154); 

                auto tg_xxyyzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 155); 

                auto tg_xxyzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 156); 

                auto tg_xxyzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 157); 

                auto tg_xxyzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 158); 

                auto tg_xxyzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 159); 

                auto tg_xxyzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 160); 

                auto tg_xxyzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 161); 

                auto tg_xxzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 162); 

                auto tg_xxzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 163); 

                auto tg_xxzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 164); 

                auto tg_xxzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 165); 

                auto tg_xxzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 166); 

                auto tg_xxzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 167); 

                auto tg_xyyyyyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 168); 

                auto tg_xyyyyyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 169); 

                auto tg_xyyyyyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 170); 

                auto tg_xyyyyyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 171); 

                auto tg_xyyyyyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 172); 

                auto tg_xyyyyyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 173); 

                auto tg_xyyyyyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 174); 

                auto tg_xyyyyyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 175); 

                auto tg_xyyyyyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 176); 

                auto tg_xyyyyyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 177); 

                auto tg_xyyyyyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 178); 

                auto tg_xyyyyyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 179); 

                // Batch of Integrals (90,180)

                #pragma omp simd aligned(fxn, fza, tg_xxxyyyyy_xx_0, tg_xxxyyyyy_xy_0, tg_xxxyyyyy_xz_0, \
                                         tg_xxxyyyyy_yy_0, tg_xxxyyyyy_yz_0, tg_xxxyyyyy_zz_0, tg_xxxyyyyz_xx_0, \
                                         tg_xxxyyyyz_xy_0, tg_xxxyyyyz_xz_0, tg_xxxyyyyz_yy_0, tg_xxxyyyyz_yz_0, \
                                         tg_xxxyyyyz_zz_0, tg_xxxyyyzz_xx_0, tg_xxxyyyzz_xy_0, tg_xxxyyyzz_xz_0, \
                                         tg_xxxyyyzz_yy_0, tg_xxxyyyzz_yz_0, tg_xxxyyyzz_zz_0, tg_xxxyyzzz_xx_0, \
                                         tg_xxxyyzzz_xy_0, tg_xxxyyzzz_xz_0, tg_xxxyyzzz_yy_0, tg_xxxyyzzz_yz_0, \
                                         tg_xxxyyzzz_zz_0, tg_xxxyzzzz_xx_0, tg_xxxyzzzz_xy_0, tg_xxxyzzzz_xz_0, \
                                         tg_xxxyzzzz_yy_0, tg_xxxyzzzz_yz_0, tg_xxxyzzzz_zz_0, tg_xxxzzzzz_xx_0, \
                                         tg_xxxzzzzz_xy_0, tg_xxxzzzzz_xz_0, tg_xxxzzzzz_yy_0, tg_xxxzzzzz_yz_0, \
                                         tg_xxxzzzzz_zz_0, tg_xxyyyyy_x_1, tg_xxyyyyy_xx_0, tg_xxyyyyy_xx_1, tg_xxyyyyy_xy_0, \
                                         tg_xxyyyyy_xy_1, tg_xxyyyyy_xz_0, tg_xxyyyyy_xz_1, tg_xxyyyyy_y_1, tg_xxyyyyy_yy_0, \
                                         tg_xxyyyyy_yy_1, tg_xxyyyyy_yz_0, tg_xxyyyyy_yz_1, tg_xxyyyyy_z_1, tg_xxyyyyy_zz_0, \
                                         tg_xxyyyyy_zz_1, tg_xxyyyyyy_xx_0, tg_xxyyyyyy_xy_0, tg_xxyyyyyy_xz_0, \
                                         tg_xxyyyyyy_yy_0, tg_xxyyyyyy_yz_0, tg_xxyyyyyy_zz_0, tg_xxyyyyyz_xx_0, \
                                         tg_xxyyyyyz_xy_0, tg_xxyyyyyz_xz_0, tg_xxyyyyyz_yy_0, tg_xxyyyyyz_yz_0, \
                                         tg_xxyyyyyz_zz_0, tg_xxyyyyz_x_1, tg_xxyyyyz_xx_0, tg_xxyyyyz_xx_1, tg_xxyyyyz_xy_0, \
                                         tg_xxyyyyz_xy_1, tg_xxyyyyz_xz_0, tg_xxyyyyz_xz_1, tg_xxyyyyz_y_1, tg_xxyyyyz_yy_0, \
                                         tg_xxyyyyz_yy_1, tg_xxyyyyz_yz_0, tg_xxyyyyz_yz_1, tg_xxyyyyz_z_1, tg_xxyyyyz_zz_0, \
                                         tg_xxyyyyz_zz_1, tg_xxyyyyzz_xx_0, tg_xxyyyyzz_xy_0, tg_xxyyyyzz_xz_0, \
                                         tg_xxyyyyzz_yy_0, tg_xxyyyyzz_yz_0, tg_xxyyyyzz_zz_0, tg_xxyyyzz_x_1, \
                                         tg_xxyyyzz_xx_0, tg_xxyyyzz_xx_1, tg_xxyyyzz_xy_0, tg_xxyyyzz_xy_1, tg_xxyyyzz_xz_0, \
                                         tg_xxyyyzz_xz_1, tg_xxyyyzz_y_1, tg_xxyyyzz_yy_0, tg_xxyyyzz_yy_1, tg_xxyyyzz_yz_0, \
                                         tg_xxyyyzz_yz_1, tg_xxyyyzz_z_1, tg_xxyyyzz_zz_0, tg_xxyyyzz_zz_1, tg_xxyyyzzz_xx_0, \
                                         tg_xxyyyzzz_xy_0, tg_xxyyyzzz_xz_0, tg_xxyyyzzz_yy_0, tg_xxyyyzzz_yz_0, \
                                         tg_xxyyyzzz_zz_0, tg_xxyyzzz_x_1, tg_xxyyzzz_xx_0, tg_xxyyzzz_xx_1, tg_xxyyzzz_xy_0, \
                                         tg_xxyyzzz_xy_1, tg_xxyyzzz_xz_0, tg_xxyyzzz_xz_1, tg_xxyyzzz_y_1, tg_xxyyzzz_yy_0, \
                                         tg_xxyyzzz_yy_1, tg_xxyyzzz_yz_0, tg_xxyyzzz_yz_1, tg_xxyyzzz_z_1, tg_xxyyzzz_zz_0, \
                                         tg_xxyyzzz_zz_1, tg_xxyyzzzz_xx_0, tg_xxyyzzzz_xy_0, tg_xxyyzzzz_xz_0, \
                                         tg_xxyyzzzz_yy_0, tg_xxyyzzzz_yz_0, tg_xxyyzzzz_zz_0, tg_xxyzzzz_x_1, \
                                         tg_xxyzzzz_xx_0, tg_xxyzzzz_xx_1, tg_xxyzzzz_xy_0, tg_xxyzzzz_xy_1, tg_xxyzzzz_xz_0, \
                                         tg_xxyzzzz_xz_1, tg_xxyzzzz_y_1, tg_xxyzzzz_yy_0, tg_xxyzzzz_yy_1, tg_xxyzzzz_yz_0, \
                                         tg_xxyzzzz_yz_1, tg_xxyzzzz_z_1, tg_xxyzzzz_zz_0, tg_xxyzzzz_zz_1, tg_xxyzzzzz_xx_0, \
                                         tg_xxyzzzzz_xy_0, tg_xxyzzzzz_xz_0, tg_xxyzzzzz_yy_0, tg_xxyzzzzz_yz_0, \
                                         tg_xxyzzzzz_zz_0, tg_xxzzzzz_x_1, tg_xxzzzzz_xx_0, tg_xxzzzzz_xx_1, tg_xxzzzzz_xy_0, \
                                         tg_xxzzzzz_xy_1, tg_xxzzzzz_xz_0, tg_xxzzzzz_xz_1, tg_xxzzzzz_y_1, tg_xxzzzzz_yy_0, \
                                         tg_xxzzzzz_yy_1, tg_xxzzzzz_yz_0, tg_xxzzzzz_yz_1, tg_xxzzzzz_z_1, tg_xxzzzzz_zz_0, \
                                         tg_xxzzzzz_zz_1, tg_xxzzzzzz_xx_0, tg_xxzzzzzz_xy_0, tg_xxzzzzzz_xz_0, \
                                         tg_xxzzzzzz_yy_0, tg_xxzzzzzz_yz_0, tg_xxzzzzzz_zz_0, tg_xyyyyy_xx_0, tg_xyyyyy_xx_1, \
                                         tg_xyyyyy_xy_0, tg_xyyyyy_xy_1, tg_xyyyyy_xz_0, tg_xyyyyy_xz_1, tg_xyyyyy_yy_0, \
                                         tg_xyyyyy_yy_1, tg_xyyyyy_yz_0, tg_xyyyyy_yz_1, tg_xyyyyy_zz_0, tg_xyyyyy_zz_1, \
                                         tg_xyyyyyy_x_1, tg_xyyyyyy_xx_0, tg_xyyyyyy_xx_1, tg_xyyyyyy_xy_0, tg_xyyyyyy_xy_1, \
                                         tg_xyyyyyy_xz_0, tg_xyyyyyy_xz_1, tg_xyyyyyy_y_1, tg_xyyyyyy_yy_0, tg_xyyyyyy_yy_1, \
                                         tg_xyyyyyy_yz_0, tg_xyyyyyy_yz_1, tg_xyyyyyy_z_1, tg_xyyyyyy_zz_0, tg_xyyyyyy_zz_1, \
                                         tg_xyyyyyyy_xx_0, tg_xyyyyyyy_xy_0, tg_xyyyyyyy_xz_0, tg_xyyyyyyy_yy_0, \
                                         tg_xyyyyyyy_yz_0, tg_xyyyyyyy_zz_0, tg_xyyyyyyz_xx_0, tg_xyyyyyyz_xy_0, \
                                         tg_xyyyyyyz_xz_0, tg_xyyyyyyz_yy_0, tg_xyyyyyyz_yz_0, tg_xyyyyyyz_zz_0, \
                                         tg_xyyyyyz_x_1, tg_xyyyyyz_xx_0, tg_xyyyyyz_xx_1, tg_xyyyyyz_xy_0, tg_xyyyyyz_xy_1, \
                                         tg_xyyyyyz_xz_0, tg_xyyyyyz_xz_1, tg_xyyyyyz_y_1, tg_xyyyyyz_yy_0, tg_xyyyyyz_yy_1, \
                                         tg_xyyyyyz_yz_0, tg_xyyyyyz_yz_1, tg_xyyyyyz_z_1, tg_xyyyyyz_zz_0, tg_xyyyyyz_zz_1, \
                                         tg_xyyyyz_xx_0, tg_xyyyyz_xx_1, tg_xyyyyz_xy_0, tg_xyyyyz_xy_1, tg_xyyyyz_xz_0, \
                                         tg_xyyyyz_xz_1, tg_xyyyyz_yy_0, tg_xyyyyz_yy_1, tg_xyyyyz_yz_0, tg_xyyyyz_yz_1, \
                                         tg_xyyyyz_zz_0, tg_xyyyyz_zz_1, tg_xyyyyzz_x_1, tg_xyyyyzz_xx_0, tg_xyyyyzz_xx_1, \
                                         tg_xyyyyzz_xy_0, tg_xyyyyzz_xy_1, tg_xyyyyzz_xz_0, tg_xyyyyzz_xz_1, tg_xyyyyzz_y_1, \
                                         tg_xyyyyzz_yy_0, tg_xyyyyzz_yy_1, tg_xyyyyzz_yz_0, tg_xyyyyzz_yz_1, tg_xyyyyzz_z_1, \
                                         tg_xyyyyzz_zz_0, tg_xyyyyzz_zz_1, tg_xyyyzz_xx_0, tg_xyyyzz_xx_1, tg_xyyyzz_xy_0, \
                                         tg_xyyyzz_xy_1, tg_xyyyzz_xz_0, tg_xyyyzz_xz_1, tg_xyyyzz_yy_0, tg_xyyyzz_yy_1, \
                                         tg_xyyyzz_yz_0, tg_xyyyzz_yz_1, tg_xyyyzz_zz_0, tg_xyyyzz_zz_1, tg_xyyyzzz_x_1, \
                                         tg_xyyyzzz_xx_0, tg_xyyyzzz_xx_1, tg_xyyyzzz_xy_0, tg_xyyyzzz_xy_1, tg_xyyyzzz_xz_0, \
                                         tg_xyyyzzz_xz_1, tg_xyyyzzz_y_1, tg_xyyyzzz_yy_0, tg_xyyyzzz_yy_1, tg_xyyyzzz_yz_0, \
                                         tg_xyyyzzz_yz_1, tg_xyyyzzz_z_1, tg_xyyyzzz_zz_0, tg_xyyyzzz_zz_1, tg_xyyzzz_xx_0, \
                                         tg_xyyzzz_xx_1, tg_xyyzzz_xy_0, tg_xyyzzz_xy_1, tg_xyyzzz_xz_0, tg_xyyzzz_xz_1, \
                                         tg_xyyzzz_yy_0, tg_xyyzzz_yy_1, tg_xyyzzz_yz_0, tg_xyyzzz_yz_1, tg_xyyzzz_zz_0, \
                                         tg_xyyzzz_zz_1, tg_xyyzzzz_x_1, tg_xyyzzzz_xx_0, tg_xyyzzzz_xx_1, tg_xyyzzzz_xy_0, \
                                         tg_xyyzzzz_xy_1, tg_xyyzzzz_xz_0, tg_xyyzzzz_xz_1, tg_xyyzzzz_y_1, tg_xyyzzzz_yy_0, \
                                         tg_xyyzzzz_yy_1, tg_xyyzzzz_yz_0, tg_xyyzzzz_yz_1, tg_xyyzzzz_z_1, tg_xyyzzzz_zz_0, \
                                         tg_xyyzzzz_zz_1, tg_xyzzzz_xx_0, tg_xyzzzz_xx_1, tg_xyzzzz_xy_0, tg_xyzzzz_xy_1, \
                                         tg_xyzzzz_xz_0, tg_xyzzzz_xz_1, tg_xyzzzz_yy_0, tg_xyzzzz_yy_1, tg_xyzzzz_yz_0, \
                                         tg_xyzzzz_yz_1, tg_xyzzzz_zz_0, tg_xyzzzz_zz_1, tg_xyzzzzz_x_1, tg_xyzzzzz_xx_0, \
                                         tg_xyzzzzz_xx_1, tg_xyzzzzz_xy_0, tg_xyzzzzz_xy_1, tg_xyzzzzz_xz_0, tg_xyzzzzz_xz_1, \
                                         tg_xyzzzzz_y_1, tg_xyzzzzz_yy_0, tg_xyzzzzz_yy_1, tg_xyzzzzz_yz_0, tg_xyzzzzz_yz_1, \
                                         tg_xyzzzzz_z_1, tg_xyzzzzz_zz_0, tg_xyzzzzz_zz_1, tg_xzzzzz_xx_0, tg_xzzzzz_xx_1, \
                                         tg_xzzzzz_xy_0, tg_xzzzzz_xy_1, tg_xzzzzz_xz_0, tg_xzzzzz_xz_1, tg_xzzzzz_yy_0, \
                                         tg_xzzzzz_yy_1, tg_xzzzzz_yz_0, tg_xzzzzz_yz_1, tg_xzzzzz_zz_0, tg_xzzzzz_zz_1, \
                                         tg_xzzzzzz_x_1, tg_xzzzzzz_xx_0, tg_xzzzzzz_xx_1, tg_xzzzzzz_xy_0, tg_xzzzzzz_xy_1, \
                                         tg_xzzzzzz_xz_0, tg_xzzzzzz_xz_1, tg_xzzzzzz_y_1, tg_xzzzzzz_yy_0, tg_xzzzzzz_yy_1, \
                                         tg_xzzzzzz_yz_0, tg_xzzzzzz_yz_1, tg_xzzzzzz_z_1, tg_xzzzzzz_zz_0, tg_xzzzzzz_zz_1, \
                                         tg_yyyyyy_xx_0, tg_yyyyyy_xx_1, tg_yyyyyy_xy_0, tg_yyyyyy_xy_1, tg_yyyyyy_xz_0, \
                                         tg_yyyyyy_xz_1, tg_yyyyyy_yy_0, tg_yyyyyy_yy_1, tg_yyyyyy_yz_0, tg_yyyyyy_yz_1, \
                                         tg_yyyyyy_zz_0, tg_yyyyyy_zz_1, tg_yyyyyyy_x_1, tg_yyyyyyy_xx_0, tg_yyyyyyy_xx_1, \
                                         tg_yyyyyyy_xy_0, tg_yyyyyyy_xy_1, tg_yyyyyyy_xz_0, tg_yyyyyyy_xz_1, tg_yyyyyyy_y_1, \
                                         tg_yyyyyyy_yy_0, tg_yyyyyyy_yy_1, tg_yyyyyyy_yz_0, tg_yyyyyyy_yz_1, tg_yyyyyyy_z_1, \
                                         tg_yyyyyyy_zz_0, tg_yyyyyyy_zz_1, tg_yyyyyyz_x_1, tg_yyyyyyz_xx_0, tg_yyyyyyz_xx_1, \
                                         tg_yyyyyyz_xy_0, tg_yyyyyyz_xy_1, tg_yyyyyyz_xz_0, tg_yyyyyyz_xz_1, tg_yyyyyyz_y_1, \
                                         tg_yyyyyyz_yy_0, tg_yyyyyyz_yy_1, tg_yyyyyyz_yz_0, tg_yyyyyyz_yz_1, tg_yyyyyyz_z_1, \
                                         tg_yyyyyyz_zz_0, tg_yyyyyyz_zz_1, tg_yyyyyz_xx_0, tg_yyyyyz_xx_1, tg_yyyyyz_xy_0, \
                                         tg_yyyyyz_xy_1, tg_yyyyyz_xz_0, tg_yyyyyz_xz_1, tg_yyyyyz_yy_0, tg_yyyyyz_yy_1, \
                                         tg_yyyyyz_yz_0, tg_yyyyyz_yz_1, tg_yyyyyz_zz_0, tg_yyyyyz_zz_1, tg_yyyyzz_xx_0, \
                                         tg_yyyyzz_xx_1, tg_yyyyzz_xy_0, tg_yyyyzz_xy_1, tg_yyyyzz_xz_0, tg_yyyyzz_xz_1, \
                                         tg_yyyyzz_yy_0, tg_yyyyzz_yy_1, tg_yyyyzz_yz_0, tg_yyyyzz_yz_1, tg_yyyyzz_zz_0, \
                                         tg_yyyyzz_zz_1, tg_yyyzzz_xx_0, tg_yyyzzz_xx_1, tg_yyyzzz_xy_0, tg_yyyzzz_xy_1, \
                                         tg_yyyzzz_xz_0, tg_yyyzzz_xz_1, tg_yyyzzz_yy_0, tg_yyyzzz_yy_1, tg_yyyzzz_yz_0, \
                                         tg_yyyzzz_yz_1, tg_yyyzzz_zz_0, tg_yyyzzz_zz_1, tg_yyzzzz_xx_0, tg_yyzzzz_xx_1, \
                                         tg_yyzzzz_xy_0, tg_yyzzzz_xy_1, tg_yyzzzz_xz_0, tg_yyzzzz_xz_1, tg_yyzzzz_yy_0, \
                                         tg_yyzzzz_yy_1, tg_yyzzzz_yz_0, tg_yyzzzz_yz_1, tg_yyzzzz_zz_0, tg_yyzzzz_zz_1, \
                                         tg_yzzzzz_xx_0, tg_yzzzzz_xx_1, tg_yzzzzz_xy_0, tg_yzzzzz_xy_1, tg_yzzzzz_xz_0, \
                                         tg_yzzzzz_xz_1, tg_yzzzzz_yy_0, tg_yzzzzz_yy_1, tg_yzzzzz_yz_0, tg_yzzzzz_yz_1, \
                                         tg_yzzzzz_zz_0, tg_yzzzzz_zz_1, tg_zzzzzz_xx_0, tg_zzzzzz_xx_1, tg_zzzzzz_xy_0, \
                                         tg_zzzzzz_xy_1, tg_zzzzzz_xz_0, tg_zzzzzz_xz_1, tg_zzzzzz_yy_0, tg_zzzzzz_yy_1, \
                                         tg_zzzzzz_yz_0, tg_zzzzzz_yz_1, tg_zzzzzz_zz_0, tg_zzzzzz_zz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyyyyy_xx_0[j] = pb_x * tg_xxyyyyy_xx_0[j] + fr * tg_xxyyyyy_xx_1[j] + fl1_fx * (tg_xyyyyy_xx_0[j] - tg_xyyyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_x_1[j];

                    tg_xxxyyyyy_xy_0[j] = pb_x * tg_xxyyyyy_xy_0[j] + fr * tg_xxyyyyy_xy_1[j] + fl1_fx * (tg_xyyyyy_xy_0[j] - tg_xyyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_y_1[j];

                    tg_xxxyyyyy_xz_0[j] = pb_x * tg_xxyyyyy_xz_0[j] + fr * tg_xxyyyyy_xz_1[j] + fl1_fx * (tg_xyyyyy_xz_0[j] - tg_xyyyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_z_1[j];

                    tg_xxxyyyyy_yy_0[j] = pb_x * tg_xxyyyyy_yy_0[j] + fr * tg_xxyyyyy_yy_1[j] + fl1_fx * (tg_xyyyyy_yy_0[j] - tg_xyyyyy_yy_1[j] * fl1_fza);

                    tg_xxxyyyyy_yz_0[j] = pb_x * tg_xxyyyyy_yz_0[j] + fr * tg_xxyyyyy_yz_1[j] + fl1_fx * (tg_xyyyyy_yz_0[j] - tg_xyyyyy_yz_1[j] * fl1_fza);

                    tg_xxxyyyyy_zz_0[j] = pb_x * tg_xxyyyyy_zz_0[j] + fr * tg_xxyyyyy_zz_1[j] + fl1_fx * (tg_xyyyyy_zz_0[j] - tg_xyyyyy_zz_1[j] * fl1_fza);

                    tg_xxxyyyyz_xx_0[j] = pb_x * tg_xxyyyyz_xx_0[j] + fr * tg_xxyyyyz_xx_1[j] + fl1_fx * (tg_xyyyyz_xx_0[j] - tg_xyyyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_x_1[j];

                    tg_xxxyyyyz_xy_0[j] = pb_x * tg_xxyyyyz_xy_0[j] + fr * tg_xxyyyyz_xy_1[j] + fl1_fx * (tg_xyyyyz_xy_0[j] - tg_xyyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_y_1[j];

                    tg_xxxyyyyz_xz_0[j] = pb_x * tg_xxyyyyz_xz_0[j] + fr * tg_xxyyyyz_xz_1[j] + fl1_fx * (tg_xyyyyz_xz_0[j] - tg_xyyyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_z_1[j];

                    tg_xxxyyyyz_yy_0[j] = pb_x * tg_xxyyyyz_yy_0[j] + fr * tg_xxyyyyz_yy_1[j] + fl1_fx * (tg_xyyyyz_yy_0[j] - tg_xyyyyz_yy_1[j] * fl1_fza);

                    tg_xxxyyyyz_yz_0[j] = pb_x * tg_xxyyyyz_yz_0[j] + fr * tg_xxyyyyz_yz_1[j] + fl1_fx * (tg_xyyyyz_yz_0[j] - tg_xyyyyz_yz_1[j] * fl1_fza);

                    tg_xxxyyyyz_zz_0[j] = pb_x * tg_xxyyyyz_zz_0[j] + fr * tg_xxyyyyz_zz_1[j] + fl1_fx * (tg_xyyyyz_zz_0[j] - tg_xyyyyz_zz_1[j] * fl1_fza);

                    tg_xxxyyyzz_xx_0[j] = pb_x * tg_xxyyyzz_xx_0[j] + fr * tg_xxyyyzz_xx_1[j] + fl1_fx * (tg_xyyyzz_xx_0[j] - tg_xyyyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_x_1[j];

                    tg_xxxyyyzz_xy_0[j] = pb_x * tg_xxyyyzz_xy_0[j] + fr * tg_xxyyyzz_xy_1[j] + fl1_fx * (tg_xyyyzz_xy_0[j] - tg_xyyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_y_1[j];

                    tg_xxxyyyzz_xz_0[j] = pb_x * tg_xxyyyzz_xz_0[j] + fr * tg_xxyyyzz_xz_1[j] + fl1_fx * (tg_xyyyzz_xz_0[j] - tg_xyyyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_z_1[j];

                    tg_xxxyyyzz_yy_0[j] = pb_x * tg_xxyyyzz_yy_0[j] + fr * tg_xxyyyzz_yy_1[j] + fl1_fx * (tg_xyyyzz_yy_0[j] - tg_xyyyzz_yy_1[j] * fl1_fza);

                    tg_xxxyyyzz_yz_0[j] = pb_x * tg_xxyyyzz_yz_0[j] + fr * tg_xxyyyzz_yz_1[j] + fl1_fx * (tg_xyyyzz_yz_0[j] - tg_xyyyzz_yz_1[j] * fl1_fza);

                    tg_xxxyyyzz_zz_0[j] = pb_x * tg_xxyyyzz_zz_0[j] + fr * tg_xxyyyzz_zz_1[j] + fl1_fx * (tg_xyyyzz_zz_0[j] - tg_xyyyzz_zz_1[j] * fl1_fza);

                    tg_xxxyyzzz_xx_0[j] = pb_x * tg_xxyyzzz_xx_0[j] + fr * tg_xxyyzzz_xx_1[j] + fl1_fx * (tg_xyyzzz_xx_0[j] - tg_xyyzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_x_1[j];

                    tg_xxxyyzzz_xy_0[j] = pb_x * tg_xxyyzzz_xy_0[j] + fr * tg_xxyyzzz_xy_1[j] + fl1_fx * (tg_xyyzzz_xy_0[j] - tg_xyyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_y_1[j];

                    tg_xxxyyzzz_xz_0[j] = pb_x * tg_xxyyzzz_xz_0[j] + fr * tg_xxyyzzz_xz_1[j] + fl1_fx * (tg_xyyzzz_xz_0[j] - tg_xyyzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_z_1[j];

                    tg_xxxyyzzz_yy_0[j] = pb_x * tg_xxyyzzz_yy_0[j] + fr * tg_xxyyzzz_yy_1[j] + fl1_fx * (tg_xyyzzz_yy_0[j] - tg_xyyzzz_yy_1[j] * fl1_fza);

                    tg_xxxyyzzz_yz_0[j] = pb_x * tg_xxyyzzz_yz_0[j] + fr * tg_xxyyzzz_yz_1[j] + fl1_fx * (tg_xyyzzz_yz_0[j] - tg_xyyzzz_yz_1[j] * fl1_fza);

                    tg_xxxyyzzz_zz_0[j] = pb_x * tg_xxyyzzz_zz_0[j] + fr * tg_xxyyzzz_zz_1[j] + fl1_fx * (tg_xyyzzz_zz_0[j] - tg_xyyzzz_zz_1[j] * fl1_fza);

                    tg_xxxyzzzz_xx_0[j] = pb_x * tg_xxyzzzz_xx_0[j] + fr * tg_xxyzzzz_xx_1[j] + fl1_fx * (tg_xyzzzz_xx_0[j] - tg_xyzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_x_1[j];

                    tg_xxxyzzzz_xy_0[j] = pb_x * tg_xxyzzzz_xy_0[j] + fr * tg_xxyzzzz_xy_1[j] + fl1_fx * (tg_xyzzzz_xy_0[j] - tg_xyzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_y_1[j];

                    tg_xxxyzzzz_xz_0[j] = pb_x * tg_xxyzzzz_xz_0[j] + fr * tg_xxyzzzz_xz_1[j] + fl1_fx * (tg_xyzzzz_xz_0[j] - tg_xyzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_z_1[j];

                    tg_xxxyzzzz_yy_0[j] = pb_x * tg_xxyzzzz_yy_0[j] + fr * tg_xxyzzzz_yy_1[j] + fl1_fx * (tg_xyzzzz_yy_0[j] - tg_xyzzzz_yy_1[j] * fl1_fza);

                    tg_xxxyzzzz_yz_0[j] = pb_x * tg_xxyzzzz_yz_0[j] + fr * tg_xxyzzzz_yz_1[j] + fl1_fx * (tg_xyzzzz_yz_0[j] - tg_xyzzzz_yz_1[j] * fl1_fza);

                    tg_xxxyzzzz_zz_0[j] = pb_x * tg_xxyzzzz_zz_0[j] + fr * tg_xxyzzzz_zz_1[j] + fl1_fx * (tg_xyzzzz_zz_0[j] - tg_xyzzzz_zz_1[j] * fl1_fza);

                    tg_xxxzzzzz_xx_0[j] = pb_x * tg_xxzzzzz_xx_0[j] + fr * tg_xxzzzzz_xx_1[j] + fl1_fx * (tg_xzzzzz_xx_0[j] - tg_xzzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_x_1[j];

                    tg_xxxzzzzz_xy_0[j] = pb_x * tg_xxzzzzz_xy_0[j] + fr * tg_xxzzzzz_xy_1[j] + fl1_fx * (tg_xzzzzz_xy_0[j] - tg_xzzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_y_1[j];

                    tg_xxxzzzzz_xz_0[j] = pb_x * tg_xxzzzzz_xz_0[j] + fr * tg_xxzzzzz_xz_1[j] + fl1_fx * (tg_xzzzzz_xz_0[j] - tg_xzzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_z_1[j];

                    tg_xxxzzzzz_yy_0[j] = pb_x * tg_xxzzzzz_yy_0[j] + fr * tg_xxzzzzz_yy_1[j] + fl1_fx * (tg_xzzzzz_yy_0[j] - tg_xzzzzz_yy_1[j] * fl1_fza);

                    tg_xxxzzzzz_yz_0[j] = pb_x * tg_xxzzzzz_yz_0[j] + fr * tg_xxzzzzz_yz_1[j] + fl1_fx * (tg_xzzzzz_yz_0[j] - tg_xzzzzz_yz_1[j] * fl1_fza);

                    tg_xxxzzzzz_zz_0[j] = pb_x * tg_xxzzzzz_zz_0[j] + fr * tg_xxzzzzz_zz_1[j] + fl1_fx * (tg_xzzzzz_zz_0[j] - tg_xzzzzz_zz_1[j] * fl1_fza);

                    tg_xxyyyyyy_xx_0[j] = pb_x * tg_xyyyyyy_xx_0[j] + fr * tg_xyyyyyy_xx_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xx_0[j] - tg_yyyyyy_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_x_1[j];

                    tg_xxyyyyyy_xy_0[j] = pb_x * tg_xyyyyyy_xy_0[j] + fr * tg_xyyyyyy_xy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xy_0[j] - tg_yyyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_y_1[j];

                    tg_xxyyyyyy_xz_0[j] = pb_x * tg_xyyyyyy_xz_0[j] + fr * tg_xyyyyyy_xz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xz_0[j] - tg_yyyyyy_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_z_1[j];

                    tg_xxyyyyyy_yy_0[j] = pb_x * tg_xyyyyyy_yy_0[j] + fr * tg_xyyyyyy_yy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yy_0[j] - tg_yyyyyy_yy_1[j] * fl1_fza);

                    tg_xxyyyyyy_yz_0[j] = pb_x * tg_xyyyyyy_yz_0[j] + fr * tg_xyyyyyy_yz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yz_0[j] - tg_yyyyyy_yz_1[j] * fl1_fza);

                    tg_xxyyyyyy_zz_0[j] = pb_x * tg_xyyyyyy_zz_0[j] + fr * tg_xyyyyyy_zz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_zz_0[j] - tg_yyyyyy_zz_1[j] * fl1_fza);

                    tg_xxyyyyyz_xx_0[j] = pb_x * tg_xyyyyyz_xx_0[j] + fr * tg_xyyyyyz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xx_0[j] - tg_yyyyyz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_x_1[j];

                    tg_xxyyyyyz_xy_0[j] = pb_x * tg_xyyyyyz_xy_0[j] + fr * tg_xyyyyyz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xy_0[j] - tg_yyyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_y_1[j];

                    tg_xxyyyyyz_xz_0[j] = pb_x * tg_xyyyyyz_xz_0[j] + fr * tg_xyyyyyz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xz_0[j] - tg_yyyyyz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_z_1[j];

                    tg_xxyyyyyz_yy_0[j] = pb_x * tg_xyyyyyz_yy_0[j] + fr * tg_xyyyyyz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yy_0[j] - tg_yyyyyz_yy_1[j] * fl1_fza);

                    tg_xxyyyyyz_yz_0[j] = pb_x * tg_xyyyyyz_yz_0[j] + fr * tg_xyyyyyz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yz_0[j] - tg_yyyyyz_yz_1[j] * fl1_fza);

                    tg_xxyyyyyz_zz_0[j] = pb_x * tg_xyyyyyz_zz_0[j] + fr * tg_xyyyyyz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_zz_0[j] - tg_yyyyyz_zz_1[j] * fl1_fza);

                    tg_xxyyyyzz_xx_0[j] = pb_x * tg_xyyyyzz_xx_0[j] + fr * tg_xyyyyzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xx_0[j] - tg_yyyyzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_x_1[j];

                    tg_xxyyyyzz_xy_0[j] = pb_x * tg_xyyyyzz_xy_0[j] + fr * tg_xyyyyzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xy_0[j] - tg_yyyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_y_1[j];

                    tg_xxyyyyzz_xz_0[j] = pb_x * tg_xyyyyzz_xz_0[j] + fr * tg_xyyyyzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xz_0[j] - tg_yyyyzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_z_1[j];

                    tg_xxyyyyzz_yy_0[j] = pb_x * tg_xyyyyzz_yy_0[j] + fr * tg_xyyyyzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yy_0[j] - tg_yyyyzz_yy_1[j] * fl1_fza);

                    tg_xxyyyyzz_yz_0[j] = pb_x * tg_xyyyyzz_yz_0[j] + fr * tg_xyyyyzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yz_0[j] - tg_yyyyzz_yz_1[j] * fl1_fza);

                    tg_xxyyyyzz_zz_0[j] = pb_x * tg_xyyyyzz_zz_0[j] + fr * tg_xyyyyzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_zz_0[j] - tg_yyyyzz_zz_1[j] * fl1_fza);

                    tg_xxyyyzzz_xx_0[j] = pb_x * tg_xyyyzzz_xx_0[j] + fr * tg_xyyyzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xx_0[j] - tg_yyyzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_x_1[j];

                    tg_xxyyyzzz_xy_0[j] = pb_x * tg_xyyyzzz_xy_0[j] + fr * tg_xyyyzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xy_0[j] - tg_yyyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_y_1[j];

                    tg_xxyyyzzz_xz_0[j] = pb_x * tg_xyyyzzz_xz_0[j] + fr * tg_xyyyzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xz_0[j] - tg_yyyzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_z_1[j];

                    tg_xxyyyzzz_yy_0[j] = pb_x * tg_xyyyzzz_yy_0[j] + fr * tg_xyyyzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yy_0[j] - tg_yyyzzz_yy_1[j] * fl1_fza);

                    tg_xxyyyzzz_yz_0[j] = pb_x * tg_xyyyzzz_yz_0[j] + fr * tg_xyyyzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yz_0[j] - tg_yyyzzz_yz_1[j] * fl1_fza);

                    tg_xxyyyzzz_zz_0[j] = pb_x * tg_xyyyzzz_zz_0[j] + fr * tg_xyyyzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_zz_0[j] - tg_yyyzzz_zz_1[j] * fl1_fza);

                    tg_xxyyzzzz_xx_0[j] = pb_x * tg_xyyzzzz_xx_0[j] + fr * tg_xyyzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xx_0[j] - tg_yyzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_x_1[j];

                    tg_xxyyzzzz_xy_0[j] = pb_x * tg_xyyzzzz_xy_0[j] + fr * tg_xyyzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xy_0[j] - tg_yyzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_y_1[j];

                    tg_xxyyzzzz_xz_0[j] = pb_x * tg_xyyzzzz_xz_0[j] + fr * tg_xyyzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xz_0[j] - tg_yyzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_z_1[j];

                    tg_xxyyzzzz_yy_0[j] = pb_x * tg_xyyzzzz_yy_0[j] + fr * tg_xyyzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yy_0[j] - tg_yyzzzz_yy_1[j] * fl1_fza);

                    tg_xxyyzzzz_yz_0[j] = pb_x * tg_xyyzzzz_yz_0[j] + fr * tg_xyyzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yz_0[j] - tg_yyzzzz_yz_1[j] * fl1_fza);

                    tg_xxyyzzzz_zz_0[j] = pb_x * tg_xyyzzzz_zz_0[j] + fr * tg_xyyzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_zz_0[j] - tg_yyzzzz_zz_1[j] * fl1_fza);

                    tg_xxyzzzzz_xx_0[j] = pb_x * tg_xyzzzzz_xx_0[j] + fr * tg_xyzzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xx_0[j] - tg_yzzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_x_1[j];

                    tg_xxyzzzzz_xy_0[j] = pb_x * tg_xyzzzzz_xy_0[j] + fr * tg_xyzzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xy_0[j] - tg_yzzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_y_1[j];

                    tg_xxyzzzzz_xz_0[j] = pb_x * tg_xyzzzzz_xz_0[j] + fr * tg_xyzzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xz_0[j] - tg_yzzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_z_1[j];

                    tg_xxyzzzzz_yy_0[j] = pb_x * tg_xyzzzzz_yy_0[j] + fr * tg_xyzzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yy_0[j] - tg_yzzzzz_yy_1[j] * fl1_fza);

                    tg_xxyzzzzz_yz_0[j] = pb_x * tg_xyzzzzz_yz_0[j] + fr * tg_xyzzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yz_0[j] - tg_yzzzzz_yz_1[j] * fl1_fza);

                    tg_xxyzzzzz_zz_0[j] = pb_x * tg_xyzzzzz_zz_0[j] + fr * tg_xyzzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_zz_0[j] - tg_yzzzzz_zz_1[j] * fl1_fza);

                    tg_xxzzzzzz_xx_0[j] = pb_x * tg_xzzzzzz_xx_0[j] + fr * tg_xzzzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xx_0[j] - tg_zzzzzz_xx_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_x_1[j];

                    tg_xxzzzzzz_xy_0[j] = pb_x * tg_xzzzzzz_xy_0[j] + fr * tg_xzzzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xy_0[j] - tg_zzzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_y_1[j];

                    tg_xxzzzzzz_xz_0[j] = pb_x * tg_xzzzzzz_xz_0[j] + fr * tg_xzzzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xz_0[j] - tg_zzzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_z_1[j];

                    tg_xxzzzzzz_yy_0[j] = pb_x * tg_xzzzzzz_yy_0[j] + fr * tg_xzzzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yy_0[j] - tg_zzzzzz_yy_1[j] * fl1_fza);

                    tg_xxzzzzzz_yz_0[j] = pb_x * tg_xzzzzzz_yz_0[j] + fr * tg_xzzzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yz_0[j] - tg_zzzzzz_yz_1[j] * fl1_fza);

                    tg_xxzzzzzz_zz_0[j] = pb_x * tg_xzzzzzz_zz_0[j] + fr * tg_xzzzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_zz_0[j] - tg_zzzzzz_zz_1[j] * fl1_fza);

                    tg_xyyyyyyy_xx_0[j] = pb_x * tg_yyyyyyy_xx_0[j] + fr * tg_yyyyyyy_xx_1[j] + fl1_fxn * tg_yyyyyyy_x_1[j];

                    tg_xyyyyyyy_xy_0[j] = pb_x * tg_yyyyyyy_xy_0[j] + fr * tg_yyyyyyy_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_y_1[j];

                    tg_xyyyyyyy_xz_0[j] = pb_x * tg_yyyyyyy_xz_0[j] + fr * tg_yyyyyyy_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_z_1[j];

                    tg_xyyyyyyy_yy_0[j] = pb_x * tg_yyyyyyy_yy_0[j] + fr * tg_yyyyyyy_yy_1[j];

                    tg_xyyyyyyy_yz_0[j] = pb_x * tg_yyyyyyy_yz_0[j] + fr * tg_yyyyyyy_yz_1[j];

                    tg_xyyyyyyy_zz_0[j] = pb_x * tg_yyyyyyy_zz_0[j] + fr * tg_yyyyyyy_zz_1[j];

                    tg_xyyyyyyz_xx_0[j] = pb_x * tg_yyyyyyz_xx_0[j] + fr * tg_yyyyyyz_xx_1[j] + fl1_fxn * tg_yyyyyyz_x_1[j];

                    tg_xyyyyyyz_xy_0[j] = pb_x * tg_yyyyyyz_xy_0[j] + fr * tg_yyyyyyz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_y_1[j];

                    tg_xyyyyyyz_xz_0[j] = pb_x * tg_yyyyyyz_xz_0[j] + fr * tg_yyyyyyz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_z_1[j];

                    tg_xyyyyyyz_yy_0[j] = pb_x * tg_yyyyyyz_yy_0[j] + fr * tg_yyyyyyz_yy_1[j];

                    tg_xyyyyyyz_yz_0[j] = pb_x * tg_yyyyyyz_yz_0[j] + fr * tg_yyyyyyz_yz_1[j];

                    tg_xyyyyyyz_zz_0[j] = pb_x * tg_yyyyyyz_zz_0[j] + fr * tg_yyyyyyz_zz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSD_180_270(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (180,270)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {2, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_2_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_1_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {1, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_2_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_2_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {2, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yyyyyyy_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 168); 

                auto tg_yyyyyyy_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 169); 

                auto tg_yyyyyyy_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 170); 

                auto tg_yyyyyyy_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 171); 

                auto tg_yyyyyyy_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 172); 

                auto tg_yyyyyyy_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 173); 

                auto tg_yyyyyyz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 174); 

                auto tg_yyyyyyz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 175); 

                auto tg_yyyyyyz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 176); 

                auto tg_yyyyyyz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 177); 

                auto tg_yyyyyyz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 178); 

                auto tg_yyyyyyz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 179); 

                auto tg_yyyyyzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 180); 

                auto tg_yyyyyzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 181); 

                auto tg_yyyyyzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 182); 

                auto tg_yyyyyzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 183); 

                auto tg_yyyyyzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 184); 

                auto tg_yyyyyzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 185); 

                auto tg_yyyyzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 186); 

                auto tg_yyyyzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 187); 

                auto tg_yyyyzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 188); 

                auto tg_yyyyzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 189); 

                auto tg_yyyyzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 190); 

                auto tg_yyyyzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 191); 

                auto tg_yyyzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 192); 

                auto tg_yyyzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 193); 

                auto tg_yyyzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 194); 

                auto tg_yyyzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 195); 

                auto tg_yyyzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 196); 

                auto tg_yyyzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 197); 

                auto tg_yyzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 198); 

                auto tg_yyzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 199); 

                auto tg_yyzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 200); 

                auto tg_yyzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 201); 

                auto tg_yyzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 202); 

                auto tg_yyzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 203); 

                auto tg_yzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 204); 

                auto tg_yzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 205); 

                auto tg_yzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 206); 

                auto tg_yzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 207); 

                auto tg_yzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 208); 

                auto tg_yzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 209); 

                auto tg_zzzzzzz_xx_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 210); 

                auto tg_zzzzzzz_xy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 211); 

                auto tg_zzzzzzz_xz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 212); 

                auto tg_zzzzzzz_yy_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 213); 

                auto tg_zzzzzzz_yz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 214); 

                auto tg_zzzzzzz_zz_0 = primBuffer[pidx_g_7_2_m0].data(216 * idx + 215); 

                auto tg_yyyyyyy_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 168); 

                auto tg_yyyyyyy_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 169); 

                auto tg_yyyyyyy_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 170); 

                auto tg_yyyyyyy_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 171); 

                auto tg_yyyyyyy_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 172); 

                auto tg_yyyyyyy_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 173); 

                auto tg_yyyyyyz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 174); 

                auto tg_yyyyyyz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 175); 

                auto tg_yyyyyyz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 176); 

                auto tg_yyyyyyz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 177); 

                auto tg_yyyyyyz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 178); 

                auto tg_yyyyyyz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 179); 

                auto tg_yyyyyzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 180); 

                auto tg_yyyyyzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 181); 

                auto tg_yyyyyzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 182); 

                auto tg_yyyyyzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 183); 

                auto tg_yyyyyzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 184); 

                auto tg_yyyyyzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 185); 

                auto tg_yyyyzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 186); 

                auto tg_yyyyzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 187); 

                auto tg_yyyyzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 188); 

                auto tg_yyyyzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 189); 

                auto tg_yyyyzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 190); 

                auto tg_yyyyzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 191); 

                auto tg_yyyzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 192); 

                auto tg_yyyzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 193); 

                auto tg_yyyzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 194); 

                auto tg_yyyzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 195); 

                auto tg_yyyzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 196); 

                auto tg_yyyzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 197); 

                auto tg_yyzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 198); 

                auto tg_yyzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 199); 

                auto tg_yyzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 200); 

                auto tg_yyzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 201); 

                auto tg_yyzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 202); 

                auto tg_yyzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 203); 

                auto tg_yzzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 204); 

                auto tg_yzzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 205); 

                auto tg_yzzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 206); 

                auto tg_yzzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 207); 

                auto tg_yzzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 208); 

                auto tg_yzzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 209); 

                auto tg_zzzzzzz_xx_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 210); 

                auto tg_zzzzzzz_xy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 211); 

                auto tg_zzzzzzz_xz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 212); 

                auto tg_zzzzzzz_yy_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 213); 

                auto tg_zzzzzzz_yz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 214); 

                auto tg_zzzzzzz_zz_1 = primBuffer[pidx_g_7_2_m1].data(216 * idx + 215); 

                auto tg_yyyyyy_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_0 = primBuffer[pidx_g_6_2_m0].data(168 * idx + 167); 

                auto tg_yyyyyy_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 126); 

                auto tg_yyyyyy_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 127); 

                auto tg_yyyyyy_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 128); 

                auto tg_yyyyyy_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 129); 

                auto tg_yyyyyy_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 130); 

                auto tg_yyyyyy_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 131); 

                auto tg_yyyyyz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 132); 

                auto tg_yyyyyz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 133); 

                auto tg_yyyyyz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 134); 

                auto tg_yyyyyz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 135); 

                auto tg_yyyyyz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 136); 

                auto tg_yyyyyz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 137); 

                auto tg_yyyyzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 138); 

                auto tg_yyyyzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 139); 

                auto tg_yyyyzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 140); 

                auto tg_yyyyzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 141); 

                auto tg_yyyyzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 142); 

                auto tg_yyyyzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 143); 

                auto tg_yyyzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 144); 

                auto tg_yyyzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 145); 

                auto tg_yyyzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 146); 

                auto tg_yyyzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 147); 

                auto tg_yyyzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 148); 

                auto tg_yyyzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 149); 

                auto tg_yyzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 150); 

                auto tg_yyzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 151); 

                auto tg_yyzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 152); 

                auto tg_yyzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 153); 

                auto tg_yyzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 154); 

                auto tg_yyzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 155); 

                auto tg_yzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 156); 

                auto tg_yzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 157); 

                auto tg_yzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 158); 

                auto tg_yzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 159); 

                auto tg_yzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 160); 

                auto tg_yzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 161); 

                auto tg_zzzzzz_xx_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 162); 

                auto tg_zzzzzz_xy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 163); 

                auto tg_zzzzzz_xz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 164); 

                auto tg_zzzzzz_yy_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 165); 

                auto tg_zzzzzz_yz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 166); 

                auto tg_zzzzzz_zz_1 = primBuffer[pidx_g_6_2_m1].data(168 * idx + 167); 

                auto tg_yyyyyyy_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 84); 

                auto tg_yyyyyyy_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 85); 

                auto tg_yyyyyyy_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 86); 

                auto tg_yyyyyyz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 87); 

                auto tg_yyyyyyz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 88); 

                auto tg_yyyyyyz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 89); 

                auto tg_yyyyyzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 90); 

                auto tg_yyyyyzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 91); 

                auto tg_yyyyyzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 92); 

                auto tg_yyyyzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 93); 

                auto tg_yyyyzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 94); 

                auto tg_yyyyzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 95); 

                auto tg_yyyzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 96); 

                auto tg_yyyzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 97); 

                auto tg_yyyzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 98); 

                auto tg_yyzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 99); 

                auto tg_yyzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 100); 

                auto tg_yyzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 101); 

                auto tg_yzzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 102); 

                auto tg_yzzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 103); 

                auto tg_yzzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 104); 

                auto tg_zzzzzzz_x_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 105); 

                auto tg_zzzzzzz_y_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 106); 

                auto tg_zzzzzzz_z_1 = primBuffer[pidx_g_7_1_m1].data(108 * idx + 107); 

                // set up pointers to integrals

                auto tg_xyyyyyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 180); 

                auto tg_xyyyyyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 181); 

                auto tg_xyyyyyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 182); 

                auto tg_xyyyyyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 183); 

                auto tg_xyyyyyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 184); 

                auto tg_xyyyyyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 185); 

                auto tg_xyyyyzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 186); 

                auto tg_xyyyyzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 187); 

                auto tg_xyyyyzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 188); 

                auto tg_xyyyyzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 189); 

                auto tg_xyyyyzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 190); 

                auto tg_xyyyyzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 191); 

                auto tg_xyyyzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 192); 

                auto tg_xyyyzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 193); 

                auto tg_xyyyzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 194); 

                auto tg_xyyyzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 195); 

                auto tg_xyyyzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 196); 

                auto tg_xyyyzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 197); 

                auto tg_xyyzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 198); 

                auto tg_xyyzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 199); 

                auto tg_xyyzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 200); 

                auto tg_xyyzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 201); 

                auto tg_xyyzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 202); 

                auto tg_xyyzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 203); 

                auto tg_xyzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 204); 

                auto tg_xyzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 205); 

                auto tg_xyzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 206); 

                auto tg_xyzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 207); 

                auto tg_xyzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 208); 

                auto tg_xyzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 209); 

                auto tg_xzzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 210); 

                auto tg_xzzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 211); 

                auto tg_xzzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 212); 

                auto tg_xzzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 213); 

                auto tg_xzzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 214); 

                auto tg_xzzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 215); 

                auto tg_yyyyyyyy_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 216); 

                auto tg_yyyyyyyy_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 217); 

                auto tg_yyyyyyyy_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 218); 

                auto tg_yyyyyyyy_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 219); 

                auto tg_yyyyyyyy_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 220); 

                auto tg_yyyyyyyy_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 221); 

                auto tg_yyyyyyyz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 222); 

                auto tg_yyyyyyyz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 223); 

                auto tg_yyyyyyyz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 224); 

                auto tg_yyyyyyyz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 225); 

                auto tg_yyyyyyyz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 226); 

                auto tg_yyyyyyyz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 227); 

                auto tg_yyyyyyzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 228); 

                auto tg_yyyyyyzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 229); 

                auto tg_yyyyyyzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 230); 

                auto tg_yyyyyyzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 231); 

                auto tg_yyyyyyzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 232); 

                auto tg_yyyyyyzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 233); 

                auto tg_yyyyyzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 234); 

                auto tg_yyyyyzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 235); 

                auto tg_yyyyyzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 236); 

                auto tg_yyyyyzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 237); 

                auto tg_yyyyyzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 238); 

                auto tg_yyyyyzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 239); 

                auto tg_yyyyzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 240); 

                auto tg_yyyyzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 241); 

                auto tg_yyyyzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 242); 

                auto tg_yyyyzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 243); 

                auto tg_yyyyzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 244); 

                auto tg_yyyyzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 245); 

                auto tg_yyyzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 246); 

                auto tg_yyyzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 247); 

                auto tg_yyyzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 248); 

                auto tg_yyyzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 249); 

                auto tg_yyyzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 250); 

                auto tg_yyyzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 251); 

                auto tg_yyzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 252); 

                auto tg_yyzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 253); 

                auto tg_yyzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 254); 

                auto tg_yyzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 255); 

                auto tg_yyzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 256); 

                auto tg_yyzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 257); 

                auto tg_yzzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 258); 

                auto tg_yzzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 259); 

                auto tg_yzzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 260); 

                auto tg_yzzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 261); 

                auto tg_yzzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 262); 

                auto tg_yzzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 263); 

                auto tg_zzzzzzzz_xx_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 264); 

                auto tg_zzzzzzzz_xy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 265); 

                auto tg_zzzzzzzz_xz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 266); 

                auto tg_zzzzzzzz_yy_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 267); 

                auto tg_zzzzzzzz_yz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 268); 

                auto tg_zzzzzzzz_zz_0 = primBuffer[pidx_g_8_2_m0].data(270 * idx + 269); 

                // Batch of Integrals (180,270)

                #pragma omp simd aligned(fxn, fza, tg_xyyyyyzz_xx_0, tg_xyyyyyzz_xy_0, tg_xyyyyyzz_xz_0, \
                                         tg_xyyyyyzz_yy_0, tg_xyyyyyzz_yz_0, tg_xyyyyyzz_zz_0, tg_xyyyyzzz_xx_0, \
                                         tg_xyyyyzzz_xy_0, tg_xyyyyzzz_xz_0, tg_xyyyyzzz_yy_0, tg_xyyyyzzz_yz_0, \
                                         tg_xyyyyzzz_zz_0, tg_xyyyzzzz_xx_0, tg_xyyyzzzz_xy_0, tg_xyyyzzzz_xz_0, \
                                         tg_xyyyzzzz_yy_0, tg_xyyyzzzz_yz_0, tg_xyyyzzzz_zz_0, tg_xyyzzzzz_xx_0, \
                                         tg_xyyzzzzz_xy_0, tg_xyyzzzzz_xz_0, tg_xyyzzzzz_yy_0, tg_xyyzzzzz_yz_0, \
                                         tg_xyyzzzzz_zz_0, tg_xyzzzzzz_xx_0, tg_xyzzzzzz_xy_0, tg_xyzzzzzz_xz_0, \
                                         tg_xyzzzzzz_yy_0, tg_xyzzzzzz_yz_0, tg_xyzzzzzz_zz_0, tg_xzzzzzzz_xx_0, \
                                         tg_xzzzzzzz_xy_0, tg_xzzzzzzz_xz_0, tg_xzzzzzzz_yy_0, tg_xzzzzzzz_yz_0, \
                                         tg_xzzzzzzz_zz_0, tg_yyyyyy_xx_0, tg_yyyyyy_xx_1, tg_yyyyyy_xy_0, tg_yyyyyy_xy_1, \
                                         tg_yyyyyy_xz_0, tg_yyyyyy_xz_1, tg_yyyyyy_yy_0, tg_yyyyyy_yy_1, tg_yyyyyy_yz_0, \
                                         tg_yyyyyy_yz_1, tg_yyyyyy_zz_0, tg_yyyyyy_zz_1, tg_yyyyyyy_x_1, tg_yyyyyyy_xx_0, \
                                         tg_yyyyyyy_xx_1, tg_yyyyyyy_xy_0, tg_yyyyyyy_xy_1, tg_yyyyyyy_xz_0, tg_yyyyyyy_xz_1, \
                                         tg_yyyyyyy_y_1, tg_yyyyyyy_yy_0, tg_yyyyyyy_yy_1, tg_yyyyyyy_yz_0, tg_yyyyyyy_yz_1, \
                                         tg_yyyyyyy_z_1, tg_yyyyyyy_zz_0, tg_yyyyyyy_zz_1, tg_yyyyyyyy_xx_0, \
                                         tg_yyyyyyyy_xy_0, tg_yyyyyyyy_xz_0, tg_yyyyyyyy_yy_0, tg_yyyyyyyy_yz_0, \
                                         tg_yyyyyyyy_zz_0, tg_yyyyyyyz_xx_0, tg_yyyyyyyz_xy_0, tg_yyyyyyyz_xz_0, \
                                         tg_yyyyyyyz_yy_0, tg_yyyyyyyz_yz_0, tg_yyyyyyyz_zz_0, tg_yyyyyyz_x_1, \
                                         tg_yyyyyyz_xx_0, tg_yyyyyyz_xx_1, tg_yyyyyyz_xy_0, tg_yyyyyyz_xy_1, tg_yyyyyyz_xz_0, \
                                         tg_yyyyyyz_xz_1, tg_yyyyyyz_y_1, tg_yyyyyyz_yy_0, tg_yyyyyyz_yy_1, tg_yyyyyyz_yz_0, \
                                         tg_yyyyyyz_yz_1, tg_yyyyyyz_z_1, tg_yyyyyyz_zz_0, tg_yyyyyyz_zz_1, tg_yyyyyyzz_xx_0, \
                                         tg_yyyyyyzz_xy_0, tg_yyyyyyzz_xz_0, tg_yyyyyyzz_yy_0, tg_yyyyyyzz_yz_0, \
                                         tg_yyyyyyzz_zz_0, tg_yyyyyz_xx_0, tg_yyyyyz_xx_1, tg_yyyyyz_xy_0, tg_yyyyyz_xy_1, \
                                         tg_yyyyyz_xz_0, tg_yyyyyz_xz_1, tg_yyyyyz_yy_0, tg_yyyyyz_yy_1, tg_yyyyyz_yz_0, \
                                         tg_yyyyyz_yz_1, tg_yyyyyz_zz_0, tg_yyyyyz_zz_1, tg_yyyyyzz_x_1, tg_yyyyyzz_xx_0, \
                                         tg_yyyyyzz_xx_1, tg_yyyyyzz_xy_0, tg_yyyyyzz_xy_1, tg_yyyyyzz_xz_0, tg_yyyyyzz_xz_1, \
                                         tg_yyyyyzz_y_1, tg_yyyyyzz_yy_0, tg_yyyyyzz_yy_1, tg_yyyyyzz_yz_0, tg_yyyyyzz_yz_1, \
                                         tg_yyyyyzz_z_1, tg_yyyyyzz_zz_0, tg_yyyyyzz_zz_1, tg_yyyyyzzz_xx_0, \
                                         tg_yyyyyzzz_xy_0, tg_yyyyyzzz_xz_0, tg_yyyyyzzz_yy_0, tg_yyyyyzzz_yz_0, \
                                         tg_yyyyyzzz_zz_0, tg_yyyyzz_xx_0, tg_yyyyzz_xx_1, tg_yyyyzz_xy_0, tg_yyyyzz_xy_1, \
                                         tg_yyyyzz_xz_0, tg_yyyyzz_xz_1, tg_yyyyzz_yy_0, tg_yyyyzz_yy_1, tg_yyyyzz_yz_0, \
                                         tg_yyyyzz_yz_1, tg_yyyyzz_zz_0, tg_yyyyzz_zz_1, tg_yyyyzzz_x_1, tg_yyyyzzz_xx_0, \
                                         tg_yyyyzzz_xx_1, tg_yyyyzzz_xy_0, tg_yyyyzzz_xy_1, tg_yyyyzzz_xz_0, tg_yyyyzzz_xz_1, \
                                         tg_yyyyzzz_y_1, tg_yyyyzzz_yy_0, tg_yyyyzzz_yy_1, tg_yyyyzzz_yz_0, tg_yyyyzzz_yz_1, \
                                         tg_yyyyzzz_z_1, tg_yyyyzzz_zz_0, tg_yyyyzzz_zz_1, tg_yyyyzzzz_xx_0, \
                                         tg_yyyyzzzz_xy_0, tg_yyyyzzzz_xz_0, tg_yyyyzzzz_yy_0, tg_yyyyzzzz_yz_0, \
                                         tg_yyyyzzzz_zz_0, tg_yyyzzz_xx_0, tg_yyyzzz_xx_1, tg_yyyzzz_xy_0, tg_yyyzzz_xy_1, \
                                         tg_yyyzzz_xz_0, tg_yyyzzz_xz_1, tg_yyyzzz_yy_0, tg_yyyzzz_yy_1, tg_yyyzzz_yz_0, \
                                         tg_yyyzzz_yz_1, tg_yyyzzz_zz_0, tg_yyyzzz_zz_1, tg_yyyzzzz_x_1, tg_yyyzzzz_xx_0, \
                                         tg_yyyzzzz_xx_1, tg_yyyzzzz_xy_0, tg_yyyzzzz_xy_1, tg_yyyzzzz_xz_0, tg_yyyzzzz_xz_1, \
                                         tg_yyyzzzz_y_1, tg_yyyzzzz_yy_0, tg_yyyzzzz_yy_1, tg_yyyzzzz_yz_0, tg_yyyzzzz_yz_1, \
                                         tg_yyyzzzz_z_1, tg_yyyzzzz_zz_0, tg_yyyzzzz_zz_1, tg_yyyzzzzz_xx_0, \
                                         tg_yyyzzzzz_xy_0, tg_yyyzzzzz_xz_0, tg_yyyzzzzz_yy_0, tg_yyyzzzzz_yz_0, \
                                         tg_yyyzzzzz_zz_0, tg_yyzzzz_xx_0, tg_yyzzzz_xx_1, tg_yyzzzz_xy_0, tg_yyzzzz_xy_1, \
                                         tg_yyzzzz_xz_0, tg_yyzzzz_xz_1, tg_yyzzzz_yy_0, tg_yyzzzz_yy_1, tg_yyzzzz_yz_0, \
                                         tg_yyzzzz_yz_1, tg_yyzzzz_zz_0, tg_yyzzzz_zz_1, tg_yyzzzzz_x_1, tg_yyzzzzz_xx_0, \
                                         tg_yyzzzzz_xx_1, tg_yyzzzzz_xy_0, tg_yyzzzzz_xy_1, tg_yyzzzzz_xz_0, tg_yyzzzzz_xz_1, \
                                         tg_yyzzzzz_y_1, tg_yyzzzzz_yy_0, tg_yyzzzzz_yy_1, tg_yyzzzzz_yz_0, tg_yyzzzzz_yz_1, \
                                         tg_yyzzzzz_z_1, tg_yyzzzzz_zz_0, tg_yyzzzzz_zz_1, tg_yyzzzzzz_xx_0, \
                                         tg_yyzzzzzz_xy_0, tg_yyzzzzzz_xz_0, tg_yyzzzzzz_yy_0, tg_yyzzzzzz_yz_0, \
                                         tg_yyzzzzzz_zz_0, tg_yzzzzz_xx_0, tg_yzzzzz_xx_1, tg_yzzzzz_xy_0, tg_yzzzzz_xy_1, \
                                         tg_yzzzzz_xz_0, tg_yzzzzz_xz_1, tg_yzzzzz_yy_0, tg_yzzzzz_yy_1, tg_yzzzzz_yz_0, \
                                         tg_yzzzzz_yz_1, tg_yzzzzz_zz_0, tg_yzzzzz_zz_1, tg_yzzzzzz_x_1, tg_yzzzzzz_xx_0, \
                                         tg_yzzzzzz_xx_1, tg_yzzzzzz_xy_0, tg_yzzzzzz_xy_1, tg_yzzzzzz_xz_0, tg_yzzzzzz_xz_1, \
                                         tg_yzzzzzz_y_1, tg_yzzzzzz_yy_0, tg_yzzzzzz_yy_1, tg_yzzzzzz_yz_0, tg_yzzzzzz_yz_1, \
                                         tg_yzzzzzz_z_1, tg_yzzzzzz_zz_0, tg_yzzzzzz_zz_1, tg_yzzzzzzz_xx_0, \
                                         tg_yzzzzzzz_xy_0, tg_yzzzzzzz_xz_0, tg_yzzzzzzz_yy_0, tg_yzzzzzzz_yz_0, \
                                         tg_yzzzzzzz_zz_0, tg_zzzzzz_xx_0, tg_zzzzzz_xx_1, tg_zzzzzz_xy_0, tg_zzzzzz_xy_1, \
                                         tg_zzzzzz_xz_0, tg_zzzzzz_xz_1, tg_zzzzzz_yy_0, tg_zzzzzz_yy_1, tg_zzzzzz_yz_0, \
                                         tg_zzzzzz_yz_1, tg_zzzzzz_zz_0, tg_zzzzzz_zz_1, tg_zzzzzzz_x_1, tg_zzzzzzz_xx_0, \
                                         tg_zzzzzzz_xx_1, tg_zzzzzzz_xy_0, tg_zzzzzzz_xy_1, tg_zzzzzzz_xz_0, tg_zzzzzzz_xz_1, \
                                         tg_zzzzzzz_y_1, tg_zzzzzzz_yy_0, tg_zzzzzzz_yy_1, tg_zzzzzzz_yz_0, tg_zzzzzzz_yz_1, \
                                         tg_zzzzzzz_z_1, tg_zzzzzzz_zz_0, tg_zzzzzzz_zz_1, tg_zzzzzzzz_xx_0, \
                                         tg_zzzzzzzz_xy_0, tg_zzzzzzzz_xz_0, tg_zzzzzzzz_yy_0, tg_zzzzzzzz_yz_0, \
                                         tg_zzzzzzzz_zz_0, wp_x, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xyyyyyzz_xx_0[j] = pb_x * tg_yyyyyzz_xx_0[j] + fr * tg_yyyyyzz_xx_1[j] + fl1_fxn * tg_yyyyyzz_x_1[j];

                    tg_xyyyyyzz_xy_0[j] = pb_x * tg_yyyyyzz_xy_0[j] + fr * tg_yyyyyzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_y_1[j];

                    tg_xyyyyyzz_xz_0[j] = pb_x * tg_yyyyyzz_xz_0[j] + fr * tg_yyyyyzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_z_1[j];

                    tg_xyyyyyzz_yy_0[j] = pb_x * tg_yyyyyzz_yy_0[j] + fr * tg_yyyyyzz_yy_1[j];

                    tg_xyyyyyzz_yz_0[j] = pb_x * tg_yyyyyzz_yz_0[j] + fr * tg_yyyyyzz_yz_1[j];

                    tg_xyyyyyzz_zz_0[j] = pb_x * tg_yyyyyzz_zz_0[j] + fr * tg_yyyyyzz_zz_1[j];

                    tg_xyyyyzzz_xx_0[j] = pb_x * tg_yyyyzzz_xx_0[j] + fr * tg_yyyyzzz_xx_1[j] + fl1_fxn * tg_yyyyzzz_x_1[j];

                    tg_xyyyyzzz_xy_0[j] = pb_x * tg_yyyyzzz_xy_0[j] + fr * tg_yyyyzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_y_1[j];

                    tg_xyyyyzzz_xz_0[j] = pb_x * tg_yyyyzzz_xz_0[j] + fr * tg_yyyyzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_z_1[j];

                    tg_xyyyyzzz_yy_0[j] = pb_x * tg_yyyyzzz_yy_0[j] + fr * tg_yyyyzzz_yy_1[j];

                    tg_xyyyyzzz_yz_0[j] = pb_x * tg_yyyyzzz_yz_0[j] + fr * tg_yyyyzzz_yz_1[j];

                    tg_xyyyyzzz_zz_0[j] = pb_x * tg_yyyyzzz_zz_0[j] + fr * tg_yyyyzzz_zz_1[j];

                    tg_xyyyzzzz_xx_0[j] = pb_x * tg_yyyzzzz_xx_0[j] + fr * tg_yyyzzzz_xx_1[j] + fl1_fxn * tg_yyyzzzz_x_1[j];

                    tg_xyyyzzzz_xy_0[j] = pb_x * tg_yyyzzzz_xy_0[j] + fr * tg_yyyzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_y_1[j];

                    tg_xyyyzzzz_xz_0[j] = pb_x * tg_yyyzzzz_xz_0[j] + fr * tg_yyyzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_z_1[j];

                    tg_xyyyzzzz_yy_0[j] = pb_x * tg_yyyzzzz_yy_0[j] + fr * tg_yyyzzzz_yy_1[j];

                    tg_xyyyzzzz_yz_0[j] = pb_x * tg_yyyzzzz_yz_0[j] + fr * tg_yyyzzzz_yz_1[j];

                    tg_xyyyzzzz_zz_0[j] = pb_x * tg_yyyzzzz_zz_0[j] + fr * tg_yyyzzzz_zz_1[j];

                    tg_xyyzzzzz_xx_0[j] = pb_x * tg_yyzzzzz_xx_0[j] + fr * tg_yyzzzzz_xx_1[j] + fl1_fxn * tg_yyzzzzz_x_1[j];

                    tg_xyyzzzzz_xy_0[j] = pb_x * tg_yyzzzzz_xy_0[j] + fr * tg_yyzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_y_1[j];

                    tg_xyyzzzzz_xz_0[j] = pb_x * tg_yyzzzzz_xz_0[j] + fr * tg_yyzzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_z_1[j];

                    tg_xyyzzzzz_yy_0[j] = pb_x * tg_yyzzzzz_yy_0[j] + fr * tg_yyzzzzz_yy_1[j];

                    tg_xyyzzzzz_yz_0[j] = pb_x * tg_yyzzzzz_yz_0[j] + fr * tg_yyzzzzz_yz_1[j];

                    tg_xyyzzzzz_zz_0[j] = pb_x * tg_yyzzzzz_zz_0[j] + fr * tg_yyzzzzz_zz_1[j];

                    tg_xyzzzzzz_xx_0[j] = pb_x * tg_yzzzzzz_xx_0[j] + fr * tg_yzzzzzz_xx_1[j] + fl1_fxn * tg_yzzzzzz_x_1[j];

                    tg_xyzzzzzz_xy_0[j] = pb_x * tg_yzzzzzz_xy_0[j] + fr * tg_yzzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_y_1[j];

                    tg_xyzzzzzz_xz_0[j] = pb_x * tg_yzzzzzz_xz_0[j] + fr * tg_yzzzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_z_1[j];

                    tg_xyzzzzzz_yy_0[j] = pb_x * tg_yzzzzzz_yy_0[j] + fr * tg_yzzzzzz_yy_1[j];

                    tg_xyzzzzzz_yz_0[j] = pb_x * tg_yzzzzzz_yz_0[j] + fr * tg_yzzzzzz_yz_1[j];

                    tg_xyzzzzzz_zz_0[j] = pb_x * tg_yzzzzzz_zz_0[j] + fr * tg_yzzzzzz_zz_1[j];

                    tg_xzzzzzzz_xx_0[j] = pb_x * tg_zzzzzzz_xx_0[j] + fr * tg_zzzzzzz_xx_1[j] + fl1_fxn * tg_zzzzzzz_x_1[j];

                    tg_xzzzzzzz_xy_0[j] = pb_x * tg_zzzzzzz_xy_0[j] + fr * tg_zzzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_y_1[j];

                    tg_xzzzzzzz_xz_0[j] = pb_x * tg_zzzzzzz_xz_0[j] + fr * tg_zzzzzzz_xz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_z_1[j];

                    tg_xzzzzzzz_yy_0[j] = pb_x * tg_zzzzzzz_yy_0[j] + fr * tg_zzzzzzz_yy_1[j];

                    tg_xzzzzzzz_yz_0[j] = pb_x * tg_zzzzzzz_yz_0[j] + fr * tg_zzzzzzz_yz_1[j];

                    tg_xzzzzzzz_zz_0[j] = pb_x * tg_zzzzzzz_zz_0[j] + fr * tg_zzzzzzz_zz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyyyy_xx_0[j] = pb_y * tg_yyyyyyy_xx_0[j] + fr * tg_yyyyyyy_xx_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xx_0[j] - tg_yyyyyy_xx_1[j] * fl1_fza);

                    tg_yyyyyyyy_xy_0[j] = pb_y * tg_yyyyyyy_xy_0[j] + fr * tg_yyyyyyy_xy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xy_0[j] - tg_yyyyyy_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_x_1[j];

                    tg_yyyyyyyy_xz_0[j] = pb_y * tg_yyyyyyy_xz_0[j] + fr * tg_yyyyyyy_xz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xz_0[j] - tg_yyyyyy_xz_1[j] * fl1_fza);

                    tg_yyyyyyyy_yy_0[j] = pb_y * tg_yyyyyyy_yy_0[j] + fr * tg_yyyyyyy_yy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yy_0[j] - tg_yyyyyy_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_y_1[j];

                    tg_yyyyyyyy_yz_0[j] = pb_y * tg_yyyyyyy_yz_0[j] + fr * tg_yyyyyyy_yz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yz_0[j] - tg_yyyyyy_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_z_1[j];

                    tg_yyyyyyyy_zz_0[j] = pb_y * tg_yyyyyyy_zz_0[j] + fr * tg_yyyyyyy_zz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_zz_0[j] - tg_yyyyyy_zz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xx_0[j] = pb_y * tg_yyyyyyz_xx_0[j] + fr * tg_yyyyyyz_xx_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xx_0[j] - tg_yyyyyz_xx_1[j] * fl1_fza);

                    tg_yyyyyyyz_xy_0[j] = pb_y * tg_yyyyyyz_xy_0[j] + fr * tg_yyyyyyz_xy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xy_0[j] - tg_yyyyyz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_x_1[j];

                    tg_yyyyyyyz_xz_0[j] = pb_y * tg_yyyyyyz_xz_0[j] + fr * tg_yyyyyyz_xz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xz_0[j] - tg_yyyyyz_xz_1[j] * fl1_fza);

                    tg_yyyyyyyz_yy_0[j] = pb_y * tg_yyyyyyz_yy_0[j] + fr * tg_yyyyyyz_yy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yy_0[j] - tg_yyyyyz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_y_1[j];

                    tg_yyyyyyyz_yz_0[j] = pb_y * tg_yyyyyyz_yz_0[j] + fr * tg_yyyyyyz_yz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yz_0[j] - tg_yyyyyz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_z_1[j];

                    tg_yyyyyyyz_zz_0[j] = pb_y * tg_yyyyyyz_zz_0[j] + fr * tg_yyyyyyz_zz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_zz_0[j] - tg_yyyyyz_zz_1[j] * fl1_fza);

                    tg_yyyyyyzz_xx_0[j] = pb_y * tg_yyyyyzz_xx_0[j] + fr * tg_yyyyyzz_xx_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xx_0[j] - tg_yyyyzz_xx_1[j] * fl1_fza);

                    tg_yyyyyyzz_xy_0[j] = pb_y * tg_yyyyyzz_xy_0[j] + fr * tg_yyyyyzz_xy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xy_0[j] - tg_yyyyzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_x_1[j];

                    tg_yyyyyyzz_xz_0[j] = pb_y * tg_yyyyyzz_xz_0[j] + fr * tg_yyyyyzz_xz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xz_0[j] - tg_yyyyzz_xz_1[j] * fl1_fza);

                    tg_yyyyyyzz_yy_0[j] = pb_y * tg_yyyyyzz_yy_0[j] + fr * tg_yyyyyzz_yy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yy_0[j] - tg_yyyyzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_y_1[j];

                    tg_yyyyyyzz_yz_0[j] = pb_y * tg_yyyyyzz_yz_0[j] + fr * tg_yyyyyzz_yz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yz_0[j] - tg_yyyyzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_z_1[j];

                    tg_yyyyyyzz_zz_0[j] = pb_y * tg_yyyyyzz_zz_0[j] + fr * tg_yyyyyzz_zz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_zz_0[j] - tg_yyyyzz_zz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xx_0[j] = pb_y * tg_yyyyzzz_xx_0[j] + fr * tg_yyyyzzz_xx_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xx_0[j] - tg_yyyzzz_xx_1[j] * fl1_fza);

                    tg_yyyyyzzz_xy_0[j] = pb_y * tg_yyyyzzz_xy_0[j] + fr * tg_yyyyzzz_xy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xy_0[j] - tg_yyyzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_x_1[j];

                    tg_yyyyyzzz_xz_0[j] = pb_y * tg_yyyyzzz_xz_0[j] + fr * tg_yyyyzzz_xz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xz_0[j] - tg_yyyzzz_xz_1[j] * fl1_fza);

                    tg_yyyyyzzz_yy_0[j] = pb_y * tg_yyyyzzz_yy_0[j] + fr * tg_yyyyzzz_yy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yy_0[j] - tg_yyyzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_y_1[j];

                    tg_yyyyyzzz_yz_0[j] = pb_y * tg_yyyyzzz_yz_0[j] + fr * tg_yyyyzzz_yz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yz_0[j] - tg_yyyzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_z_1[j];

                    tg_yyyyyzzz_zz_0[j] = pb_y * tg_yyyyzzz_zz_0[j] + fr * tg_yyyyzzz_zz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_zz_0[j] - tg_yyyzzz_zz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xx_0[j] = pb_y * tg_yyyzzzz_xx_0[j] + fr * tg_yyyzzzz_xx_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xx_0[j] - tg_yyzzzz_xx_1[j] * fl1_fza);

                    tg_yyyyzzzz_xy_0[j] = pb_y * tg_yyyzzzz_xy_0[j] + fr * tg_yyyzzzz_xy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xy_0[j] - tg_yyzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_x_1[j];

                    tg_yyyyzzzz_xz_0[j] = pb_y * tg_yyyzzzz_xz_0[j] + fr * tg_yyyzzzz_xz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xz_0[j] - tg_yyzzzz_xz_1[j] * fl1_fza);

                    tg_yyyyzzzz_yy_0[j] = pb_y * tg_yyyzzzz_yy_0[j] + fr * tg_yyyzzzz_yy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yy_0[j] - tg_yyzzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_y_1[j];

                    tg_yyyyzzzz_yz_0[j] = pb_y * tg_yyyzzzz_yz_0[j] + fr * tg_yyyzzzz_yz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yz_0[j] - tg_yyzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_z_1[j];

                    tg_yyyyzzzz_zz_0[j] = pb_y * tg_yyyzzzz_zz_0[j] + fr * tg_yyyzzzz_zz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_zz_0[j] - tg_yyzzzz_zz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xx_0[j] = pb_y * tg_yyzzzzz_xx_0[j] + fr * tg_yyzzzzz_xx_1[j] + fl1_fx * (tg_yzzzzz_xx_0[j] - tg_yzzzzz_xx_1[j] * fl1_fza);

                    tg_yyyzzzzz_xy_0[j] = pb_y * tg_yyzzzzz_xy_0[j] + fr * tg_yyzzzzz_xy_1[j] + fl1_fx * (tg_yzzzzz_xy_0[j] - tg_yzzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_x_1[j];

                    tg_yyyzzzzz_xz_0[j] = pb_y * tg_yyzzzzz_xz_0[j] + fr * tg_yyzzzzz_xz_1[j] + fl1_fx * (tg_yzzzzz_xz_0[j] - tg_yzzzzz_xz_1[j] * fl1_fza);

                    tg_yyyzzzzz_yy_0[j] = pb_y * tg_yyzzzzz_yy_0[j] + fr * tg_yyzzzzz_yy_1[j] + fl1_fx * (tg_yzzzzz_yy_0[j] - tg_yzzzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_y_1[j];

                    tg_yyyzzzzz_yz_0[j] = pb_y * tg_yyzzzzz_yz_0[j] + fr * tg_yyzzzzz_yz_1[j] + fl1_fx * (tg_yzzzzz_yz_0[j] - tg_yzzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_z_1[j];

                    tg_yyyzzzzz_zz_0[j] = pb_y * tg_yyzzzzz_zz_0[j] + fr * tg_yyzzzzz_zz_1[j] + fl1_fx * (tg_yzzzzz_zz_0[j] - tg_yzzzzz_zz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xx_0[j] = pb_y * tg_yzzzzzz_xx_0[j] + fr * tg_yzzzzzz_xx_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xx_0[j] - tg_zzzzzz_xx_1[j] * fl1_fza);

                    tg_yyzzzzzz_xy_0[j] = pb_y * tg_yzzzzzz_xy_0[j] + fr * tg_yzzzzzz_xy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xy_0[j] - tg_zzzzzz_xy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_x_1[j];

                    tg_yyzzzzzz_xz_0[j] = pb_y * tg_yzzzzzz_xz_0[j] + fr * tg_yzzzzzz_xz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xz_0[j] - tg_zzzzzz_xz_1[j] * fl1_fza);

                    tg_yyzzzzzz_yy_0[j] = pb_y * tg_yzzzzzz_yy_0[j] + fr * tg_yzzzzzz_yy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yy_0[j] - tg_zzzzzz_yy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_y_1[j];

                    tg_yyzzzzzz_yz_0[j] = pb_y * tg_yzzzzzz_yz_0[j] + fr * tg_yzzzzzz_yz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yz_0[j] - tg_zzzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_z_1[j];

                    tg_yyzzzzzz_zz_0[j] = pb_y * tg_yzzzzzz_zz_0[j] + fr * tg_yzzzzzz_zz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_zz_0[j] - tg_zzzzzz_zz_1[j] * fl1_fza);

                    tg_yzzzzzzz_xx_0[j] = pb_y * tg_zzzzzzz_xx_0[j] + fr * tg_zzzzzzz_xx_1[j];

                    tg_yzzzzzzz_xy_0[j] = pb_y * tg_zzzzzzz_xy_0[j] + fr * tg_zzzzzzz_xy_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_x_1[j];

                    tg_yzzzzzzz_xz_0[j] = pb_y * tg_zzzzzzz_xz_0[j] + fr * tg_zzzzzzz_xz_1[j];

                    tg_yzzzzzzz_yy_0[j] = pb_y * tg_zzzzzzz_yy_0[j] + fr * tg_zzzzzzz_yy_1[j] + fl1_fxn * tg_zzzzzzz_y_1[j];

                    tg_yzzzzzzz_yz_0[j] = pb_y * tg_zzzzzzz_yz_0[j] + fr * tg_zzzzzzz_yz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_z_1[j];

                    tg_yzzzzzzz_zz_0[j] = pb_y * tg_zzzzzzz_zz_0[j] + fr * tg_zzzzzzz_zz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzzzz_xx_0[j] = pb_z * tg_zzzzzzz_xx_0[j] + fr * tg_zzzzzzz_xx_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xx_0[j] - tg_zzzzzz_xx_1[j] * fl1_fza);

                    tg_zzzzzzzz_xy_0[j] = pb_z * tg_zzzzzzz_xy_0[j] + fr * tg_zzzzzzz_xy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xy_0[j] - tg_zzzzzz_xy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xz_0[j] = pb_z * tg_zzzzzzz_xz_0[j] + fr * tg_zzzzzzz_xz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xz_0[j] - tg_zzzzzz_xz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_x_1[j];

                    tg_zzzzzzzz_yy_0[j] = pb_z * tg_zzzzzzz_yy_0[j] + fr * tg_zzzzzzz_yy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yy_0[j] - tg_zzzzzz_yy_1[j] * fl1_fza);

                    tg_zzzzzzzz_yz_0[j] = pb_z * tg_zzzzzzz_yz_0[j] + fr * tg_zzzzzzz_yz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yz_0[j] - tg_zzzzzz_yz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_y_1[j];

                    tg_zzzzzzzz_zz_0[j] = pb_z * tg_zzzzzzz_zz_0[j] + fr * tg_zzzzzzz_zz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_zz_0[j] - tg_zzzzzz_zz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_z_1[j];
                }

                idx++;
            }
        }
    }


} // erirecfunc namespace

