//
//                           VELOXCHEM 1.0-RC
//      ---------------------------------------------------
//                     An Electronic Structure Code
//
//  Copyright © 2018-2020 by VeloxChem developers. All rights reserved.
//  Contact: https://veloxchem.org/contact

#include "ElectronRepulsionRecFuncForIL.hpp"

namespace erirecfunc { // erirecfunc namespace

    void
    compElectronRepulsionForSISL(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSISL_0_97(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_97_194(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_194_291(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_291_388(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_388_485(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_485_582(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_582_679(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_679_776(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_776_873(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_873_970(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_970_1067(primBuffer,
                                                          recursionMap,
                                                          osFactors,
                                                          wpDistances, 
                                                          braGtoPairsBlock,
                                                          ketGtoPairsBlock,
                                                          nKetPrimPairs,
                                                          iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_1067_1164(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 

        erirecfunc::compElectronRepulsionForSISL_1164_1260(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 
    }

    void
    compElectronRepulsionForSISL_0_97(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,97)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxx_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx); 

                auto tg_xxxxx_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 1); 

                auto tg_xxxxx_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 2); 

                auto tg_xxxxx_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 3); 

                auto tg_xxxxx_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 4); 

                auto tg_xxxxx_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 5); 

                auto tg_xxxxx_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 6); 

                auto tg_xxxxx_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 7); 

                auto tg_xxxxx_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 8); 

                auto tg_xxxxx_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 9); 

                auto tg_xxxxx_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 10); 

                auto tg_xxxxx_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 11); 

                auto tg_xxxxx_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 12); 

                auto tg_xxxxx_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 13); 

                auto tg_xxxxx_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 14); 

                auto tg_xxxxx_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 15); 

                auto tg_xxxxx_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 16); 

                auto tg_xxxxx_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 17); 

                auto tg_xxxxx_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 18); 

                auto tg_xxxxx_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 19); 

                auto tg_xxxxx_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 20); 

                auto tg_xxxxx_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 21); 

                auto tg_xxxxx_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 22); 

                auto tg_xxxxx_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 23); 

                auto tg_xxxxx_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 24); 

                auto tg_xxxxx_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 25); 

                auto tg_xxxxx_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 26); 

                auto tg_xxxxx_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 27); 

                auto tg_xxxxx_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 28); 

                auto tg_xxxxx_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 29); 

                auto tg_xxxxx_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 30); 

                auto tg_xxxxx_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 31); 

                auto tg_xxxxx_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 32); 

                auto tg_xxxxx_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 33); 

                auto tg_xxxxx_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 34); 

                auto tg_xxxxx_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 35); 

                auto tg_xxxxx_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 36); 

                auto tg_xxxxx_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 37); 

                auto tg_xxxxx_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 38); 

                auto tg_xxxxx_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 39); 

                auto tg_xxxxx_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 40); 

                auto tg_xxxxx_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 41); 

                auto tg_xxxxx_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 42); 

                auto tg_xxxxx_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 43); 

                auto tg_xxxxx_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 44); 

                auto tg_xxxxy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 45); 

                auto tg_xxxxy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 46); 

                auto tg_xxxxy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 47); 

                auto tg_xxxxy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 48); 

                auto tg_xxxxy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 49); 

                auto tg_xxxxy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 50); 

                auto tg_xxxxy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 51); 

                auto tg_xxxxy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 52); 

                auto tg_xxxxy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 53); 

                auto tg_xxxxy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 54); 

                auto tg_xxxxy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 55); 

                auto tg_xxxxy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 56); 

                auto tg_xxxxy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 57); 

                auto tg_xxxxy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 58); 

                auto tg_xxxxy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 59); 

                auto tg_xxxxy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 60); 

                auto tg_xxxxy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 61); 

                auto tg_xxxxy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 62); 

                auto tg_xxxxy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 63); 

                auto tg_xxxxy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 64); 

                auto tg_xxxxy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 65); 

                auto tg_xxxxy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 66); 

                auto tg_xxxxy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 67); 

                auto tg_xxxxy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 68); 

                auto tg_xxxxy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 69); 

                auto tg_xxxxy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 70); 

                auto tg_xxxxy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 71); 

                auto tg_xxxxy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 72); 

                auto tg_xxxxy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 73); 

                auto tg_xxxxy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 74); 

                auto tg_xxxxy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 75); 

                auto tg_xxxxy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 76); 

                auto tg_xxxxy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 77); 

                auto tg_xxxxy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 78); 

                auto tg_xxxxy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 79); 

                auto tg_xxxxy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 80); 

                auto tg_xxxxy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 81); 

                auto tg_xxxxy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 82); 

                auto tg_xxxxy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 83); 

                auto tg_xxxxy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 84); 

                auto tg_xxxxy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 85); 

                auto tg_xxxxy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 86); 

                auto tg_xxxxy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 87); 

                auto tg_xxxxy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 88); 

                auto tg_xxxxy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 89); 

                auto tg_xxxxz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 90); 

                auto tg_xxxxz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 91); 

                auto tg_xxxxz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 92); 

                auto tg_xxxxz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 93); 

                auto tg_xxxxz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 94); 

                auto tg_xxxxz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 95); 

                auto tg_xxxxz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 96); 

                auto tg_xxxxx_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx); 

                auto tg_xxxxx_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 1); 

                auto tg_xxxxx_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 2); 

                auto tg_xxxxx_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 3); 

                auto tg_xxxxx_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 4); 

                auto tg_xxxxx_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 5); 

                auto tg_xxxxx_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 6); 

                auto tg_xxxxx_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 7); 

                auto tg_xxxxx_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 8); 

                auto tg_xxxxx_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 9); 

                auto tg_xxxxx_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 10); 

                auto tg_xxxxx_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 11); 

                auto tg_xxxxx_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 12); 

                auto tg_xxxxx_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 13); 

                auto tg_xxxxx_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 14); 

                auto tg_xxxxx_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 15); 

                auto tg_xxxxx_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 16); 

                auto tg_xxxxx_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 17); 

                auto tg_xxxxx_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 18); 

                auto tg_xxxxx_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 19); 

                auto tg_xxxxx_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 20); 

                auto tg_xxxxx_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 21); 

                auto tg_xxxxx_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 22); 

                auto tg_xxxxx_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 23); 

                auto tg_xxxxx_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 24); 

                auto tg_xxxxx_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 25); 

                auto tg_xxxxx_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 26); 

                auto tg_xxxxx_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 27); 

                auto tg_xxxxx_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 28); 

                auto tg_xxxxx_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 29); 

                auto tg_xxxxx_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 30); 

                auto tg_xxxxx_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 31); 

                auto tg_xxxxx_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 32); 

                auto tg_xxxxx_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 33); 

                auto tg_xxxxx_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 34); 

                auto tg_xxxxx_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 35); 

                auto tg_xxxxx_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 36); 

                auto tg_xxxxx_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 37); 

                auto tg_xxxxx_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 38); 

                auto tg_xxxxx_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 39); 

                auto tg_xxxxx_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 40); 

                auto tg_xxxxx_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 41); 

                auto tg_xxxxx_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 42); 

                auto tg_xxxxx_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 43); 

                auto tg_xxxxx_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 44); 

                auto tg_xxxxy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 45); 

                auto tg_xxxxy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 46); 

                auto tg_xxxxy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 47); 

                auto tg_xxxxy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 48); 

                auto tg_xxxxy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 49); 

                auto tg_xxxxy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 50); 

                auto tg_xxxxy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 51); 

                auto tg_xxxxy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 52); 

                auto tg_xxxxy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 53); 

                auto tg_xxxxy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 54); 

                auto tg_xxxxy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 55); 

                auto tg_xxxxy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 56); 

                auto tg_xxxxy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 57); 

                auto tg_xxxxy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 58); 

                auto tg_xxxxy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 59); 

                auto tg_xxxxy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 60); 

                auto tg_xxxxy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 61); 

                auto tg_xxxxy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 62); 

                auto tg_xxxxy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 63); 

                auto tg_xxxxy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 64); 

                auto tg_xxxxy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 65); 

                auto tg_xxxxy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 66); 

                auto tg_xxxxy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 67); 

                auto tg_xxxxy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 68); 

                auto tg_xxxxy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 69); 

                auto tg_xxxxy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 70); 

                auto tg_xxxxy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 71); 

                auto tg_xxxxy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 72); 

                auto tg_xxxxy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 73); 

                auto tg_xxxxy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 74); 

                auto tg_xxxxy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 75); 

                auto tg_xxxxy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 76); 

                auto tg_xxxxy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 77); 

                auto tg_xxxxy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 78); 

                auto tg_xxxxy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 79); 

                auto tg_xxxxy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 80); 

                auto tg_xxxxy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 81); 

                auto tg_xxxxy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 82); 

                auto tg_xxxxy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 83); 

                auto tg_xxxxy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 84); 

                auto tg_xxxxy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 85); 

                auto tg_xxxxy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 86); 

                auto tg_xxxxy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 87); 

                auto tg_xxxxy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 88); 

                auto tg_xxxxy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 89); 

                auto tg_xxxxz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 90); 

                auto tg_xxxxz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 91); 

                auto tg_xxxxz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 92); 

                auto tg_xxxxz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 93); 

                auto tg_xxxxz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 94); 

                auto tg_xxxxz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 95); 

                auto tg_xxxxz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 96); 

                auto tg_xxxx_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx); 

                auto tg_xxxx_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 1); 

                auto tg_xxxx_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 2); 

                auto tg_xxxx_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 3); 

                auto tg_xxxx_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 4); 

                auto tg_xxxx_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 5); 

                auto tg_xxxx_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 6); 

                auto tg_xxxx_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 7); 

                auto tg_xxxx_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 8); 

                auto tg_xxxx_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 9); 

                auto tg_xxxx_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 10); 

                auto tg_xxxx_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 11); 

                auto tg_xxxx_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 12); 

                auto tg_xxxx_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 13); 

                auto tg_xxxx_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 14); 

                auto tg_xxxx_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 15); 

                auto tg_xxxx_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 16); 

                auto tg_xxxx_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 17); 

                auto tg_xxxx_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 18); 

                auto tg_xxxx_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 19); 

                auto tg_xxxx_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 20); 

                auto tg_xxxx_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 21); 

                auto tg_xxxx_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 22); 

                auto tg_xxxx_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 23); 

                auto tg_xxxx_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 24); 

                auto tg_xxxx_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 25); 

                auto tg_xxxx_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 26); 

                auto tg_xxxx_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 27); 

                auto tg_xxxx_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 28); 

                auto tg_xxxx_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 29); 

                auto tg_xxxx_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 30); 

                auto tg_xxxx_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 31); 

                auto tg_xxxx_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 32); 

                auto tg_xxxx_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 33); 

                auto tg_xxxx_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 34); 

                auto tg_xxxx_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 35); 

                auto tg_xxxx_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 36); 

                auto tg_xxxx_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 37); 

                auto tg_xxxx_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 38); 

                auto tg_xxxx_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 39); 

                auto tg_xxxx_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 40); 

                auto tg_xxxx_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 41); 

                auto tg_xxxx_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 42); 

                auto tg_xxxx_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 43); 

                auto tg_xxxx_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 44); 

                auto tg_xxxy_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 45); 

                auto tg_xxxy_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 46); 

                auto tg_xxxy_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 47); 

                auto tg_xxxy_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 48); 

                auto tg_xxxy_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 49); 

                auto tg_xxxy_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 50); 

                auto tg_xxxy_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 51); 

                auto tg_xxxy_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 52); 

                auto tg_xxxy_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 53); 

                auto tg_xxxy_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 54); 

                auto tg_xxxy_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 55); 

                auto tg_xxxy_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 56); 

                auto tg_xxxy_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 57); 

                auto tg_xxxy_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 58); 

                auto tg_xxxy_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 59); 

                auto tg_xxxy_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 60); 

                auto tg_xxxy_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 61); 

                auto tg_xxxy_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 62); 

                auto tg_xxxy_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 63); 

                auto tg_xxxy_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 64); 

                auto tg_xxxy_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 65); 

                auto tg_xxxy_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 66); 

                auto tg_xxxy_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 67); 

                auto tg_xxxy_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 68); 

                auto tg_xxxy_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 69); 

                auto tg_xxxy_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 70); 

                auto tg_xxxy_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 71); 

                auto tg_xxxy_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 72); 

                auto tg_xxxy_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 73); 

                auto tg_xxxy_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 74); 

                auto tg_xxxy_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 75); 

                auto tg_xxxy_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 76); 

                auto tg_xxxy_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 77); 

                auto tg_xxxy_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 78); 

                auto tg_xxxy_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 79); 

                auto tg_xxxy_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 80); 

                auto tg_xxxy_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 81); 

                auto tg_xxxy_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 82); 

                auto tg_xxxy_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 83); 

                auto tg_xxxy_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 84); 

                auto tg_xxxy_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 85); 

                auto tg_xxxy_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 86); 

                auto tg_xxxy_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 87); 

                auto tg_xxxy_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 88); 

                auto tg_xxxy_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 89); 

                auto tg_xxxz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 90); 

                auto tg_xxxz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 91); 

                auto tg_xxxz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 92); 

                auto tg_xxxz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 93); 

                auto tg_xxxz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 94); 

                auto tg_xxxz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 95); 

                auto tg_xxxz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 96); 

                auto tg_xxxx_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx); 

                auto tg_xxxx_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 1); 

                auto tg_xxxx_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 2); 

                auto tg_xxxx_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 3); 

                auto tg_xxxx_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 4); 

                auto tg_xxxx_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 5); 

                auto tg_xxxx_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 6); 

                auto tg_xxxx_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 7); 

                auto tg_xxxx_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 8); 

                auto tg_xxxx_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 9); 

                auto tg_xxxx_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 10); 

                auto tg_xxxx_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 11); 

                auto tg_xxxx_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 12); 

                auto tg_xxxx_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 13); 

                auto tg_xxxx_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 14); 

                auto tg_xxxx_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 15); 

                auto tg_xxxx_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 16); 

                auto tg_xxxx_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 17); 

                auto tg_xxxx_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 18); 

                auto tg_xxxx_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 19); 

                auto tg_xxxx_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 20); 

                auto tg_xxxx_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 21); 

                auto tg_xxxx_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 22); 

                auto tg_xxxx_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 23); 

                auto tg_xxxx_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 24); 

                auto tg_xxxx_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 25); 

                auto tg_xxxx_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 26); 

                auto tg_xxxx_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 27); 

                auto tg_xxxx_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 28); 

                auto tg_xxxx_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 29); 

                auto tg_xxxx_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 30); 

                auto tg_xxxx_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 31); 

                auto tg_xxxx_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 32); 

                auto tg_xxxx_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 33); 

                auto tg_xxxx_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 34); 

                auto tg_xxxx_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 35); 

                auto tg_xxxx_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 36); 

                auto tg_xxxx_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 37); 

                auto tg_xxxx_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 38); 

                auto tg_xxxx_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 39); 

                auto tg_xxxx_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 40); 

                auto tg_xxxx_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 41); 

                auto tg_xxxx_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 42); 

                auto tg_xxxx_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 43); 

                auto tg_xxxx_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 44); 

                auto tg_xxxy_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 45); 

                auto tg_xxxy_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 46); 

                auto tg_xxxy_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 47); 

                auto tg_xxxy_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 48); 

                auto tg_xxxy_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 49); 

                auto tg_xxxy_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 50); 

                auto tg_xxxy_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 51); 

                auto tg_xxxy_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 52); 

                auto tg_xxxy_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 53); 

                auto tg_xxxy_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 54); 

                auto tg_xxxy_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 55); 

                auto tg_xxxy_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 56); 

                auto tg_xxxy_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 57); 

                auto tg_xxxy_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 58); 

                auto tg_xxxy_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 59); 

                auto tg_xxxy_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 60); 

                auto tg_xxxy_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 61); 

                auto tg_xxxy_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 62); 

                auto tg_xxxy_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 63); 

                auto tg_xxxy_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 64); 

                auto tg_xxxy_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 65); 

                auto tg_xxxy_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 66); 

                auto tg_xxxy_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 67); 

                auto tg_xxxy_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 68); 

                auto tg_xxxy_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 69); 

                auto tg_xxxy_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 70); 

                auto tg_xxxy_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 71); 

                auto tg_xxxy_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 72); 

                auto tg_xxxy_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 73); 

                auto tg_xxxy_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 74); 

                auto tg_xxxy_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 75); 

                auto tg_xxxy_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 76); 

                auto tg_xxxy_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 77); 

                auto tg_xxxy_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 78); 

                auto tg_xxxy_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 79); 

                auto tg_xxxy_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 80); 

                auto tg_xxxy_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 81); 

                auto tg_xxxy_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 82); 

                auto tg_xxxy_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 83); 

                auto tg_xxxy_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 84); 

                auto tg_xxxy_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 85); 

                auto tg_xxxy_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 86); 

                auto tg_xxxy_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 87); 

                auto tg_xxxy_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 88); 

                auto tg_xxxy_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 89); 

                auto tg_xxxz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 90); 

                auto tg_xxxz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 91); 

                auto tg_xxxz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 92); 

                auto tg_xxxz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 93); 

                auto tg_xxxz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 94); 

                auto tg_xxxz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 95); 

                auto tg_xxxz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 96); 

                auto tg_xxxxx_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx); 

                auto tg_xxxxx_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 1); 

                auto tg_xxxxx_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 2); 

                auto tg_xxxxx_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 3); 

                auto tg_xxxxx_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 4); 

                auto tg_xxxxx_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 5); 

                auto tg_xxxxx_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 6); 

                auto tg_xxxxx_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 7); 

                auto tg_xxxxx_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 8); 

                auto tg_xxxxx_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 9); 

                auto tg_xxxxx_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 10); 

                auto tg_xxxxx_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 11); 

                auto tg_xxxxx_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 12); 

                auto tg_xxxxx_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 13); 

                auto tg_xxxxx_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 14); 

                auto tg_xxxxx_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 15); 

                auto tg_xxxxx_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 16); 

                auto tg_xxxxx_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 17); 

                auto tg_xxxxx_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 18); 

                auto tg_xxxxx_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 19); 

                auto tg_xxxxx_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 20); 

                auto tg_xxxxx_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 21); 

                auto tg_xxxxx_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 22); 

                auto tg_xxxxx_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 23); 

                auto tg_xxxxx_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 24); 

                auto tg_xxxxx_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 25); 

                auto tg_xxxxx_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 26); 

                auto tg_xxxxx_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 27); 

                auto tg_xxxxx_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 28); 

                auto tg_xxxxx_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 29); 

                auto tg_xxxxx_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 30); 

                auto tg_xxxxx_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 31); 

                auto tg_xxxxx_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 32); 

                auto tg_xxxxx_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 33); 

                auto tg_xxxxx_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 34); 

                auto tg_xxxxx_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 35); 

                auto tg_xxxxy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 36); 

                auto tg_xxxxy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 37); 

                auto tg_xxxxy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 38); 

                auto tg_xxxxy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 39); 

                auto tg_xxxxy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 40); 

                auto tg_xxxxy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 41); 

                auto tg_xxxxy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 42); 

                auto tg_xxxxy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 43); 

                auto tg_xxxxy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 44); 

                auto tg_xxxxy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 45); 

                auto tg_xxxxy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 46); 

                auto tg_xxxxy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 47); 

                auto tg_xxxxy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 48); 

                auto tg_xxxxy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 49); 

                auto tg_xxxxy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 50); 

                auto tg_xxxxy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 51); 

                auto tg_xxxxy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 52); 

                auto tg_xxxxy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 53); 

                auto tg_xxxxy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 54); 

                auto tg_xxxxy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 55); 

                auto tg_xxxxy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 56); 

                auto tg_xxxxy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 57); 

                auto tg_xxxxy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 58); 

                auto tg_xxxxy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 59); 

                auto tg_xxxxy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 60); 

                auto tg_xxxxy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 61); 

                auto tg_xxxxy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 62); 

                auto tg_xxxxy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 63); 

                auto tg_xxxxy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 64); 

                auto tg_xxxxy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 65); 

                auto tg_xxxxy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 66); 

                auto tg_xxxxy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 67); 

                auto tg_xxxxy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 68); 

                auto tg_xxxxy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 69); 

                auto tg_xxxxy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 70); 

                auto tg_xxxxy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 71); 

                auto tg_xxxxz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 72); 

                auto tg_xxxxz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 73); 

                auto tg_xxxxz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 74); 

                auto tg_xxxxz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 75); 

                auto tg_xxxxz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 76); 

                auto tg_xxxxz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 77); 

                auto tg_xxxxz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 78); 

                // set up pointers to integrals

                auto tg_xxxxxx_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx); 

                auto tg_xxxxxx_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1); 

                auto tg_xxxxxx_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 2); 

                auto tg_xxxxxx_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 3); 

                auto tg_xxxxxx_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 4); 

                auto tg_xxxxxx_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 5); 

                auto tg_xxxxxx_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 6); 

                auto tg_xxxxxx_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 7); 

                auto tg_xxxxxx_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 8); 

                auto tg_xxxxxx_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 9); 

                auto tg_xxxxxx_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 10); 

                auto tg_xxxxxx_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 11); 

                auto tg_xxxxxx_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 12); 

                auto tg_xxxxxx_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 13); 

                auto tg_xxxxxx_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 14); 

                auto tg_xxxxxx_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 15); 

                auto tg_xxxxxx_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 16); 

                auto tg_xxxxxx_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 17); 

                auto tg_xxxxxx_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 18); 

                auto tg_xxxxxx_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 19); 

                auto tg_xxxxxx_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 20); 

                auto tg_xxxxxx_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 21); 

                auto tg_xxxxxx_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 22); 

                auto tg_xxxxxx_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 23); 

                auto tg_xxxxxx_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 24); 

                auto tg_xxxxxx_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 25); 

                auto tg_xxxxxx_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 26); 

                auto tg_xxxxxx_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 27); 

                auto tg_xxxxxx_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 28); 

                auto tg_xxxxxx_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 29); 

                auto tg_xxxxxx_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 30); 

                auto tg_xxxxxx_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 31); 

                auto tg_xxxxxx_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 32); 

                auto tg_xxxxxx_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 33); 

                auto tg_xxxxxx_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 34); 

                auto tg_xxxxxx_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 35); 

                auto tg_xxxxxx_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 36); 

                auto tg_xxxxxx_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 37); 

                auto tg_xxxxxx_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 38); 

                auto tg_xxxxxx_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 39); 

                auto tg_xxxxxx_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 40); 

                auto tg_xxxxxx_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 41); 

                auto tg_xxxxxx_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 42); 

                auto tg_xxxxxx_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 43); 

                auto tg_xxxxxx_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 44); 

                auto tg_xxxxxy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 45); 

                auto tg_xxxxxy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 46); 

                auto tg_xxxxxy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 47); 

                auto tg_xxxxxy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 48); 

                auto tg_xxxxxy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 49); 

                auto tg_xxxxxy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 50); 

                auto tg_xxxxxy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 51); 

                auto tg_xxxxxy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 52); 

                auto tg_xxxxxy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 53); 

                auto tg_xxxxxy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 54); 

                auto tg_xxxxxy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 55); 

                auto tg_xxxxxy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 56); 

                auto tg_xxxxxy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 57); 

                auto tg_xxxxxy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 58); 

                auto tg_xxxxxy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 59); 

                auto tg_xxxxxy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 60); 

                auto tg_xxxxxy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 61); 

                auto tg_xxxxxy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 62); 

                auto tg_xxxxxy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 63); 

                auto tg_xxxxxy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 64); 

                auto tg_xxxxxy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 65); 

                auto tg_xxxxxy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 66); 

                auto tg_xxxxxy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 67); 

                auto tg_xxxxxy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 68); 

                auto tg_xxxxxy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 69); 

                auto tg_xxxxxy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 70); 

                auto tg_xxxxxy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 71); 

                auto tg_xxxxxy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 72); 

                auto tg_xxxxxy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 73); 

                auto tg_xxxxxy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 74); 

                auto tg_xxxxxy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 75); 

                auto tg_xxxxxy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 76); 

                auto tg_xxxxxy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 77); 

                auto tg_xxxxxy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 78); 

                auto tg_xxxxxy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 79); 

                auto tg_xxxxxy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 80); 

                auto tg_xxxxxy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 81); 

                auto tg_xxxxxy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 82); 

                auto tg_xxxxxy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 83); 

                auto tg_xxxxxy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 84); 

                auto tg_xxxxxy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 85); 

                auto tg_xxxxxy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 86); 

                auto tg_xxxxxy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 87); 

                auto tg_xxxxxy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 88); 

                auto tg_xxxxxy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 89); 

                auto tg_xxxxxz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 90); 

                auto tg_xxxxxz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 91); 

                auto tg_xxxxxz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 92); 

                auto tg_xxxxxz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 93); 

                auto tg_xxxxxz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 94); 

                auto tg_xxxxxz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 95); 

                auto tg_xxxxxz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 96); 

                // Batch of Integrals (0,97)

                #pragma omp simd aligned(fxn, fza, tg_xxxx_xxxxxxxx_0, tg_xxxx_xxxxxxxx_1, tg_xxxx_xxxxxxxy_0, \
                                         tg_xxxx_xxxxxxxy_1, tg_xxxx_xxxxxxxz_0, tg_xxxx_xxxxxxxz_1, tg_xxxx_xxxxxxyy_0, \
                                         tg_xxxx_xxxxxxyy_1, tg_xxxx_xxxxxxyz_0, tg_xxxx_xxxxxxyz_1, tg_xxxx_xxxxxxzz_0, \
                                         tg_xxxx_xxxxxxzz_1, tg_xxxx_xxxxxyyy_0, tg_xxxx_xxxxxyyy_1, tg_xxxx_xxxxxyyz_0, \
                                         tg_xxxx_xxxxxyyz_1, tg_xxxx_xxxxxyzz_0, tg_xxxx_xxxxxyzz_1, tg_xxxx_xxxxxzzz_0, \
                                         tg_xxxx_xxxxxzzz_1, tg_xxxx_xxxxyyyy_0, tg_xxxx_xxxxyyyy_1, tg_xxxx_xxxxyyyz_0, \
                                         tg_xxxx_xxxxyyyz_1, tg_xxxx_xxxxyyzz_0, tg_xxxx_xxxxyyzz_1, tg_xxxx_xxxxyzzz_0, \
                                         tg_xxxx_xxxxyzzz_1, tg_xxxx_xxxxzzzz_0, tg_xxxx_xxxxzzzz_1, tg_xxxx_xxxyyyyy_0, \
                                         tg_xxxx_xxxyyyyy_1, tg_xxxx_xxxyyyyz_0, tg_xxxx_xxxyyyyz_1, tg_xxxx_xxxyyyzz_0, \
                                         tg_xxxx_xxxyyyzz_1, tg_xxxx_xxxyyzzz_0, tg_xxxx_xxxyyzzz_1, tg_xxxx_xxxyzzzz_0, \
                                         tg_xxxx_xxxyzzzz_1, tg_xxxx_xxxzzzzz_0, tg_xxxx_xxxzzzzz_1, tg_xxxx_xxyyyyyy_0, \
                                         tg_xxxx_xxyyyyyy_1, tg_xxxx_xxyyyyyz_0, tg_xxxx_xxyyyyyz_1, tg_xxxx_xxyyyyzz_0, \
                                         tg_xxxx_xxyyyyzz_1, tg_xxxx_xxyyyzzz_0, tg_xxxx_xxyyyzzz_1, tg_xxxx_xxyyzzzz_0, \
                                         tg_xxxx_xxyyzzzz_1, tg_xxxx_xxyzzzzz_0, tg_xxxx_xxyzzzzz_1, tg_xxxx_xxzzzzzz_0, \
                                         tg_xxxx_xxzzzzzz_1, tg_xxxx_xyyyyyyy_0, tg_xxxx_xyyyyyyy_1, tg_xxxx_xyyyyyyz_0, \
                                         tg_xxxx_xyyyyyyz_1, tg_xxxx_xyyyyyzz_0, tg_xxxx_xyyyyyzz_1, tg_xxxx_xyyyyzzz_0, \
                                         tg_xxxx_xyyyyzzz_1, tg_xxxx_xyyyzzzz_0, tg_xxxx_xyyyzzzz_1, tg_xxxx_xyyzzzzz_0, \
                                         tg_xxxx_xyyzzzzz_1, tg_xxxx_xyzzzzzz_0, tg_xxxx_xyzzzzzz_1, tg_xxxx_xzzzzzzz_0, \
                                         tg_xxxx_xzzzzzzz_1, tg_xxxx_yyyyyyyy_0, tg_xxxx_yyyyyyyy_1, tg_xxxx_yyyyyyyz_0, \
                                         tg_xxxx_yyyyyyyz_1, tg_xxxx_yyyyyyzz_0, tg_xxxx_yyyyyyzz_1, tg_xxxx_yyyyyzzz_0, \
                                         tg_xxxx_yyyyyzzz_1, tg_xxxx_yyyyzzzz_0, tg_xxxx_yyyyzzzz_1, tg_xxxx_yyyzzzzz_0, \
                                         tg_xxxx_yyyzzzzz_1, tg_xxxx_yyzzzzzz_0, tg_xxxx_yyzzzzzz_1, tg_xxxx_yzzzzzzz_0, \
                                         tg_xxxx_yzzzzzzz_1, tg_xxxx_zzzzzzzz_0, tg_xxxx_zzzzzzzz_1, tg_xxxxx_xxxxxxx_1, \
                                         tg_xxxxx_xxxxxxxx_0, tg_xxxxx_xxxxxxxx_1, tg_xxxxx_xxxxxxxy_0, tg_xxxxx_xxxxxxxy_1, \
                                         tg_xxxxx_xxxxxxxz_0, tg_xxxxx_xxxxxxxz_1, tg_xxxxx_xxxxxxy_1, tg_xxxxx_xxxxxxyy_0, \
                                         tg_xxxxx_xxxxxxyy_1, tg_xxxxx_xxxxxxyz_0, tg_xxxxx_xxxxxxyz_1, tg_xxxxx_xxxxxxz_1, \
                                         tg_xxxxx_xxxxxxzz_0, tg_xxxxx_xxxxxxzz_1, tg_xxxxx_xxxxxyy_1, tg_xxxxx_xxxxxyyy_0, \
                                         tg_xxxxx_xxxxxyyy_1, tg_xxxxx_xxxxxyyz_0, tg_xxxxx_xxxxxyyz_1, tg_xxxxx_xxxxxyz_1, \
                                         tg_xxxxx_xxxxxyzz_0, tg_xxxxx_xxxxxyzz_1, tg_xxxxx_xxxxxzz_1, tg_xxxxx_xxxxxzzz_0, \
                                         tg_xxxxx_xxxxxzzz_1, tg_xxxxx_xxxxyyy_1, tg_xxxxx_xxxxyyyy_0, tg_xxxxx_xxxxyyyy_1, \
                                         tg_xxxxx_xxxxyyyz_0, tg_xxxxx_xxxxyyyz_1, tg_xxxxx_xxxxyyz_1, tg_xxxxx_xxxxyyzz_0, \
                                         tg_xxxxx_xxxxyyzz_1, tg_xxxxx_xxxxyzz_1, tg_xxxxx_xxxxyzzz_0, tg_xxxxx_xxxxyzzz_1, \
                                         tg_xxxxx_xxxxzzz_1, tg_xxxxx_xxxxzzzz_0, tg_xxxxx_xxxxzzzz_1, tg_xxxxx_xxxyyyy_1, \
                                         tg_xxxxx_xxxyyyyy_0, tg_xxxxx_xxxyyyyy_1, tg_xxxxx_xxxyyyyz_0, tg_xxxxx_xxxyyyyz_1, \
                                         tg_xxxxx_xxxyyyz_1, tg_xxxxx_xxxyyyzz_0, tg_xxxxx_xxxyyyzz_1, tg_xxxxx_xxxyyzz_1, \
                                         tg_xxxxx_xxxyyzzz_0, tg_xxxxx_xxxyyzzz_1, tg_xxxxx_xxxyzzz_1, tg_xxxxx_xxxyzzzz_0, \
                                         tg_xxxxx_xxxyzzzz_1, tg_xxxxx_xxxzzzz_1, tg_xxxxx_xxxzzzzz_0, tg_xxxxx_xxxzzzzz_1, \
                                         tg_xxxxx_xxyyyyy_1, tg_xxxxx_xxyyyyyy_0, tg_xxxxx_xxyyyyyy_1, tg_xxxxx_xxyyyyyz_0, \
                                         tg_xxxxx_xxyyyyyz_1, tg_xxxxx_xxyyyyz_1, tg_xxxxx_xxyyyyzz_0, tg_xxxxx_xxyyyyzz_1, \
                                         tg_xxxxx_xxyyyzz_1, tg_xxxxx_xxyyyzzz_0, tg_xxxxx_xxyyyzzz_1, tg_xxxxx_xxyyzzz_1, \
                                         tg_xxxxx_xxyyzzzz_0, tg_xxxxx_xxyyzzzz_1, tg_xxxxx_xxyzzzz_1, tg_xxxxx_xxyzzzzz_0, \
                                         tg_xxxxx_xxyzzzzz_1, tg_xxxxx_xxzzzzz_1, tg_xxxxx_xxzzzzzz_0, tg_xxxxx_xxzzzzzz_1, \
                                         tg_xxxxx_xyyyyyy_1, tg_xxxxx_xyyyyyyy_0, tg_xxxxx_xyyyyyyy_1, tg_xxxxx_xyyyyyyz_0, \
                                         tg_xxxxx_xyyyyyyz_1, tg_xxxxx_xyyyyyz_1, tg_xxxxx_xyyyyyzz_0, tg_xxxxx_xyyyyyzz_1, \
                                         tg_xxxxx_xyyyyzz_1, tg_xxxxx_xyyyyzzz_0, tg_xxxxx_xyyyyzzz_1, tg_xxxxx_xyyyzzz_1, \
                                         tg_xxxxx_xyyyzzzz_0, tg_xxxxx_xyyyzzzz_1, tg_xxxxx_xyyzzzz_1, tg_xxxxx_xyyzzzzz_0, \
                                         tg_xxxxx_xyyzzzzz_1, tg_xxxxx_xyzzzzz_1, tg_xxxxx_xyzzzzzz_0, tg_xxxxx_xyzzzzzz_1, \
                                         tg_xxxxx_xzzzzzz_1, tg_xxxxx_xzzzzzzz_0, tg_xxxxx_xzzzzzzz_1, tg_xxxxx_yyyyyyy_1, \
                                         tg_xxxxx_yyyyyyyy_0, tg_xxxxx_yyyyyyyy_1, tg_xxxxx_yyyyyyyz_0, tg_xxxxx_yyyyyyyz_1, \
                                         tg_xxxxx_yyyyyyz_1, tg_xxxxx_yyyyyyzz_0, tg_xxxxx_yyyyyyzz_1, tg_xxxxx_yyyyyzz_1, \
                                         tg_xxxxx_yyyyyzzz_0, tg_xxxxx_yyyyyzzz_1, tg_xxxxx_yyyyzzz_1, tg_xxxxx_yyyyzzzz_0, \
                                         tg_xxxxx_yyyyzzzz_1, tg_xxxxx_yyyzzzz_1, tg_xxxxx_yyyzzzzz_0, tg_xxxxx_yyyzzzzz_1, \
                                         tg_xxxxx_yyzzzzz_1, tg_xxxxx_yyzzzzzz_0, tg_xxxxx_yyzzzzzz_1, tg_xxxxx_yzzzzzz_1, \
                                         tg_xxxxx_yzzzzzzz_0, tg_xxxxx_yzzzzzzz_1, tg_xxxxx_zzzzzzz_1, tg_xxxxx_zzzzzzzz_0, \
                                         tg_xxxxx_zzzzzzzz_1, tg_xxxxxx_xxxxxxxx_0, tg_xxxxxx_xxxxxxxy_0, tg_xxxxxx_xxxxxxxz_0, \
                                         tg_xxxxxx_xxxxxxyy_0, tg_xxxxxx_xxxxxxyz_0, tg_xxxxxx_xxxxxxzz_0, tg_xxxxxx_xxxxxyyy_0, \
                                         tg_xxxxxx_xxxxxyyz_0, tg_xxxxxx_xxxxxyzz_0, tg_xxxxxx_xxxxxzzz_0, tg_xxxxxx_xxxxyyyy_0, \
                                         tg_xxxxxx_xxxxyyyz_0, tg_xxxxxx_xxxxyyzz_0, tg_xxxxxx_xxxxyzzz_0, tg_xxxxxx_xxxxzzzz_0, \
                                         tg_xxxxxx_xxxyyyyy_0, tg_xxxxxx_xxxyyyyz_0, tg_xxxxxx_xxxyyyzz_0, tg_xxxxxx_xxxyyzzz_0, \
                                         tg_xxxxxx_xxxyzzzz_0, tg_xxxxxx_xxxzzzzz_0, tg_xxxxxx_xxyyyyyy_0, tg_xxxxxx_xxyyyyyz_0, \
                                         tg_xxxxxx_xxyyyyzz_0, tg_xxxxxx_xxyyyzzz_0, tg_xxxxxx_xxyyzzzz_0, tg_xxxxxx_xxyzzzzz_0, \
                                         tg_xxxxxx_xxzzzzzz_0, tg_xxxxxx_xyyyyyyy_0, tg_xxxxxx_xyyyyyyz_0, tg_xxxxxx_xyyyyyzz_0, \
                                         tg_xxxxxx_xyyyyzzz_0, tg_xxxxxx_xyyyzzzz_0, tg_xxxxxx_xyyzzzzz_0, tg_xxxxxx_xyzzzzzz_0, \
                                         tg_xxxxxx_xzzzzzzz_0, tg_xxxxxx_yyyyyyyy_0, tg_xxxxxx_yyyyyyyz_0, tg_xxxxxx_yyyyyyzz_0, \
                                         tg_xxxxxx_yyyyyzzz_0, tg_xxxxxx_yyyyzzzz_0, tg_xxxxxx_yyyzzzzz_0, tg_xxxxxx_yyzzzzzz_0, \
                                         tg_xxxxxx_yzzzzzzz_0, tg_xxxxxx_zzzzzzzz_0, tg_xxxxxy_xxxxxxxx_0, tg_xxxxxy_xxxxxxxy_0, \
                                         tg_xxxxxy_xxxxxxxz_0, tg_xxxxxy_xxxxxxyy_0, tg_xxxxxy_xxxxxxyz_0, tg_xxxxxy_xxxxxxzz_0, \
                                         tg_xxxxxy_xxxxxyyy_0, tg_xxxxxy_xxxxxyyz_0, tg_xxxxxy_xxxxxyzz_0, tg_xxxxxy_xxxxxzzz_0, \
                                         tg_xxxxxy_xxxxyyyy_0, tg_xxxxxy_xxxxyyyz_0, tg_xxxxxy_xxxxyyzz_0, tg_xxxxxy_xxxxyzzz_0, \
                                         tg_xxxxxy_xxxxzzzz_0, tg_xxxxxy_xxxyyyyy_0, tg_xxxxxy_xxxyyyyz_0, tg_xxxxxy_xxxyyyzz_0, \
                                         tg_xxxxxy_xxxyyzzz_0, tg_xxxxxy_xxxyzzzz_0, tg_xxxxxy_xxxzzzzz_0, tg_xxxxxy_xxyyyyyy_0, \
                                         tg_xxxxxy_xxyyyyyz_0, tg_xxxxxy_xxyyyyzz_0, tg_xxxxxy_xxyyyzzz_0, tg_xxxxxy_xxyyzzzz_0, \
                                         tg_xxxxxy_xxyzzzzz_0, tg_xxxxxy_xxzzzzzz_0, tg_xxxxxy_xyyyyyyy_0, tg_xxxxxy_xyyyyyyz_0, \
                                         tg_xxxxxy_xyyyyyzz_0, tg_xxxxxy_xyyyyzzz_0, tg_xxxxxy_xyyyzzzz_0, tg_xxxxxy_xyyzzzzz_0, \
                                         tg_xxxxxy_xyzzzzzz_0, tg_xxxxxy_xzzzzzzz_0, tg_xxxxxy_yyyyyyyy_0, tg_xxxxxy_yyyyyyyz_0, \
                                         tg_xxxxxy_yyyyyyzz_0, tg_xxxxxy_yyyyyzzz_0, tg_xxxxxy_yyyyzzzz_0, tg_xxxxxy_yyyzzzzz_0, \
                                         tg_xxxxxy_yyzzzzzz_0, tg_xxxxxy_yzzzzzzz_0, tg_xxxxxy_zzzzzzzz_0, tg_xxxxxz_xxxxxxxx_0, \
                                         tg_xxxxxz_xxxxxxxy_0, tg_xxxxxz_xxxxxxxz_0, tg_xxxxxz_xxxxxxyy_0, tg_xxxxxz_xxxxxxyz_0, \
                                         tg_xxxxxz_xxxxxxzz_0, tg_xxxxxz_xxxxxyyy_0, tg_xxxxy_xxxxxxx_1, tg_xxxxy_xxxxxxxx_0, \
                                         tg_xxxxy_xxxxxxxx_1, tg_xxxxy_xxxxxxxy_0, tg_xxxxy_xxxxxxxy_1, tg_xxxxy_xxxxxxxz_0, \
                                         tg_xxxxy_xxxxxxxz_1, tg_xxxxy_xxxxxxy_1, tg_xxxxy_xxxxxxyy_0, tg_xxxxy_xxxxxxyy_1, \
                                         tg_xxxxy_xxxxxxyz_0, tg_xxxxy_xxxxxxyz_1, tg_xxxxy_xxxxxxz_1, tg_xxxxy_xxxxxxzz_0, \
                                         tg_xxxxy_xxxxxxzz_1, tg_xxxxy_xxxxxyy_1, tg_xxxxy_xxxxxyyy_0, tg_xxxxy_xxxxxyyy_1, \
                                         tg_xxxxy_xxxxxyyz_0, tg_xxxxy_xxxxxyyz_1, tg_xxxxy_xxxxxyz_1, tg_xxxxy_xxxxxyzz_0, \
                                         tg_xxxxy_xxxxxyzz_1, tg_xxxxy_xxxxxzz_1, tg_xxxxy_xxxxxzzz_0, tg_xxxxy_xxxxxzzz_1, \
                                         tg_xxxxy_xxxxyyy_1, tg_xxxxy_xxxxyyyy_0, tg_xxxxy_xxxxyyyy_1, tg_xxxxy_xxxxyyyz_0, \
                                         tg_xxxxy_xxxxyyyz_1, tg_xxxxy_xxxxyyz_1, tg_xxxxy_xxxxyyzz_0, tg_xxxxy_xxxxyyzz_1, \
                                         tg_xxxxy_xxxxyzz_1, tg_xxxxy_xxxxyzzz_0, tg_xxxxy_xxxxyzzz_1, tg_xxxxy_xxxxzzz_1, \
                                         tg_xxxxy_xxxxzzzz_0, tg_xxxxy_xxxxzzzz_1, tg_xxxxy_xxxyyyy_1, tg_xxxxy_xxxyyyyy_0, \
                                         tg_xxxxy_xxxyyyyy_1, tg_xxxxy_xxxyyyyz_0, tg_xxxxy_xxxyyyyz_1, tg_xxxxy_xxxyyyz_1, \
                                         tg_xxxxy_xxxyyyzz_0, tg_xxxxy_xxxyyyzz_1, tg_xxxxy_xxxyyzz_1, tg_xxxxy_xxxyyzzz_0, \
                                         tg_xxxxy_xxxyyzzz_1, tg_xxxxy_xxxyzzz_1, tg_xxxxy_xxxyzzzz_0, tg_xxxxy_xxxyzzzz_1, \
                                         tg_xxxxy_xxxzzzz_1, tg_xxxxy_xxxzzzzz_0, tg_xxxxy_xxxzzzzz_1, tg_xxxxy_xxyyyyy_1, \
                                         tg_xxxxy_xxyyyyyy_0, tg_xxxxy_xxyyyyyy_1, tg_xxxxy_xxyyyyyz_0, tg_xxxxy_xxyyyyyz_1, \
                                         tg_xxxxy_xxyyyyz_1, tg_xxxxy_xxyyyyzz_0, tg_xxxxy_xxyyyyzz_1, tg_xxxxy_xxyyyzz_1, \
                                         tg_xxxxy_xxyyyzzz_0, tg_xxxxy_xxyyyzzz_1, tg_xxxxy_xxyyzzz_1, tg_xxxxy_xxyyzzzz_0, \
                                         tg_xxxxy_xxyyzzzz_1, tg_xxxxy_xxyzzzz_1, tg_xxxxy_xxyzzzzz_0, tg_xxxxy_xxyzzzzz_1, \
                                         tg_xxxxy_xxzzzzz_1, tg_xxxxy_xxzzzzzz_0, tg_xxxxy_xxzzzzzz_1, tg_xxxxy_xyyyyyy_1, \
                                         tg_xxxxy_xyyyyyyy_0, tg_xxxxy_xyyyyyyy_1, tg_xxxxy_xyyyyyyz_0, tg_xxxxy_xyyyyyyz_1, \
                                         tg_xxxxy_xyyyyyz_1, tg_xxxxy_xyyyyyzz_0, tg_xxxxy_xyyyyyzz_1, tg_xxxxy_xyyyyzz_1, \
                                         tg_xxxxy_xyyyyzzz_0, tg_xxxxy_xyyyyzzz_1, tg_xxxxy_xyyyzzz_1, tg_xxxxy_xyyyzzzz_0, \
                                         tg_xxxxy_xyyyzzzz_1, tg_xxxxy_xyyzzzz_1, tg_xxxxy_xyyzzzzz_0, tg_xxxxy_xyyzzzzz_1, \
                                         tg_xxxxy_xyzzzzz_1, tg_xxxxy_xyzzzzzz_0, tg_xxxxy_xyzzzzzz_1, tg_xxxxy_xzzzzzz_1, \
                                         tg_xxxxy_xzzzzzzz_0, tg_xxxxy_xzzzzzzz_1, tg_xxxxy_yyyyyyy_1, tg_xxxxy_yyyyyyyy_0, \
                                         tg_xxxxy_yyyyyyyy_1, tg_xxxxy_yyyyyyyz_0, tg_xxxxy_yyyyyyyz_1, tg_xxxxy_yyyyyyz_1, \
                                         tg_xxxxy_yyyyyyzz_0, tg_xxxxy_yyyyyyzz_1, tg_xxxxy_yyyyyzz_1, tg_xxxxy_yyyyyzzz_0, \
                                         tg_xxxxy_yyyyyzzz_1, tg_xxxxy_yyyyzzz_1, tg_xxxxy_yyyyzzzz_0, tg_xxxxy_yyyyzzzz_1, \
                                         tg_xxxxy_yyyzzzz_1, tg_xxxxy_yyyzzzzz_0, tg_xxxxy_yyyzzzzz_1, tg_xxxxy_yyzzzzz_1, \
                                         tg_xxxxy_yyzzzzzz_0, tg_xxxxy_yyzzzzzz_1, tg_xxxxy_yzzzzzz_1, tg_xxxxy_yzzzzzzz_0, \
                                         tg_xxxxy_yzzzzzzz_1, tg_xxxxy_zzzzzzz_1, tg_xxxxy_zzzzzzzz_0, tg_xxxxy_zzzzzzzz_1, \
                                         tg_xxxxz_xxxxxxx_1, tg_xxxxz_xxxxxxxx_0, tg_xxxxz_xxxxxxxx_1, tg_xxxxz_xxxxxxxy_0, \
                                         tg_xxxxz_xxxxxxxy_1, tg_xxxxz_xxxxxxxz_0, tg_xxxxz_xxxxxxxz_1, tg_xxxxz_xxxxxxy_1, \
                                         tg_xxxxz_xxxxxxyy_0, tg_xxxxz_xxxxxxyy_1, tg_xxxxz_xxxxxxyz_0, tg_xxxxz_xxxxxxyz_1, \
                                         tg_xxxxz_xxxxxxz_1, tg_xxxxz_xxxxxxzz_0, tg_xxxxz_xxxxxxzz_1, tg_xxxxz_xxxxxyy_1, \
                                         tg_xxxxz_xxxxxyyy_0, tg_xxxxz_xxxxxyyy_1, tg_xxxxz_xxxxxyz_1, tg_xxxxz_xxxxxzz_1, \
                                         tg_xxxxz_xxxxyyy_1, tg_xxxy_xxxxxxxx_0, tg_xxxy_xxxxxxxx_1, tg_xxxy_xxxxxxxy_0, \
                                         tg_xxxy_xxxxxxxy_1, tg_xxxy_xxxxxxxz_0, tg_xxxy_xxxxxxxz_1, tg_xxxy_xxxxxxyy_0, \
                                         tg_xxxy_xxxxxxyy_1, tg_xxxy_xxxxxxyz_0, tg_xxxy_xxxxxxyz_1, tg_xxxy_xxxxxxzz_0, \
                                         tg_xxxy_xxxxxxzz_1, tg_xxxy_xxxxxyyy_0, tg_xxxy_xxxxxyyy_1, tg_xxxy_xxxxxyyz_0, \
                                         tg_xxxy_xxxxxyyz_1, tg_xxxy_xxxxxyzz_0, tg_xxxy_xxxxxyzz_1, tg_xxxy_xxxxxzzz_0, \
                                         tg_xxxy_xxxxxzzz_1, tg_xxxy_xxxxyyyy_0, tg_xxxy_xxxxyyyy_1, tg_xxxy_xxxxyyyz_0, \
                                         tg_xxxy_xxxxyyyz_1, tg_xxxy_xxxxyyzz_0, tg_xxxy_xxxxyyzz_1, tg_xxxy_xxxxyzzz_0, \
                                         tg_xxxy_xxxxyzzz_1, tg_xxxy_xxxxzzzz_0, tg_xxxy_xxxxzzzz_1, tg_xxxy_xxxyyyyy_0, \
                                         tg_xxxy_xxxyyyyy_1, tg_xxxy_xxxyyyyz_0, tg_xxxy_xxxyyyyz_1, tg_xxxy_xxxyyyzz_0, \
                                         tg_xxxy_xxxyyyzz_1, tg_xxxy_xxxyyzzz_0, tg_xxxy_xxxyyzzz_1, tg_xxxy_xxxyzzzz_0, \
                                         tg_xxxy_xxxyzzzz_1, tg_xxxy_xxxzzzzz_0, tg_xxxy_xxxzzzzz_1, tg_xxxy_xxyyyyyy_0, \
                                         tg_xxxy_xxyyyyyy_1, tg_xxxy_xxyyyyyz_0, tg_xxxy_xxyyyyyz_1, tg_xxxy_xxyyyyzz_0, \
                                         tg_xxxy_xxyyyyzz_1, tg_xxxy_xxyyyzzz_0, tg_xxxy_xxyyyzzz_1, tg_xxxy_xxyyzzzz_0, \
                                         tg_xxxy_xxyyzzzz_1, tg_xxxy_xxyzzzzz_0, tg_xxxy_xxyzzzzz_1, tg_xxxy_xxzzzzzz_0, \
                                         tg_xxxy_xxzzzzzz_1, tg_xxxy_xyyyyyyy_0, tg_xxxy_xyyyyyyy_1, tg_xxxy_xyyyyyyz_0, \
                                         tg_xxxy_xyyyyyyz_1, tg_xxxy_xyyyyyzz_0, tg_xxxy_xyyyyyzz_1, tg_xxxy_xyyyyzzz_0, \
                                         tg_xxxy_xyyyyzzz_1, tg_xxxy_xyyyzzzz_0, tg_xxxy_xyyyzzzz_1, tg_xxxy_xyyzzzzz_0, \
                                         tg_xxxy_xyyzzzzz_1, tg_xxxy_xyzzzzzz_0, tg_xxxy_xyzzzzzz_1, tg_xxxy_xzzzzzzz_0, \
                                         tg_xxxy_xzzzzzzz_1, tg_xxxy_yyyyyyyy_0, tg_xxxy_yyyyyyyy_1, tg_xxxy_yyyyyyyz_0, \
                                         tg_xxxy_yyyyyyyz_1, tg_xxxy_yyyyyyzz_0, tg_xxxy_yyyyyyzz_1, tg_xxxy_yyyyyzzz_0, \
                                         tg_xxxy_yyyyyzzz_1, tg_xxxy_yyyyzzzz_0, tg_xxxy_yyyyzzzz_1, tg_xxxy_yyyzzzzz_0, \
                                         tg_xxxy_yyyzzzzz_1, tg_xxxy_yyzzzzzz_0, tg_xxxy_yyzzzzzz_1, tg_xxxy_yzzzzzzz_0, \
                                         tg_xxxy_yzzzzzzz_1, tg_xxxy_zzzzzzzz_0, tg_xxxy_zzzzzzzz_1, tg_xxxz_xxxxxxxx_0, \
                                         tg_xxxz_xxxxxxxx_1, tg_xxxz_xxxxxxxy_0, tg_xxxz_xxxxxxxy_1, tg_xxxz_xxxxxxxz_0, \
                                         tg_xxxz_xxxxxxxz_1, tg_xxxz_xxxxxxyy_0, tg_xxxz_xxxxxxyy_1, tg_xxxz_xxxxxxyz_0, \
                                         tg_xxxz_xxxxxxyz_1, tg_xxxz_xxxxxxzz_0, tg_xxxz_xxxxxxzz_1, tg_xxxz_xxxxxyyy_0, \
                                         tg_xxxz_xxxxxyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxx_xxxxxxxx_0[j] = pb_x * tg_xxxxx_xxxxxxxx_0[j] + fr * tg_xxxxx_xxxxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxxx_0[j] - tg_xxxx_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxxx_xxxxxxx_1[j];

                    tg_xxxxxx_xxxxxxxy_0[j] = pb_x * tg_xxxxx_xxxxxxxy_0[j] + fr * tg_xxxxx_xxxxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxxy_0[j] - tg_xxxx_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxx_xxxxxxy_1[j];

                    tg_xxxxxx_xxxxxxxz_0[j] = pb_x * tg_xxxxx_xxxxxxxz_0[j] + fr * tg_xxxxx_xxxxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxxz_0[j] - tg_xxxx_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxx_xxxxxxz_1[j];

                    tg_xxxxxx_xxxxxxyy_0[j] = pb_x * tg_xxxxx_xxxxxxyy_0[j] + fr * tg_xxxxx_xxxxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxyy_0[j] - tg_xxxx_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxx_xxxxxyy_1[j];

                    tg_xxxxxx_xxxxxxyz_0[j] = pb_x * tg_xxxxx_xxxxxxyz_0[j] + fr * tg_xxxxx_xxxxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxyz_0[j] - tg_xxxx_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxx_xxxxxyz_1[j];

                    tg_xxxxxx_xxxxxxzz_0[j] = pb_x * tg_xxxxx_xxxxxxzz_0[j] + fr * tg_xxxxx_xxxxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxxzz_0[j] - tg_xxxx_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxx_xxxxxzz_1[j];

                    tg_xxxxxx_xxxxxyyy_0[j] = pb_x * tg_xxxxx_xxxxxyyy_0[j] + fr * tg_xxxxx_xxxxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxyyy_0[j] - tg_xxxx_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxx_xxxxyyy_1[j];

                    tg_xxxxxx_xxxxxyyz_0[j] = pb_x * tg_xxxxx_xxxxxyyz_0[j] + fr * tg_xxxxx_xxxxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxyyz_0[j] - tg_xxxx_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxx_xxxxyyz_1[j];

                    tg_xxxxxx_xxxxxyzz_0[j] = pb_x * tg_xxxxx_xxxxxyzz_0[j] + fr * tg_xxxxx_xxxxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxyzz_0[j] - tg_xxxx_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxx_xxxxyzz_1[j];

                    tg_xxxxxx_xxxxxzzz_0[j] = pb_x * tg_xxxxx_xxxxxzzz_0[j] + fr * tg_xxxxx_xxxxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxxzzz_0[j] - tg_xxxx_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxx_xxxxzzz_1[j];

                    tg_xxxxxx_xxxxyyyy_0[j] = pb_x * tg_xxxxx_xxxxyyyy_0[j] + fr * tg_xxxxx_xxxxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxyyyy_0[j] - tg_xxxx_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxx_xxxyyyy_1[j];

                    tg_xxxxxx_xxxxyyyz_0[j] = pb_x * tg_xxxxx_xxxxyyyz_0[j] + fr * tg_xxxxx_xxxxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxyyyz_0[j] - tg_xxxx_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxx_xxxyyyz_1[j];

                    tg_xxxxxx_xxxxyyzz_0[j] = pb_x * tg_xxxxx_xxxxyyzz_0[j] + fr * tg_xxxxx_xxxxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxyyzz_0[j] - tg_xxxx_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxx_xxxyyzz_1[j];

                    tg_xxxxxx_xxxxyzzz_0[j] = pb_x * tg_xxxxx_xxxxyzzz_0[j] + fr * tg_xxxxx_xxxxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxyzzz_0[j] - tg_xxxx_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxx_xxxyzzz_1[j];

                    tg_xxxxxx_xxxxzzzz_0[j] = pb_x * tg_xxxxx_xxxxzzzz_0[j] + fr * tg_xxxxx_xxxxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxxzzzz_0[j] - tg_xxxx_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxx_xxxzzzz_1[j];

                    tg_xxxxxx_xxxyyyyy_0[j] = pb_x * tg_xxxxx_xxxyyyyy_0[j] + fr * tg_xxxxx_xxxyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxyyyyy_0[j] - tg_xxxx_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxyyyyy_1[j];

                    tg_xxxxxx_xxxyyyyz_0[j] = pb_x * tg_xxxxx_xxxyyyyz_0[j] + fr * tg_xxxxx_xxxyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxyyyyz_0[j] - tg_xxxx_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxyyyyz_1[j];

                    tg_xxxxxx_xxxyyyzz_0[j] = pb_x * tg_xxxxx_xxxyyyzz_0[j] + fr * tg_xxxxx_xxxyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxyyyzz_0[j] - tg_xxxx_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxyyyzz_1[j];

                    tg_xxxxxx_xxxyyzzz_0[j] = pb_x * tg_xxxxx_xxxyyzzz_0[j] + fr * tg_xxxxx_xxxyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxyyzzz_0[j] - tg_xxxx_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxyyzzz_1[j];

                    tg_xxxxxx_xxxyzzzz_0[j] = pb_x * tg_xxxxx_xxxyzzzz_0[j] + fr * tg_xxxxx_xxxyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxyzzzz_0[j] - tg_xxxx_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxyzzzz_1[j];

                    tg_xxxxxx_xxxzzzzz_0[j] = pb_x * tg_xxxxx_xxxzzzzz_0[j] + fr * tg_xxxxx_xxxzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxxzzzzz_0[j] - tg_xxxx_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxx_xxzzzzz_1[j];

                    tg_xxxxxx_xxyyyyyy_0[j] = pb_x * tg_xxxxx_xxyyyyyy_0[j] + fr * tg_xxxxx_xxyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyyyyyy_0[j] - tg_xxxx_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyyyyyy_1[j];

                    tg_xxxxxx_xxyyyyyz_0[j] = pb_x * tg_xxxxx_xxyyyyyz_0[j] + fr * tg_xxxxx_xxyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyyyyyz_0[j] - tg_xxxx_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyyyyyz_1[j];

                    tg_xxxxxx_xxyyyyzz_0[j] = pb_x * tg_xxxxx_xxyyyyzz_0[j] + fr * tg_xxxxx_xxyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyyyyzz_0[j] - tg_xxxx_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyyyyzz_1[j];

                    tg_xxxxxx_xxyyyzzz_0[j] = pb_x * tg_xxxxx_xxyyyzzz_0[j] + fr * tg_xxxxx_xxyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyyyzzz_0[j] - tg_xxxx_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyyyzzz_1[j];

                    tg_xxxxxx_xxyyzzzz_0[j] = pb_x * tg_xxxxx_xxyyzzzz_0[j] + fr * tg_xxxxx_xxyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyyzzzz_0[j] - tg_xxxx_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyyzzzz_1[j];

                    tg_xxxxxx_xxyzzzzz_0[j] = pb_x * tg_xxxxx_xxyzzzzz_0[j] + fr * tg_xxxxx_xxyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxyzzzzz_0[j] - tg_xxxx_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xyzzzzz_1[j];

                    tg_xxxxxx_xxzzzzzz_0[j] = pb_x * tg_xxxxx_xxzzzzzz_0[j] + fr * tg_xxxxx_xxzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xxzzzzzz_0[j] - tg_xxxx_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxx_xzzzzzz_1[j];

                    tg_xxxxxx_xyyyyyyy_0[j] = pb_x * tg_xxxxx_xyyyyyyy_0[j] + fr * tg_xxxxx_xyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyyyyyy_0[j] - tg_xxxx_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyyyyyy_1[j];

                    tg_xxxxxx_xyyyyyyz_0[j] = pb_x * tg_xxxxx_xyyyyyyz_0[j] + fr * tg_xxxxx_xyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyyyyyz_0[j] - tg_xxxx_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyyyyyz_1[j];

                    tg_xxxxxx_xyyyyyzz_0[j] = pb_x * tg_xxxxx_xyyyyyzz_0[j] + fr * tg_xxxxx_xyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyyyyzz_0[j] - tg_xxxx_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyyyyzz_1[j];

                    tg_xxxxxx_xyyyyzzz_0[j] = pb_x * tg_xxxxx_xyyyyzzz_0[j] + fr * tg_xxxxx_xyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyyyzzz_0[j] - tg_xxxx_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyyyzzz_1[j];

                    tg_xxxxxx_xyyyzzzz_0[j] = pb_x * tg_xxxxx_xyyyzzzz_0[j] + fr * tg_xxxxx_xyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyyzzzz_0[j] - tg_xxxx_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyyzzzz_1[j];

                    tg_xxxxxx_xyyzzzzz_0[j] = pb_x * tg_xxxxx_xyyzzzzz_0[j] + fr * tg_xxxxx_xyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyyzzzzz_0[j] - tg_xxxx_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yyzzzzz_1[j];

                    tg_xxxxxx_xyzzzzzz_0[j] = pb_x * tg_xxxxx_xyzzzzzz_0[j] + fr * tg_xxxxx_xyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xyzzzzzz_0[j] - tg_xxxx_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_yzzzzzz_1[j];

                    tg_xxxxxx_xzzzzzzz_0[j] = pb_x * tg_xxxxx_xzzzzzzz_0[j] + fr * tg_xxxxx_xzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_xzzzzzzz_0[j] - tg_xxxx_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxx_zzzzzzz_1[j];

                    tg_xxxxxx_yyyyyyyy_0[j] = pb_x * tg_xxxxx_yyyyyyyy_0[j] + fr * tg_xxxxx_yyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyyyyyy_0[j] - tg_xxxx_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxx_yyyyyyyz_0[j] = pb_x * tg_xxxxx_yyyyyyyz_0[j] + fr * tg_xxxxx_yyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyyyyyz_0[j] - tg_xxxx_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxx_yyyyyyzz_0[j] = pb_x * tg_xxxxx_yyyyyyzz_0[j] + fr * tg_xxxxx_yyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyyyyzz_0[j] - tg_xxxx_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxx_yyyyyzzz_0[j] = pb_x * tg_xxxxx_yyyyyzzz_0[j] + fr * tg_xxxxx_yyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyyyzzz_0[j] - tg_xxxx_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxx_yyyyzzzz_0[j] = pb_x * tg_xxxxx_yyyyzzzz_0[j] + fr * tg_xxxxx_yyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyyzzzz_0[j] - tg_xxxx_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxx_yyyzzzzz_0[j] = pb_x * tg_xxxxx_yyyzzzzz_0[j] + fr * tg_xxxxx_yyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyyzzzzz_0[j] - tg_xxxx_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxx_yyzzzzzz_0[j] = pb_x * tg_xxxxx_yyzzzzzz_0[j] + fr * tg_xxxxx_yyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yyzzzzzz_0[j] - tg_xxxx_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxx_yzzzzzzz_0[j] = pb_x * tg_xxxxx_yzzzzzzz_0[j] + fr * tg_xxxxx_yzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_yzzzzzzz_0[j] - tg_xxxx_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxx_zzzzzzzz_0[j] = pb_x * tg_xxxxx_zzzzzzzz_0[j] + fr * tg_xxxxx_zzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxx_zzzzzzzz_0[j] - tg_xxxx_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxy_xxxxxxxx_0[j] = pb_x * tg_xxxxy_xxxxxxxx_0[j] + fr * tg_xxxxy_xxxxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxxx_0[j] - tg_xxxy_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxxy_xxxxxxx_1[j];

                    tg_xxxxxy_xxxxxxxy_0[j] = pb_x * tg_xxxxy_xxxxxxxy_0[j] + fr * tg_xxxxy_xxxxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxxy_0[j] - tg_xxxy_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxy_xxxxxxy_1[j];

                    tg_xxxxxy_xxxxxxxz_0[j] = pb_x * tg_xxxxy_xxxxxxxz_0[j] + fr * tg_xxxxy_xxxxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxxz_0[j] - tg_xxxy_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxy_xxxxxxz_1[j];

                    tg_xxxxxy_xxxxxxyy_0[j] = pb_x * tg_xxxxy_xxxxxxyy_0[j] + fr * tg_xxxxy_xxxxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxyy_0[j] - tg_xxxy_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxy_xxxxxyy_1[j];

                    tg_xxxxxy_xxxxxxyz_0[j] = pb_x * tg_xxxxy_xxxxxxyz_0[j] + fr * tg_xxxxy_xxxxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxyz_0[j] - tg_xxxy_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxy_xxxxxyz_1[j];

                    tg_xxxxxy_xxxxxxzz_0[j] = pb_x * tg_xxxxy_xxxxxxzz_0[j] + fr * tg_xxxxy_xxxxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxxzz_0[j] - tg_xxxy_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxy_xxxxxzz_1[j];

                    tg_xxxxxy_xxxxxyyy_0[j] = pb_x * tg_xxxxy_xxxxxyyy_0[j] + fr * tg_xxxxy_xxxxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxyyy_0[j] - tg_xxxy_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxy_xxxxyyy_1[j];

                    tg_xxxxxy_xxxxxyyz_0[j] = pb_x * tg_xxxxy_xxxxxyyz_0[j] + fr * tg_xxxxy_xxxxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxyyz_0[j] - tg_xxxy_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxy_xxxxyyz_1[j];

                    tg_xxxxxy_xxxxxyzz_0[j] = pb_x * tg_xxxxy_xxxxxyzz_0[j] + fr * tg_xxxxy_xxxxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxyzz_0[j] - tg_xxxy_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxy_xxxxyzz_1[j];

                    tg_xxxxxy_xxxxxzzz_0[j] = pb_x * tg_xxxxy_xxxxxzzz_0[j] + fr * tg_xxxxy_xxxxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxxzzz_0[j] - tg_xxxy_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxy_xxxxzzz_1[j];

                    tg_xxxxxy_xxxxyyyy_0[j] = pb_x * tg_xxxxy_xxxxyyyy_0[j] + fr * tg_xxxxy_xxxxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxyyyy_0[j] - tg_xxxy_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxy_xxxyyyy_1[j];

                    tg_xxxxxy_xxxxyyyz_0[j] = pb_x * tg_xxxxy_xxxxyyyz_0[j] + fr * tg_xxxxy_xxxxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxyyyz_0[j] - tg_xxxy_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxy_xxxyyyz_1[j];

                    tg_xxxxxy_xxxxyyzz_0[j] = pb_x * tg_xxxxy_xxxxyyzz_0[j] + fr * tg_xxxxy_xxxxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxyyzz_0[j] - tg_xxxy_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxy_xxxyyzz_1[j];

                    tg_xxxxxy_xxxxyzzz_0[j] = pb_x * tg_xxxxy_xxxxyzzz_0[j] + fr * tg_xxxxy_xxxxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxyzzz_0[j] - tg_xxxy_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxy_xxxyzzz_1[j];

                    tg_xxxxxy_xxxxzzzz_0[j] = pb_x * tg_xxxxy_xxxxzzzz_0[j] + fr * tg_xxxxy_xxxxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxxzzzz_0[j] - tg_xxxy_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxy_xxxzzzz_1[j];

                    tg_xxxxxy_xxxyyyyy_0[j] = pb_x * tg_xxxxy_xxxyyyyy_0[j] + fr * tg_xxxxy_xxxyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxyyyyy_0[j] - tg_xxxy_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxyyyyy_1[j];

                    tg_xxxxxy_xxxyyyyz_0[j] = pb_x * tg_xxxxy_xxxyyyyz_0[j] + fr * tg_xxxxy_xxxyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxyyyyz_0[j] - tg_xxxy_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxyyyyz_1[j];

                    tg_xxxxxy_xxxyyyzz_0[j] = pb_x * tg_xxxxy_xxxyyyzz_0[j] + fr * tg_xxxxy_xxxyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxyyyzz_0[j] - tg_xxxy_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxyyyzz_1[j];

                    tg_xxxxxy_xxxyyzzz_0[j] = pb_x * tg_xxxxy_xxxyyzzz_0[j] + fr * tg_xxxxy_xxxyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxyyzzz_0[j] - tg_xxxy_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxyyzzz_1[j];

                    tg_xxxxxy_xxxyzzzz_0[j] = pb_x * tg_xxxxy_xxxyzzzz_0[j] + fr * tg_xxxxy_xxxyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxyzzzz_0[j] - tg_xxxy_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxyzzzz_1[j];

                    tg_xxxxxy_xxxzzzzz_0[j] = pb_x * tg_xxxxy_xxxzzzzz_0[j] + fr * tg_xxxxy_xxxzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxxzzzzz_0[j] - tg_xxxy_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxy_xxzzzzz_1[j];

                    tg_xxxxxy_xxyyyyyy_0[j] = pb_x * tg_xxxxy_xxyyyyyy_0[j] + fr * tg_xxxxy_xxyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyyyyyy_0[j] - tg_xxxy_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyyyyyy_1[j];

                    tg_xxxxxy_xxyyyyyz_0[j] = pb_x * tg_xxxxy_xxyyyyyz_0[j] + fr * tg_xxxxy_xxyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyyyyyz_0[j] - tg_xxxy_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyyyyyz_1[j];

                    tg_xxxxxy_xxyyyyzz_0[j] = pb_x * tg_xxxxy_xxyyyyzz_0[j] + fr * tg_xxxxy_xxyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyyyyzz_0[j] - tg_xxxy_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyyyyzz_1[j];

                    tg_xxxxxy_xxyyyzzz_0[j] = pb_x * tg_xxxxy_xxyyyzzz_0[j] + fr * tg_xxxxy_xxyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyyyzzz_0[j] - tg_xxxy_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyyyzzz_1[j];

                    tg_xxxxxy_xxyyzzzz_0[j] = pb_x * tg_xxxxy_xxyyzzzz_0[j] + fr * tg_xxxxy_xxyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyyzzzz_0[j] - tg_xxxy_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyyzzzz_1[j];

                    tg_xxxxxy_xxyzzzzz_0[j] = pb_x * tg_xxxxy_xxyzzzzz_0[j] + fr * tg_xxxxy_xxyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxyzzzzz_0[j] - tg_xxxy_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xyzzzzz_1[j];

                    tg_xxxxxy_xxzzzzzz_0[j] = pb_x * tg_xxxxy_xxzzzzzz_0[j] + fr * tg_xxxxy_xxzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xxzzzzzz_0[j] - tg_xxxy_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxy_xzzzzzz_1[j];

                    tg_xxxxxy_xyyyyyyy_0[j] = pb_x * tg_xxxxy_xyyyyyyy_0[j] + fr * tg_xxxxy_xyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyyyyyy_0[j] - tg_xxxy_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyyyyyy_1[j];

                    tg_xxxxxy_xyyyyyyz_0[j] = pb_x * tg_xxxxy_xyyyyyyz_0[j] + fr * tg_xxxxy_xyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyyyyyz_0[j] - tg_xxxy_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyyyyyz_1[j];

                    tg_xxxxxy_xyyyyyzz_0[j] = pb_x * tg_xxxxy_xyyyyyzz_0[j] + fr * tg_xxxxy_xyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyyyyzz_0[j] - tg_xxxy_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyyyyzz_1[j];

                    tg_xxxxxy_xyyyyzzz_0[j] = pb_x * tg_xxxxy_xyyyyzzz_0[j] + fr * tg_xxxxy_xyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyyyzzz_0[j] - tg_xxxy_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyyyzzz_1[j];

                    tg_xxxxxy_xyyyzzzz_0[j] = pb_x * tg_xxxxy_xyyyzzzz_0[j] + fr * tg_xxxxy_xyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyyzzzz_0[j] - tg_xxxy_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyyzzzz_1[j];

                    tg_xxxxxy_xyyzzzzz_0[j] = pb_x * tg_xxxxy_xyyzzzzz_0[j] + fr * tg_xxxxy_xyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyyzzzzz_0[j] - tg_xxxy_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yyzzzzz_1[j];

                    tg_xxxxxy_xyzzzzzz_0[j] = pb_x * tg_xxxxy_xyzzzzzz_0[j] + fr * tg_xxxxy_xyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xyzzzzzz_0[j] - tg_xxxy_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_yzzzzzz_1[j];

                    tg_xxxxxy_xzzzzzzz_0[j] = pb_x * tg_xxxxy_xzzzzzzz_0[j] + fr * tg_xxxxy_xzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_xzzzzzzz_0[j] - tg_xxxy_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxy_zzzzzzz_1[j];

                    tg_xxxxxy_yyyyyyyy_0[j] = pb_x * tg_xxxxy_yyyyyyyy_0[j] + fr * tg_xxxxy_yyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyyyyyy_0[j] - tg_xxxy_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxy_yyyyyyyz_0[j] = pb_x * tg_xxxxy_yyyyyyyz_0[j] + fr * tg_xxxxy_yyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyyyyyz_0[j] - tg_xxxy_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxy_yyyyyyzz_0[j] = pb_x * tg_xxxxy_yyyyyyzz_0[j] + fr * tg_xxxxy_yyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyyyyzz_0[j] - tg_xxxy_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxy_yyyyyzzz_0[j] = pb_x * tg_xxxxy_yyyyyzzz_0[j] + fr * tg_xxxxy_yyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyyyzzz_0[j] - tg_xxxy_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxy_yyyyzzzz_0[j] = pb_x * tg_xxxxy_yyyyzzzz_0[j] + fr * tg_xxxxy_yyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyyzzzz_0[j] - tg_xxxy_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxy_yyyzzzzz_0[j] = pb_x * tg_xxxxy_yyyzzzzz_0[j] + fr * tg_xxxxy_yyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyyzzzzz_0[j] - tg_xxxy_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxy_yyzzzzzz_0[j] = pb_x * tg_xxxxy_yyzzzzzz_0[j] + fr * tg_xxxxy_yyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yyzzzzzz_0[j] - tg_xxxy_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxy_yzzzzzzz_0[j] = pb_x * tg_xxxxy_yzzzzzzz_0[j] + fr * tg_xxxxy_yzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_yzzzzzzz_0[j] - tg_xxxy_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxy_zzzzzzzz_0[j] = pb_x * tg_xxxxy_zzzzzzzz_0[j] + fr * tg_xxxxy_zzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxy_zzzzzzzz_0[j] - tg_xxxy_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxz_xxxxxxxx_0[j] = pb_x * tg_xxxxz_xxxxxxxx_0[j] + fr * tg_xxxxz_xxxxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxxx_0[j] - tg_xxxz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxxz_xxxxxxx_1[j];

                    tg_xxxxxz_xxxxxxxy_0[j] = pb_x * tg_xxxxz_xxxxxxxy_0[j] + fr * tg_xxxxz_xxxxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxxy_0[j] - tg_xxxz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxz_xxxxxxy_1[j];

                    tg_xxxxxz_xxxxxxxz_0[j] = pb_x * tg_xxxxz_xxxxxxxz_0[j] + fr * tg_xxxxz_xxxxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxxz_0[j] - tg_xxxz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxz_xxxxxxz_1[j];

                    tg_xxxxxz_xxxxxxyy_0[j] = pb_x * tg_xxxxz_xxxxxxyy_0[j] + fr * tg_xxxxz_xxxxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxyy_0[j] - tg_xxxz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxz_xxxxxyy_1[j];

                    tg_xxxxxz_xxxxxxyz_0[j] = pb_x * tg_xxxxz_xxxxxxyz_0[j] + fr * tg_xxxxz_xxxxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxyz_0[j] - tg_xxxz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxz_xxxxxyz_1[j];

                    tg_xxxxxz_xxxxxxzz_0[j] = pb_x * tg_xxxxz_xxxxxxzz_0[j] + fr * tg_xxxxz_xxxxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxxzz_0[j] - tg_xxxz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxz_xxxxxzz_1[j];

                    tg_xxxxxz_xxxxxyyy_0[j] = pb_x * tg_xxxxz_xxxxxyyy_0[j] + fr * tg_xxxxz_xxxxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxyyy_0[j] - tg_xxxz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxz_xxxxyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_97_194(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (97,194)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 97); 

                auto tg_xxxxz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 98); 

                auto tg_xxxxz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 99); 

                auto tg_xxxxz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 100); 

                auto tg_xxxxz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 101); 

                auto tg_xxxxz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 102); 

                auto tg_xxxxz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 103); 

                auto tg_xxxxz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 104); 

                auto tg_xxxxz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 105); 

                auto tg_xxxxz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 106); 

                auto tg_xxxxz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 107); 

                auto tg_xxxxz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 108); 

                auto tg_xxxxz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 109); 

                auto tg_xxxxz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 110); 

                auto tg_xxxxz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 111); 

                auto tg_xxxxz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 112); 

                auto tg_xxxxz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 113); 

                auto tg_xxxxz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 114); 

                auto tg_xxxxz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 115); 

                auto tg_xxxxz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 116); 

                auto tg_xxxxz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 117); 

                auto tg_xxxxz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 118); 

                auto tg_xxxxz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 119); 

                auto tg_xxxxz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 120); 

                auto tg_xxxxz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 121); 

                auto tg_xxxxz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 122); 

                auto tg_xxxxz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 123); 

                auto tg_xxxxz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 124); 

                auto tg_xxxxz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 125); 

                auto tg_xxxxz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 126); 

                auto tg_xxxxz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 127); 

                auto tg_xxxxz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 128); 

                auto tg_xxxxz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 129); 

                auto tg_xxxxz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 130); 

                auto tg_xxxxz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 131); 

                auto tg_xxxxz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 132); 

                auto tg_xxxxz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 133); 

                auto tg_xxxxz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 134); 

                auto tg_xxxyy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 135); 

                auto tg_xxxyy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 136); 

                auto tg_xxxyy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 137); 

                auto tg_xxxyy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 138); 

                auto tg_xxxyy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 139); 

                auto tg_xxxyy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 140); 

                auto tg_xxxyy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 141); 

                auto tg_xxxyy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 142); 

                auto tg_xxxyy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 143); 

                auto tg_xxxyy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 144); 

                auto tg_xxxyy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 145); 

                auto tg_xxxyy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 146); 

                auto tg_xxxyy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 147); 

                auto tg_xxxyy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 148); 

                auto tg_xxxyy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 149); 

                auto tg_xxxyy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 150); 

                auto tg_xxxyy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 151); 

                auto tg_xxxyy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 152); 

                auto tg_xxxyy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 153); 

                auto tg_xxxyy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 154); 

                auto tg_xxxyy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 155); 

                auto tg_xxxyy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 156); 

                auto tg_xxxyy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 157); 

                auto tg_xxxyy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 158); 

                auto tg_xxxyy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 159); 

                auto tg_xxxyy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 160); 

                auto tg_xxxyy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 161); 

                auto tg_xxxyy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 162); 

                auto tg_xxxyy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 163); 

                auto tg_xxxyy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 164); 

                auto tg_xxxyy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 165); 

                auto tg_xxxyy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 166); 

                auto tg_xxxyy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 167); 

                auto tg_xxxyy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 168); 

                auto tg_xxxyy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 169); 

                auto tg_xxxyy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 170); 

                auto tg_xxxyy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 171); 

                auto tg_xxxyy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 172); 

                auto tg_xxxyy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 173); 

                auto tg_xxxyy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 174); 

                auto tg_xxxyy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 175); 

                auto tg_xxxyy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 176); 

                auto tg_xxxyy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 177); 

                auto tg_xxxyy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 178); 

                auto tg_xxxyy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 179); 

                auto tg_xxxyz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 180); 

                auto tg_xxxyz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 181); 

                auto tg_xxxyz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 182); 

                auto tg_xxxyz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 183); 

                auto tg_xxxyz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 184); 

                auto tg_xxxyz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 185); 

                auto tg_xxxyz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 186); 

                auto tg_xxxyz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 187); 

                auto tg_xxxyz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 188); 

                auto tg_xxxyz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 189); 

                auto tg_xxxyz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 190); 

                auto tg_xxxyz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 191); 

                auto tg_xxxyz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 192); 

                auto tg_xxxyz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 193); 

                auto tg_xxxxz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 97); 

                auto tg_xxxxz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 98); 

                auto tg_xxxxz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 99); 

                auto tg_xxxxz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 100); 

                auto tg_xxxxz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 101); 

                auto tg_xxxxz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 102); 

                auto tg_xxxxz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 103); 

                auto tg_xxxxz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 104); 

                auto tg_xxxxz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 105); 

                auto tg_xxxxz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 106); 

                auto tg_xxxxz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 107); 

                auto tg_xxxxz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 108); 

                auto tg_xxxxz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 109); 

                auto tg_xxxxz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 110); 

                auto tg_xxxxz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 111); 

                auto tg_xxxxz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 112); 

                auto tg_xxxxz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 113); 

                auto tg_xxxxz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 114); 

                auto tg_xxxxz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 115); 

                auto tg_xxxxz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 116); 

                auto tg_xxxxz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 117); 

                auto tg_xxxxz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 118); 

                auto tg_xxxxz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 119); 

                auto tg_xxxxz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 120); 

                auto tg_xxxxz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 121); 

                auto tg_xxxxz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 122); 

                auto tg_xxxxz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 123); 

                auto tg_xxxxz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 124); 

                auto tg_xxxxz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 125); 

                auto tg_xxxxz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 126); 

                auto tg_xxxxz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 127); 

                auto tg_xxxxz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 128); 

                auto tg_xxxxz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 129); 

                auto tg_xxxxz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 130); 

                auto tg_xxxxz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 131); 

                auto tg_xxxxz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 132); 

                auto tg_xxxxz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 133); 

                auto tg_xxxxz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 134); 

                auto tg_xxxyy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 135); 

                auto tg_xxxyy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 136); 

                auto tg_xxxyy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 137); 

                auto tg_xxxyy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 138); 

                auto tg_xxxyy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 139); 

                auto tg_xxxyy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 140); 

                auto tg_xxxyy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 141); 

                auto tg_xxxyy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 142); 

                auto tg_xxxyy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 143); 

                auto tg_xxxyy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 144); 

                auto tg_xxxyy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 145); 

                auto tg_xxxyy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 146); 

                auto tg_xxxyy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 147); 

                auto tg_xxxyy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 148); 

                auto tg_xxxyy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 149); 

                auto tg_xxxyy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 150); 

                auto tg_xxxyy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 151); 

                auto tg_xxxyy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 152); 

                auto tg_xxxyy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 153); 

                auto tg_xxxyy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 154); 

                auto tg_xxxyy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 155); 

                auto tg_xxxyy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 156); 

                auto tg_xxxyy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 157); 

                auto tg_xxxyy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 158); 

                auto tg_xxxyy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 159); 

                auto tg_xxxyy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 160); 

                auto tg_xxxyy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 161); 

                auto tg_xxxyy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 162); 

                auto tg_xxxyy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 163); 

                auto tg_xxxyy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 164); 

                auto tg_xxxyy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 165); 

                auto tg_xxxyy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 166); 

                auto tg_xxxyy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 167); 

                auto tg_xxxyy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 168); 

                auto tg_xxxyy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 169); 

                auto tg_xxxyy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 170); 

                auto tg_xxxyy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 171); 

                auto tg_xxxyy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 172); 

                auto tg_xxxyy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 173); 

                auto tg_xxxyy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 174); 

                auto tg_xxxyy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 175); 

                auto tg_xxxyy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 176); 

                auto tg_xxxyy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 177); 

                auto tg_xxxyy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 178); 

                auto tg_xxxyy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 179); 

                auto tg_xxxyz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 180); 

                auto tg_xxxyz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 181); 

                auto tg_xxxyz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 182); 

                auto tg_xxxyz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 183); 

                auto tg_xxxyz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 184); 

                auto tg_xxxyz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 185); 

                auto tg_xxxyz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 186); 

                auto tg_xxxyz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 187); 

                auto tg_xxxyz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 188); 

                auto tg_xxxyz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 189); 

                auto tg_xxxyz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 190); 

                auto tg_xxxyz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 191); 

                auto tg_xxxyz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 192); 

                auto tg_xxxyz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 193); 

                auto tg_xxxz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 97); 

                auto tg_xxxz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 98); 

                auto tg_xxxz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 99); 

                auto tg_xxxz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 100); 

                auto tg_xxxz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 101); 

                auto tg_xxxz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 102); 

                auto tg_xxxz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 103); 

                auto tg_xxxz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 104); 

                auto tg_xxxz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 105); 

                auto tg_xxxz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 106); 

                auto tg_xxxz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 107); 

                auto tg_xxxz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 108); 

                auto tg_xxxz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 109); 

                auto tg_xxxz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 110); 

                auto tg_xxxz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 111); 

                auto tg_xxxz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 112); 

                auto tg_xxxz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 113); 

                auto tg_xxxz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 114); 

                auto tg_xxxz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 115); 

                auto tg_xxxz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 116); 

                auto tg_xxxz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 117); 

                auto tg_xxxz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 118); 

                auto tg_xxxz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 119); 

                auto tg_xxxz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 120); 

                auto tg_xxxz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 121); 

                auto tg_xxxz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 122); 

                auto tg_xxxz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 123); 

                auto tg_xxxz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 124); 

                auto tg_xxxz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 125); 

                auto tg_xxxz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 126); 

                auto tg_xxxz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 127); 

                auto tg_xxxz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 128); 

                auto tg_xxxz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 129); 

                auto tg_xxxz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 130); 

                auto tg_xxxz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 131); 

                auto tg_xxxz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 132); 

                auto tg_xxxz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 133); 

                auto tg_xxxz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 134); 

                auto tg_xxyy_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 135); 

                auto tg_xxyy_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 136); 

                auto tg_xxyy_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 137); 

                auto tg_xxyy_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 138); 

                auto tg_xxyy_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 139); 

                auto tg_xxyy_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 140); 

                auto tg_xxyy_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 141); 

                auto tg_xxyy_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 142); 

                auto tg_xxyy_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 143); 

                auto tg_xxyy_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 144); 

                auto tg_xxyy_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 145); 

                auto tg_xxyy_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 146); 

                auto tg_xxyy_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 147); 

                auto tg_xxyy_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 148); 

                auto tg_xxyy_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 149); 

                auto tg_xxyy_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 150); 

                auto tg_xxyy_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 151); 

                auto tg_xxyy_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 152); 

                auto tg_xxyy_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 153); 

                auto tg_xxyy_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 154); 

                auto tg_xxyy_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 155); 

                auto tg_xxyy_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 156); 

                auto tg_xxyy_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 157); 

                auto tg_xxyy_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 158); 

                auto tg_xxyy_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 159); 

                auto tg_xxyy_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 160); 

                auto tg_xxyy_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 161); 

                auto tg_xxyy_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 162); 

                auto tg_xxyy_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 163); 

                auto tg_xxyy_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 164); 

                auto tg_xxyy_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 165); 

                auto tg_xxyy_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 166); 

                auto tg_xxyy_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 167); 

                auto tg_xxyy_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 168); 

                auto tg_xxyy_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 169); 

                auto tg_xxyy_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 170); 

                auto tg_xxyy_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 171); 

                auto tg_xxyy_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 172); 

                auto tg_xxyy_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 173); 

                auto tg_xxyy_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 174); 

                auto tg_xxyy_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 175); 

                auto tg_xxyy_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 176); 

                auto tg_xxyy_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 177); 

                auto tg_xxyy_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 178); 

                auto tg_xxyy_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 179); 

                auto tg_xxyz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 180); 

                auto tg_xxyz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 181); 

                auto tg_xxyz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 182); 

                auto tg_xxyz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 183); 

                auto tg_xxyz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 184); 

                auto tg_xxyz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 185); 

                auto tg_xxyz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 186); 

                auto tg_xxyz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 187); 

                auto tg_xxyz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 188); 

                auto tg_xxyz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 189); 

                auto tg_xxyz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 190); 

                auto tg_xxyz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 191); 

                auto tg_xxyz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 192); 

                auto tg_xxyz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 193); 

                auto tg_xxxz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 97); 

                auto tg_xxxz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 98); 

                auto tg_xxxz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 99); 

                auto tg_xxxz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 100); 

                auto tg_xxxz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 101); 

                auto tg_xxxz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 102); 

                auto tg_xxxz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 103); 

                auto tg_xxxz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 104); 

                auto tg_xxxz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 105); 

                auto tg_xxxz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 106); 

                auto tg_xxxz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 107); 

                auto tg_xxxz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 108); 

                auto tg_xxxz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 109); 

                auto tg_xxxz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 110); 

                auto tg_xxxz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 111); 

                auto tg_xxxz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 112); 

                auto tg_xxxz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 113); 

                auto tg_xxxz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 114); 

                auto tg_xxxz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 115); 

                auto tg_xxxz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 116); 

                auto tg_xxxz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 117); 

                auto tg_xxxz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 118); 

                auto tg_xxxz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 119); 

                auto tg_xxxz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 120); 

                auto tg_xxxz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 121); 

                auto tg_xxxz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 122); 

                auto tg_xxxz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 123); 

                auto tg_xxxz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 124); 

                auto tg_xxxz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 125); 

                auto tg_xxxz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 126); 

                auto tg_xxxz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 127); 

                auto tg_xxxz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 128); 

                auto tg_xxxz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 129); 

                auto tg_xxxz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 130); 

                auto tg_xxxz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 131); 

                auto tg_xxxz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 132); 

                auto tg_xxxz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 133); 

                auto tg_xxxz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 134); 

                auto tg_xxyy_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 135); 

                auto tg_xxyy_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 136); 

                auto tg_xxyy_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 137); 

                auto tg_xxyy_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 138); 

                auto tg_xxyy_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 139); 

                auto tg_xxyy_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 140); 

                auto tg_xxyy_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 141); 

                auto tg_xxyy_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 142); 

                auto tg_xxyy_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 143); 

                auto tg_xxyy_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 144); 

                auto tg_xxyy_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 145); 

                auto tg_xxyy_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 146); 

                auto tg_xxyy_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 147); 

                auto tg_xxyy_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 148); 

                auto tg_xxyy_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 149); 

                auto tg_xxyy_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 150); 

                auto tg_xxyy_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 151); 

                auto tg_xxyy_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 152); 

                auto tg_xxyy_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 153); 

                auto tg_xxyy_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 154); 

                auto tg_xxyy_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 155); 

                auto tg_xxyy_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 156); 

                auto tg_xxyy_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 157); 

                auto tg_xxyy_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 158); 

                auto tg_xxyy_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 159); 

                auto tg_xxyy_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 160); 

                auto tg_xxyy_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 161); 

                auto tg_xxyy_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 162); 

                auto tg_xxyy_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 163); 

                auto tg_xxyy_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 164); 

                auto tg_xxyy_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 165); 

                auto tg_xxyy_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 166); 

                auto tg_xxyy_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 167); 

                auto tg_xxyy_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 168); 

                auto tg_xxyy_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 169); 

                auto tg_xxyy_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 170); 

                auto tg_xxyy_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 171); 

                auto tg_xxyy_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 172); 

                auto tg_xxyy_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 173); 

                auto tg_xxyy_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 174); 

                auto tg_xxyy_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 175); 

                auto tg_xxyy_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 176); 

                auto tg_xxyy_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 177); 

                auto tg_xxyy_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 178); 

                auto tg_xxyy_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 179); 

                auto tg_xxyz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 180); 

                auto tg_xxyz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 181); 

                auto tg_xxyz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 182); 

                auto tg_xxyz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 183); 

                auto tg_xxyz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 184); 

                auto tg_xxyz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 185); 

                auto tg_xxyz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 186); 

                auto tg_xxyz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 187); 

                auto tg_xxyz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 188); 

                auto tg_xxyz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 189); 

                auto tg_xxyz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 190); 

                auto tg_xxyz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 191); 

                auto tg_xxyz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 192); 

                auto tg_xxyz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 193); 

                auto tg_xxxxz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 79); 

                auto tg_xxxxz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 80); 

                auto tg_xxxxz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 81); 

                auto tg_xxxxz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 82); 

                auto tg_xxxxz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 83); 

                auto tg_xxxxz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 84); 

                auto tg_xxxxz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 85); 

                auto tg_xxxxz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 86); 

                auto tg_xxxxz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 87); 

                auto tg_xxxxz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 88); 

                auto tg_xxxxz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 89); 

                auto tg_xxxxz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 90); 

                auto tg_xxxxz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 91); 

                auto tg_xxxxz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 92); 

                auto tg_xxxxz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 93); 

                auto tg_xxxxz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 94); 

                auto tg_xxxxz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 95); 

                auto tg_xxxxz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 96); 

                auto tg_xxxxz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 97); 

                auto tg_xxxxz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 98); 

                auto tg_xxxxz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 99); 

                auto tg_xxxxz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 100); 

                auto tg_xxxxz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 101); 

                auto tg_xxxxz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 102); 

                auto tg_xxxxz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 103); 

                auto tg_xxxxz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 104); 

                auto tg_xxxxz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 105); 

                auto tg_xxxxz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 106); 

                auto tg_xxxxz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 107); 

                auto tg_xxxyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 108); 

                auto tg_xxxyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 109); 

                auto tg_xxxyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 110); 

                auto tg_xxxyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 111); 

                auto tg_xxxyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 112); 

                auto tg_xxxyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 113); 

                auto tg_xxxyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 114); 

                auto tg_xxxyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 115); 

                auto tg_xxxyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 116); 

                auto tg_xxxyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 117); 

                auto tg_xxxyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 118); 

                auto tg_xxxyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 119); 

                auto tg_xxxyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 120); 

                auto tg_xxxyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 121); 

                auto tg_xxxyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 122); 

                auto tg_xxxyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 123); 

                auto tg_xxxyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 124); 

                auto tg_xxxyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 125); 

                auto tg_xxxyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 126); 

                auto tg_xxxyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 127); 

                auto tg_xxxyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 128); 

                auto tg_xxxyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 129); 

                auto tg_xxxyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 130); 

                auto tg_xxxyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 131); 

                auto tg_xxxyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 132); 

                auto tg_xxxyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 133); 

                auto tg_xxxyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 134); 

                auto tg_xxxyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 135); 

                auto tg_xxxyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 136); 

                auto tg_xxxyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 137); 

                auto tg_xxxyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 138); 

                auto tg_xxxyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 139); 

                auto tg_xxxyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 140); 

                auto tg_xxxyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 141); 

                auto tg_xxxyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 142); 

                auto tg_xxxyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 143); 

                auto tg_xxxyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 144); 

                auto tg_xxxyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 145); 

                auto tg_xxxyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 146); 

                auto tg_xxxyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 147); 

                auto tg_xxxyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 148); 

                auto tg_xxxyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 149); 

                auto tg_xxxyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 150); 

                auto tg_xxxyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 151); 

                auto tg_xxxyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 152); 

                auto tg_xxxyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 153); 

                auto tg_xxxyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 154); 

                auto tg_xxxyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 155); 

                auto tg_xxxyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 156); 

                auto tg_xxxyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 157); 

                // set up pointers to integrals

                auto tg_xxxxxz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 97); 

                auto tg_xxxxxz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 98); 

                auto tg_xxxxxz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 99); 

                auto tg_xxxxxz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 100); 

                auto tg_xxxxxz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 101); 

                auto tg_xxxxxz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 102); 

                auto tg_xxxxxz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 103); 

                auto tg_xxxxxz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 104); 

                auto tg_xxxxxz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 105); 

                auto tg_xxxxxz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 106); 

                auto tg_xxxxxz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 107); 

                auto tg_xxxxxz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 108); 

                auto tg_xxxxxz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 109); 

                auto tg_xxxxxz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 110); 

                auto tg_xxxxxz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 111); 

                auto tg_xxxxxz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 112); 

                auto tg_xxxxxz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 113); 

                auto tg_xxxxxz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 114); 

                auto tg_xxxxxz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 115); 

                auto tg_xxxxxz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 116); 

                auto tg_xxxxxz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 117); 

                auto tg_xxxxxz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 118); 

                auto tg_xxxxxz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 119); 

                auto tg_xxxxxz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 120); 

                auto tg_xxxxxz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 121); 

                auto tg_xxxxxz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 122); 

                auto tg_xxxxxz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 123); 

                auto tg_xxxxxz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 124); 

                auto tg_xxxxxz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 125); 

                auto tg_xxxxxz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 126); 

                auto tg_xxxxxz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 127); 

                auto tg_xxxxxz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 128); 

                auto tg_xxxxxz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 129); 

                auto tg_xxxxxz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 130); 

                auto tg_xxxxxz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 131); 

                auto tg_xxxxxz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 132); 

                auto tg_xxxxxz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 133); 

                auto tg_xxxxxz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 134); 

                auto tg_xxxxyy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 135); 

                auto tg_xxxxyy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 136); 

                auto tg_xxxxyy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 137); 

                auto tg_xxxxyy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 138); 

                auto tg_xxxxyy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 139); 

                auto tg_xxxxyy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 140); 

                auto tg_xxxxyy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 141); 

                auto tg_xxxxyy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 142); 

                auto tg_xxxxyy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 143); 

                auto tg_xxxxyy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 144); 

                auto tg_xxxxyy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 145); 

                auto tg_xxxxyy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 146); 

                auto tg_xxxxyy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 147); 

                auto tg_xxxxyy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 148); 

                auto tg_xxxxyy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 149); 

                auto tg_xxxxyy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 150); 

                auto tg_xxxxyy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 151); 

                auto tg_xxxxyy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 152); 

                auto tg_xxxxyy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 153); 

                auto tg_xxxxyy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 154); 

                auto tg_xxxxyy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 155); 

                auto tg_xxxxyy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 156); 

                auto tg_xxxxyy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 157); 

                auto tg_xxxxyy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 158); 

                auto tg_xxxxyy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 159); 

                auto tg_xxxxyy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 160); 

                auto tg_xxxxyy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 161); 

                auto tg_xxxxyy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 162); 

                auto tg_xxxxyy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 163); 

                auto tg_xxxxyy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 164); 

                auto tg_xxxxyy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 165); 

                auto tg_xxxxyy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 166); 

                auto tg_xxxxyy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 167); 

                auto tg_xxxxyy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 168); 

                auto tg_xxxxyy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 169); 

                auto tg_xxxxyy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 170); 

                auto tg_xxxxyy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 171); 

                auto tg_xxxxyy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 172); 

                auto tg_xxxxyy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 173); 

                auto tg_xxxxyy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 174); 

                auto tg_xxxxyy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 175); 

                auto tg_xxxxyy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 176); 

                auto tg_xxxxyy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 177); 

                auto tg_xxxxyy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 178); 

                auto tg_xxxxyy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 179); 

                auto tg_xxxxyz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 180); 

                auto tg_xxxxyz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 181); 

                auto tg_xxxxyz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 182); 

                auto tg_xxxxyz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 183); 

                auto tg_xxxxyz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 184); 

                auto tg_xxxxyz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 185); 

                auto tg_xxxxyz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 186); 

                auto tg_xxxxyz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 187); 

                auto tg_xxxxyz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 188); 

                auto tg_xxxxyz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 189); 

                auto tg_xxxxyz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 190); 

                auto tg_xxxxyz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 191); 

                auto tg_xxxxyz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 192); 

                auto tg_xxxxyz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 193); 

                // Batch of Integrals (97,194)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxz_xxxxxyyz_0, tg_xxxxxz_xxxxxyzz_0, \
                                         tg_xxxxxz_xxxxxzzz_0, tg_xxxxxz_xxxxyyyy_0, tg_xxxxxz_xxxxyyyz_0, tg_xxxxxz_xxxxyyzz_0, \
                                         tg_xxxxxz_xxxxyzzz_0, tg_xxxxxz_xxxxzzzz_0, tg_xxxxxz_xxxyyyyy_0, tg_xxxxxz_xxxyyyyz_0, \
                                         tg_xxxxxz_xxxyyyzz_0, tg_xxxxxz_xxxyyzzz_0, tg_xxxxxz_xxxyzzzz_0, tg_xxxxxz_xxxzzzzz_0, \
                                         tg_xxxxxz_xxyyyyyy_0, tg_xxxxxz_xxyyyyyz_0, tg_xxxxxz_xxyyyyzz_0, tg_xxxxxz_xxyyyzzz_0, \
                                         tg_xxxxxz_xxyyzzzz_0, tg_xxxxxz_xxyzzzzz_0, tg_xxxxxz_xxzzzzzz_0, tg_xxxxxz_xyyyyyyy_0, \
                                         tg_xxxxxz_xyyyyyyz_0, tg_xxxxxz_xyyyyyzz_0, tg_xxxxxz_xyyyyzzz_0, tg_xxxxxz_xyyyzzzz_0, \
                                         tg_xxxxxz_xyyzzzzz_0, tg_xxxxxz_xyzzzzzz_0, tg_xxxxxz_xzzzzzzz_0, tg_xxxxxz_yyyyyyyy_0, \
                                         tg_xxxxxz_yyyyyyyz_0, tg_xxxxxz_yyyyyyzz_0, tg_xxxxxz_yyyyyzzz_0, tg_xxxxxz_yyyyzzzz_0, \
                                         tg_xxxxxz_yyyzzzzz_0, tg_xxxxxz_yyzzzzzz_0, tg_xxxxxz_yzzzzzzz_0, tg_xxxxxz_zzzzzzzz_0, \
                                         tg_xxxxyy_xxxxxxxx_0, tg_xxxxyy_xxxxxxxy_0, tg_xxxxyy_xxxxxxxz_0, tg_xxxxyy_xxxxxxyy_0, \
                                         tg_xxxxyy_xxxxxxyz_0, tg_xxxxyy_xxxxxxzz_0, tg_xxxxyy_xxxxxyyy_0, tg_xxxxyy_xxxxxyyz_0, \
                                         tg_xxxxyy_xxxxxyzz_0, tg_xxxxyy_xxxxxzzz_0, tg_xxxxyy_xxxxyyyy_0, tg_xxxxyy_xxxxyyyz_0, \
                                         tg_xxxxyy_xxxxyyzz_0, tg_xxxxyy_xxxxyzzz_0, tg_xxxxyy_xxxxzzzz_0, tg_xxxxyy_xxxyyyyy_0, \
                                         tg_xxxxyy_xxxyyyyz_0, tg_xxxxyy_xxxyyyzz_0, tg_xxxxyy_xxxyyzzz_0, tg_xxxxyy_xxxyzzzz_0, \
                                         tg_xxxxyy_xxxzzzzz_0, tg_xxxxyy_xxyyyyyy_0, tg_xxxxyy_xxyyyyyz_0, tg_xxxxyy_xxyyyyzz_0, \
                                         tg_xxxxyy_xxyyyzzz_0, tg_xxxxyy_xxyyzzzz_0, tg_xxxxyy_xxyzzzzz_0, tg_xxxxyy_xxzzzzzz_0, \
                                         tg_xxxxyy_xyyyyyyy_0, tg_xxxxyy_xyyyyyyz_0, tg_xxxxyy_xyyyyyzz_0, tg_xxxxyy_xyyyyzzz_0, \
                                         tg_xxxxyy_xyyyzzzz_0, tg_xxxxyy_xyyzzzzz_0, tg_xxxxyy_xyzzzzzz_0, tg_xxxxyy_xzzzzzzz_0, \
                                         tg_xxxxyy_yyyyyyyy_0, tg_xxxxyy_yyyyyyyz_0, tg_xxxxyy_yyyyyyzz_0, tg_xxxxyy_yyyyyzzz_0, \
                                         tg_xxxxyy_yyyyzzzz_0, tg_xxxxyy_yyyzzzzz_0, tg_xxxxyy_yyzzzzzz_0, tg_xxxxyy_yzzzzzzz_0, \
                                         tg_xxxxyy_zzzzzzzz_0, tg_xxxxyz_xxxxxxxx_0, tg_xxxxyz_xxxxxxxy_0, tg_xxxxyz_xxxxxxxz_0, \
                                         tg_xxxxyz_xxxxxxyy_0, tg_xxxxyz_xxxxxxyz_0, tg_xxxxyz_xxxxxxzz_0, tg_xxxxyz_xxxxxyyy_0, \
                                         tg_xxxxyz_xxxxxyyz_0, tg_xxxxyz_xxxxxyzz_0, tg_xxxxyz_xxxxxzzz_0, tg_xxxxyz_xxxxyyyy_0, \
                                         tg_xxxxyz_xxxxyyyz_0, tg_xxxxyz_xxxxyyzz_0, tg_xxxxyz_xxxxyzzz_0, tg_xxxxz_xxxxxyyz_0, \
                                         tg_xxxxz_xxxxxyyz_1, tg_xxxxz_xxxxxyzz_0, tg_xxxxz_xxxxxyzz_1, tg_xxxxz_xxxxxzzz_0, \
                                         tg_xxxxz_xxxxxzzz_1, tg_xxxxz_xxxxyyyy_0, tg_xxxxz_xxxxyyyy_1, tg_xxxxz_xxxxyyyz_0, \
                                         tg_xxxxz_xxxxyyyz_1, tg_xxxxz_xxxxyyz_1, tg_xxxxz_xxxxyyzz_0, tg_xxxxz_xxxxyyzz_1, \
                                         tg_xxxxz_xxxxyzz_1, tg_xxxxz_xxxxyzzz_0, tg_xxxxz_xxxxyzzz_1, tg_xxxxz_xxxxzzz_1, \
                                         tg_xxxxz_xxxxzzzz_0, tg_xxxxz_xxxxzzzz_1, tg_xxxxz_xxxyyyy_1, tg_xxxxz_xxxyyyyy_0, \
                                         tg_xxxxz_xxxyyyyy_1, tg_xxxxz_xxxyyyyz_0, tg_xxxxz_xxxyyyyz_1, tg_xxxxz_xxxyyyz_1, \
                                         tg_xxxxz_xxxyyyzz_0, tg_xxxxz_xxxyyyzz_1, tg_xxxxz_xxxyyzz_1, tg_xxxxz_xxxyyzzz_0, \
                                         tg_xxxxz_xxxyyzzz_1, tg_xxxxz_xxxyzzz_1, tg_xxxxz_xxxyzzzz_0, tg_xxxxz_xxxyzzzz_1, \
                                         tg_xxxxz_xxxzzzz_1, tg_xxxxz_xxxzzzzz_0, tg_xxxxz_xxxzzzzz_1, tg_xxxxz_xxyyyyy_1, \
                                         tg_xxxxz_xxyyyyyy_0, tg_xxxxz_xxyyyyyy_1, tg_xxxxz_xxyyyyyz_0, tg_xxxxz_xxyyyyyz_1, \
                                         tg_xxxxz_xxyyyyz_1, tg_xxxxz_xxyyyyzz_0, tg_xxxxz_xxyyyyzz_1, tg_xxxxz_xxyyyzz_1, \
                                         tg_xxxxz_xxyyyzzz_0, tg_xxxxz_xxyyyzzz_1, tg_xxxxz_xxyyzzz_1, tg_xxxxz_xxyyzzzz_0, \
                                         tg_xxxxz_xxyyzzzz_1, tg_xxxxz_xxyzzzz_1, tg_xxxxz_xxyzzzzz_0, tg_xxxxz_xxyzzzzz_1, \
                                         tg_xxxxz_xxzzzzz_1, tg_xxxxz_xxzzzzzz_0, tg_xxxxz_xxzzzzzz_1, tg_xxxxz_xyyyyyy_1, \
                                         tg_xxxxz_xyyyyyyy_0, tg_xxxxz_xyyyyyyy_1, tg_xxxxz_xyyyyyyz_0, tg_xxxxz_xyyyyyyz_1, \
                                         tg_xxxxz_xyyyyyz_1, tg_xxxxz_xyyyyyzz_0, tg_xxxxz_xyyyyyzz_1, tg_xxxxz_xyyyyzz_1, \
                                         tg_xxxxz_xyyyyzzz_0, tg_xxxxz_xyyyyzzz_1, tg_xxxxz_xyyyzzz_1, tg_xxxxz_xyyyzzzz_0, \
                                         tg_xxxxz_xyyyzzzz_1, tg_xxxxz_xyyzzzz_1, tg_xxxxz_xyyzzzzz_0, tg_xxxxz_xyyzzzzz_1, \
                                         tg_xxxxz_xyzzzzz_1, tg_xxxxz_xyzzzzzz_0, tg_xxxxz_xyzzzzzz_1, tg_xxxxz_xzzzzzz_1, \
                                         tg_xxxxz_xzzzzzzz_0, tg_xxxxz_xzzzzzzz_1, tg_xxxxz_yyyyyyy_1, tg_xxxxz_yyyyyyyy_0, \
                                         tg_xxxxz_yyyyyyyy_1, tg_xxxxz_yyyyyyyz_0, tg_xxxxz_yyyyyyyz_1, tg_xxxxz_yyyyyyz_1, \
                                         tg_xxxxz_yyyyyyzz_0, tg_xxxxz_yyyyyyzz_1, tg_xxxxz_yyyyyzz_1, tg_xxxxz_yyyyyzzz_0, \
                                         tg_xxxxz_yyyyyzzz_1, tg_xxxxz_yyyyzzz_1, tg_xxxxz_yyyyzzzz_0, tg_xxxxz_yyyyzzzz_1, \
                                         tg_xxxxz_yyyzzzz_1, tg_xxxxz_yyyzzzzz_0, tg_xxxxz_yyyzzzzz_1, tg_xxxxz_yyzzzzz_1, \
                                         tg_xxxxz_yyzzzzzz_0, tg_xxxxz_yyzzzzzz_1, tg_xxxxz_yzzzzzz_1, tg_xxxxz_yzzzzzzz_0, \
                                         tg_xxxxz_yzzzzzzz_1, tg_xxxxz_zzzzzzz_1, tg_xxxxz_zzzzzzzz_0, tg_xxxxz_zzzzzzzz_1, \
                                         tg_xxxyy_xxxxxxx_1, tg_xxxyy_xxxxxxxx_0, tg_xxxyy_xxxxxxxx_1, tg_xxxyy_xxxxxxxy_0, \
                                         tg_xxxyy_xxxxxxxy_1, tg_xxxyy_xxxxxxxz_0, tg_xxxyy_xxxxxxxz_1, tg_xxxyy_xxxxxxy_1, \
                                         tg_xxxyy_xxxxxxyy_0, tg_xxxyy_xxxxxxyy_1, tg_xxxyy_xxxxxxyz_0, tg_xxxyy_xxxxxxyz_1, \
                                         tg_xxxyy_xxxxxxz_1, tg_xxxyy_xxxxxxzz_0, tg_xxxyy_xxxxxxzz_1, tg_xxxyy_xxxxxyy_1, \
                                         tg_xxxyy_xxxxxyyy_0, tg_xxxyy_xxxxxyyy_1, tg_xxxyy_xxxxxyyz_0, tg_xxxyy_xxxxxyyz_1, \
                                         tg_xxxyy_xxxxxyz_1, tg_xxxyy_xxxxxyzz_0, tg_xxxyy_xxxxxyzz_1, tg_xxxyy_xxxxxzz_1, \
                                         tg_xxxyy_xxxxxzzz_0, tg_xxxyy_xxxxxzzz_1, tg_xxxyy_xxxxyyy_1, tg_xxxyy_xxxxyyyy_0, \
                                         tg_xxxyy_xxxxyyyy_1, tg_xxxyy_xxxxyyyz_0, tg_xxxyy_xxxxyyyz_1, tg_xxxyy_xxxxyyz_1, \
                                         tg_xxxyy_xxxxyyzz_0, tg_xxxyy_xxxxyyzz_1, tg_xxxyy_xxxxyzz_1, tg_xxxyy_xxxxyzzz_0, \
                                         tg_xxxyy_xxxxyzzz_1, tg_xxxyy_xxxxzzz_1, tg_xxxyy_xxxxzzzz_0, tg_xxxyy_xxxxzzzz_1, \
                                         tg_xxxyy_xxxyyyy_1, tg_xxxyy_xxxyyyyy_0, tg_xxxyy_xxxyyyyy_1, tg_xxxyy_xxxyyyyz_0, \
                                         tg_xxxyy_xxxyyyyz_1, tg_xxxyy_xxxyyyz_1, tg_xxxyy_xxxyyyzz_0, tg_xxxyy_xxxyyyzz_1, \
                                         tg_xxxyy_xxxyyzz_1, tg_xxxyy_xxxyyzzz_0, tg_xxxyy_xxxyyzzz_1, tg_xxxyy_xxxyzzz_1, \
                                         tg_xxxyy_xxxyzzzz_0, tg_xxxyy_xxxyzzzz_1, tg_xxxyy_xxxzzzz_1, tg_xxxyy_xxxzzzzz_0, \
                                         tg_xxxyy_xxxzzzzz_1, tg_xxxyy_xxyyyyy_1, tg_xxxyy_xxyyyyyy_0, tg_xxxyy_xxyyyyyy_1, \
                                         tg_xxxyy_xxyyyyyz_0, tg_xxxyy_xxyyyyyz_1, tg_xxxyy_xxyyyyz_1, tg_xxxyy_xxyyyyzz_0, \
                                         tg_xxxyy_xxyyyyzz_1, tg_xxxyy_xxyyyzz_1, tg_xxxyy_xxyyyzzz_0, tg_xxxyy_xxyyyzzz_1, \
                                         tg_xxxyy_xxyyzzz_1, tg_xxxyy_xxyyzzzz_0, tg_xxxyy_xxyyzzzz_1, tg_xxxyy_xxyzzzz_1, \
                                         tg_xxxyy_xxyzzzzz_0, tg_xxxyy_xxyzzzzz_1, tg_xxxyy_xxzzzzz_1, tg_xxxyy_xxzzzzzz_0, \
                                         tg_xxxyy_xxzzzzzz_1, tg_xxxyy_xyyyyyy_1, tg_xxxyy_xyyyyyyy_0, tg_xxxyy_xyyyyyyy_1, \
                                         tg_xxxyy_xyyyyyyz_0, tg_xxxyy_xyyyyyyz_1, tg_xxxyy_xyyyyyz_1, tg_xxxyy_xyyyyyzz_0, \
                                         tg_xxxyy_xyyyyyzz_1, tg_xxxyy_xyyyyzz_1, tg_xxxyy_xyyyyzzz_0, tg_xxxyy_xyyyyzzz_1, \
                                         tg_xxxyy_xyyyzzz_1, tg_xxxyy_xyyyzzzz_0, tg_xxxyy_xyyyzzzz_1, tg_xxxyy_xyyzzzz_1, \
                                         tg_xxxyy_xyyzzzzz_0, tg_xxxyy_xyyzzzzz_1, tg_xxxyy_xyzzzzz_1, tg_xxxyy_xyzzzzzz_0, \
                                         tg_xxxyy_xyzzzzzz_1, tg_xxxyy_xzzzzzz_1, tg_xxxyy_xzzzzzzz_0, tg_xxxyy_xzzzzzzz_1, \
                                         tg_xxxyy_yyyyyyy_1, tg_xxxyy_yyyyyyyy_0, tg_xxxyy_yyyyyyyy_1, tg_xxxyy_yyyyyyyz_0, \
                                         tg_xxxyy_yyyyyyyz_1, tg_xxxyy_yyyyyyz_1, tg_xxxyy_yyyyyyzz_0, tg_xxxyy_yyyyyyzz_1, \
                                         tg_xxxyy_yyyyyzz_1, tg_xxxyy_yyyyyzzz_0, tg_xxxyy_yyyyyzzz_1, tg_xxxyy_yyyyzzz_1, \
                                         tg_xxxyy_yyyyzzzz_0, tg_xxxyy_yyyyzzzz_1, tg_xxxyy_yyyzzzz_1, tg_xxxyy_yyyzzzzz_0, \
                                         tg_xxxyy_yyyzzzzz_1, tg_xxxyy_yyzzzzz_1, tg_xxxyy_yyzzzzzz_0, tg_xxxyy_yyzzzzzz_1, \
                                         tg_xxxyy_yzzzzzz_1, tg_xxxyy_yzzzzzzz_0, tg_xxxyy_yzzzzzzz_1, tg_xxxyy_zzzzzzz_1, \
                                         tg_xxxyy_zzzzzzzz_0, tg_xxxyy_zzzzzzzz_1, tg_xxxyz_xxxxxxx_1, tg_xxxyz_xxxxxxxx_0, \
                                         tg_xxxyz_xxxxxxxx_1, tg_xxxyz_xxxxxxxy_0, tg_xxxyz_xxxxxxxy_1, tg_xxxyz_xxxxxxxz_0, \
                                         tg_xxxyz_xxxxxxxz_1, tg_xxxyz_xxxxxxy_1, tg_xxxyz_xxxxxxyy_0, tg_xxxyz_xxxxxxyy_1, \
                                         tg_xxxyz_xxxxxxyz_0, tg_xxxyz_xxxxxxyz_1, tg_xxxyz_xxxxxxz_1, tg_xxxyz_xxxxxxzz_0, \
                                         tg_xxxyz_xxxxxxzz_1, tg_xxxyz_xxxxxyy_1, tg_xxxyz_xxxxxyyy_0, tg_xxxyz_xxxxxyyy_1, \
                                         tg_xxxyz_xxxxxyyz_0, tg_xxxyz_xxxxxyyz_1, tg_xxxyz_xxxxxyz_1, tg_xxxyz_xxxxxyzz_0, \
                                         tg_xxxyz_xxxxxyzz_1, tg_xxxyz_xxxxxzz_1, tg_xxxyz_xxxxxzzz_0, tg_xxxyz_xxxxxzzz_1, \
                                         tg_xxxyz_xxxxyyy_1, tg_xxxyz_xxxxyyyy_0, tg_xxxyz_xxxxyyyy_1, tg_xxxyz_xxxxyyyz_0, \
                                         tg_xxxyz_xxxxyyyz_1, tg_xxxyz_xxxxyyz_1, tg_xxxyz_xxxxyyzz_0, tg_xxxyz_xxxxyyzz_1, \
                                         tg_xxxyz_xxxxyzz_1, tg_xxxyz_xxxxyzzz_0, tg_xxxyz_xxxxyzzz_1, tg_xxxyz_xxxxzzz_1, \
                                         tg_xxxyz_xxxyyyy_1, tg_xxxyz_xxxyyyz_1, tg_xxxyz_xxxyyzz_1, tg_xxxyz_xxxyzzz_1, \
                                         tg_xxxz_xxxxxyyz_0, tg_xxxz_xxxxxyyz_1, tg_xxxz_xxxxxyzz_0, tg_xxxz_xxxxxyzz_1, \
                                         tg_xxxz_xxxxxzzz_0, tg_xxxz_xxxxxzzz_1, tg_xxxz_xxxxyyyy_0, tg_xxxz_xxxxyyyy_1, \
                                         tg_xxxz_xxxxyyyz_0, tg_xxxz_xxxxyyyz_1, tg_xxxz_xxxxyyzz_0, tg_xxxz_xxxxyyzz_1, \
                                         tg_xxxz_xxxxyzzz_0, tg_xxxz_xxxxyzzz_1, tg_xxxz_xxxxzzzz_0, tg_xxxz_xxxxzzzz_1, \
                                         tg_xxxz_xxxyyyyy_0, tg_xxxz_xxxyyyyy_1, tg_xxxz_xxxyyyyz_0, tg_xxxz_xxxyyyyz_1, \
                                         tg_xxxz_xxxyyyzz_0, tg_xxxz_xxxyyyzz_1, tg_xxxz_xxxyyzzz_0, tg_xxxz_xxxyyzzz_1, \
                                         tg_xxxz_xxxyzzzz_0, tg_xxxz_xxxyzzzz_1, tg_xxxz_xxxzzzzz_0, tg_xxxz_xxxzzzzz_1, \
                                         tg_xxxz_xxyyyyyy_0, tg_xxxz_xxyyyyyy_1, tg_xxxz_xxyyyyyz_0, tg_xxxz_xxyyyyyz_1, \
                                         tg_xxxz_xxyyyyzz_0, tg_xxxz_xxyyyyzz_1, tg_xxxz_xxyyyzzz_0, tg_xxxz_xxyyyzzz_1, \
                                         tg_xxxz_xxyyzzzz_0, tg_xxxz_xxyyzzzz_1, tg_xxxz_xxyzzzzz_0, tg_xxxz_xxyzzzzz_1, \
                                         tg_xxxz_xxzzzzzz_0, tg_xxxz_xxzzzzzz_1, tg_xxxz_xyyyyyyy_0, tg_xxxz_xyyyyyyy_1, \
                                         tg_xxxz_xyyyyyyz_0, tg_xxxz_xyyyyyyz_1, tg_xxxz_xyyyyyzz_0, tg_xxxz_xyyyyyzz_1, \
                                         tg_xxxz_xyyyyzzz_0, tg_xxxz_xyyyyzzz_1, tg_xxxz_xyyyzzzz_0, tg_xxxz_xyyyzzzz_1, \
                                         tg_xxxz_xyyzzzzz_0, tg_xxxz_xyyzzzzz_1, tg_xxxz_xyzzzzzz_0, tg_xxxz_xyzzzzzz_1, \
                                         tg_xxxz_xzzzzzzz_0, tg_xxxz_xzzzzzzz_1, tg_xxxz_yyyyyyyy_0, tg_xxxz_yyyyyyyy_1, \
                                         tg_xxxz_yyyyyyyz_0, tg_xxxz_yyyyyyyz_1, tg_xxxz_yyyyyyzz_0, tg_xxxz_yyyyyyzz_1, \
                                         tg_xxxz_yyyyyzzz_0, tg_xxxz_yyyyyzzz_1, tg_xxxz_yyyyzzzz_0, tg_xxxz_yyyyzzzz_1, \
                                         tg_xxxz_yyyzzzzz_0, tg_xxxz_yyyzzzzz_1, tg_xxxz_yyzzzzzz_0, tg_xxxz_yyzzzzzz_1, \
                                         tg_xxxz_yzzzzzzz_0, tg_xxxz_yzzzzzzz_1, tg_xxxz_zzzzzzzz_0, tg_xxxz_zzzzzzzz_1, \
                                         tg_xxyy_xxxxxxxx_0, tg_xxyy_xxxxxxxx_1, tg_xxyy_xxxxxxxy_0, tg_xxyy_xxxxxxxy_1, \
                                         tg_xxyy_xxxxxxxz_0, tg_xxyy_xxxxxxxz_1, tg_xxyy_xxxxxxyy_0, tg_xxyy_xxxxxxyy_1, \
                                         tg_xxyy_xxxxxxyz_0, tg_xxyy_xxxxxxyz_1, tg_xxyy_xxxxxxzz_0, tg_xxyy_xxxxxxzz_1, \
                                         tg_xxyy_xxxxxyyy_0, tg_xxyy_xxxxxyyy_1, tg_xxyy_xxxxxyyz_0, tg_xxyy_xxxxxyyz_1, \
                                         tg_xxyy_xxxxxyzz_0, tg_xxyy_xxxxxyzz_1, tg_xxyy_xxxxxzzz_0, tg_xxyy_xxxxxzzz_1, \
                                         tg_xxyy_xxxxyyyy_0, tg_xxyy_xxxxyyyy_1, tg_xxyy_xxxxyyyz_0, tg_xxyy_xxxxyyyz_1, \
                                         tg_xxyy_xxxxyyzz_0, tg_xxyy_xxxxyyzz_1, tg_xxyy_xxxxyzzz_0, tg_xxyy_xxxxyzzz_1, \
                                         tg_xxyy_xxxxzzzz_0, tg_xxyy_xxxxzzzz_1, tg_xxyy_xxxyyyyy_0, tg_xxyy_xxxyyyyy_1, \
                                         tg_xxyy_xxxyyyyz_0, tg_xxyy_xxxyyyyz_1, tg_xxyy_xxxyyyzz_0, tg_xxyy_xxxyyyzz_1, \
                                         tg_xxyy_xxxyyzzz_0, tg_xxyy_xxxyyzzz_1, tg_xxyy_xxxyzzzz_0, tg_xxyy_xxxyzzzz_1, \
                                         tg_xxyy_xxxzzzzz_0, tg_xxyy_xxxzzzzz_1, tg_xxyy_xxyyyyyy_0, tg_xxyy_xxyyyyyy_1, \
                                         tg_xxyy_xxyyyyyz_0, tg_xxyy_xxyyyyyz_1, tg_xxyy_xxyyyyzz_0, tg_xxyy_xxyyyyzz_1, \
                                         tg_xxyy_xxyyyzzz_0, tg_xxyy_xxyyyzzz_1, tg_xxyy_xxyyzzzz_0, tg_xxyy_xxyyzzzz_1, \
                                         tg_xxyy_xxyzzzzz_0, tg_xxyy_xxyzzzzz_1, tg_xxyy_xxzzzzzz_0, tg_xxyy_xxzzzzzz_1, \
                                         tg_xxyy_xyyyyyyy_0, tg_xxyy_xyyyyyyy_1, tg_xxyy_xyyyyyyz_0, tg_xxyy_xyyyyyyz_1, \
                                         tg_xxyy_xyyyyyzz_0, tg_xxyy_xyyyyyzz_1, tg_xxyy_xyyyyzzz_0, tg_xxyy_xyyyyzzz_1, \
                                         tg_xxyy_xyyyzzzz_0, tg_xxyy_xyyyzzzz_1, tg_xxyy_xyyzzzzz_0, tg_xxyy_xyyzzzzz_1, \
                                         tg_xxyy_xyzzzzzz_0, tg_xxyy_xyzzzzzz_1, tg_xxyy_xzzzzzzz_0, tg_xxyy_xzzzzzzz_1, \
                                         tg_xxyy_yyyyyyyy_0, tg_xxyy_yyyyyyyy_1, tg_xxyy_yyyyyyyz_0, tg_xxyy_yyyyyyyz_1, \
                                         tg_xxyy_yyyyyyzz_0, tg_xxyy_yyyyyyzz_1, tg_xxyy_yyyyyzzz_0, tg_xxyy_yyyyyzzz_1, \
                                         tg_xxyy_yyyyzzzz_0, tg_xxyy_yyyyzzzz_1, tg_xxyy_yyyzzzzz_0, tg_xxyy_yyyzzzzz_1, \
                                         tg_xxyy_yyzzzzzz_0, tg_xxyy_yyzzzzzz_1, tg_xxyy_yzzzzzzz_0, tg_xxyy_yzzzzzzz_1, \
                                         tg_xxyy_zzzzzzzz_0, tg_xxyy_zzzzzzzz_1, tg_xxyz_xxxxxxxx_0, tg_xxyz_xxxxxxxx_1, \
                                         tg_xxyz_xxxxxxxy_0, tg_xxyz_xxxxxxxy_1, tg_xxyz_xxxxxxxz_0, tg_xxyz_xxxxxxxz_1, \
                                         tg_xxyz_xxxxxxyy_0, tg_xxyz_xxxxxxyy_1, tg_xxyz_xxxxxxyz_0, tg_xxyz_xxxxxxyz_1, \
                                         tg_xxyz_xxxxxxzz_0, tg_xxyz_xxxxxxzz_1, tg_xxyz_xxxxxyyy_0, tg_xxyz_xxxxxyyy_1, \
                                         tg_xxyz_xxxxxyyz_0, tg_xxyz_xxxxxyyz_1, tg_xxyz_xxxxxyzz_0, tg_xxyz_xxxxxyzz_1, \
                                         tg_xxyz_xxxxxzzz_0, tg_xxyz_xxxxxzzz_1, tg_xxyz_xxxxyyyy_0, tg_xxyz_xxxxyyyy_1, \
                                         tg_xxyz_xxxxyyyz_0, tg_xxyz_xxxxyyyz_1, tg_xxyz_xxxxyyzz_0, tg_xxyz_xxxxyyzz_1, \
                                         tg_xxyz_xxxxyzzz_0, tg_xxyz_xxxxyzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxz_xxxxxyyz_0[j] = pb_x * tg_xxxxz_xxxxxyyz_0[j] + fr * tg_xxxxz_xxxxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxyyz_0[j] - tg_xxxz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxz_xxxxyyz_1[j];

                    tg_xxxxxz_xxxxxyzz_0[j] = pb_x * tg_xxxxz_xxxxxyzz_0[j] + fr * tg_xxxxz_xxxxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxyzz_0[j] - tg_xxxz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxz_xxxxyzz_1[j];

                    tg_xxxxxz_xxxxxzzz_0[j] = pb_x * tg_xxxxz_xxxxxzzz_0[j] + fr * tg_xxxxz_xxxxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxxzzz_0[j] - tg_xxxz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxz_xxxxzzz_1[j];

                    tg_xxxxxz_xxxxyyyy_0[j] = pb_x * tg_xxxxz_xxxxyyyy_0[j] + fr * tg_xxxxz_xxxxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxyyyy_0[j] - tg_xxxz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxz_xxxyyyy_1[j];

                    tg_xxxxxz_xxxxyyyz_0[j] = pb_x * tg_xxxxz_xxxxyyyz_0[j] + fr * tg_xxxxz_xxxxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxyyyz_0[j] - tg_xxxz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxz_xxxyyyz_1[j];

                    tg_xxxxxz_xxxxyyzz_0[j] = pb_x * tg_xxxxz_xxxxyyzz_0[j] + fr * tg_xxxxz_xxxxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxyyzz_0[j] - tg_xxxz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxz_xxxyyzz_1[j];

                    tg_xxxxxz_xxxxyzzz_0[j] = pb_x * tg_xxxxz_xxxxyzzz_0[j] + fr * tg_xxxxz_xxxxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxyzzz_0[j] - tg_xxxz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxz_xxxyzzz_1[j];

                    tg_xxxxxz_xxxxzzzz_0[j] = pb_x * tg_xxxxz_xxxxzzzz_0[j] + fr * tg_xxxxz_xxxxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxxzzzz_0[j] - tg_xxxz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxz_xxxzzzz_1[j];

                    tg_xxxxxz_xxxyyyyy_0[j] = pb_x * tg_xxxxz_xxxyyyyy_0[j] + fr * tg_xxxxz_xxxyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxyyyyy_0[j] - tg_xxxz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxyyyyy_1[j];

                    tg_xxxxxz_xxxyyyyz_0[j] = pb_x * tg_xxxxz_xxxyyyyz_0[j] + fr * tg_xxxxz_xxxyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxyyyyz_0[j] - tg_xxxz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxyyyyz_1[j];

                    tg_xxxxxz_xxxyyyzz_0[j] = pb_x * tg_xxxxz_xxxyyyzz_0[j] + fr * tg_xxxxz_xxxyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxyyyzz_0[j] - tg_xxxz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxyyyzz_1[j];

                    tg_xxxxxz_xxxyyzzz_0[j] = pb_x * tg_xxxxz_xxxyyzzz_0[j] + fr * tg_xxxxz_xxxyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxyyzzz_0[j] - tg_xxxz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxyyzzz_1[j];

                    tg_xxxxxz_xxxyzzzz_0[j] = pb_x * tg_xxxxz_xxxyzzzz_0[j] + fr * tg_xxxxz_xxxyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxyzzzz_0[j] - tg_xxxz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxyzzzz_1[j];

                    tg_xxxxxz_xxxzzzzz_0[j] = pb_x * tg_xxxxz_xxxzzzzz_0[j] + fr * tg_xxxxz_xxxzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxxzzzzz_0[j] - tg_xxxz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxz_xxzzzzz_1[j];

                    tg_xxxxxz_xxyyyyyy_0[j] = pb_x * tg_xxxxz_xxyyyyyy_0[j] + fr * tg_xxxxz_xxyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyyyyyy_0[j] - tg_xxxz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyyyyyy_1[j];

                    tg_xxxxxz_xxyyyyyz_0[j] = pb_x * tg_xxxxz_xxyyyyyz_0[j] + fr * tg_xxxxz_xxyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyyyyyz_0[j] - tg_xxxz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyyyyyz_1[j];

                    tg_xxxxxz_xxyyyyzz_0[j] = pb_x * tg_xxxxz_xxyyyyzz_0[j] + fr * tg_xxxxz_xxyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyyyyzz_0[j] - tg_xxxz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyyyyzz_1[j];

                    tg_xxxxxz_xxyyyzzz_0[j] = pb_x * tg_xxxxz_xxyyyzzz_0[j] + fr * tg_xxxxz_xxyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyyyzzz_0[j] - tg_xxxz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyyyzzz_1[j];

                    tg_xxxxxz_xxyyzzzz_0[j] = pb_x * tg_xxxxz_xxyyzzzz_0[j] + fr * tg_xxxxz_xxyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyyzzzz_0[j] - tg_xxxz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyyzzzz_1[j];

                    tg_xxxxxz_xxyzzzzz_0[j] = pb_x * tg_xxxxz_xxyzzzzz_0[j] + fr * tg_xxxxz_xxyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxyzzzzz_0[j] - tg_xxxz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xyzzzzz_1[j];

                    tg_xxxxxz_xxzzzzzz_0[j] = pb_x * tg_xxxxz_xxzzzzzz_0[j] + fr * tg_xxxxz_xxzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xxzzzzzz_0[j] - tg_xxxz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxz_xzzzzzz_1[j];

                    tg_xxxxxz_xyyyyyyy_0[j] = pb_x * tg_xxxxz_xyyyyyyy_0[j] + fr * tg_xxxxz_xyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyyyyyy_0[j] - tg_xxxz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyyyyyy_1[j];

                    tg_xxxxxz_xyyyyyyz_0[j] = pb_x * tg_xxxxz_xyyyyyyz_0[j] + fr * tg_xxxxz_xyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyyyyyz_0[j] - tg_xxxz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyyyyyz_1[j];

                    tg_xxxxxz_xyyyyyzz_0[j] = pb_x * tg_xxxxz_xyyyyyzz_0[j] + fr * tg_xxxxz_xyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyyyyzz_0[j] - tg_xxxz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyyyyzz_1[j];

                    tg_xxxxxz_xyyyyzzz_0[j] = pb_x * tg_xxxxz_xyyyyzzz_0[j] + fr * tg_xxxxz_xyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyyyzzz_0[j] - tg_xxxz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyyyzzz_1[j];

                    tg_xxxxxz_xyyyzzzz_0[j] = pb_x * tg_xxxxz_xyyyzzzz_0[j] + fr * tg_xxxxz_xyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyyzzzz_0[j] - tg_xxxz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyyzzzz_1[j];

                    tg_xxxxxz_xyyzzzzz_0[j] = pb_x * tg_xxxxz_xyyzzzzz_0[j] + fr * tg_xxxxz_xyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyyzzzzz_0[j] - tg_xxxz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yyzzzzz_1[j];

                    tg_xxxxxz_xyzzzzzz_0[j] = pb_x * tg_xxxxz_xyzzzzzz_0[j] + fr * tg_xxxxz_xyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xyzzzzzz_0[j] - tg_xxxz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_yzzzzzz_1[j];

                    tg_xxxxxz_xzzzzzzz_0[j] = pb_x * tg_xxxxz_xzzzzzzz_0[j] + fr * tg_xxxxz_xzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_xzzzzzzz_0[j] - tg_xxxz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxz_zzzzzzz_1[j];

                    tg_xxxxxz_yyyyyyyy_0[j] = pb_x * tg_xxxxz_yyyyyyyy_0[j] + fr * tg_xxxxz_yyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyyyyyy_0[j] - tg_xxxz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxz_yyyyyyyz_0[j] = pb_x * tg_xxxxz_yyyyyyyz_0[j] + fr * tg_xxxxz_yyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyyyyyz_0[j] - tg_xxxz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxz_yyyyyyzz_0[j] = pb_x * tg_xxxxz_yyyyyyzz_0[j] + fr * tg_xxxxz_yyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyyyyzz_0[j] - tg_xxxz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxz_yyyyyzzz_0[j] = pb_x * tg_xxxxz_yyyyyzzz_0[j] + fr * tg_xxxxz_yyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyyyzzz_0[j] - tg_xxxz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxz_yyyyzzzz_0[j] = pb_x * tg_xxxxz_yyyyzzzz_0[j] + fr * tg_xxxxz_yyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyyzzzz_0[j] - tg_xxxz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxz_yyyzzzzz_0[j] = pb_x * tg_xxxxz_yyyzzzzz_0[j] + fr * tg_xxxxz_yyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyyzzzzz_0[j] - tg_xxxz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxz_yyzzzzzz_0[j] = pb_x * tg_xxxxz_yyzzzzzz_0[j] + fr * tg_xxxxz_yyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yyzzzzzz_0[j] - tg_xxxz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxz_yzzzzzzz_0[j] = pb_x * tg_xxxxz_yzzzzzzz_0[j] + fr * tg_xxxxz_yzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_yzzzzzzz_0[j] - tg_xxxz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxz_zzzzzzzz_0[j] = pb_x * tg_xxxxz_zzzzzzzz_0[j] + fr * tg_xxxxz_zzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxz_zzzzzzzz_0[j] - tg_xxxz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyy_xxxxxxxx_0[j] = pb_x * tg_xxxyy_xxxxxxxx_0[j] + fr * tg_xxxyy_xxxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxxx_0[j] - tg_xxyy_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxyy_xxxxxxx_1[j];

                    tg_xxxxyy_xxxxxxxy_0[j] = pb_x * tg_xxxyy_xxxxxxxy_0[j] + fr * tg_xxxyy_xxxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxxy_0[j] - tg_xxyy_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyy_xxxxxxy_1[j];

                    tg_xxxxyy_xxxxxxxz_0[j] = pb_x * tg_xxxyy_xxxxxxxz_0[j] + fr * tg_xxxyy_xxxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxxz_0[j] - tg_xxyy_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyy_xxxxxxz_1[j];

                    tg_xxxxyy_xxxxxxyy_0[j] = pb_x * tg_xxxyy_xxxxxxyy_0[j] + fr * tg_xxxyy_xxxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxyy_0[j] - tg_xxyy_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyy_xxxxxyy_1[j];

                    tg_xxxxyy_xxxxxxyz_0[j] = pb_x * tg_xxxyy_xxxxxxyz_0[j] + fr * tg_xxxyy_xxxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxyz_0[j] - tg_xxyy_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyy_xxxxxyz_1[j];

                    tg_xxxxyy_xxxxxxzz_0[j] = pb_x * tg_xxxyy_xxxxxxzz_0[j] + fr * tg_xxxyy_xxxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxxzz_0[j] - tg_xxyy_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyy_xxxxxzz_1[j];

                    tg_xxxxyy_xxxxxyyy_0[j] = pb_x * tg_xxxyy_xxxxxyyy_0[j] + fr * tg_xxxyy_xxxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxyyy_0[j] - tg_xxyy_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyy_xxxxyyy_1[j];

                    tg_xxxxyy_xxxxxyyz_0[j] = pb_x * tg_xxxyy_xxxxxyyz_0[j] + fr * tg_xxxyy_xxxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxyyz_0[j] - tg_xxyy_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyy_xxxxyyz_1[j];

                    tg_xxxxyy_xxxxxyzz_0[j] = pb_x * tg_xxxyy_xxxxxyzz_0[j] + fr * tg_xxxyy_xxxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxyzz_0[j] - tg_xxyy_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyy_xxxxyzz_1[j];

                    tg_xxxxyy_xxxxxzzz_0[j] = pb_x * tg_xxxyy_xxxxxzzz_0[j] + fr * tg_xxxyy_xxxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxxzzz_0[j] - tg_xxyy_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyy_xxxxzzz_1[j];

                    tg_xxxxyy_xxxxyyyy_0[j] = pb_x * tg_xxxyy_xxxxyyyy_0[j] + fr * tg_xxxyy_xxxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxyyyy_0[j] - tg_xxyy_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyy_xxxyyyy_1[j];

                    tg_xxxxyy_xxxxyyyz_0[j] = pb_x * tg_xxxyy_xxxxyyyz_0[j] + fr * tg_xxxyy_xxxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxyyyz_0[j] - tg_xxyy_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyy_xxxyyyz_1[j];

                    tg_xxxxyy_xxxxyyzz_0[j] = pb_x * tg_xxxyy_xxxxyyzz_0[j] + fr * tg_xxxyy_xxxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxyyzz_0[j] - tg_xxyy_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyy_xxxyyzz_1[j];

                    tg_xxxxyy_xxxxyzzz_0[j] = pb_x * tg_xxxyy_xxxxyzzz_0[j] + fr * tg_xxxyy_xxxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxyzzz_0[j] - tg_xxyy_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyy_xxxyzzz_1[j];

                    tg_xxxxyy_xxxxzzzz_0[j] = pb_x * tg_xxxyy_xxxxzzzz_0[j] + fr * tg_xxxyy_xxxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxxzzzz_0[j] - tg_xxyy_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyy_xxxzzzz_1[j];

                    tg_xxxxyy_xxxyyyyy_0[j] = pb_x * tg_xxxyy_xxxyyyyy_0[j] + fr * tg_xxxyy_xxxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxyyyyy_0[j] - tg_xxyy_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxyyyyy_1[j];

                    tg_xxxxyy_xxxyyyyz_0[j] = pb_x * tg_xxxyy_xxxyyyyz_0[j] + fr * tg_xxxyy_xxxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxyyyyz_0[j] - tg_xxyy_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxyyyyz_1[j];

                    tg_xxxxyy_xxxyyyzz_0[j] = pb_x * tg_xxxyy_xxxyyyzz_0[j] + fr * tg_xxxyy_xxxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxyyyzz_0[j] - tg_xxyy_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxyyyzz_1[j];

                    tg_xxxxyy_xxxyyzzz_0[j] = pb_x * tg_xxxyy_xxxyyzzz_0[j] + fr * tg_xxxyy_xxxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxyyzzz_0[j] - tg_xxyy_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxyyzzz_1[j];

                    tg_xxxxyy_xxxyzzzz_0[j] = pb_x * tg_xxxyy_xxxyzzzz_0[j] + fr * tg_xxxyy_xxxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxyzzzz_0[j] - tg_xxyy_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxyzzzz_1[j];

                    tg_xxxxyy_xxxzzzzz_0[j] = pb_x * tg_xxxyy_xxxzzzzz_0[j] + fr * tg_xxxyy_xxxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxxzzzzz_0[j] - tg_xxyy_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyy_xxzzzzz_1[j];

                    tg_xxxxyy_xxyyyyyy_0[j] = pb_x * tg_xxxyy_xxyyyyyy_0[j] + fr * tg_xxxyy_xxyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyyyyyy_0[j] - tg_xxyy_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyyyyyy_1[j];

                    tg_xxxxyy_xxyyyyyz_0[j] = pb_x * tg_xxxyy_xxyyyyyz_0[j] + fr * tg_xxxyy_xxyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyyyyyz_0[j] - tg_xxyy_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyyyyyz_1[j];

                    tg_xxxxyy_xxyyyyzz_0[j] = pb_x * tg_xxxyy_xxyyyyzz_0[j] + fr * tg_xxxyy_xxyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyyyyzz_0[j] - tg_xxyy_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyyyyzz_1[j];

                    tg_xxxxyy_xxyyyzzz_0[j] = pb_x * tg_xxxyy_xxyyyzzz_0[j] + fr * tg_xxxyy_xxyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyyyzzz_0[j] - tg_xxyy_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyyyzzz_1[j];

                    tg_xxxxyy_xxyyzzzz_0[j] = pb_x * tg_xxxyy_xxyyzzzz_0[j] + fr * tg_xxxyy_xxyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyyzzzz_0[j] - tg_xxyy_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyyzzzz_1[j];

                    tg_xxxxyy_xxyzzzzz_0[j] = pb_x * tg_xxxyy_xxyzzzzz_0[j] + fr * tg_xxxyy_xxyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxyzzzzz_0[j] - tg_xxyy_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xyzzzzz_1[j];

                    tg_xxxxyy_xxzzzzzz_0[j] = pb_x * tg_xxxyy_xxzzzzzz_0[j] + fr * tg_xxxyy_xxzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xxzzzzzz_0[j] - tg_xxyy_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyy_xzzzzzz_1[j];

                    tg_xxxxyy_xyyyyyyy_0[j] = pb_x * tg_xxxyy_xyyyyyyy_0[j] + fr * tg_xxxyy_xyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyyyyyy_0[j] - tg_xxyy_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyyyyyy_1[j];

                    tg_xxxxyy_xyyyyyyz_0[j] = pb_x * tg_xxxyy_xyyyyyyz_0[j] + fr * tg_xxxyy_xyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyyyyyz_0[j] - tg_xxyy_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyyyyyz_1[j];

                    tg_xxxxyy_xyyyyyzz_0[j] = pb_x * tg_xxxyy_xyyyyyzz_0[j] + fr * tg_xxxyy_xyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyyyyzz_0[j] - tg_xxyy_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyyyyzz_1[j];

                    tg_xxxxyy_xyyyyzzz_0[j] = pb_x * tg_xxxyy_xyyyyzzz_0[j] + fr * tg_xxxyy_xyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyyyzzz_0[j] - tg_xxyy_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyyyzzz_1[j];

                    tg_xxxxyy_xyyyzzzz_0[j] = pb_x * tg_xxxyy_xyyyzzzz_0[j] + fr * tg_xxxyy_xyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyyzzzz_0[j] - tg_xxyy_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyyzzzz_1[j];

                    tg_xxxxyy_xyyzzzzz_0[j] = pb_x * tg_xxxyy_xyyzzzzz_0[j] + fr * tg_xxxyy_xyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyyzzzzz_0[j] - tg_xxyy_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yyzzzzz_1[j];

                    tg_xxxxyy_xyzzzzzz_0[j] = pb_x * tg_xxxyy_xyzzzzzz_0[j] + fr * tg_xxxyy_xyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xyzzzzzz_0[j] - tg_xxyy_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_yzzzzzz_1[j];

                    tg_xxxxyy_xzzzzzzz_0[j] = pb_x * tg_xxxyy_xzzzzzzz_0[j] + fr * tg_xxxyy_xzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_xzzzzzzz_0[j] - tg_xxyy_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyy_zzzzzzz_1[j];

                    tg_xxxxyy_yyyyyyyy_0[j] = pb_x * tg_xxxyy_yyyyyyyy_0[j] + fr * tg_xxxyy_yyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyyyyyy_0[j] - tg_xxyy_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxyy_yyyyyyyz_0[j] = pb_x * tg_xxxyy_yyyyyyyz_0[j] + fr * tg_xxxyy_yyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyyyyyz_0[j] - tg_xxyy_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxyy_yyyyyyzz_0[j] = pb_x * tg_xxxyy_yyyyyyzz_0[j] + fr * tg_xxxyy_yyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyyyyzz_0[j] - tg_xxyy_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxyy_yyyyyzzz_0[j] = pb_x * tg_xxxyy_yyyyyzzz_0[j] + fr * tg_xxxyy_yyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyyyzzz_0[j] - tg_xxyy_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxyy_yyyyzzzz_0[j] = pb_x * tg_xxxyy_yyyyzzzz_0[j] + fr * tg_xxxyy_yyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyyzzzz_0[j] - tg_xxyy_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxyy_yyyzzzzz_0[j] = pb_x * tg_xxxyy_yyyzzzzz_0[j] + fr * tg_xxxyy_yyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyyzzzzz_0[j] - tg_xxyy_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxyy_yyzzzzzz_0[j] = pb_x * tg_xxxyy_yyzzzzzz_0[j] + fr * tg_xxxyy_yyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yyzzzzzz_0[j] - tg_xxyy_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyy_yzzzzzzz_0[j] = pb_x * tg_xxxyy_yzzzzzzz_0[j] + fr * tg_xxxyy_yzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_yzzzzzzz_0[j] - tg_xxyy_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyy_zzzzzzzz_0[j] = pb_x * tg_xxxyy_zzzzzzzz_0[j] + fr * tg_xxxyy_zzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyy_zzzzzzzz_0[j] - tg_xxyy_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyz_xxxxxxxx_0[j] = pb_x * tg_xxxyz_xxxxxxxx_0[j] + fr * tg_xxxyz_xxxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxxx_0[j] - tg_xxyz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxyz_xxxxxxx_1[j];

                    tg_xxxxyz_xxxxxxxy_0[j] = pb_x * tg_xxxyz_xxxxxxxy_0[j] + fr * tg_xxxyz_xxxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxxy_0[j] - tg_xxyz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyz_xxxxxxy_1[j];

                    tg_xxxxyz_xxxxxxxz_0[j] = pb_x * tg_xxxyz_xxxxxxxz_0[j] + fr * tg_xxxyz_xxxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxxz_0[j] - tg_xxyz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyz_xxxxxxz_1[j];

                    tg_xxxxyz_xxxxxxyy_0[j] = pb_x * tg_xxxyz_xxxxxxyy_0[j] + fr * tg_xxxyz_xxxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxyy_0[j] - tg_xxyz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyz_xxxxxyy_1[j];

                    tg_xxxxyz_xxxxxxyz_0[j] = pb_x * tg_xxxyz_xxxxxxyz_0[j] + fr * tg_xxxyz_xxxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxyz_0[j] - tg_xxyz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyz_xxxxxyz_1[j];

                    tg_xxxxyz_xxxxxxzz_0[j] = pb_x * tg_xxxyz_xxxxxxzz_0[j] + fr * tg_xxxyz_xxxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxxzz_0[j] - tg_xxyz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyz_xxxxxzz_1[j];

                    tg_xxxxyz_xxxxxyyy_0[j] = pb_x * tg_xxxyz_xxxxxyyy_0[j] + fr * tg_xxxyz_xxxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxyyy_0[j] - tg_xxyz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyz_xxxxyyy_1[j];

                    tg_xxxxyz_xxxxxyyz_0[j] = pb_x * tg_xxxyz_xxxxxyyz_0[j] + fr * tg_xxxyz_xxxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxyyz_0[j] - tg_xxyz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyz_xxxxyyz_1[j];

                    tg_xxxxyz_xxxxxyzz_0[j] = pb_x * tg_xxxyz_xxxxxyzz_0[j] + fr * tg_xxxyz_xxxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxyzz_0[j] - tg_xxyz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyz_xxxxyzz_1[j];

                    tg_xxxxyz_xxxxxzzz_0[j] = pb_x * tg_xxxyz_xxxxxzzz_0[j] + fr * tg_xxxyz_xxxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxxzzz_0[j] - tg_xxyz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyz_xxxxzzz_1[j];

                    tg_xxxxyz_xxxxyyyy_0[j] = pb_x * tg_xxxyz_xxxxyyyy_0[j] + fr * tg_xxxyz_xxxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxyyyy_0[j] - tg_xxyz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyz_xxxyyyy_1[j];

                    tg_xxxxyz_xxxxyyyz_0[j] = pb_x * tg_xxxyz_xxxxyyyz_0[j] + fr * tg_xxxyz_xxxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxyyyz_0[j] - tg_xxyz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyz_xxxyyyz_1[j];

                    tg_xxxxyz_xxxxyyzz_0[j] = pb_x * tg_xxxyz_xxxxyyzz_0[j] + fr * tg_xxxyz_xxxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxyyzz_0[j] - tg_xxyz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyz_xxxyyzz_1[j];

                    tg_xxxxyz_xxxxyzzz_0[j] = pb_x * tg_xxxyz_xxxxyzzz_0[j] + fr * tg_xxxyz_xxxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxyzzz_0[j] - tg_xxyz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyz_xxxyzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_194_291(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (194,291)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxyz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 194); 

                auto tg_xxxyz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 195); 

                auto tg_xxxyz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 196); 

                auto tg_xxxyz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 197); 

                auto tg_xxxyz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 198); 

                auto tg_xxxyz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 199); 

                auto tg_xxxyz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 200); 

                auto tg_xxxyz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 201); 

                auto tg_xxxyz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 202); 

                auto tg_xxxyz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 203); 

                auto tg_xxxyz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 204); 

                auto tg_xxxyz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 205); 

                auto tg_xxxyz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 206); 

                auto tg_xxxyz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 207); 

                auto tg_xxxyz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 208); 

                auto tg_xxxyz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 209); 

                auto tg_xxxyz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 210); 

                auto tg_xxxyz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 211); 

                auto tg_xxxyz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 212); 

                auto tg_xxxyz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 213); 

                auto tg_xxxyz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 214); 

                auto tg_xxxyz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 215); 

                auto tg_xxxyz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 216); 

                auto tg_xxxyz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 217); 

                auto tg_xxxyz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 218); 

                auto tg_xxxyz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 219); 

                auto tg_xxxyz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 220); 

                auto tg_xxxyz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 221); 

                auto tg_xxxyz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 222); 

                auto tg_xxxyz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 223); 

                auto tg_xxxyz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 224); 

                auto tg_xxxzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 225); 

                auto tg_xxxzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 226); 

                auto tg_xxxzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 227); 

                auto tg_xxxzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 228); 

                auto tg_xxxzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 229); 

                auto tg_xxxzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 230); 

                auto tg_xxxzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 231); 

                auto tg_xxxzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 232); 

                auto tg_xxxzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 233); 

                auto tg_xxxzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 234); 

                auto tg_xxxzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 235); 

                auto tg_xxxzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 236); 

                auto tg_xxxzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 237); 

                auto tg_xxxzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 238); 

                auto tg_xxxzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 239); 

                auto tg_xxxzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 240); 

                auto tg_xxxzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 241); 

                auto tg_xxxzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 242); 

                auto tg_xxxzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 243); 

                auto tg_xxxzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 244); 

                auto tg_xxxzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 245); 

                auto tg_xxxzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 246); 

                auto tg_xxxzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 247); 

                auto tg_xxxzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 248); 

                auto tg_xxxzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 249); 

                auto tg_xxxzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 250); 

                auto tg_xxxzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 251); 

                auto tg_xxxzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 252); 

                auto tg_xxxzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 253); 

                auto tg_xxxzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 254); 

                auto tg_xxxzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 255); 

                auto tg_xxxzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 256); 

                auto tg_xxxzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 257); 

                auto tg_xxxzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 258); 

                auto tg_xxxzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 259); 

                auto tg_xxxzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 260); 

                auto tg_xxxzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 261); 

                auto tg_xxxzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 262); 

                auto tg_xxxzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 263); 

                auto tg_xxxzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 264); 

                auto tg_xxxzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 265); 

                auto tg_xxxzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 266); 

                auto tg_xxxzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 267); 

                auto tg_xxxzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 268); 

                auto tg_xxxzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 269); 

                auto tg_xxyyy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 270); 

                auto tg_xxyyy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 271); 

                auto tg_xxyyy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 272); 

                auto tg_xxyyy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 273); 

                auto tg_xxyyy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 274); 

                auto tg_xxyyy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 275); 

                auto tg_xxyyy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 276); 

                auto tg_xxyyy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 277); 

                auto tg_xxyyy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 278); 

                auto tg_xxyyy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 279); 

                auto tg_xxyyy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 280); 

                auto tg_xxyyy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 281); 

                auto tg_xxyyy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 282); 

                auto tg_xxyyy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 283); 

                auto tg_xxyyy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 284); 

                auto tg_xxyyy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 285); 

                auto tg_xxyyy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 286); 

                auto tg_xxyyy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 287); 

                auto tg_xxyyy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 288); 

                auto tg_xxyyy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 289); 

                auto tg_xxyyy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 290); 

                auto tg_xxxyz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 194); 

                auto tg_xxxyz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 195); 

                auto tg_xxxyz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 196); 

                auto tg_xxxyz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 197); 

                auto tg_xxxyz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 198); 

                auto tg_xxxyz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 199); 

                auto tg_xxxyz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 200); 

                auto tg_xxxyz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 201); 

                auto tg_xxxyz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 202); 

                auto tg_xxxyz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 203); 

                auto tg_xxxyz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 204); 

                auto tg_xxxyz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 205); 

                auto tg_xxxyz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 206); 

                auto tg_xxxyz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 207); 

                auto tg_xxxyz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 208); 

                auto tg_xxxyz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 209); 

                auto tg_xxxyz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 210); 

                auto tg_xxxyz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 211); 

                auto tg_xxxyz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 212); 

                auto tg_xxxyz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 213); 

                auto tg_xxxyz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 214); 

                auto tg_xxxyz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 215); 

                auto tg_xxxyz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 216); 

                auto tg_xxxyz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 217); 

                auto tg_xxxyz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 218); 

                auto tg_xxxyz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 219); 

                auto tg_xxxyz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 220); 

                auto tg_xxxyz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 221); 

                auto tg_xxxyz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 222); 

                auto tg_xxxyz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 223); 

                auto tg_xxxyz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 224); 

                auto tg_xxxzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 225); 

                auto tg_xxxzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 226); 

                auto tg_xxxzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 227); 

                auto tg_xxxzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 228); 

                auto tg_xxxzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 229); 

                auto tg_xxxzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 230); 

                auto tg_xxxzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 231); 

                auto tg_xxxzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 232); 

                auto tg_xxxzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 233); 

                auto tg_xxxzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 234); 

                auto tg_xxxzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 235); 

                auto tg_xxxzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 236); 

                auto tg_xxxzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 237); 

                auto tg_xxxzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 238); 

                auto tg_xxxzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 239); 

                auto tg_xxxzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 240); 

                auto tg_xxxzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 241); 

                auto tg_xxxzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 242); 

                auto tg_xxxzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 243); 

                auto tg_xxxzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 244); 

                auto tg_xxxzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 245); 

                auto tg_xxxzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 246); 

                auto tg_xxxzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 247); 

                auto tg_xxxzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 248); 

                auto tg_xxxzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 249); 

                auto tg_xxxzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 250); 

                auto tg_xxxzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 251); 

                auto tg_xxxzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 252); 

                auto tg_xxxzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 253); 

                auto tg_xxxzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 254); 

                auto tg_xxxzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 255); 

                auto tg_xxxzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 256); 

                auto tg_xxxzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 257); 

                auto tg_xxxzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 258); 

                auto tg_xxxzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 259); 

                auto tg_xxxzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 260); 

                auto tg_xxxzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 261); 

                auto tg_xxxzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 262); 

                auto tg_xxxzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 263); 

                auto tg_xxxzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 264); 

                auto tg_xxxzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 265); 

                auto tg_xxxzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 266); 

                auto tg_xxxzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 267); 

                auto tg_xxxzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 268); 

                auto tg_xxxzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 269); 

                auto tg_xxyyy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 270); 

                auto tg_xxyyy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 271); 

                auto tg_xxyyy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 272); 

                auto tg_xxyyy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 273); 

                auto tg_xxyyy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 274); 

                auto tg_xxyyy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 275); 

                auto tg_xxyyy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 276); 

                auto tg_xxyyy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 277); 

                auto tg_xxyyy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 278); 

                auto tg_xxyyy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 279); 

                auto tg_xxyyy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 280); 

                auto tg_xxyyy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 281); 

                auto tg_xxyyy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 282); 

                auto tg_xxyyy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 283); 

                auto tg_xxyyy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 284); 

                auto tg_xxyyy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 285); 

                auto tg_xxyyy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 286); 

                auto tg_xxyyy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 287); 

                auto tg_xxyyy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 288); 

                auto tg_xxyyy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 289); 

                auto tg_xxyyy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 290); 

                auto tg_xxyz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 194); 

                auto tg_xxyz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 195); 

                auto tg_xxyz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 196); 

                auto tg_xxyz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 197); 

                auto tg_xxyz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 198); 

                auto tg_xxyz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 199); 

                auto tg_xxyz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 200); 

                auto tg_xxyz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 201); 

                auto tg_xxyz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 202); 

                auto tg_xxyz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 203); 

                auto tg_xxyz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 204); 

                auto tg_xxyz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 205); 

                auto tg_xxyz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 206); 

                auto tg_xxyz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 207); 

                auto tg_xxyz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 208); 

                auto tg_xxyz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 209); 

                auto tg_xxyz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 210); 

                auto tg_xxyz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 211); 

                auto tg_xxyz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 212); 

                auto tg_xxyz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 213); 

                auto tg_xxyz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 214); 

                auto tg_xxyz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 215); 

                auto tg_xxyz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 216); 

                auto tg_xxyz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 217); 

                auto tg_xxyz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 218); 

                auto tg_xxyz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 219); 

                auto tg_xxyz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 220); 

                auto tg_xxyz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 221); 

                auto tg_xxyz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 222); 

                auto tg_xxyz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 223); 

                auto tg_xxyz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 224); 

                auto tg_xxzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 225); 

                auto tg_xxzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 226); 

                auto tg_xxzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 227); 

                auto tg_xxzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 228); 

                auto tg_xxzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 229); 

                auto tg_xxzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 230); 

                auto tg_xxzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 231); 

                auto tg_xxzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 232); 

                auto tg_xxzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 233); 

                auto tg_xxzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 234); 

                auto tg_xxzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 235); 

                auto tg_xxzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 236); 

                auto tg_xxzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 237); 

                auto tg_xxzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 238); 

                auto tg_xxzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 239); 

                auto tg_xxzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 240); 

                auto tg_xxzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 241); 

                auto tg_xxzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 242); 

                auto tg_xxzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 243); 

                auto tg_xxzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 244); 

                auto tg_xxzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 245); 

                auto tg_xxzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 246); 

                auto tg_xxzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 247); 

                auto tg_xxzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 248); 

                auto tg_xxzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 249); 

                auto tg_xxzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 250); 

                auto tg_xxzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 251); 

                auto tg_xxzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 252); 

                auto tg_xxzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 253); 

                auto tg_xxzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 254); 

                auto tg_xxzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 255); 

                auto tg_xxzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 256); 

                auto tg_xxzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 257); 

                auto tg_xxzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 258); 

                auto tg_xxzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 259); 

                auto tg_xxzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 260); 

                auto tg_xxzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 261); 

                auto tg_xxzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 262); 

                auto tg_xxzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 263); 

                auto tg_xxzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 264); 

                auto tg_xxzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 265); 

                auto tg_xxzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 266); 

                auto tg_xxzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 267); 

                auto tg_xxzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 268); 

                auto tg_xxzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 269); 

                auto tg_xyyy_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 270); 

                auto tg_xyyy_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 271); 

                auto tg_xyyy_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 272); 

                auto tg_xyyy_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 273); 

                auto tg_xyyy_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 274); 

                auto tg_xyyy_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 275); 

                auto tg_xyyy_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 276); 

                auto tg_xyyy_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 277); 

                auto tg_xyyy_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 278); 

                auto tg_xyyy_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 279); 

                auto tg_xyyy_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 280); 

                auto tg_xyyy_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 281); 

                auto tg_xyyy_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 282); 

                auto tg_xyyy_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 283); 

                auto tg_xyyy_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 284); 

                auto tg_xyyy_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 285); 

                auto tg_xyyy_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 286); 

                auto tg_xyyy_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 287); 

                auto tg_xyyy_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 288); 

                auto tg_xyyy_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 289); 

                auto tg_xyyy_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 290); 

                auto tg_xxyz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 194); 

                auto tg_xxyz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 195); 

                auto tg_xxyz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 196); 

                auto tg_xxyz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 197); 

                auto tg_xxyz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 198); 

                auto tg_xxyz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 199); 

                auto tg_xxyz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 200); 

                auto tg_xxyz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 201); 

                auto tg_xxyz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 202); 

                auto tg_xxyz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 203); 

                auto tg_xxyz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 204); 

                auto tg_xxyz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 205); 

                auto tg_xxyz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 206); 

                auto tg_xxyz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 207); 

                auto tg_xxyz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 208); 

                auto tg_xxyz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 209); 

                auto tg_xxyz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 210); 

                auto tg_xxyz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 211); 

                auto tg_xxyz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 212); 

                auto tg_xxyz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 213); 

                auto tg_xxyz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 214); 

                auto tg_xxyz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 215); 

                auto tg_xxyz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 216); 

                auto tg_xxyz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 217); 

                auto tg_xxyz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 218); 

                auto tg_xxyz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 219); 

                auto tg_xxyz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 220); 

                auto tg_xxyz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 221); 

                auto tg_xxyz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 222); 

                auto tg_xxyz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 223); 

                auto tg_xxyz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 224); 

                auto tg_xxzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 225); 

                auto tg_xxzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 226); 

                auto tg_xxzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 227); 

                auto tg_xxzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 228); 

                auto tg_xxzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 229); 

                auto tg_xxzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 230); 

                auto tg_xxzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 231); 

                auto tg_xxzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 232); 

                auto tg_xxzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 233); 

                auto tg_xxzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 234); 

                auto tg_xxzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 235); 

                auto tg_xxzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 236); 

                auto tg_xxzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 237); 

                auto tg_xxzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 238); 

                auto tg_xxzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 239); 

                auto tg_xxzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 240); 

                auto tg_xxzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 241); 

                auto tg_xxzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 242); 

                auto tg_xxzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 243); 

                auto tg_xxzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 244); 

                auto tg_xxzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 245); 

                auto tg_xxzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 246); 

                auto tg_xxzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 247); 

                auto tg_xxzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 248); 

                auto tg_xxzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 249); 

                auto tg_xxzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 250); 

                auto tg_xxzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 251); 

                auto tg_xxzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 252); 

                auto tg_xxzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 253); 

                auto tg_xxzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 254); 

                auto tg_xxzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 255); 

                auto tg_xxzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 256); 

                auto tg_xxzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 257); 

                auto tg_xxzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 258); 

                auto tg_xxzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 259); 

                auto tg_xxzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 260); 

                auto tg_xxzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 261); 

                auto tg_xxzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 262); 

                auto tg_xxzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 263); 

                auto tg_xxzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 264); 

                auto tg_xxzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 265); 

                auto tg_xxzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 266); 

                auto tg_xxzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 267); 

                auto tg_xxzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 268); 

                auto tg_xxzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 269); 

                auto tg_xyyy_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 270); 

                auto tg_xyyy_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 271); 

                auto tg_xyyy_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 272); 

                auto tg_xyyy_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 273); 

                auto tg_xyyy_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 274); 

                auto tg_xyyy_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 275); 

                auto tg_xyyy_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 276); 

                auto tg_xyyy_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 277); 

                auto tg_xyyy_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 278); 

                auto tg_xyyy_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 279); 

                auto tg_xyyy_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 280); 

                auto tg_xyyy_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 281); 

                auto tg_xyyy_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 282); 

                auto tg_xyyy_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 283); 

                auto tg_xyyy_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 284); 

                auto tg_xyyy_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 285); 

                auto tg_xyyy_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 286); 

                auto tg_xyyy_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 287); 

                auto tg_xyyy_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 288); 

                auto tg_xyyy_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 289); 

                auto tg_xyyy_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 290); 

                auto tg_xxxyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 158); 

                auto tg_xxxyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 159); 

                auto tg_xxxyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 160); 

                auto tg_xxxyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 161); 

                auto tg_xxxyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 162); 

                auto tg_xxxyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 163); 

                auto tg_xxxyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 164); 

                auto tg_xxxyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 165); 

                auto tg_xxxyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 166); 

                auto tg_xxxyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 167); 

                auto tg_xxxyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 168); 

                auto tg_xxxyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 169); 

                auto tg_xxxyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 170); 

                auto tg_xxxyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 171); 

                auto tg_xxxyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 172); 

                auto tg_xxxyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 173); 

                auto tg_xxxyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 174); 

                auto tg_xxxyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 175); 

                auto tg_xxxyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 176); 

                auto tg_xxxyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 177); 

                auto tg_xxxyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 178); 

                auto tg_xxxyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 179); 

                auto tg_xxxzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 180); 

                auto tg_xxxzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 181); 

                auto tg_xxxzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 182); 

                auto tg_xxxzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 183); 

                auto tg_xxxzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 184); 

                auto tg_xxxzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 185); 

                auto tg_xxxzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 186); 

                auto tg_xxxzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 187); 

                auto tg_xxxzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 188); 

                auto tg_xxxzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 189); 

                auto tg_xxxzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 190); 

                auto tg_xxxzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 191); 

                auto tg_xxxzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 192); 

                auto tg_xxxzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 193); 

                auto tg_xxxzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 194); 

                auto tg_xxxzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 195); 

                auto tg_xxxzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 196); 

                auto tg_xxxzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 197); 

                auto tg_xxxzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 198); 

                auto tg_xxxzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 199); 

                auto tg_xxxzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 200); 

                auto tg_xxxzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 201); 

                auto tg_xxxzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 202); 

                auto tg_xxxzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 203); 

                auto tg_xxxzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 204); 

                auto tg_xxxzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 205); 

                auto tg_xxxzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 206); 

                auto tg_xxxzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 207); 

                auto tg_xxxzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 208); 

                auto tg_xxxzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 209); 

                auto tg_xxxzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 210); 

                auto tg_xxxzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 211); 

                auto tg_xxxzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 212); 

                auto tg_xxxzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 213); 

                auto tg_xxxzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 214); 

                auto tg_xxxzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 215); 

                auto tg_xxyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 216); 

                auto tg_xxyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 217); 

                auto tg_xxyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 218); 

                auto tg_xxyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 219); 

                auto tg_xxyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 220); 

                auto tg_xxyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 221); 

                auto tg_xxyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 222); 

                auto tg_xxyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 223); 

                auto tg_xxyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 224); 

                auto tg_xxyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 225); 

                auto tg_xxyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 226); 

                auto tg_xxyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 227); 

                auto tg_xxyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 228); 

                auto tg_xxyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 229); 

                auto tg_xxyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 230); 

                auto tg_xxyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 231); 

                auto tg_xxyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 232); 

                auto tg_xxyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 233); 

                auto tg_xxyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 234); 

                auto tg_xxyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 235); 

                auto tg_xxyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 236); 

                // set up pointers to integrals

                auto tg_xxxxyz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 194); 

                auto tg_xxxxyz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 195); 

                auto tg_xxxxyz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 196); 

                auto tg_xxxxyz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 197); 

                auto tg_xxxxyz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 198); 

                auto tg_xxxxyz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 199); 

                auto tg_xxxxyz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 200); 

                auto tg_xxxxyz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 201); 

                auto tg_xxxxyz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 202); 

                auto tg_xxxxyz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 203); 

                auto tg_xxxxyz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 204); 

                auto tg_xxxxyz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 205); 

                auto tg_xxxxyz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 206); 

                auto tg_xxxxyz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 207); 

                auto tg_xxxxyz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 208); 

                auto tg_xxxxyz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 209); 

                auto tg_xxxxyz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 210); 

                auto tg_xxxxyz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 211); 

                auto tg_xxxxyz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 212); 

                auto tg_xxxxyz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 213); 

                auto tg_xxxxyz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 214); 

                auto tg_xxxxyz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 215); 

                auto tg_xxxxyz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 216); 

                auto tg_xxxxyz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 217); 

                auto tg_xxxxyz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 218); 

                auto tg_xxxxyz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 219); 

                auto tg_xxxxyz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 220); 

                auto tg_xxxxyz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 221); 

                auto tg_xxxxyz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 222); 

                auto tg_xxxxyz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 223); 

                auto tg_xxxxyz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 224); 

                auto tg_xxxxzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 225); 

                auto tg_xxxxzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 226); 

                auto tg_xxxxzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 227); 

                auto tg_xxxxzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 228); 

                auto tg_xxxxzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 229); 

                auto tg_xxxxzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 230); 

                auto tg_xxxxzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 231); 

                auto tg_xxxxzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 232); 

                auto tg_xxxxzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 233); 

                auto tg_xxxxzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 234); 

                auto tg_xxxxzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 235); 

                auto tg_xxxxzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 236); 

                auto tg_xxxxzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 237); 

                auto tg_xxxxzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 238); 

                auto tg_xxxxzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 239); 

                auto tg_xxxxzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 240); 

                auto tg_xxxxzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 241); 

                auto tg_xxxxzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 242); 

                auto tg_xxxxzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 243); 

                auto tg_xxxxzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 244); 

                auto tg_xxxxzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 245); 

                auto tg_xxxxzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 246); 

                auto tg_xxxxzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 247); 

                auto tg_xxxxzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 248); 

                auto tg_xxxxzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 249); 

                auto tg_xxxxzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 250); 

                auto tg_xxxxzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 251); 

                auto tg_xxxxzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 252); 

                auto tg_xxxxzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 253); 

                auto tg_xxxxzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 254); 

                auto tg_xxxxzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 255); 

                auto tg_xxxxzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 256); 

                auto tg_xxxxzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 257); 

                auto tg_xxxxzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 258); 

                auto tg_xxxxzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 259); 

                auto tg_xxxxzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 260); 

                auto tg_xxxxzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 261); 

                auto tg_xxxxzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 262); 

                auto tg_xxxxzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 263); 

                auto tg_xxxxzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 264); 

                auto tg_xxxxzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 265); 

                auto tg_xxxxzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 266); 

                auto tg_xxxxzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 267); 

                auto tg_xxxxzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 268); 

                auto tg_xxxxzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 269); 

                auto tg_xxxyyy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 270); 

                auto tg_xxxyyy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 271); 

                auto tg_xxxyyy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 272); 

                auto tg_xxxyyy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 273); 

                auto tg_xxxyyy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 274); 

                auto tg_xxxyyy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 275); 

                auto tg_xxxyyy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 276); 

                auto tg_xxxyyy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 277); 

                auto tg_xxxyyy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 278); 

                auto tg_xxxyyy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 279); 

                auto tg_xxxyyy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 280); 

                auto tg_xxxyyy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 281); 

                auto tg_xxxyyy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 282); 

                auto tg_xxxyyy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 283); 

                auto tg_xxxyyy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 284); 

                auto tg_xxxyyy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 285); 

                auto tg_xxxyyy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 286); 

                auto tg_xxxyyy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 287); 

                auto tg_xxxyyy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 288); 

                auto tg_xxxyyy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 289); 

                auto tg_xxxyyy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 290); 

                // Batch of Integrals (194,291)

                #pragma omp simd aligned(fxn, fza, tg_xxxxyz_xxxxzzzz_0, tg_xxxxyz_xxxyyyyy_0, \
                                         tg_xxxxyz_xxxyyyyz_0, tg_xxxxyz_xxxyyyzz_0, tg_xxxxyz_xxxyyzzz_0, tg_xxxxyz_xxxyzzzz_0, \
                                         tg_xxxxyz_xxxzzzzz_0, tg_xxxxyz_xxyyyyyy_0, tg_xxxxyz_xxyyyyyz_0, tg_xxxxyz_xxyyyyzz_0, \
                                         tg_xxxxyz_xxyyyzzz_0, tg_xxxxyz_xxyyzzzz_0, tg_xxxxyz_xxyzzzzz_0, tg_xxxxyz_xxzzzzzz_0, \
                                         tg_xxxxyz_xyyyyyyy_0, tg_xxxxyz_xyyyyyyz_0, tg_xxxxyz_xyyyyyzz_0, tg_xxxxyz_xyyyyzzz_0, \
                                         tg_xxxxyz_xyyyzzzz_0, tg_xxxxyz_xyyzzzzz_0, tg_xxxxyz_xyzzzzzz_0, tg_xxxxyz_xzzzzzzz_0, \
                                         tg_xxxxyz_yyyyyyyy_0, tg_xxxxyz_yyyyyyyz_0, tg_xxxxyz_yyyyyyzz_0, tg_xxxxyz_yyyyyzzz_0, \
                                         tg_xxxxyz_yyyyzzzz_0, tg_xxxxyz_yyyzzzzz_0, tg_xxxxyz_yyzzzzzz_0, tg_xxxxyz_yzzzzzzz_0, \
                                         tg_xxxxyz_zzzzzzzz_0, tg_xxxxzz_xxxxxxxx_0, tg_xxxxzz_xxxxxxxy_0, tg_xxxxzz_xxxxxxxz_0, \
                                         tg_xxxxzz_xxxxxxyy_0, tg_xxxxzz_xxxxxxyz_0, tg_xxxxzz_xxxxxxzz_0, tg_xxxxzz_xxxxxyyy_0, \
                                         tg_xxxxzz_xxxxxyyz_0, tg_xxxxzz_xxxxxyzz_0, tg_xxxxzz_xxxxxzzz_0, tg_xxxxzz_xxxxyyyy_0, \
                                         tg_xxxxzz_xxxxyyyz_0, tg_xxxxzz_xxxxyyzz_0, tg_xxxxzz_xxxxyzzz_0, tg_xxxxzz_xxxxzzzz_0, \
                                         tg_xxxxzz_xxxyyyyy_0, tg_xxxxzz_xxxyyyyz_0, tg_xxxxzz_xxxyyyzz_0, tg_xxxxzz_xxxyyzzz_0, \
                                         tg_xxxxzz_xxxyzzzz_0, tg_xxxxzz_xxxzzzzz_0, tg_xxxxzz_xxyyyyyy_0, tg_xxxxzz_xxyyyyyz_0, \
                                         tg_xxxxzz_xxyyyyzz_0, tg_xxxxzz_xxyyyzzz_0, tg_xxxxzz_xxyyzzzz_0, tg_xxxxzz_xxyzzzzz_0, \
                                         tg_xxxxzz_xxzzzzzz_0, tg_xxxxzz_xyyyyyyy_0, tg_xxxxzz_xyyyyyyz_0, tg_xxxxzz_xyyyyyzz_0, \
                                         tg_xxxxzz_xyyyyzzz_0, tg_xxxxzz_xyyyzzzz_0, tg_xxxxzz_xyyzzzzz_0, tg_xxxxzz_xyzzzzzz_0, \
                                         tg_xxxxzz_xzzzzzzz_0, tg_xxxxzz_yyyyyyyy_0, tg_xxxxzz_yyyyyyyz_0, tg_xxxxzz_yyyyyyzz_0, \
                                         tg_xxxxzz_yyyyyzzz_0, tg_xxxxzz_yyyyzzzz_0, tg_xxxxzz_yyyzzzzz_0, tg_xxxxzz_yyzzzzzz_0, \
                                         tg_xxxxzz_yzzzzzzz_0, tg_xxxxzz_zzzzzzzz_0, tg_xxxyyy_xxxxxxxx_0, tg_xxxyyy_xxxxxxxy_0, \
                                         tg_xxxyyy_xxxxxxxz_0, tg_xxxyyy_xxxxxxyy_0, tg_xxxyyy_xxxxxxyz_0, tg_xxxyyy_xxxxxxzz_0, \
                                         tg_xxxyyy_xxxxxyyy_0, tg_xxxyyy_xxxxxyyz_0, tg_xxxyyy_xxxxxyzz_0, tg_xxxyyy_xxxxxzzz_0, \
                                         tg_xxxyyy_xxxxyyyy_0, tg_xxxyyy_xxxxyyyz_0, tg_xxxyyy_xxxxyyzz_0, tg_xxxyyy_xxxxyzzz_0, \
                                         tg_xxxyyy_xxxxzzzz_0, tg_xxxyyy_xxxyyyyy_0, tg_xxxyyy_xxxyyyyz_0, tg_xxxyyy_xxxyyyzz_0, \
                                         tg_xxxyyy_xxxyyzzz_0, tg_xxxyyy_xxxyzzzz_0, tg_xxxyyy_xxxzzzzz_0, tg_xxxyz_xxxxzzzz_0, \
                                         tg_xxxyz_xxxxzzzz_1, tg_xxxyz_xxxyyyyy_0, tg_xxxyz_xxxyyyyy_1, tg_xxxyz_xxxyyyyz_0, \
                                         tg_xxxyz_xxxyyyyz_1, tg_xxxyz_xxxyyyzz_0, tg_xxxyz_xxxyyyzz_1, tg_xxxyz_xxxyyzzz_0, \
                                         tg_xxxyz_xxxyyzzz_1, tg_xxxyz_xxxyzzzz_0, tg_xxxyz_xxxyzzzz_1, tg_xxxyz_xxxzzzz_1, \
                                         tg_xxxyz_xxxzzzzz_0, tg_xxxyz_xxxzzzzz_1, tg_xxxyz_xxyyyyy_1, tg_xxxyz_xxyyyyyy_0, \
                                         tg_xxxyz_xxyyyyyy_1, tg_xxxyz_xxyyyyyz_0, tg_xxxyz_xxyyyyyz_1, tg_xxxyz_xxyyyyz_1, \
                                         tg_xxxyz_xxyyyyzz_0, tg_xxxyz_xxyyyyzz_1, tg_xxxyz_xxyyyzz_1, tg_xxxyz_xxyyyzzz_0, \
                                         tg_xxxyz_xxyyyzzz_1, tg_xxxyz_xxyyzzz_1, tg_xxxyz_xxyyzzzz_0, tg_xxxyz_xxyyzzzz_1, \
                                         tg_xxxyz_xxyzzzz_1, tg_xxxyz_xxyzzzzz_0, tg_xxxyz_xxyzzzzz_1, tg_xxxyz_xxzzzzz_1, \
                                         tg_xxxyz_xxzzzzzz_0, tg_xxxyz_xxzzzzzz_1, tg_xxxyz_xyyyyyy_1, tg_xxxyz_xyyyyyyy_0, \
                                         tg_xxxyz_xyyyyyyy_1, tg_xxxyz_xyyyyyyz_0, tg_xxxyz_xyyyyyyz_1, tg_xxxyz_xyyyyyz_1, \
                                         tg_xxxyz_xyyyyyzz_0, tg_xxxyz_xyyyyyzz_1, tg_xxxyz_xyyyyzz_1, tg_xxxyz_xyyyyzzz_0, \
                                         tg_xxxyz_xyyyyzzz_1, tg_xxxyz_xyyyzzz_1, tg_xxxyz_xyyyzzzz_0, tg_xxxyz_xyyyzzzz_1, \
                                         tg_xxxyz_xyyzzzz_1, tg_xxxyz_xyyzzzzz_0, tg_xxxyz_xyyzzzzz_1, tg_xxxyz_xyzzzzz_1, \
                                         tg_xxxyz_xyzzzzzz_0, tg_xxxyz_xyzzzzzz_1, tg_xxxyz_xzzzzzz_1, tg_xxxyz_xzzzzzzz_0, \
                                         tg_xxxyz_xzzzzzzz_1, tg_xxxyz_yyyyyyy_1, tg_xxxyz_yyyyyyyy_0, tg_xxxyz_yyyyyyyy_1, \
                                         tg_xxxyz_yyyyyyyz_0, tg_xxxyz_yyyyyyyz_1, tg_xxxyz_yyyyyyz_1, tg_xxxyz_yyyyyyzz_0, \
                                         tg_xxxyz_yyyyyyzz_1, tg_xxxyz_yyyyyzz_1, tg_xxxyz_yyyyyzzz_0, tg_xxxyz_yyyyyzzz_1, \
                                         tg_xxxyz_yyyyzzz_1, tg_xxxyz_yyyyzzzz_0, tg_xxxyz_yyyyzzzz_1, tg_xxxyz_yyyzzzz_1, \
                                         tg_xxxyz_yyyzzzzz_0, tg_xxxyz_yyyzzzzz_1, tg_xxxyz_yyzzzzz_1, tg_xxxyz_yyzzzzzz_0, \
                                         tg_xxxyz_yyzzzzzz_1, tg_xxxyz_yzzzzzz_1, tg_xxxyz_yzzzzzzz_0, tg_xxxyz_yzzzzzzz_1, \
                                         tg_xxxyz_zzzzzzz_1, tg_xxxyz_zzzzzzzz_0, tg_xxxyz_zzzzzzzz_1, tg_xxxzz_xxxxxxx_1, \
                                         tg_xxxzz_xxxxxxxx_0, tg_xxxzz_xxxxxxxx_1, tg_xxxzz_xxxxxxxy_0, tg_xxxzz_xxxxxxxy_1, \
                                         tg_xxxzz_xxxxxxxz_0, tg_xxxzz_xxxxxxxz_1, tg_xxxzz_xxxxxxy_1, tg_xxxzz_xxxxxxyy_0, \
                                         tg_xxxzz_xxxxxxyy_1, tg_xxxzz_xxxxxxyz_0, tg_xxxzz_xxxxxxyz_1, tg_xxxzz_xxxxxxz_1, \
                                         tg_xxxzz_xxxxxxzz_0, tg_xxxzz_xxxxxxzz_1, tg_xxxzz_xxxxxyy_1, tg_xxxzz_xxxxxyyy_0, \
                                         tg_xxxzz_xxxxxyyy_1, tg_xxxzz_xxxxxyyz_0, tg_xxxzz_xxxxxyyz_1, tg_xxxzz_xxxxxyz_1, \
                                         tg_xxxzz_xxxxxyzz_0, tg_xxxzz_xxxxxyzz_1, tg_xxxzz_xxxxxzz_1, tg_xxxzz_xxxxxzzz_0, \
                                         tg_xxxzz_xxxxxzzz_1, tg_xxxzz_xxxxyyy_1, tg_xxxzz_xxxxyyyy_0, tg_xxxzz_xxxxyyyy_1, \
                                         tg_xxxzz_xxxxyyyz_0, tg_xxxzz_xxxxyyyz_1, tg_xxxzz_xxxxyyz_1, tg_xxxzz_xxxxyyzz_0, \
                                         tg_xxxzz_xxxxyyzz_1, tg_xxxzz_xxxxyzz_1, tg_xxxzz_xxxxyzzz_0, tg_xxxzz_xxxxyzzz_1, \
                                         tg_xxxzz_xxxxzzz_1, tg_xxxzz_xxxxzzzz_0, tg_xxxzz_xxxxzzzz_1, tg_xxxzz_xxxyyyy_1, \
                                         tg_xxxzz_xxxyyyyy_0, tg_xxxzz_xxxyyyyy_1, tg_xxxzz_xxxyyyyz_0, tg_xxxzz_xxxyyyyz_1, \
                                         tg_xxxzz_xxxyyyz_1, tg_xxxzz_xxxyyyzz_0, tg_xxxzz_xxxyyyzz_1, tg_xxxzz_xxxyyzz_1, \
                                         tg_xxxzz_xxxyyzzz_0, tg_xxxzz_xxxyyzzz_1, tg_xxxzz_xxxyzzz_1, tg_xxxzz_xxxyzzzz_0, \
                                         tg_xxxzz_xxxyzzzz_1, tg_xxxzz_xxxzzzz_1, tg_xxxzz_xxxzzzzz_0, tg_xxxzz_xxxzzzzz_1, \
                                         tg_xxxzz_xxyyyyy_1, tg_xxxzz_xxyyyyyy_0, tg_xxxzz_xxyyyyyy_1, tg_xxxzz_xxyyyyyz_0, \
                                         tg_xxxzz_xxyyyyyz_1, tg_xxxzz_xxyyyyz_1, tg_xxxzz_xxyyyyzz_0, tg_xxxzz_xxyyyyzz_1, \
                                         tg_xxxzz_xxyyyzz_1, tg_xxxzz_xxyyyzzz_0, tg_xxxzz_xxyyyzzz_1, tg_xxxzz_xxyyzzz_1, \
                                         tg_xxxzz_xxyyzzzz_0, tg_xxxzz_xxyyzzzz_1, tg_xxxzz_xxyzzzz_1, tg_xxxzz_xxyzzzzz_0, \
                                         tg_xxxzz_xxyzzzzz_1, tg_xxxzz_xxzzzzz_1, tg_xxxzz_xxzzzzzz_0, tg_xxxzz_xxzzzzzz_1, \
                                         tg_xxxzz_xyyyyyy_1, tg_xxxzz_xyyyyyyy_0, tg_xxxzz_xyyyyyyy_1, tg_xxxzz_xyyyyyyz_0, \
                                         tg_xxxzz_xyyyyyyz_1, tg_xxxzz_xyyyyyz_1, tg_xxxzz_xyyyyyzz_0, tg_xxxzz_xyyyyyzz_1, \
                                         tg_xxxzz_xyyyyzz_1, tg_xxxzz_xyyyyzzz_0, tg_xxxzz_xyyyyzzz_1, tg_xxxzz_xyyyzzz_1, \
                                         tg_xxxzz_xyyyzzzz_0, tg_xxxzz_xyyyzzzz_1, tg_xxxzz_xyyzzzz_1, tg_xxxzz_xyyzzzzz_0, \
                                         tg_xxxzz_xyyzzzzz_1, tg_xxxzz_xyzzzzz_1, tg_xxxzz_xyzzzzzz_0, tg_xxxzz_xyzzzzzz_1, \
                                         tg_xxxzz_xzzzzzz_1, tg_xxxzz_xzzzzzzz_0, tg_xxxzz_xzzzzzzz_1, tg_xxxzz_yyyyyyy_1, \
                                         tg_xxxzz_yyyyyyyy_0, tg_xxxzz_yyyyyyyy_1, tg_xxxzz_yyyyyyyz_0, tg_xxxzz_yyyyyyyz_1, \
                                         tg_xxxzz_yyyyyyz_1, tg_xxxzz_yyyyyyzz_0, tg_xxxzz_yyyyyyzz_1, tg_xxxzz_yyyyyzz_1, \
                                         tg_xxxzz_yyyyyzzz_0, tg_xxxzz_yyyyyzzz_1, tg_xxxzz_yyyyzzz_1, tg_xxxzz_yyyyzzzz_0, \
                                         tg_xxxzz_yyyyzzzz_1, tg_xxxzz_yyyzzzz_1, tg_xxxzz_yyyzzzzz_0, tg_xxxzz_yyyzzzzz_1, \
                                         tg_xxxzz_yyzzzzz_1, tg_xxxzz_yyzzzzzz_0, tg_xxxzz_yyzzzzzz_1, tg_xxxzz_yzzzzzz_1, \
                                         tg_xxxzz_yzzzzzzz_0, tg_xxxzz_yzzzzzzz_1, tg_xxxzz_zzzzzzz_1, tg_xxxzz_zzzzzzzz_0, \
                                         tg_xxxzz_zzzzzzzz_1, tg_xxyyy_xxxxxxx_1, tg_xxyyy_xxxxxxxx_0, tg_xxyyy_xxxxxxxx_1, \
                                         tg_xxyyy_xxxxxxxy_0, tg_xxyyy_xxxxxxxy_1, tg_xxyyy_xxxxxxxz_0, tg_xxyyy_xxxxxxxz_1, \
                                         tg_xxyyy_xxxxxxy_1, tg_xxyyy_xxxxxxyy_0, tg_xxyyy_xxxxxxyy_1, tg_xxyyy_xxxxxxyz_0, \
                                         tg_xxyyy_xxxxxxyz_1, tg_xxyyy_xxxxxxz_1, tg_xxyyy_xxxxxxzz_0, tg_xxyyy_xxxxxxzz_1, \
                                         tg_xxyyy_xxxxxyy_1, tg_xxyyy_xxxxxyyy_0, tg_xxyyy_xxxxxyyy_1, tg_xxyyy_xxxxxyyz_0, \
                                         tg_xxyyy_xxxxxyyz_1, tg_xxyyy_xxxxxyz_1, tg_xxyyy_xxxxxyzz_0, tg_xxyyy_xxxxxyzz_1, \
                                         tg_xxyyy_xxxxxzz_1, tg_xxyyy_xxxxxzzz_0, tg_xxyyy_xxxxxzzz_1, tg_xxyyy_xxxxyyy_1, \
                                         tg_xxyyy_xxxxyyyy_0, tg_xxyyy_xxxxyyyy_1, tg_xxyyy_xxxxyyyz_0, tg_xxyyy_xxxxyyyz_1, \
                                         tg_xxyyy_xxxxyyz_1, tg_xxyyy_xxxxyyzz_0, tg_xxyyy_xxxxyyzz_1, tg_xxyyy_xxxxyzz_1, \
                                         tg_xxyyy_xxxxyzzz_0, tg_xxyyy_xxxxyzzz_1, tg_xxyyy_xxxxzzz_1, tg_xxyyy_xxxxzzzz_0, \
                                         tg_xxyyy_xxxxzzzz_1, tg_xxyyy_xxxyyyy_1, tg_xxyyy_xxxyyyyy_0, tg_xxyyy_xxxyyyyy_1, \
                                         tg_xxyyy_xxxyyyyz_0, tg_xxyyy_xxxyyyyz_1, tg_xxyyy_xxxyyyz_1, tg_xxyyy_xxxyyyzz_0, \
                                         tg_xxyyy_xxxyyyzz_1, tg_xxyyy_xxxyyzz_1, tg_xxyyy_xxxyyzzz_0, tg_xxyyy_xxxyyzzz_1, \
                                         tg_xxyyy_xxxyzzz_1, tg_xxyyy_xxxyzzzz_0, tg_xxyyy_xxxyzzzz_1, tg_xxyyy_xxxzzzz_1, \
                                         tg_xxyyy_xxxzzzzz_0, tg_xxyyy_xxxzzzzz_1, tg_xxyyy_xxyyyyy_1, tg_xxyyy_xxyyyyz_1, \
                                         tg_xxyyy_xxyyyzz_1, tg_xxyyy_xxyyzzz_1, tg_xxyyy_xxyzzzz_1, tg_xxyyy_xxzzzzz_1, \
                                         tg_xxyz_xxxxzzzz_0, tg_xxyz_xxxxzzzz_1, tg_xxyz_xxxyyyyy_0, tg_xxyz_xxxyyyyy_1, \
                                         tg_xxyz_xxxyyyyz_0, tg_xxyz_xxxyyyyz_1, tg_xxyz_xxxyyyzz_0, tg_xxyz_xxxyyyzz_1, \
                                         tg_xxyz_xxxyyzzz_0, tg_xxyz_xxxyyzzz_1, tg_xxyz_xxxyzzzz_0, tg_xxyz_xxxyzzzz_1, \
                                         tg_xxyz_xxxzzzzz_0, tg_xxyz_xxxzzzzz_1, tg_xxyz_xxyyyyyy_0, tg_xxyz_xxyyyyyy_1, \
                                         tg_xxyz_xxyyyyyz_0, tg_xxyz_xxyyyyyz_1, tg_xxyz_xxyyyyzz_0, tg_xxyz_xxyyyyzz_1, \
                                         tg_xxyz_xxyyyzzz_0, tg_xxyz_xxyyyzzz_1, tg_xxyz_xxyyzzzz_0, tg_xxyz_xxyyzzzz_1, \
                                         tg_xxyz_xxyzzzzz_0, tg_xxyz_xxyzzzzz_1, tg_xxyz_xxzzzzzz_0, tg_xxyz_xxzzzzzz_1, \
                                         tg_xxyz_xyyyyyyy_0, tg_xxyz_xyyyyyyy_1, tg_xxyz_xyyyyyyz_0, tg_xxyz_xyyyyyyz_1, \
                                         tg_xxyz_xyyyyyzz_0, tg_xxyz_xyyyyyzz_1, tg_xxyz_xyyyyzzz_0, tg_xxyz_xyyyyzzz_1, \
                                         tg_xxyz_xyyyzzzz_0, tg_xxyz_xyyyzzzz_1, tg_xxyz_xyyzzzzz_0, tg_xxyz_xyyzzzzz_1, \
                                         tg_xxyz_xyzzzzzz_0, tg_xxyz_xyzzzzzz_1, tg_xxyz_xzzzzzzz_0, tg_xxyz_xzzzzzzz_1, \
                                         tg_xxyz_yyyyyyyy_0, tg_xxyz_yyyyyyyy_1, tg_xxyz_yyyyyyyz_0, tg_xxyz_yyyyyyyz_1, \
                                         tg_xxyz_yyyyyyzz_0, tg_xxyz_yyyyyyzz_1, tg_xxyz_yyyyyzzz_0, tg_xxyz_yyyyyzzz_1, \
                                         tg_xxyz_yyyyzzzz_0, tg_xxyz_yyyyzzzz_1, tg_xxyz_yyyzzzzz_0, tg_xxyz_yyyzzzzz_1, \
                                         tg_xxyz_yyzzzzzz_0, tg_xxyz_yyzzzzzz_1, tg_xxyz_yzzzzzzz_0, tg_xxyz_yzzzzzzz_1, \
                                         tg_xxyz_zzzzzzzz_0, tg_xxyz_zzzzzzzz_1, tg_xxzz_xxxxxxxx_0, tg_xxzz_xxxxxxxx_1, \
                                         tg_xxzz_xxxxxxxy_0, tg_xxzz_xxxxxxxy_1, tg_xxzz_xxxxxxxz_0, tg_xxzz_xxxxxxxz_1, \
                                         tg_xxzz_xxxxxxyy_0, tg_xxzz_xxxxxxyy_1, tg_xxzz_xxxxxxyz_0, tg_xxzz_xxxxxxyz_1, \
                                         tg_xxzz_xxxxxxzz_0, tg_xxzz_xxxxxxzz_1, tg_xxzz_xxxxxyyy_0, tg_xxzz_xxxxxyyy_1, \
                                         tg_xxzz_xxxxxyyz_0, tg_xxzz_xxxxxyyz_1, tg_xxzz_xxxxxyzz_0, tg_xxzz_xxxxxyzz_1, \
                                         tg_xxzz_xxxxxzzz_0, tg_xxzz_xxxxxzzz_1, tg_xxzz_xxxxyyyy_0, tg_xxzz_xxxxyyyy_1, \
                                         tg_xxzz_xxxxyyyz_0, tg_xxzz_xxxxyyyz_1, tg_xxzz_xxxxyyzz_0, tg_xxzz_xxxxyyzz_1, \
                                         tg_xxzz_xxxxyzzz_0, tg_xxzz_xxxxyzzz_1, tg_xxzz_xxxxzzzz_0, tg_xxzz_xxxxzzzz_1, \
                                         tg_xxzz_xxxyyyyy_0, tg_xxzz_xxxyyyyy_1, tg_xxzz_xxxyyyyz_0, tg_xxzz_xxxyyyyz_1, \
                                         tg_xxzz_xxxyyyzz_0, tg_xxzz_xxxyyyzz_1, tg_xxzz_xxxyyzzz_0, tg_xxzz_xxxyyzzz_1, \
                                         tg_xxzz_xxxyzzzz_0, tg_xxzz_xxxyzzzz_1, tg_xxzz_xxxzzzzz_0, tg_xxzz_xxxzzzzz_1, \
                                         tg_xxzz_xxyyyyyy_0, tg_xxzz_xxyyyyyy_1, tg_xxzz_xxyyyyyz_0, tg_xxzz_xxyyyyyz_1, \
                                         tg_xxzz_xxyyyyzz_0, tg_xxzz_xxyyyyzz_1, tg_xxzz_xxyyyzzz_0, tg_xxzz_xxyyyzzz_1, \
                                         tg_xxzz_xxyyzzzz_0, tg_xxzz_xxyyzzzz_1, tg_xxzz_xxyzzzzz_0, tg_xxzz_xxyzzzzz_1, \
                                         tg_xxzz_xxzzzzzz_0, tg_xxzz_xxzzzzzz_1, tg_xxzz_xyyyyyyy_0, tg_xxzz_xyyyyyyy_1, \
                                         tg_xxzz_xyyyyyyz_0, tg_xxzz_xyyyyyyz_1, tg_xxzz_xyyyyyzz_0, tg_xxzz_xyyyyyzz_1, \
                                         tg_xxzz_xyyyyzzz_0, tg_xxzz_xyyyyzzz_1, tg_xxzz_xyyyzzzz_0, tg_xxzz_xyyyzzzz_1, \
                                         tg_xxzz_xyyzzzzz_0, tg_xxzz_xyyzzzzz_1, tg_xxzz_xyzzzzzz_0, tg_xxzz_xyzzzzzz_1, \
                                         tg_xxzz_xzzzzzzz_0, tg_xxzz_xzzzzzzz_1, tg_xxzz_yyyyyyyy_0, tg_xxzz_yyyyyyyy_1, \
                                         tg_xxzz_yyyyyyyz_0, tg_xxzz_yyyyyyyz_1, tg_xxzz_yyyyyyzz_0, tg_xxzz_yyyyyyzz_1, \
                                         tg_xxzz_yyyyyzzz_0, tg_xxzz_yyyyyzzz_1, tg_xxzz_yyyyzzzz_0, tg_xxzz_yyyyzzzz_1, \
                                         tg_xxzz_yyyzzzzz_0, tg_xxzz_yyyzzzzz_1, tg_xxzz_yyzzzzzz_0, tg_xxzz_yyzzzzzz_1, \
                                         tg_xxzz_yzzzzzzz_0, tg_xxzz_yzzzzzzz_1, tg_xxzz_zzzzzzzz_0, tg_xxzz_zzzzzzzz_1, \
                                         tg_xyyy_xxxxxxxx_0, tg_xyyy_xxxxxxxx_1, tg_xyyy_xxxxxxxy_0, tg_xyyy_xxxxxxxy_1, \
                                         tg_xyyy_xxxxxxxz_0, tg_xyyy_xxxxxxxz_1, tg_xyyy_xxxxxxyy_0, tg_xyyy_xxxxxxyy_1, \
                                         tg_xyyy_xxxxxxyz_0, tg_xyyy_xxxxxxyz_1, tg_xyyy_xxxxxxzz_0, tg_xyyy_xxxxxxzz_1, \
                                         tg_xyyy_xxxxxyyy_0, tg_xyyy_xxxxxyyy_1, tg_xyyy_xxxxxyyz_0, tg_xyyy_xxxxxyyz_1, \
                                         tg_xyyy_xxxxxyzz_0, tg_xyyy_xxxxxyzz_1, tg_xyyy_xxxxxzzz_0, tg_xyyy_xxxxxzzz_1, \
                                         tg_xyyy_xxxxyyyy_0, tg_xyyy_xxxxyyyy_1, tg_xyyy_xxxxyyyz_0, tg_xyyy_xxxxyyyz_1, \
                                         tg_xyyy_xxxxyyzz_0, tg_xyyy_xxxxyyzz_1, tg_xyyy_xxxxyzzz_0, tg_xyyy_xxxxyzzz_1, \
                                         tg_xyyy_xxxxzzzz_0, tg_xyyy_xxxxzzzz_1, tg_xyyy_xxxyyyyy_0, tg_xyyy_xxxyyyyy_1, \
                                         tg_xyyy_xxxyyyyz_0, tg_xyyy_xxxyyyyz_1, tg_xyyy_xxxyyyzz_0, tg_xyyy_xxxyyyzz_1, \
                                         tg_xyyy_xxxyyzzz_0, tg_xyyy_xxxyyzzz_1, tg_xyyy_xxxyzzzz_0, tg_xyyy_xxxyzzzz_1, \
                                         tg_xyyy_xxxzzzzz_0, tg_xyyy_xxxzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxyz_xxxxzzzz_0[j] = pb_x * tg_xxxyz_xxxxzzzz_0[j] + fr * tg_xxxyz_xxxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxxzzzz_0[j] - tg_xxyz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyz_xxxzzzz_1[j];

                    tg_xxxxyz_xxxyyyyy_0[j] = pb_x * tg_xxxyz_xxxyyyyy_0[j] + fr * tg_xxxyz_xxxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxyyyyy_0[j] - tg_xxyz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxyyyyy_1[j];

                    tg_xxxxyz_xxxyyyyz_0[j] = pb_x * tg_xxxyz_xxxyyyyz_0[j] + fr * tg_xxxyz_xxxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxyyyyz_0[j] - tg_xxyz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxyyyyz_1[j];

                    tg_xxxxyz_xxxyyyzz_0[j] = pb_x * tg_xxxyz_xxxyyyzz_0[j] + fr * tg_xxxyz_xxxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxyyyzz_0[j] - tg_xxyz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxyyyzz_1[j];

                    tg_xxxxyz_xxxyyzzz_0[j] = pb_x * tg_xxxyz_xxxyyzzz_0[j] + fr * tg_xxxyz_xxxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxyyzzz_0[j] - tg_xxyz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxyyzzz_1[j];

                    tg_xxxxyz_xxxyzzzz_0[j] = pb_x * tg_xxxyz_xxxyzzzz_0[j] + fr * tg_xxxyz_xxxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxyzzzz_0[j] - tg_xxyz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxyzzzz_1[j];

                    tg_xxxxyz_xxxzzzzz_0[j] = pb_x * tg_xxxyz_xxxzzzzz_0[j] + fr * tg_xxxyz_xxxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxxzzzzz_0[j] - tg_xxyz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyz_xxzzzzz_1[j];

                    tg_xxxxyz_xxyyyyyy_0[j] = pb_x * tg_xxxyz_xxyyyyyy_0[j] + fr * tg_xxxyz_xxyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyyyyyy_0[j] - tg_xxyz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyyyyyy_1[j];

                    tg_xxxxyz_xxyyyyyz_0[j] = pb_x * tg_xxxyz_xxyyyyyz_0[j] + fr * tg_xxxyz_xxyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyyyyyz_0[j] - tg_xxyz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyyyyyz_1[j];

                    tg_xxxxyz_xxyyyyzz_0[j] = pb_x * tg_xxxyz_xxyyyyzz_0[j] + fr * tg_xxxyz_xxyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyyyyzz_0[j] - tg_xxyz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyyyyzz_1[j];

                    tg_xxxxyz_xxyyyzzz_0[j] = pb_x * tg_xxxyz_xxyyyzzz_0[j] + fr * tg_xxxyz_xxyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyyyzzz_0[j] - tg_xxyz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyyyzzz_1[j];

                    tg_xxxxyz_xxyyzzzz_0[j] = pb_x * tg_xxxyz_xxyyzzzz_0[j] + fr * tg_xxxyz_xxyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyyzzzz_0[j] - tg_xxyz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyyzzzz_1[j];

                    tg_xxxxyz_xxyzzzzz_0[j] = pb_x * tg_xxxyz_xxyzzzzz_0[j] + fr * tg_xxxyz_xxyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxyzzzzz_0[j] - tg_xxyz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xyzzzzz_1[j];

                    tg_xxxxyz_xxzzzzzz_0[j] = pb_x * tg_xxxyz_xxzzzzzz_0[j] + fr * tg_xxxyz_xxzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xxzzzzzz_0[j] - tg_xxyz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyz_xzzzzzz_1[j];

                    tg_xxxxyz_xyyyyyyy_0[j] = pb_x * tg_xxxyz_xyyyyyyy_0[j] + fr * tg_xxxyz_xyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyyyyyy_0[j] - tg_xxyz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyyyyyy_1[j];

                    tg_xxxxyz_xyyyyyyz_0[j] = pb_x * tg_xxxyz_xyyyyyyz_0[j] + fr * tg_xxxyz_xyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyyyyyz_0[j] - tg_xxyz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyyyyyz_1[j];

                    tg_xxxxyz_xyyyyyzz_0[j] = pb_x * tg_xxxyz_xyyyyyzz_0[j] + fr * tg_xxxyz_xyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyyyyzz_0[j] - tg_xxyz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyyyyzz_1[j];

                    tg_xxxxyz_xyyyyzzz_0[j] = pb_x * tg_xxxyz_xyyyyzzz_0[j] + fr * tg_xxxyz_xyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyyyzzz_0[j] - tg_xxyz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyyyzzz_1[j];

                    tg_xxxxyz_xyyyzzzz_0[j] = pb_x * tg_xxxyz_xyyyzzzz_0[j] + fr * tg_xxxyz_xyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyyzzzz_0[j] - tg_xxyz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyyzzzz_1[j];

                    tg_xxxxyz_xyyzzzzz_0[j] = pb_x * tg_xxxyz_xyyzzzzz_0[j] + fr * tg_xxxyz_xyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyyzzzzz_0[j] - tg_xxyz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yyzzzzz_1[j];

                    tg_xxxxyz_xyzzzzzz_0[j] = pb_x * tg_xxxyz_xyzzzzzz_0[j] + fr * tg_xxxyz_xyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xyzzzzzz_0[j] - tg_xxyz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_yzzzzzz_1[j];

                    tg_xxxxyz_xzzzzzzz_0[j] = pb_x * tg_xxxyz_xzzzzzzz_0[j] + fr * tg_xxxyz_xzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_xzzzzzzz_0[j] - tg_xxyz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyz_zzzzzzz_1[j];

                    tg_xxxxyz_yyyyyyyy_0[j] = pb_x * tg_xxxyz_yyyyyyyy_0[j] + fr * tg_xxxyz_yyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyyyyyy_0[j] - tg_xxyz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxyz_yyyyyyyz_0[j] = pb_x * tg_xxxyz_yyyyyyyz_0[j] + fr * tg_xxxyz_yyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyyyyyz_0[j] - tg_xxyz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxyz_yyyyyyzz_0[j] = pb_x * tg_xxxyz_yyyyyyzz_0[j] + fr * tg_xxxyz_yyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyyyyzz_0[j] - tg_xxyz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxyz_yyyyyzzz_0[j] = pb_x * tg_xxxyz_yyyyyzzz_0[j] + fr * tg_xxxyz_yyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyyyzzz_0[j] - tg_xxyz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxyz_yyyyzzzz_0[j] = pb_x * tg_xxxyz_yyyyzzzz_0[j] + fr * tg_xxxyz_yyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyyzzzz_0[j] - tg_xxyz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxyz_yyyzzzzz_0[j] = pb_x * tg_xxxyz_yyyzzzzz_0[j] + fr * tg_xxxyz_yyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyyzzzzz_0[j] - tg_xxyz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxyz_yyzzzzzz_0[j] = pb_x * tg_xxxyz_yyzzzzzz_0[j] + fr * tg_xxxyz_yyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yyzzzzzz_0[j] - tg_xxyz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyz_yzzzzzzz_0[j] = pb_x * tg_xxxyz_yzzzzzzz_0[j] + fr * tg_xxxyz_yzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_yzzzzzzz_0[j] - tg_xxyz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyz_zzzzzzzz_0[j] = pb_x * tg_xxxyz_zzzzzzzz_0[j] + fr * tg_xxxyz_zzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyz_zzzzzzzz_0[j] - tg_xxyz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxzz_xxxxxxxx_0[j] = pb_x * tg_xxxzz_xxxxxxxx_0[j] + fr * tg_xxxzz_xxxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxxx_0[j] - tg_xxzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxxzz_xxxxxxx_1[j];

                    tg_xxxxzz_xxxxxxxy_0[j] = pb_x * tg_xxxzz_xxxxxxxy_0[j] + fr * tg_xxxzz_xxxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxxy_0[j] - tg_xxzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxzz_xxxxxxy_1[j];

                    tg_xxxxzz_xxxxxxxz_0[j] = pb_x * tg_xxxzz_xxxxxxxz_0[j] + fr * tg_xxxzz_xxxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxxz_0[j] - tg_xxzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxzz_xxxxxxz_1[j];

                    tg_xxxxzz_xxxxxxyy_0[j] = pb_x * tg_xxxzz_xxxxxxyy_0[j] + fr * tg_xxxzz_xxxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxyy_0[j] - tg_xxzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzz_xxxxxyy_1[j];

                    tg_xxxxzz_xxxxxxyz_0[j] = pb_x * tg_xxxzz_xxxxxxyz_0[j] + fr * tg_xxxzz_xxxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxyz_0[j] - tg_xxzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzz_xxxxxyz_1[j];

                    tg_xxxxzz_xxxxxxzz_0[j] = pb_x * tg_xxxzz_xxxxxxzz_0[j] + fr * tg_xxxzz_xxxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxxzz_0[j] - tg_xxzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzz_xxxxxzz_1[j];

                    tg_xxxxzz_xxxxxyyy_0[j] = pb_x * tg_xxxzz_xxxxxyyy_0[j] + fr * tg_xxxzz_xxxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxyyy_0[j] - tg_xxzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzz_xxxxyyy_1[j];

                    tg_xxxxzz_xxxxxyyz_0[j] = pb_x * tg_xxxzz_xxxxxyyz_0[j] + fr * tg_xxxzz_xxxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxyyz_0[j] - tg_xxzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzz_xxxxyyz_1[j];

                    tg_xxxxzz_xxxxxyzz_0[j] = pb_x * tg_xxxzz_xxxxxyzz_0[j] + fr * tg_xxxzz_xxxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxyzz_0[j] - tg_xxzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzz_xxxxyzz_1[j];

                    tg_xxxxzz_xxxxxzzz_0[j] = pb_x * tg_xxxzz_xxxxxzzz_0[j] + fr * tg_xxxzz_xxxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxxzzz_0[j] - tg_xxzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzz_xxxxzzz_1[j];

                    tg_xxxxzz_xxxxyyyy_0[j] = pb_x * tg_xxxzz_xxxxyyyy_0[j] + fr * tg_xxxzz_xxxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxyyyy_0[j] - tg_xxzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzz_xxxyyyy_1[j];

                    tg_xxxxzz_xxxxyyyz_0[j] = pb_x * tg_xxxzz_xxxxyyyz_0[j] + fr * tg_xxxzz_xxxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxyyyz_0[j] - tg_xxzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzz_xxxyyyz_1[j];

                    tg_xxxxzz_xxxxyyzz_0[j] = pb_x * tg_xxxzz_xxxxyyzz_0[j] + fr * tg_xxxzz_xxxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxyyzz_0[j] - tg_xxzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzz_xxxyyzz_1[j];

                    tg_xxxxzz_xxxxyzzz_0[j] = pb_x * tg_xxxzz_xxxxyzzz_0[j] + fr * tg_xxxzz_xxxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxyzzz_0[j] - tg_xxzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzz_xxxyzzz_1[j];

                    tg_xxxxzz_xxxxzzzz_0[j] = pb_x * tg_xxxzz_xxxxzzzz_0[j] + fr * tg_xxxzz_xxxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxxzzzz_0[j] - tg_xxzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzz_xxxzzzz_1[j];

                    tg_xxxxzz_xxxyyyyy_0[j] = pb_x * tg_xxxzz_xxxyyyyy_0[j] + fr * tg_xxxzz_xxxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxyyyyy_0[j] - tg_xxzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxyyyyy_1[j];

                    tg_xxxxzz_xxxyyyyz_0[j] = pb_x * tg_xxxzz_xxxyyyyz_0[j] + fr * tg_xxxzz_xxxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxyyyyz_0[j] - tg_xxzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxyyyyz_1[j];

                    tg_xxxxzz_xxxyyyzz_0[j] = pb_x * tg_xxxzz_xxxyyyzz_0[j] + fr * tg_xxxzz_xxxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxyyyzz_0[j] - tg_xxzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxyyyzz_1[j];

                    tg_xxxxzz_xxxyyzzz_0[j] = pb_x * tg_xxxzz_xxxyyzzz_0[j] + fr * tg_xxxzz_xxxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxyyzzz_0[j] - tg_xxzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxyyzzz_1[j];

                    tg_xxxxzz_xxxyzzzz_0[j] = pb_x * tg_xxxzz_xxxyzzzz_0[j] + fr * tg_xxxzz_xxxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxyzzzz_0[j] - tg_xxzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxyzzzz_1[j];

                    tg_xxxxzz_xxxzzzzz_0[j] = pb_x * tg_xxxzz_xxxzzzzz_0[j] + fr * tg_xxxzz_xxxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxxzzzzz_0[j] - tg_xxzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzz_xxzzzzz_1[j];

                    tg_xxxxzz_xxyyyyyy_0[j] = pb_x * tg_xxxzz_xxyyyyyy_0[j] + fr * tg_xxxzz_xxyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyyyyyy_0[j] - tg_xxzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyyyyyy_1[j];

                    tg_xxxxzz_xxyyyyyz_0[j] = pb_x * tg_xxxzz_xxyyyyyz_0[j] + fr * tg_xxxzz_xxyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyyyyyz_0[j] - tg_xxzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyyyyyz_1[j];

                    tg_xxxxzz_xxyyyyzz_0[j] = pb_x * tg_xxxzz_xxyyyyzz_0[j] + fr * tg_xxxzz_xxyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyyyyzz_0[j] - tg_xxzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyyyyzz_1[j];

                    tg_xxxxzz_xxyyyzzz_0[j] = pb_x * tg_xxxzz_xxyyyzzz_0[j] + fr * tg_xxxzz_xxyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyyyzzz_0[j] - tg_xxzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyyyzzz_1[j];

                    tg_xxxxzz_xxyyzzzz_0[j] = pb_x * tg_xxxzz_xxyyzzzz_0[j] + fr * tg_xxxzz_xxyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyyzzzz_0[j] - tg_xxzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyyzzzz_1[j];

                    tg_xxxxzz_xxyzzzzz_0[j] = pb_x * tg_xxxzz_xxyzzzzz_0[j] + fr * tg_xxxzz_xxyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxyzzzzz_0[j] - tg_xxzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xyzzzzz_1[j];

                    tg_xxxxzz_xxzzzzzz_0[j] = pb_x * tg_xxxzz_xxzzzzzz_0[j] + fr * tg_xxxzz_xxzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xxzzzzzz_0[j] - tg_xxzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzz_xzzzzzz_1[j];

                    tg_xxxxzz_xyyyyyyy_0[j] = pb_x * tg_xxxzz_xyyyyyyy_0[j] + fr * tg_xxxzz_xyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyyyyyy_0[j] - tg_xxzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyyyyyy_1[j];

                    tg_xxxxzz_xyyyyyyz_0[j] = pb_x * tg_xxxzz_xyyyyyyz_0[j] + fr * tg_xxxzz_xyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyyyyyz_0[j] - tg_xxzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyyyyyz_1[j];

                    tg_xxxxzz_xyyyyyzz_0[j] = pb_x * tg_xxxzz_xyyyyyzz_0[j] + fr * tg_xxxzz_xyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyyyyzz_0[j] - tg_xxzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyyyyzz_1[j];

                    tg_xxxxzz_xyyyyzzz_0[j] = pb_x * tg_xxxzz_xyyyyzzz_0[j] + fr * tg_xxxzz_xyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyyyzzz_0[j] - tg_xxzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyyyzzz_1[j];

                    tg_xxxxzz_xyyyzzzz_0[j] = pb_x * tg_xxxzz_xyyyzzzz_0[j] + fr * tg_xxxzz_xyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyyzzzz_0[j] - tg_xxzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyyzzzz_1[j];

                    tg_xxxxzz_xyyzzzzz_0[j] = pb_x * tg_xxxzz_xyyzzzzz_0[j] + fr * tg_xxxzz_xyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyyzzzzz_0[j] - tg_xxzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yyzzzzz_1[j];

                    tg_xxxxzz_xyzzzzzz_0[j] = pb_x * tg_xxxzz_xyzzzzzz_0[j] + fr * tg_xxxzz_xyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xyzzzzzz_0[j] - tg_xxzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_yzzzzzz_1[j];

                    tg_xxxxzz_xzzzzzzz_0[j] = pb_x * tg_xxxzz_xzzzzzzz_0[j] + fr * tg_xxxzz_xzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_xzzzzzzz_0[j] - tg_xxzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzz_zzzzzzz_1[j];

                    tg_xxxxzz_yyyyyyyy_0[j] = pb_x * tg_xxxzz_yyyyyyyy_0[j] + fr * tg_xxxzz_yyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyyyyyy_0[j] - tg_xxzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxxzz_yyyyyyyz_0[j] = pb_x * tg_xxxzz_yyyyyyyz_0[j] + fr * tg_xxxzz_yyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyyyyyz_0[j] - tg_xxzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxxzz_yyyyyyzz_0[j] = pb_x * tg_xxxzz_yyyyyyzz_0[j] + fr * tg_xxxzz_yyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyyyyzz_0[j] - tg_xxzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxxzz_yyyyyzzz_0[j] = pb_x * tg_xxxzz_yyyyyzzz_0[j] + fr * tg_xxxzz_yyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyyyzzz_0[j] - tg_xxzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxxzz_yyyyzzzz_0[j] = pb_x * tg_xxxzz_yyyyzzzz_0[j] + fr * tg_xxxzz_yyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyyzzzz_0[j] - tg_xxzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxxzz_yyyzzzzz_0[j] = pb_x * tg_xxxzz_yyyzzzzz_0[j] + fr * tg_xxxzz_yyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyyzzzzz_0[j] - tg_xxzz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxxzz_yyzzzzzz_0[j] = pb_x * tg_xxxzz_yyzzzzzz_0[j] + fr * tg_xxxzz_yyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yyzzzzzz_0[j] - tg_xxzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxxzz_yzzzzzzz_0[j] = pb_x * tg_xxxzz_yzzzzzzz_0[j] + fr * tg_xxxzz_yzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_yzzzzzzz_0[j] - tg_xxzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxxzz_zzzzzzzz_0[j] = pb_x * tg_xxxzz_zzzzzzzz_0[j] + fr * tg_xxxzz_zzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzz_zzzzzzzz_0[j] - tg_xxzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyy_xxxxxxxx_0[j] = pb_x * tg_xxyyy_xxxxxxxx_0[j] + fr * tg_xxyyy_xxxxxxxx_1[j] + fl1_fx * (tg_xyyy_xxxxxxxx_0[j] - tg_xyyy_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxyyy_xxxxxxx_1[j];

                    tg_xxxyyy_xxxxxxxy_0[j] = pb_x * tg_xxyyy_xxxxxxxy_0[j] + fr * tg_xxyyy_xxxxxxxy_1[j] + fl1_fx * (tg_xyyy_xxxxxxxy_0[j] - tg_xyyy_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyy_xxxxxxy_1[j];

                    tg_xxxyyy_xxxxxxxz_0[j] = pb_x * tg_xxyyy_xxxxxxxz_0[j] + fr * tg_xxyyy_xxxxxxxz_1[j] + fl1_fx * (tg_xyyy_xxxxxxxz_0[j] - tg_xyyy_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyy_xxxxxxz_1[j];

                    tg_xxxyyy_xxxxxxyy_0[j] = pb_x * tg_xxyyy_xxxxxxyy_0[j] + fr * tg_xxyyy_xxxxxxyy_1[j] + fl1_fx * (tg_xyyy_xxxxxxyy_0[j] - tg_xyyy_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyy_xxxxxyy_1[j];

                    tg_xxxyyy_xxxxxxyz_0[j] = pb_x * tg_xxyyy_xxxxxxyz_0[j] + fr * tg_xxyyy_xxxxxxyz_1[j] + fl1_fx * (tg_xyyy_xxxxxxyz_0[j] - tg_xyyy_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyy_xxxxxyz_1[j];

                    tg_xxxyyy_xxxxxxzz_0[j] = pb_x * tg_xxyyy_xxxxxxzz_0[j] + fr * tg_xxyyy_xxxxxxzz_1[j] + fl1_fx * (tg_xyyy_xxxxxxzz_0[j] - tg_xyyy_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyy_xxxxxzz_1[j];

                    tg_xxxyyy_xxxxxyyy_0[j] = pb_x * tg_xxyyy_xxxxxyyy_0[j] + fr * tg_xxyyy_xxxxxyyy_1[j] + fl1_fx * (tg_xyyy_xxxxxyyy_0[j] - tg_xyyy_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyy_xxxxyyy_1[j];

                    tg_xxxyyy_xxxxxyyz_0[j] = pb_x * tg_xxyyy_xxxxxyyz_0[j] + fr * tg_xxyyy_xxxxxyyz_1[j] + fl1_fx * (tg_xyyy_xxxxxyyz_0[j] - tg_xyyy_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyy_xxxxyyz_1[j];

                    tg_xxxyyy_xxxxxyzz_0[j] = pb_x * tg_xxyyy_xxxxxyzz_0[j] + fr * tg_xxyyy_xxxxxyzz_1[j] + fl1_fx * (tg_xyyy_xxxxxyzz_0[j] - tg_xyyy_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyy_xxxxyzz_1[j];

                    tg_xxxyyy_xxxxxzzz_0[j] = pb_x * tg_xxyyy_xxxxxzzz_0[j] + fr * tg_xxyyy_xxxxxzzz_1[j] + fl1_fx * (tg_xyyy_xxxxxzzz_0[j] - tg_xyyy_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyy_xxxxzzz_1[j];

                    tg_xxxyyy_xxxxyyyy_0[j] = pb_x * tg_xxyyy_xxxxyyyy_0[j] + fr * tg_xxyyy_xxxxyyyy_1[j] + fl1_fx * (tg_xyyy_xxxxyyyy_0[j] - tg_xyyy_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyy_xxxyyyy_1[j];

                    tg_xxxyyy_xxxxyyyz_0[j] = pb_x * tg_xxyyy_xxxxyyyz_0[j] + fr * tg_xxyyy_xxxxyyyz_1[j] + fl1_fx * (tg_xyyy_xxxxyyyz_0[j] - tg_xyyy_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyy_xxxyyyz_1[j];

                    tg_xxxyyy_xxxxyyzz_0[j] = pb_x * tg_xxyyy_xxxxyyzz_0[j] + fr * tg_xxyyy_xxxxyyzz_1[j] + fl1_fx * (tg_xyyy_xxxxyyzz_0[j] - tg_xyyy_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyy_xxxyyzz_1[j];

                    tg_xxxyyy_xxxxyzzz_0[j] = pb_x * tg_xxyyy_xxxxyzzz_0[j] + fr * tg_xxyyy_xxxxyzzz_1[j] + fl1_fx * (tg_xyyy_xxxxyzzz_0[j] - tg_xyyy_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyy_xxxyzzz_1[j];

                    tg_xxxyyy_xxxxzzzz_0[j] = pb_x * tg_xxyyy_xxxxzzzz_0[j] + fr * tg_xxyyy_xxxxzzzz_1[j] + fl1_fx * (tg_xyyy_xxxxzzzz_0[j] - tg_xyyy_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyy_xxxzzzz_1[j];

                    tg_xxxyyy_xxxyyyyy_0[j] = pb_x * tg_xxyyy_xxxyyyyy_0[j] + fr * tg_xxyyy_xxxyyyyy_1[j] + fl1_fx * (tg_xyyy_xxxyyyyy_0[j] - tg_xyyy_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxyyyyy_1[j];

                    tg_xxxyyy_xxxyyyyz_0[j] = pb_x * tg_xxyyy_xxxyyyyz_0[j] + fr * tg_xxyyy_xxxyyyyz_1[j] + fl1_fx * (tg_xyyy_xxxyyyyz_0[j] - tg_xyyy_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxyyyyz_1[j];

                    tg_xxxyyy_xxxyyyzz_0[j] = pb_x * tg_xxyyy_xxxyyyzz_0[j] + fr * tg_xxyyy_xxxyyyzz_1[j] + fl1_fx * (tg_xyyy_xxxyyyzz_0[j] - tg_xyyy_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxyyyzz_1[j];

                    tg_xxxyyy_xxxyyzzz_0[j] = pb_x * tg_xxyyy_xxxyyzzz_0[j] + fr * tg_xxyyy_xxxyyzzz_1[j] + fl1_fx * (tg_xyyy_xxxyyzzz_0[j] - tg_xyyy_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxyyzzz_1[j];

                    tg_xxxyyy_xxxyzzzz_0[j] = pb_x * tg_xxyyy_xxxyzzzz_0[j] + fr * tg_xxyyy_xxxyzzzz_1[j] + fl1_fx * (tg_xyyy_xxxyzzzz_0[j] - tg_xyyy_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxyzzzz_1[j];

                    tg_xxxyyy_xxxzzzzz_0[j] = pb_x * tg_xxyyy_xxxzzzzz_0[j] + fr * tg_xxyyy_xxxzzzzz_1[j] + fl1_fx * (tg_xyyy_xxxzzzzz_0[j] - tg_xyyy_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyy_xxzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_291_388(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (291,388)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyyy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 291); 

                auto tg_xxyyy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 292); 

                auto tg_xxyyy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 293); 

                auto tg_xxyyy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 294); 

                auto tg_xxyyy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 295); 

                auto tg_xxyyy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 296); 

                auto tg_xxyyy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 297); 

                auto tg_xxyyy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 298); 

                auto tg_xxyyy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 299); 

                auto tg_xxyyy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 300); 

                auto tg_xxyyy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 301); 

                auto tg_xxyyy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 302); 

                auto tg_xxyyy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 303); 

                auto tg_xxyyy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 304); 

                auto tg_xxyyy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 305); 

                auto tg_xxyyy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 306); 

                auto tg_xxyyy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 307); 

                auto tg_xxyyy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 308); 

                auto tg_xxyyy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 309); 

                auto tg_xxyyy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 310); 

                auto tg_xxyyy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 311); 

                auto tg_xxyyy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 312); 

                auto tg_xxyyy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 313); 

                auto tg_xxyyy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 314); 

                auto tg_xxyyz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 315); 

                auto tg_xxyyz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 316); 

                auto tg_xxyyz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 317); 

                auto tg_xxyyz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 318); 

                auto tg_xxyyz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 319); 

                auto tg_xxyyz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 320); 

                auto tg_xxyyz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 321); 

                auto tg_xxyyz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 322); 

                auto tg_xxyyz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 323); 

                auto tg_xxyyz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 324); 

                auto tg_xxyyz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 325); 

                auto tg_xxyyz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 326); 

                auto tg_xxyyz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 327); 

                auto tg_xxyyz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 328); 

                auto tg_xxyyz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 329); 

                auto tg_xxyyz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 330); 

                auto tg_xxyyz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 331); 

                auto tg_xxyyz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 332); 

                auto tg_xxyyz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 333); 

                auto tg_xxyyz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 334); 

                auto tg_xxyyz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 335); 

                auto tg_xxyyz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 336); 

                auto tg_xxyyz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 337); 

                auto tg_xxyyz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 338); 

                auto tg_xxyyz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 339); 

                auto tg_xxyyz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 340); 

                auto tg_xxyyz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 341); 

                auto tg_xxyyz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 342); 

                auto tg_xxyyz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 343); 

                auto tg_xxyyz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 344); 

                auto tg_xxyyz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 345); 

                auto tg_xxyyz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 346); 

                auto tg_xxyyz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 347); 

                auto tg_xxyyz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 348); 

                auto tg_xxyyz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 349); 

                auto tg_xxyyz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 350); 

                auto tg_xxyyz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 351); 

                auto tg_xxyyz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 352); 

                auto tg_xxyyz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 353); 

                auto tg_xxyyz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 354); 

                auto tg_xxyyz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 355); 

                auto tg_xxyyz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 356); 

                auto tg_xxyyz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 357); 

                auto tg_xxyyz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 358); 

                auto tg_xxyyz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 359); 

                auto tg_xxyzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 360); 

                auto tg_xxyzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 361); 

                auto tg_xxyzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 362); 

                auto tg_xxyzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 363); 

                auto tg_xxyzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 364); 

                auto tg_xxyzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 365); 

                auto tg_xxyzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 366); 

                auto tg_xxyzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 367); 

                auto tg_xxyzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 368); 

                auto tg_xxyzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 369); 

                auto tg_xxyzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 370); 

                auto tg_xxyzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 371); 

                auto tg_xxyzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 372); 

                auto tg_xxyzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 373); 

                auto tg_xxyzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 374); 

                auto tg_xxyzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 375); 

                auto tg_xxyzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 376); 

                auto tg_xxyzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 377); 

                auto tg_xxyzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 378); 

                auto tg_xxyzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 379); 

                auto tg_xxyzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 380); 

                auto tg_xxyzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 381); 

                auto tg_xxyzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 382); 

                auto tg_xxyzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 383); 

                auto tg_xxyzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 384); 

                auto tg_xxyzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 385); 

                auto tg_xxyzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 386); 

                auto tg_xxyzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 387); 

                auto tg_xxyyy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 291); 

                auto tg_xxyyy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 292); 

                auto tg_xxyyy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 293); 

                auto tg_xxyyy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 294); 

                auto tg_xxyyy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 295); 

                auto tg_xxyyy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 296); 

                auto tg_xxyyy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 297); 

                auto tg_xxyyy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 298); 

                auto tg_xxyyy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 299); 

                auto tg_xxyyy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 300); 

                auto tg_xxyyy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 301); 

                auto tg_xxyyy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 302); 

                auto tg_xxyyy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 303); 

                auto tg_xxyyy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 304); 

                auto tg_xxyyy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 305); 

                auto tg_xxyyy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 306); 

                auto tg_xxyyy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 307); 

                auto tg_xxyyy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 308); 

                auto tg_xxyyy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 309); 

                auto tg_xxyyy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 310); 

                auto tg_xxyyy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 311); 

                auto tg_xxyyy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 312); 

                auto tg_xxyyy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 313); 

                auto tg_xxyyy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 314); 

                auto tg_xxyyz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 315); 

                auto tg_xxyyz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 316); 

                auto tg_xxyyz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 317); 

                auto tg_xxyyz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 318); 

                auto tg_xxyyz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 319); 

                auto tg_xxyyz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 320); 

                auto tg_xxyyz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 321); 

                auto tg_xxyyz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 322); 

                auto tg_xxyyz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 323); 

                auto tg_xxyyz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 324); 

                auto tg_xxyyz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 325); 

                auto tg_xxyyz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 326); 

                auto tg_xxyyz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 327); 

                auto tg_xxyyz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 328); 

                auto tg_xxyyz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 329); 

                auto tg_xxyyz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 330); 

                auto tg_xxyyz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 331); 

                auto tg_xxyyz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 332); 

                auto tg_xxyyz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 333); 

                auto tg_xxyyz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 334); 

                auto tg_xxyyz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 335); 

                auto tg_xxyyz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 336); 

                auto tg_xxyyz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 337); 

                auto tg_xxyyz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 338); 

                auto tg_xxyyz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 339); 

                auto tg_xxyyz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 340); 

                auto tg_xxyyz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 341); 

                auto tg_xxyyz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 342); 

                auto tg_xxyyz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 343); 

                auto tg_xxyyz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 344); 

                auto tg_xxyyz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 345); 

                auto tg_xxyyz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 346); 

                auto tg_xxyyz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 347); 

                auto tg_xxyyz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 348); 

                auto tg_xxyyz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 349); 

                auto tg_xxyyz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 350); 

                auto tg_xxyyz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 351); 

                auto tg_xxyyz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 352); 

                auto tg_xxyyz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 353); 

                auto tg_xxyyz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 354); 

                auto tg_xxyyz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 355); 

                auto tg_xxyyz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 356); 

                auto tg_xxyyz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 357); 

                auto tg_xxyyz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 358); 

                auto tg_xxyyz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 359); 

                auto tg_xxyzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 360); 

                auto tg_xxyzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 361); 

                auto tg_xxyzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 362); 

                auto tg_xxyzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 363); 

                auto tg_xxyzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 364); 

                auto tg_xxyzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 365); 

                auto tg_xxyzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 366); 

                auto tg_xxyzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 367); 

                auto tg_xxyzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 368); 

                auto tg_xxyzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 369); 

                auto tg_xxyzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 370); 

                auto tg_xxyzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 371); 

                auto tg_xxyzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 372); 

                auto tg_xxyzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 373); 

                auto tg_xxyzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 374); 

                auto tg_xxyzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 375); 

                auto tg_xxyzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 376); 

                auto tg_xxyzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 377); 

                auto tg_xxyzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 378); 

                auto tg_xxyzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 379); 

                auto tg_xxyzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 380); 

                auto tg_xxyzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 381); 

                auto tg_xxyzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 382); 

                auto tg_xxyzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 383); 

                auto tg_xxyzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 384); 

                auto tg_xxyzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 385); 

                auto tg_xxyzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 386); 

                auto tg_xxyzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 387); 

                auto tg_xyyy_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 291); 

                auto tg_xyyy_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 292); 

                auto tg_xyyy_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 293); 

                auto tg_xyyy_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 294); 

                auto tg_xyyy_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 295); 

                auto tg_xyyy_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 296); 

                auto tg_xyyy_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 297); 

                auto tg_xyyy_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 298); 

                auto tg_xyyy_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 299); 

                auto tg_xyyy_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 300); 

                auto tg_xyyy_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 301); 

                auto tg_xyyy_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 302); 

                auto tg_xyyy_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 303); 

                auto tg_xyyy_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 304); 

                auto tg_xyyy_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 305); 

                auto tg_xyyy_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 306); 

                auto tg_xyyy_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 307); 

                auto tg_xyyy_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 308); 

                auto tg_xyyy_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 309); 

                auto tg_xyyy_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 310); 

                auto tg_xyyy_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 311); 

                auto tg_xyyy_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 312); 

                auto tg_xyyy_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 313); 

                auto tg_xyyy_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 314); 

                auto tg_xyyz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 315); 

                auto tg_xyyz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 316); 

                auto tg_xyyz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 317); 

                auto tg_xyyz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 318); 

                auto tg_xyyz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 319); 

                auto tg_xyyz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 320); 

                auto tg_xyyz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 321); 

                auto tg_xyyz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 322); 

                auto tg_xyyz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 323); 

                auto tg_xyyz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 324); 

                auto tg_xyyz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 325); 

                auto tg_xyyz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 326); 

                auto tg_xyyz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 327); 

                auto tg_xyyz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 328); 

                auto tg_xyyz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 329); 

                auto tg_xyyz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 330); 

                auto tg_xyyz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 331); 

                auto tg_xyyz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 332); 

                auto tg_xyyz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 333); 

                auto tg_xyyz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 334); 

                auto tg_xyyz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 335); 

                auto tg_xyyz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 336); 

                auto tg_xyyz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 337); 

                auto tg_xyyz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 338); 

                auto tg_xyyz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 339); 

                auto tg_xyyz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 340); 

                auto tg_xyyz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 341); 

                auto tg_xyyz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 342); 

                auto tg_xyyz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 343); 

                auto tg_xyyz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 344); 

                auto tg_xyyz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 345); 

                auto tg_xyyz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 346); 

                auto tg_xyyz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 347); 

                auto tg_xyyz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 348); 

                auto tg_xyyz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 349); 

                auto tg_xyyz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 350); 

                auto tg_xyyz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 351); 

                auto tg_xyyz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 352); 

                auto tg_xyyz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 353); 

                auto tg_xyyz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 354); 

                auto tg_xyyz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 355); 

                auto tg_xyyz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 356); 

                auto tg_xyyz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 357); 

                auto tg_xyyz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 358); 

                auto tg_xyyz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 359); 

                auto tg_xyzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 360); 

                auto tg_xyzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 361); 

                auto tg_xyzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 362); 

                auto tg_xyzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 363); 

                auto tg_xyzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 364); 

                auto tg_xyzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 365); 

                auto tg_xyzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 366); 

                auto tg_xyzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 367); 

                auto tg_xyzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 368); 

                auto tg_xyzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 369); 

                auto tg_xyzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 370); 

                auto tg_xyzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 371); 

                auto tg_xyzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 372); 

                auto tg_xyzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 373); 

                auto tg_xyzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 374); 

                auto tg_xyzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 375); 

                auto tg_xyzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 376); 

                auto tg_xyzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 377); 

                auto tg_xyzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 378); 

                auto tg_xyzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 379); 

                auto tg_xyzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 380); 

                auto tg_xyzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 381); 

                auto tg_xyzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 382); 

                auto tg_xyzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 383); 

                auto tg_xyzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 384); 

                auto tg_xyzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 385); 

                auto tg_xyzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 386); 

                auto tg_xyzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 387); 

                auto tg_xyyy_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 291); 

                auto tg_xyyy_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 292); 

                auto tg_xyyy_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 293); 

                auto tg_xyyy_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 294); 

                auto tg_xyyy_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 295); 

                auto tg_xyyy_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 296); 

                auto tg_xyyy_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 297); 

                auto tg_xyyy_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 298); 

                auto tg_xyyy_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 299); 

                auto tg_xyyy_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 300); 

                auto tg_xyyy_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 301); 

                auto tg_xyyy_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 302); 

                auto tg_xyyy_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 303); 

                auto tg_xyyy_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 304); 

                auto tg_xyyy_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 305); 

                auto tg_xyyy_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 306); 

                auto tg_xyyy_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 307); 

                auto tg_xyyy_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 308); 

                auto tg_xyyy_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 309); 

                auto tg_xyyy_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 310); 

                auto tg_xyyy_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 311); 

                auto tg_xyyy_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 312); 

                auto tg_xyyy_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 313); 

                auto tg_xyyy_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 314); 

                auto tg_xyyz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 315); 

                auto tg_xyyz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 316); 

                auto tg_xyyz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 317); 

                auto tg_xyyz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 318); 

                auto tg_xyyz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 319); 

                auto tg_xyyz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 320); 

                auto tg_xyyz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 321); 

                auto tg_xyyz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 322); 

                auto tg_xyyz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 323); 

                auto tg_xyyz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 324); 

                auto tg_xyyz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 325); 

                auto tg_xyyz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 326); 

                auto tg_xyyz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 327); 

                auto tg_xyyz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 328); 

                auto tg_xyyz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 329); 

                auto tg_xyyz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 330); 

                auto tg_xyyz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 331); 

                auto tg_xyyz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 332); 

                auto tg_xyyz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 333); 

                auto tg_xyyz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 334); 

                auto tg_xyyz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 335); 

                auto tg_xyyz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 336); 

                auto tg_xyyz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 337); 

                auto tg_xyyz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 338); 

                auto tg_xyyz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 339); 

                auto tg_xyyz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 340); 

                auto tg_xyyz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 341); 

                auto tg_xyyz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 342); 

                auto tg_xyyz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 343); 

                auto tg_xyyz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 344); 

                auto tg_xyyz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 345); 

                auto tg_xyyz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 346); 

                auto tg_xyyz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 347); 

                auto tg_xyyz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 348); 

                auto tg_xyyz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 349); 

                auto tg_xyyz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 350); 

                auto tg_xyyz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 351); 

                auto tg_xyyz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 352); 

                auto tg_xyyz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 353); 

                auto tg_xyyz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 354); 

                auto tg_xyyz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 355); 

                auto tg_xyyz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 356); 

                auto tg_xyyz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 357); 

                auto tg_xyyz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 358); 

                auto tg_xyyz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 359); 

                auto tg_xyzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 360); 

                auto tg_xyzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 361); 

                auto tg_xyzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 362); 

                auto tg_xyzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 363); 

                auto tg_xyzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 364); 

                auto tg_xyzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 365); 

                auto tg_xyzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 366); 

                auto tg_xyzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 367); 

                auto tg_xyzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 368); 

                auto tg_xyzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 369); 

                auto tg_xyzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 370); 

                auto tg_xyzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 371); 

                auto tg_xyzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 372); 

                auto tg_xyzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 373); 

                auto tg_xyzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 374); 

                auto tg_xyzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 375); 

                auto tg_xyzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 376); 

                auto tg_xyzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 377); 

                auto tg_xyzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 378); 

                auto tg_xyzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 379); 

                auto tg_xyzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 380); 

                auto tg_xyzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 381); 

                auto tg_xyzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 382); 

                auto tg_xyzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 383); 

                auto tg_xyzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 384); 

                auto tg_xyzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 385); 

                auto tg_xyzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 386); 

                auto tg_xyzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 387); 

                auto tg_xxyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 237); 

                auto tg_xxyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 238); 

                auto tg_xxyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 239); 

                auto tg_xxyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 240); 

                auto tg_xxyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 241); 

                auto tg_xxyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 242); 

                auto tg_xxyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 243); 

                auto tg_xxyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 244); 

                auto tg_xxyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 245); 

                auto tg_xxyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 246); 

                auto tg_xxyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 247); 

                auto tg_xxyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 248); 

                auto tg_xxyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 249); 

                auto tg_xxyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 250); 

                auto tg_xxyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 251); 

                auto tg_xxyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 252); 

                auto tg_xxyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 253); 

                auto tg_xxyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 254); 

                auto tg_xxyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 255); 

                auto tg_xxyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 256); 

                auto tg_xxyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 257); 

                auto tg_xxyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 258); 

                auto tg_xxyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 259); 

                auto tg_xxyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 260); 

                auto tg_xxyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 261); 

                auto tg_xxyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 262); 

                auto tg_xxyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 263); 

                auto tg_xxyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 264); 

                auto tg_xxyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 265); 

                auto tg_xxyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 266); 

                auto tg_xxyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 267); 

                auto tg_xxyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 268); 

                auto tg_xxyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 269); 

                auto tg_xxyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 270); 

                auto tg_xxyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 271); 

                auto tg_xxyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 272); 

                auto tg_xxyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 273); 

                auto tg_xxyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 274); 

                auto tg_xxyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 275); 

                auto tg_xxyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 276); 

                auto tg_xxyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 277); 

                auto tg_xxyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 278); 

                auto tg_xxyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 279); 

                auto tg_xxyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 280); 

                auto tg_xxyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 281); 

                auto tg_xxyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 282); 

                auto tg_xxyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 283); 

                auto tg_xxyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 284); 

                auto tg_xxyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 285); 

                auto tg_xxyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 286); 

                auto tg_xxyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 287); 

                auto tg_xxyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 288); 

                auto tg_xxyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 289); 

                auto tg_xxyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 290); 

                auto tg_xxyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 291); 

                auto tg_xxyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 292); 

                auto tg_xxyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 293); 

                auto tg_xxyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 294); 

                auto tg_xxyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 295); 

                auto tg_xxyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 296); 

                auto tg_xxyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 297); 

                auto tg_xxyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 298); 

                auto tg_xxyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 299); 

                auto tg_xxyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 300); 

                auto tg_xxyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 301); 

                auto tg_xxyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 302); 

                auto tg_xxyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 303); 

                auto tg_xxyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 304); 

                auto tg_xxyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 305); 

                auto tg_xxyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 306); 

                auto tg_xxyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 307); 

                auto tg_xxyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 308); 

                auto tg_xxyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 309); 

                auto tg_xxyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 310); 

                auto tg_xxyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 311); 

                auto tg_xxyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 312); 

                auto tg_xxyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 313); 

                auto tg_xxyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 314); 

                auto tg_xxyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 315); 

                // set up pointers to integrals

                auto tg_xxxyyy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 291); 

                auto tg_xxxyyy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 292); 

                auto tg_xxxyyy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 293); 

                auto tg_xxxyyy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 294); 

                auto tg_xxxyyy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 295); 

                auto tg_xxxyyy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 296); 

                auto tg_xxxyyy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 297); 

                auto tg_xxxyyy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 298); 

                auto tg_xxxyyy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 299); 

                auto tg_xxxyyy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 300); 

                auto tg_xxxyyy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 301); 

                auto tg_xxxyyy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 302); 

                auto tg_xxxyyy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 303); 

                auto tg_xxxyyy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 304); 

                auto tg_xxxyyy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 305); 

                auto tg_xxxyyy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 306); 

                auto tg_xxxyyy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 307); 

                auto tg_xxxyyy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 308); 

                auto tg_xxxyyy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 309); 

                auto tg_xxxyyy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 310); 

                auto tg_xxxyyy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 311); 

                auto tg_xxxyyy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 312); 

                auto tg_xxxyyy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 313); 

                auto tg_xxxyyy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 314); 

                auto tg_xxxyyz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 315); 

                auto tg_xxxyyz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 316); 

                auto tg_xxxyyz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 317); 

                auto tg_xxxyyz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 318); 

                auto tg_xxxyyz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 319); 

                auto tg_xxxyyz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 320); 

                auto tg_xxxyyz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 321); 

                auto tg_xxxyyz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 322); 

                auto tg_xxxyyz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 323); 

                auto tg_xxxyyz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 324); 

                auto tg_xxxyyz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 325); 

                auto tg_xxxyyz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 326); 

                auto tg_xxxyyz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 327); 

                auto tg_xxxyyz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 328); 

                auto tg_xxxyyz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 329); 

                auto tg_xxxyyz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 330); 

                auto tg_xxxyyz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 331); 

                auto tg_xxxyyz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 332); 

                auto tg_xxxyyz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 333); 

                auto tg_xxxyyz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 334); 

                auto tg_xxxyyz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 335); 

                auto tg_xxxyyz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 336); 

                auto tg_xxxyyz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 337); 

                auto tg_xxxyyz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 338); 

                auto tg_xxxyyz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 339); 

                auto tg_xxxyyz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 340); 

                auto tg_xxxyyz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 341); 

                auto tg_xxxyyz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 342); 

                auto tg_xxxyyz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 343); 

                auto tg_xxxyyz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 344); 

                auto tg_xxxyyz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 345); 

                auto tg_xxxyyz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 346); 

                auto tg_xxxyyz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 347); 

                auto tg_xxxyyz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 348); 

                auto tg_xxxyyz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 349); 

                auto tg_xxxyyz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 350); 

                auto tg_xxxyyz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 351); 

                auto tg_xxxyyz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 352); 

                auto tg_xxxyyz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 353); 

                auto tg_xxxyyz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 354); 

                auto tg_xxxyyz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 355); 

                auto tg_xxxyyz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 356); 

                auto tg_xxxyyz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 357); 

                auto tg_xxxyyz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 358); 

                auto tg_xxxyyz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 359); 

                auto tg_xxxyzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 360); 

                auto tg_xxxyzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 361); 

                auto tg_xxxyzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 362); 

                auto tg_xxxyzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 363); 

                auto tg_xxxyzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 364); 

                auto tg_xxxyzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 365); 

                auto tg_xxxyzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 366); 

                auto tg_xxxyzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 367); 

                auto tg_xxxyzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 368); 

                auto tg_xxxyzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 369); 

                auto tg_xxxyzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 370); 

                auto tg_xxxyzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 371); 

                auto tg_xxxyzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 372); 

                auto tg_xxxyzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 373); 

                auto tg_xxxyzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 374); 

                auto tg_xxxyzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 375); 

                auto tg_xxxyzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 376); 

                auto tg_xxxyzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 377); 

                auto tg_xxxyzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 378); 

                auto tg_xxxyzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 379); 

                auto tg_xxxyzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 380); 

                auto tg_xxxyzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 381); 

                auto tg_xxxyzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 382); 

                auto tg_xxxyzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 383); 

                auto tg_xxxyzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 384); 

                auto tg_xxxyzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 385); 

                auto tg_xxxyzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 386); 

                auto tg_xxxyzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 387); 

                // Batch of Integrals (291,388)

                #pragma omp simd aligned(fxn, fza, tg_xxxyyy_xxyyyyyy_0, tg_xxxyyy_xxyyyyyz_0, \
                                         tg_xxxyyy_xxyyyyzz_0, tg_xxxyyy_xxyyyzzz_0, tg_xxxyyy_xxyyzzzz_0, tg_xxxyyy_xxyzzzzz_0, \
                                         tg_xxxyyy_xxzzzzzz_0, tg_xxxyyy_xyyyyyyy_0, tg_xxxyyy_xyyyyyyz_0, tg_xxxyyy_xyyyyyzz_0, \
                                         tg_xxxyyy_xyyyyzzz_0, tg_xxxyyy_xyyyzzzz_0, tg_xxxyyy_xyyzzzzz_0, tg_xxxyyy_xyzzzzzz_0, \
                                         tg_xxxyyy_xzzzzzzz_0, tg_xxxyyy_yyyyyyyy_0, tg_xxxyyy_yyyyyyyz_0, tg_xxxyyy_yyyyyyzz_0, \
                                         tg_xxxyyy_yyyyyzzz_0, tg_xxxyyy_yyyyzzzz_0, tg_xxxyyy_yyyzzzzz_0, tg_xxxyyy_yyzzzzzz_0, \
                                         tg_xxxyyy_yzzzzzzz_0, tg_xxxyyy_zzzzzzzz_0, tg_xxxyyz_xxxxxxxx_0, tg_xxxyyz_xxxxxxxy_0, \
                                         tg_xxxyyz_xxxxxxxz_0, tg_xxxyyz_xxxxxxyy_0, tg_xxxyyz_xxxxxxyz_0, tg_xxxyyz_xxxxxxzz_0, \
                                         tg_xxxyyz_xxxxxyyy_0, tg_xxxyyz_xxxxxyyz_0, tg_xxxyyz_xxxxxyzz_0, tg_xxxyyz_xxxxxzzz_0, \
                                         tg_xxxyyz_xxxxyyyy_0, tg_xxxyyz_xxxxyyyz_0, tg_xxxyyz_xxxxyyzz_0, tg_xxxyyz_xxxxyzzz_0, \
                                         tg_xxxyyz_xxxxzzzz_0, tg_xxxyyz_xxxyyyyy_0, tg_xxxyyz_xxxyyyyz_0, tg_xxxyyz_xxxyyyzz_0, \
                                         tg_xxxyyz_xxxyyzzz_0, tg_xxxyyz_xxxyzzzz_0, tg_xxxyyz_xxxzzzzz_0, tg_xxxyyz_xxyyyyyy_0, \
                                         tg_xxxyyz_xxyyyyyz_0, tg_xxxyyz_xxyyyyzz_0, tg_xxxyyz_xxyyyzzz_0, tg_xxxyyz_xxyyzzzz_0, \
                                         tg_xxxyyz_xxyzzzzz_0, tg_xxxyyz_xxzzzzzz_0, tg_xxxyyz_xyyyyyyy_0, tg_xxxyyz_xyyyyyyz_0, \
                                         tg_xxxyyz_xyyyyyzz_0, tg_xxxyyz_xyyyyzzz_0, tg_xxxyyz_xyyyzzzz_0, tg_xxxyyz_xyyzzzzz_0, \
                                         tg_xxxyyz_xyzzzzzz_0, tg_xxxyyz_xzzzzzzz_0, tg_xxxyyz_yyyyyyyy_0, tg_xxxyyz_yyyyyyyz_0, \
                                         tg_xxxyyz_yyyyyyzz_0, tg_xxxyyz_yyyyyzzz_0, tg_xxxyyz_yyyyzzzz_0, tg_xxxyyz_yyyzzzzz_0, \
                                         tg_xxxyyz_yyzzzzzz_0, tg_xxxyyz_yzzzzzzz_0, tg_xxxyyz_zzzzzzzz_0, tg_xxxyzz_xxxxxxxx_0, \
                                         tg_xxxyzz_xxxxxxxy_0, tg_xxxyzz_xxxxxxxz_0, tg_xxxyzz_xxxxxxyy_0, tg_xxxyzz_xxxxxxyz_0, \
                                         tg_xxxyzz_xxxxxxzz_0, tg_xxxyzz_xxxxxyyy_0, tg_xxxyzz_xxxxxyyz_0, tg_xxxyzz_xxxxxyzz_0, \
                                         tg_xxxyzz_xxxxxzzz_0, tg_xxxyzz_xxxxyyyy_0, tg_xxxyzz_xxxxyyyz_0, tg_xxxyzz_xxxxyyzz_0, \
                                         tg_xxxyzz_xxxxyzzz_0, tg_xxxyzz_xxxxzzzz_0, tg_xxxyzz_xxxyyyyy_0, tg_xxxyzz_xxxyyyyz_0, \
                                         tg_xxxyzz_xxxyyyzz_0, tg_xxxyzz_xxxyyzzz_0, tg_xxxyzz_xxxyzzzz_0, tg_xxxyzz_xxxzzzzz_0, \
                                         tg_xxxyzz_xxyyyyyy_0, tg_xxxyzz_xxyyyyyz_0, tg_xxxyzz_xxyyyyzz_0, tg_xxxyzz_xxyyyzzz_0, \
                                         tg_xxxyzz_xxyyzzzz_0, tg_xxxyzz_xxyzzzzz_0, tg_xxxyzz_xxzzzzzz_0, tg_xxyyy_xxyyyyyy_0, \
                                         tg_xxyyy_xxyyyyyy_1, tg_xxyyy_xxyyyyyz_0, tg_xxyyy_xxyyyyyz_1, tg_xxyyy_xxyyyyzz_0, \
                                         tg_xxyyy_xxyyyyzz_1, tg_xxyyy_xxyyyzzz_0, tg_xxyyy_xxyyyzzz_1, tg_xxyyy_xxyyzzzz_0, \
                                         tg_xxyyy_xxyyzzzz_1, tg_xxyyy_xxyzzzzz_0, tg_xxyyy_xxyzzzzz_1, tg_xxyyy_xxzzzzzz_0, \
                                         tg_xxyyy_xxzzzzzz_1, tg_xxyyy_xyyyyyy_1, tg_xxyyy_xyyyyyyy_0, tg_xxyyy_xyyyyyyy_1, \
                                         tg_xxyyy_xyyyyyyz_0, tg_xxyyy_xyyyyyyz_1, tg_xxyyy_xyyyyyz_1, tg_xxyyy_xyyyyyzz_0, \
                                         tg_xxyyy_xyyyyyzz_1, tg_xxyyy_xyyyyzz_1, tg_xxyyy_xyyyyzzz_0, tg_xxyyy_xyyyyzzz_1, \
                                         tg_xxyyy_xyyyzzz_1, tg_xxyyy_xyyyzzzz_0, tg_xxyyy_xyyyzzzz_1, tg_xxyyy_xyyzzzz_1, \
                                         tg_xxyyy_xyyzzzzz_0, tg_xxyyy_xyyzzzzz_1, tg_xxyyy_xyzzzzz_1, tg_xxyyy_xyzzzzzz_0, \
                                         tg_xxyyy_xyzzzzzz_1, tg_xxyyy_xzzzzzz_1, tg_xxyyy_xzzzzzzz_0, tg_xxyyy_xzzzzzzz_1, \
                                         tg_xxyyy_yyyyyyy_1, tg_xxyyy_yyyyyyyy_0, tg_xxyyy_yyyyyyyy_1, tg_xxyyy_yyyyyyyz_0, \
                                         tg_xxyyy_yyyyyyyz_1, tg_xxyyy_yyyyyyz_1, tg_xxyyy_yyyyyyzz_0, tg_xxyyy_yyyyyyzz_1, \
                                         tg_xxyyy_yyyyyzz_1, tg_xxyyy_yyyyyzzz_0, tg_xxyyy_yyyyyzzz_1, tg_xxyyy_yyyyzzz_1, \
                                         tg_xxyyy_yyyyzzzz_0, tg_xxyyy_yyyyzzzz_1, tg_xxyyy_yyyzzzz_1, tg_xxyyy_yyyzzzzz_0, \
                                         tg_xxyyy_yyyzzzzz_1, tg_xxyyy_yyzzzzz_1, tg_xxyyy_yyzzzzzz_0, tg_xxyyy_yyzzzzzz_1, \
                                         tg_xxyyy_yzzzzzz_1, tg_xxyyy_yzzzzzzz_0, tg_xxyyy_yzzzzzzz_1, tg_xxyyy_zzzzzzz_1, \
                                         tg_xxyyy_zzzzzzzz_0, tg_xxyyy_zzzzzzzz_1, tg_xxyyz_xxxxxxx_1, tg_xxyyz_xxxxxxxx_0, \
                                         tg_xxyyz_xxxxxxxx_1, tg_xxyyz_xxxxxxxy_0, tg_xxyyz_xxxxxxxy_1, tg_xxyyz_xxxxxxxz_0, \
                                         tg_xxyyz_xxxxxxxz_1, tg_xxyyz_xxxxxxy_1, tg_xxyyz_xxxxxxyy_0, tg_xxyyz_xxxxxxyy_1, \
                                         tg_xxyyz_xxxxxxyz_0, tg_xxyyz_xxxxxxyz_1, tg_xxyyz_xxxxxxz_1, tg_xxyyz_xxxxxxzz_0, \
                                         tg_xxyyz_xxxxxxzz_1, tg_xxyyz_xxxxxyy_1, tg_xxyyz_xxxxxyyy_0, tg_xxyyz_xxxxxyyy_1, \
                                         tg_xxyyz_xxxxxyyz_0, tg_xxyyz_xxxxxyyz_1, tg_xxyyz_xxxxxyz_1, tg_xxyyz_xxxxxyzz_0, \
                                         tg_xxyyz_xxxxxyzz_1, tg_xxyyz_xxxxxzz_1, tg_xxyyz_xxxxxzzz_0, tg_xxyyz_xxxxxzzz_1, \
                                         tg_xxyyz_xxxxyyy_1, tg_xxyyz_xxxxyyyy_0, tg_xxyyz_xxxxyyyy_1, tg_xxyyz_xxxxyyyz_0, \
                                         tg_xxyyz_xxxxyyyz_1, tg_xxyyz_xxxxyyz_1, tg_xxyyz_xxxxyyzz_0, tg_xxyyz_xxxxyyzz_1, \
                                         tg_xxyyz_xxxxyzz_1, tg_xxyyz_xxxxyzzz_0, tg_xxyyz_xxxxyzzz_1, tg_xxyyz_xxxxzzz_1, \
                                         tg_xxyyz_xxxxzzzz_0, tg_xxyyz_xxxxzzzz_1, tg_xxyyz_xxxyyyy_1, tg_xxyyz_xxxyyyyy_0, \
                                         tg_xxyyz_xxxyyyyy_1, tg_xxyyz_xxxyyyyz_0, tg_xxyyz_xxxyyyyz_1, tg_xxyyz_xxxyyyz_1, \
                                         tg_xxyyz_xxxyyyzz_0, tg_xxyyz_xxxyyyzz_1, tg_xxyyz_xxxyyzz_1, tg_xxyyz_xxxyyzzz_0, \
                                         tg_xxyyz_xxxyyzzz_1, tg_xxyyz_xxxyzzz_1, tg_xxyyz_xxxyzzzz_0, tg_xxyyz_xxxyzzzz_1, \
                                         tg_xxyyz_xxxzzzz_1, tg_xxyyz_xxxzzzzz_0, tg_xxyyz_xxxzzzzz_1, tg_xxyyz_xxyyyyy_1, \
                                         tg_xxyyz_xxyyyyyy_0, tg_xxyyz_xxyyyyyy_1, tg_xxyyz_xxyyyyyz_0, tg_xxyyz_xxyyyyyz_1, \
                                         tg_xxyyz_xxyyyyz_1, tg_xxyyz_xxyyyyzz_0, tg_xxyyz_xxyyyyzz_1, tg_xxyyz_xxyyyzz_1, \
                                         tg_xxyyz_xxyyyzzz_0, tg_xxyyz_xxyyyzzz_1, tg_xxyyz_xxyyzzz_1, tg_xxyyz_xxyyzzzz_0, \
                                         tg_xxyyz_xxyyzzzz_1, tg_xxyyz_xxyzzzz_1, tg_xxyyz_xxyzzzzz_0, tg_xxyyz_xxyzzzzz_1, \
                                         tg_xxyyz_xxzzzzz_1, tg_xxyyz_xxzzzzzz_0, tg_xxyyz_xxzzzzzz_1, tg_xxyyz_xyyyyyy_1, \
                                         tg_xxyyz_xyyyyyyy_0, tg_xxyyz_xyyyyyyy_1, tg_xxyyz_xyyyyyyz_0, tg_xxyyz_xyyyyyyz_1, \
                                         tg_xxyyz_xyyyyyz_1, tg_xxyyz_xyyyyyzz_0, tg_xxyyz_xyyyyyzz_1, tg_xxyyz_xyyyyzz_1, \
                                         tg_xxyyz_xyyyyzzz_0, tg_xxyyz_xyyyyzzz_1, tg_xxyyz_xyyyzzz_1, tg_xxyyz_xyyyzzzz_0, \
                                         tg_xxyyz_xyyyzzzz_1, tg_xxyyz_xyyzzzz_1, tg_xxyyz_xyyzzzzz_0, tg_xxyyz_xyyzzzzz_1, \
                                         tg_xxyyz_xyzzzzz_1, tg_xxyyz_xyzzzzzz_0, tg_xxyyz_xyzzzzzz_1, tg_xxyyz_xzzzzzz_1, \
                                         tg_xxyyz_xzzzzzzz_0, tg_xxyyz_xzzzzzzz_1, tg_xxyyz_yyyyyyy_1, tg_xxyyz_yyyyyyyy_0, \
                                         tg_xxyyz_yyyyyyyy_1, tg_xxyyz_yyyyyyyz_0, tg_xxyyz_yyyyyyyz_1, tg_xxyyz_yyyyyyz_1, \
                                         tg_xxyyz_yyyyyyzz_0, tg_xxyyz_yyyyyyzz_1, tg_xxyyz_yyyyyzz_1, tg_xxyyz_yyyyyzzz_0, \
                                         tg_xxyyz_yyyyyzzz_1, tg_xxyyz_yyyyzzz_1, tg_xxyyz_yyyyzzzz_0, tg_xxyyz_yyyyzzzz_1, \
                                         tg_xxyyz_yyyzzzz_1, tg_xxyyz_yyyzzzzz_0, tg_xxyyz_yyyzzzzz_1, tg_xxyyz_yyzzzzz_1, \
                                         tg_xxyyz_yyzzzzzz_0, tg_xxyyz_yyzzzzzz_1, tg_xxyyz_yzzzzzz_1, tg_xxyyz_yzzzzzzz_0, \
                                         tg_xxyyz_yzzzzzzz_1, tg_xxyyz_zzzzzzz_1, tg_xxyyz_zzzzzzzz_0, tg_xxyyz_zzzzzzzz_1, \
                                         tg_xxyzz_xxxxxxx_1, tg_xxyzz_xxxxxxxx_0, tg_xxyzz_xxxxxxxx_1, tg_xxyzz_xxxxxxxy_0, \
                                         tg_xxyzz_xxxxxxxy_1, tg_xxyzz_xxxxxxxz_0, tg_xxyzz_xxxxxxxz_1, tg_xxyzz_xxxxxxy_1, \
                                         tg_xxyzz_xxxxxxyy_0, tg_xxyzz_xxxxxxyy_1, tg_xxyzz_xxxxxxyz_0, tg_xxyzz_xxxxxxyz_1, \
                                         tg_xxyzz_xxxxxxz_1, tg_xxyzz_xxxxxxzz_0, tg_xxyzz_xxxxxxzz_1, tg_xxyzz_xxxxxyy_1, \
                                         tg_xxyzz_xxxxxyyy_0, tg_xxyzz_xxxxxyyy_1, tg_xxyzz_xxxxxyyz_0, tg_xxyzz_xxxxxyyz_1, \
                                         tg_xxyzz_xxxxxyz_1, tg_xxyzz_xxxxxyzz_0, tg_xxyzz_xxxxxyzz_1, tg_xxyzz_xxxxxzz_1, \
                                         tg_xxyzz_xxxxxzzz_0, tg_xxyzz_xxxxxzzz_1, tg_xxyzz_xxxxyyy_1, tg_xxyzz_xxxxyyyy_0, \
                                         tg_xxyzz_xxxxyyyy_1, tg_xxyzz_xxxxyyyz_0, tg_xxyzz_xxxxyyyz_1, tg_xxyzz_xxxxyyz_1, \
                                         tg_xxyzz_xxxxyyzz_0, tg_xxyzz_xxxxyyzz_1, tg_xxyzz_xxxxyzz_1, tg_xxyzz_xxxxyzzz_0, \
                                         tg_xxyzz_xxxxyzzz_1, tg_xxyzz_xxxxzzz_1, tg_xxyzz_xxxxzzzz_0, tg_xxyzz_xxxxzzzz_1, \
                                         tg_xxyzz_xxxyyyy_1, tg_xxyzz_xxxyyyyy_0, tg_xxyzz_xxxyyyyy_1, tg_xxyzz_xxxyyyyz_0, \
                                         tg_xxyzz_xxxyyyyz_1, tg_xxyzz_xxxyyyz_1, tg_xxyzz_xxxyyyzz_0, tg_xxyzz_xxxyyyzz_1, \
                                         tg_xxyzz_xxxyyzz_1, tg_xxyzz_xxxyyzzz_0, tg_xxyzz_xxxyyzzz_1, tg_xxyzz_xxxyzzz_1, \
                                         tg_xxyzz_xxxyzzzz_0, tg_xxyzz_xxxyzzzz_1, tg_xxyzz_xxxzzzz_1, tg_xxyzz_xxxzzzzz_0, \
                                         tg_xxyzz_xxxzzzzz_1, tg_xxyzz_xxyyyyy_1, tg_xxyzz_xxyyyyyy_0, tg_xxyzz_xxyyyyyy_1, \
                                         tg_xxyzz_xxyyyyyz_0, tg_xxyzz_xxyyyyyz_1, tg_xxyzz_xxyyyyz_1, tg_xxyzz_xxyyyyzz_0, \
                                         tg_xxyzz_xxyyyyzz_1, tg_xxyzz_xxyyyzz_1, tg_xxyzz_xxyyyzzz_0, tg_xxyzz_xxyyyzzz_1, \
                                         tg_xxyzz_xxyyzzz_1, tg_xxyzz_xxyyzzzz_0, tg_xxyzz_xxyyzzzz_1, tg_xxyzz_xxyzzzz_1, \
                                         tg_xxyzz_xxyzzzzz_0, tg_xxyzz_xxyzzzzz_1, tg_xxyzz_xxzzzzz_1, tg_xxyzz_xxzzzzzz_0, \
                                         tg_xxyzz_xxzzzzzz_1, tg_xxyzz_xyyyyyy_1, tg_xxyzz_xyyyyyz_1, tg_xxyzz_xyyyyzz_1, \
                                         tg_xxyzz_xyyyzzz_1, tg_xxyzz_xyyzzzz_1, tg_xxyzz_xyzzzzz_1, tg_xxyzz_xzzzzzz_1, \
                                         tg_xyyy_xxyyyyyy_0, tg_xyyy_xxyyyyyy_1, tg_xyyy_xxyyyyyz_0, tg_xyyy_xxyyyyyz_1, \
                                         tg_xyyy_xxyyyyzz_0, tg_xyyy_xxyyyyzz_1, tg_xyyy_xxyyyzzz_0, tg_xyyy_xxyyyzzz_1, \
                                         tg_xyyy_xxyyzzzz_0, tg_xyyy_xxyyzzzz_1, tg_xyyy_xxyzzzzz_0, tg_xyyy_xxyzzzzz_1, \
                                         tg_xyyy_xxzzzzzz_0, tg_xyyy_xxzzzzzz_1, tg_xyyy_xyyyyyyy_0, tg_xyyy_xyyyyyyy_1, \
                                         tg_xyyy_xyyyyyyz_0, tg_xyyy_xyyyyyyz_1, tg_xyyy_xyyyyyzz_0, tg_xyyy_xyyyyyzz_1, \
                                         tg_xyyy_xyyyyzzz_0, tg_xyyy_xyyyyzzz_1, tg_xyyy_xyyyzzzz_0, tg_xyyy_xyyyzzzz_1, \
                                         tg_xyyy_xyyzzzzz_0, tg_xyyy_xyyzzzzz_1, tg_xyyy_xyzzzzzz_0, tg_xyyy_xyzzzzzz_1, \
                                         tg_xyyy_xzzzzzzz_0, tg_xyyy_xzzzzzzz_1, tg_xyyy_yyyyyyyy_0, tg_xyyy_yyyyyyyy_1, \
                                         tg_xyyy_yyyyyyyz_0, tg_xyyy_yyyyyyyz_1, tg_xyyy_yyyyyyzz_0, tg_xyyy_yyyyyyzz_1, \
                                         tg_xyyy_yyyyyzzz_0, tg_xyyy_yyyyyzzz_1, tg_xyyy_yyyyzzzz_0, tg_xyyy_yyyyzzzz_1, \
                                         tg_xyyy_yyyzzzzz_0, tg_xyyy_yyyzzzzz_1, tg_xyyy_yyzzzzzz_0, tg_xyyy_yyzzzzzz_1, \
                                         tg_xyyy_yzzzzzzz_0, tg_xyyy_yzzzzzzz_1, tg_xyyy_zzzzzzzz_0, tg_xyyy_zzzzzzzz_1, \
                                         tg_xyyz_xxxxxxxx_0, tg_xyyz_xxxxxxxx_1, tg_xyyz_xxxxxxxy_0, tg_xyyz_xxxxxxxy_1, \
                                         tg_xyyz_xxxxxxxz_0, tg_xyyz_xxxxxxxz_1, tg_xyyz_xxxxxxyy_0, tg_xyyz_xxxxxxyy_1, \
                                         tg_xyyz_xxxxxxyz_0, tg_xyyz_xxxxxxyz_1, tg_xyyz_xxxxxxzz_0, tg_xyyz_xxxxxxzz_1, \
                                         tg_xyyz_xxxxxyyy_0, tg_xyyz_xxxxxyyy_1, tg_xyyz_xxxxxyyz_0, tg_xyyz_xxxxxyyz_1, \
                                         tg_xyyz_xxxxxyzz_0, tg_xyyz_xxxxxyzz_1, tg_xyyz_xxxxxzzz_0, tg_xyyz_xxxxxzzz_1, \
                                         tg_xyyz_xxxxyyyy_0, tg_xyyz_xxxxyyyy_1, tg_xyyz_xxxxyyyz_0, tg_xyyz_xxxxyyyz_1, \
                                         tg_xyyz_xxxxyyzz_0, tg_xyyz_xxxxyyzz_1, tg_xyyz_xxxxyzzz_0, tg_xyyz_xxxxyzzz_1, \
                                         tg_xyyz_xxxxzzzz_0, tg_xyyz_xxxxzzzz_1, tg_xyyz_xxxyyyyy_0, tg_xyyz_xxxyyyyy_1, \
                                         tg_xyyz_xxxyyyyz_0, tg_xyyz_xxxyyyyz_1, tg_xyyz_xxxyyyzz_0, tg_xyyz_xxxyyyzz_1, \
                                         tg_xyyz_xxxyyzzz_0, tg_xyyz_xxxyyzzz_1, tg_xyyz_xxxyzzzz_0, tg_xyyz_xxxyzzzz_1, \
                                         tg_xyyz_xxxzzzzz_0, tg_xyyz_xxxzzzzz_1, tg_xyyz_xxyyyyyy_0, tg_xyyz_xxyyyyyy_1, \
                                         tg_xyyz_xxyyyyyz_0, tg_xyyz_xxyyyyyz_1, tg_xyyz_xxyyyyzz_0, tg_xyyz_xxyyyyzz_1, \
                                         tg_xyyz_xxyyyzzz_0, tg_xyyz_xxyyyzzz_1, tg_xyyz_xxyyzzzz_0, tg_xyyz_xxyyzzzz_1, \
                                         tg_xyyz_xxyzzzzz_0, tg_xyyz_xxyzzzzz_1, tg_xyyz_xxzzzzzz_0, tg_xyyz_xxzzzzzz_1, \
                                         tg_xyyz_xyyyyyyy_0, tg_xyyz_xyyyyyyy_1, tg_xyyz_xyyyyyyz_0, tg_xyyz_xyyyyyyz_1, \
                                         tg_xyyz_xyyyyyzz_0, tg_xyyz_xyyyyyzz_1, tg_xyyz_xyyyyzzz_0, tg_xyyz_xyyyyzzz_1, \
                                         tg_xyyz_xyyyzzzz_0, tg_xyyz_xyyyzzzz_1, tg_xyyz_xyyzzzzz_0, tg_xyyz_xyyzzzzz_1, \
                                         tg_xyyz_xyzzzzzz_0, tg_xyyz_xyzzzzzz_1, tg_xyyz_xzzzzzzz_0, tg_xyyz_xzzzzzzz_1, \
                                         tg_xyyz_yyyyyyyy_0, tg_xyyz_yyyyyyyy_1, tg_xyyz_yyyyyyyz_0, tg_xyyz_yyyyyyyz_1, \
                                         tg_xyyz_yyyyyyzz_0, tg_xyyz_yyyyyyzz_1, tg_xyyz_yyyyyzzz_0, tg_xyyz_yyyyyzzz_1, \
                                         tg_xyyz_yyyyzzzz_0, tg_xyyz_yyyyzzzz_1, tg_xyyz_yyyzzzzz_0, tg_xyyz_yyyzzzzz_1, \
                                         tg_xyyz_yyzzzzzz_0, tg_xyyz_yyzzzzzz_1, tg_xyyz_yzzzzzzz_0, tg_xyyz_yzzzzzzz_1, \
                                         tg_xyyz_zzzzzzzz_0, tg_xyyz_zzzzzzzz_1, tg_xyzz_xxxxxxxx_0, tg_xyzz_xxxxxxxx_1, \
                                         tg_xyzz_xxxxxxxy_0, tg_xyzz_xxxxxxxy_1, tg_xyzz_xxxxxxxz_0, tg_xyzz_xxxxxxxz_1, \
                                         tg_xyzz_xxxxxxyy_0, tg_xyzz_xxxxxxyy_1, tg_xyzz_xxxxxxyz_0, tg_xyzz_xxxxxxyz_1, \
                                         tg_xyzz_xxxxxxzz_0, tg_xyzz_xxxxxxzz_1, tg_xyzz_xxxxxyyy_0, tg_xyzz_xxxxxyyy_1, \
                                         tg_xyzz_xxxxxyyz_0, tg_xyzz_xxxxxyyz_1, tg_xyzz_xxxxxyzz_0, tg_xyzz_xxxxxyzz_1, \
                                         tg_xyzz_xxxxxzzz_0, tg_xyzz_xxxxxzzz_1, tg_xyzz_xxxxyyyy_0, tg_xyzz_xxxxyyyy_1, \
                                         tg_xyzz_xxxxyyyz_0, tg_xyzz_xxxxyyyz_1, tg_xyzz_xxxxyyzz_0, tg_xyzz_xxxxyyzz_1, \
                                         tg_xyzz_xxxxyzzz_0, tg_xyzz_xxxxyzzz_1, tg_xyzz_xxxxzzzz_0, tg_xyzz_xxxxzzzz_1, \
                                         tg_xyzz_xxxyyyyy_0, tg_xyzz_xxxyyyyy_1, tg_xyzz_xxxyyyyz_0, tg_xyzz_xxxyyyyz_1, \
                                         tg_xyzz_xxxyyyzz_0, tg_xyzz_xxxyyyzz_1, tg_xyzz_xxxyyzzz_0, tg_xyzz_xxxyyzzz_1, \
                                         tg_xyzz_xxxyzzzz_0, tg_xyzz_xxxyzzzz_1, tg_xyzz_xxxzzzzz_0, tg_xyzz_xxxzzzzz_1, \
                                         tg_xyzz_xxyyyyyy_0, tg_xyzz_xxyyyyyy_1, tg_xyzz_xxyyyyyz_0, tg_xyzz_xxyyyyyz_1, \
                                         tg_xyzz_xxyyyyzz_0, tg_xyzz_xxyyyyzz_1, tg_xyzz_xxyyyzzz_0, tg_xyzz_xxyyyzzz_1, \
                                         tg_xyzz_xxyyzzzz_0, tg_xyzz_xxyyzzzz_1, tg_xyzz_xxyzzzzz_0, tg_xyzz_xxyzzzzz_1, \
                                         tg_xyzz_xxzzzzzz_0, tg_xyzz_xxzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyyy_xxyyyyyy_0[j] = pb_x * tg_xxyyy_xxyyyyyy_0[j] + fr * tg_xxyyy_xxyyyyyy_1[j] + fl1_fx * (tg_xyyy_xxyyyyyy_0[j] - tg_xyyy_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyyyyyy_1[j];

                    tg_xxxyyy_xxyyyyyz_0[j] = pb_x * tg_xxyyy_xxyyyyyz_0[j] + fr * tg_xxyyy_xxyyyyyz_1[j] + fl1_fx * (tg_xyyy_xxyyyyyz_0[j] - tg_xyyy_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyyyyyz_1[j];

                    tg_xxxyyy_xxyyyyzz_0[j] = pb_x * tg_xxyyy_xxyyyyzz_0[j] + fr * tg_xxyyy_xxyyyyzz_1[j] + fl1_fx * (tg_xyyy_xxyyyyzz_0[j] - tg_xyyy_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyyyyzz_1[j];

                    tg_xxxyyy_xxyyyzzz_0[j] = pb_x * tg_xxyyy_xxyyyzzz_0[j] + fr * tg_xxyyy_xxyyyzzz_1[j] + fl1_fx * (tg_xyyy_xxyyyzzz_0[j] - tg_xyyy_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyyyzzz_1[j];

                    tg_xxxyyy_xxyyzzzz_0[j] = pb_x * tg_xxyyy_xxyyzzzz_0[j] + fr * tg_xxyyy_xxyyzzzz_1[j] + fl1_fx * (tg_xyyy_xxyyzzzz_0[j] - tg_xyyy_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyyzzzz_1[j];

                    tg_xxxyyy_xxyzzzzz_0[j] = pb_x * tg_xxyyy_xxyzzzzz_0[j] + fr * tg_xxyyy_xxyzzzzz_1[j] + fl1_fx * (tg_xyyy_xxyzzzzz_0[j] - tg_xyyy_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xyzzzzz_1[j];

                    tg_xxxyyy_xxzzzzzz_0[j] = pb_x * tg_xxyyy_xxzzzzzz_0[j] + fr * tg_xxyyy_xxzzzzzz_1[j] + fl1_fx * (tg_xyyy_xxzzzzzz_0[j] - tg_xyyy_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyy_xzzzzzz_1[j];

                    tg_xxxyyy_xyyyyyyy_0[j] = pb_x * tg_xxyyy_xyyyyyyy_0[j] + fr * tg_xxyyy_xyyyyyyy_1[j] + fl1_fx * (tg_xyyy_xyyyyyyy_0[j] - tg_xyyy_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyyyyyy_1[j];

                    tg_xxxyyy_xyyyyyyz_0[j] = pb_x * tg_xxyyy_xyyyyyyz_0[j] + fr * tg_xxyyy_xyyyyyyz_1[j] + fl1_fx * (tg_xyyy_xyyyyyyz_0[j] - tg_xyyy_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyyyyyz_1[j];

                    tg_xxxyyy_xyyyyyzz_0[j] = pb_x * tg_xxyyy_xyyyyyzz_0[j] + fr * tg_xxyyy_xyyyyyzz_1[j] + fl1_fx * (tg_xyyy_xyyyyyzz_0[j] - tg_xyyy_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyyyyzz_1[j];

                    tg_xxxyyy_xyyyyzzz_0[j] = pb_x * tg_xxyyy_xyyyyzzz_0[j] + fr * tg_xxyyy_xyyyyzzz_1[j] + fl1_fx * (tg_xyyy_xyyyyzzz_0[j] - tg_xyyy_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyyyzzz_1[j];

                    tg_xxxyyy_xyyyzzzz_0[j] = pb_x * tg_xxyyy_xyyyzzzz_0[j] + fr * tg_xxyyy_xyyyzzzz_1[j] + fl1_fx * (tg_xyyy_xyyyzzzz_0[j] - tg_xyyy_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyyzzzz_1[j];

                    tg_xxxyyy_xyyzzzzz_0[j] = pb_x * tg_xxyyy_xyyzzzzz_0[j] + fr * tg_xxyyy_xyyzzzzz_1[j] + fl1_fx * (tg_xyyy_xyyzzzzz_0[j] - tg_xyyy_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yyzzzzz_1[j];

                    tg_xxxyyy_xyzzzzzz_0[j] = pb_x * tg_xxyyy_xyzzzzzz_0[j] + fr * tg_xxyyy_xyzzzzzz_1[j] + fl1_fx * (tg_xyyy_xyzzzzzz_0[j] - tg_xyyy_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_yzzzzzz_1[j];

                    tg_xxxyyy_xzzzzzzz_0[j] = pb_x * tg_xxyyy_xzzzzzzz_0[j] + fr * tg_xxyyy_xzzzzzzz_1[j] + fl1_fx * (tg_xyyy_xzzzzzzz_0[j] - tg_xyyy_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyy_zzzzzzz_1[j];

                    tg_xxxyyy_yyyyyyyy_0[j] = pb_x * tg_xxyyy_yyyyyyyy_0[j] + fr * tg_xxyyy_yyyyyyyy_1[j] + fl1_fx * (tg_xyyy_yyyyyyyy_0[j] - tg_xyyy_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxyyy_yyyyyyyz_0[j] = pb_x * tg_xxyyy_yyyyyyyz_0[j] + fr * tg_xxyyy_yyyyyyyz_1[j] + fl1_fx * (tg_xyyy_yyyyyyyz_0[j] - tg_xyyy_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxyyy_yyyyyyzz_0[j] = pb_x * tg_xxyyy_yyyyyyzz_0[j] + fr * tg_xxyyy_yyyyyyzz_1[j] + fl1_fx * (tg_xyyy_yyyyyyzz_0[j] - tg_xyyy_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxyyy_yyyyyzzz_0[j] = pb_x * tg_xxyyy_yyyyyzzz_0[j] + fr * tg_xxyyy_yyyyyzzz_1[j] + fl1_fx * (tg_xyyy_yyyyyzzz_0[j] - tg_xyyy_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxyyy_yyyyzzzz_0[j] = pb_x * tg_xxyyy_yyyyzzzz_0[j] + fr * tg_xxyyy_yyyyzzzz_1[j] + fl1_fx * (tg_xyyy_yyyyzzzz_0[j] - tg_xyyy_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxyyy_yyyzzzzz_0[j] = pb_x * tg_xxyyy_yyyzzzzz_0[j] + fr * tg_xxyyy_yyyzzzzz_1[j] + fl1_fx * (tg_xyyy_yyyzzzzz_0[j] - tg_xyyy_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxyyy_yyzzzzzz_0[j] = pb_x * tg_xxyyy_yyzzzzzz_0[j] + fr * tg_xxyyy_yyzzzzzz_1[j] + fl1_fx * (tg_xyyy_yyzzzzzz_0[j] - tg_xyyy_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyy_yzzzzzzz_0[j] = pb_x * tg_xxyyy_yzzzzzzz_0[j] + fr * tg_xxyyy_yzzzzzzz_1[j] + fl1_fx * (tg_xyyy_yzzzzzzz_0[j] - tg_xyyy_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyy_zzzzzzzz_0[j] = pb_x * tg_xxyyy_zzzzzzzz_0[j] + fr * tg_xxyyy_zzzzzzzz_1[j] + fl1_fx * (tg_xyyy_zzzzzzzz_0[j] - tg_xyyy_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyz_xxxxxxxx_0[j] = pb_x * tg_xxyyz_xxxxxxxx_0[j] + fr * tg_xxyyz_xxxxxxxx_1[j] + fl1_fx * (tg_xyyz_xxxxxxxx_0[j] - tg_xyyz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxyyz_xxxxxxx_1[j];

                    tg_xxxyyz_xxxxxxxy_0[j] = pb_x * tg_xxyyz_xxxxxxxy_0[j] + fr * tg_xxyyz_xxxxxxxy_1[j] + fl1_fx * (tg_xyyz_xxxxxxxy_0[j] - tg_xyyz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyz_xxxxxxy_1[j];

                    tg_xxxyyz_xxxxxxxz_0[j] = pb_x * tg_xxyyz_xxxxxxxz_0[j] + fr * tg_xxyyz_xxxxxxxz_1[j] + fl1_fx * (tg_xyyz_xxxxxxxz_0[j] - tg_xyyz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyz_xxxxxxz_1[j];

                    tg_xxxyyz_xxxxxxyy_0[j] = pb_x * tg_xxyyz_xxxxxxyy_0[j] + fr * tg_xxyyz_xxxxxxyy_1[j] + fl1_fx * (tg_xyyz_xxxxxxyy_0[j] - tg_xyyz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyz_xxxxxyy_1[j];

                    tg_xxxyyz_xxxxxxyz_0[j] = pb_x * tg_xxyyz_xxxxxxyz_0[j] + fr * tg_xxyyz_xxxxxxyz_1[j] + fl1_fx * (tg_xyyz_xxxxxxyz_0[j] - tg_xyyz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyz_xxxxxyz_1[j];

                    tg_xxxyyz_xxxxxxzz_0[j] = pb_x * tg_xxyyz_xxxxxxzz_0[j] + fr * tg_xxyyz_xxxxxxzz_1[j] + fl1_fx * (tg_xyyz_xxxxxxzz_0[j] - tg_xyyz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyz_xxxxxzz_1[j];

                    tg_xxxyyz_xxxxxyyy_0[j] = pb_x * tg_xxyyz_xxxxxyyy_0[j] + fr * tg_xxyyz_xxxxxyyy_1[j] + fl1_fx * (tg_xyyz_xxxxxyyy_0[j] - tg_xyyz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyz_xxxxyyy_1[j];

                    tg_xxxyyz_xxxxxyyz_0[j] = pb_x * tg_xxyyz_xxxxxyyz_0[j] + fr * tg_xxyyz_xxxxxyyz_1[j] + fl1_fx * (tg_xyyz_xxxxxyyz_0[j] - tg_xyyz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyz_xxxxyyz_1[j];

                    tg_xxxyyz_xxxxxyzz_0[j] = pb_x * tg_xxyyz_xxxxxyzz_0[j] + fr * tg_xxyyz_xxxxxyzz_1[j] + fl1_fx * (tg_xyyz_xxxxxyzz_0[j] - tg_xyyz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyz_xxxxyzz_1[j];

                    tg_xxxyyz_xxxxxzzz_0[j] = pb_x * tg_xxyyz_xxxxxzzz_0[j] + fr * tg_xxyyz_xxxxxzzz_1[j] + fl1_fx * (tg_xyyz_xxxxxzzz_0[j] - tg_xyyz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyz_xxxxzzz_1[j];

                    tg_xxxyyz_xxxxyyyy_0[j] = pb_x * tg_xxyyz_xxxxyyyy_0[j] + fr * tg_xxyyz_xxxxyyyy_1[j] + fl1_fx * (tg_xyyz_xxxxyyyy_0[j] - tg_xyyz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyz_xxxyyyy_1[j];

                    tg_xxxyyz_xxxxyyyz_0[j] = pb_x * tg_xxyyz_xxxxyyyz_0[j] + fr * tg_xxyyz_xxxxyyyz_1[j] + fl1_fx * (tg_xyyz_xxxxyyyz_0[j] - tg_xyyz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyz_xxxyyyz_1[j];

                    tg_xxxyyz_xxxxyyzz_0[j] = pb_x * tg_xxyyz_xxxxyyzz_0[j] + fr * tg_xxyyz_xxxxyyzz_1[j] + fl1_fx * (tg_xyyz_xxxxyyzz_0[j] - tg_xyyz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyz_xxxyyzz_1[j];

                    tg_xxxyyz_xxxxyzzz_0[j] = pb_x * tg_xxyyz_xxxxyzzz_0[j] + fr * tg_xxyyz_xxxxyzzz_1[j] + fl1_fx * (tg_xyyz_xxxxyzzz_0[j] - tg_xyyz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyz_xxxyzzz_1[j];

                    tg_xxxyyz_xxxxzzzz_0[j] = pb_x * tg_xxyyz_xxxxzzzz_0[j] + fr * tg_xxyyz_xxxxzzzz_1[j] + fl1_fx * (tg_xyyz_xxxxzzzz_0[j] - tg_xyyz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyz_xxxzzzz_1[j];

                    tg_xxxyyz_xxxyyyyy_0[j] = pb_x * tg_xxyyz_xxxyyyyy_0[j] + fr * tg_xxyyz_xxxyyyyy_1[j] + fl1_fx * (tg_xyyz_xxxyyyyy_0[j] - tg_xyyz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxyyyyy_1[j];

                    tg_xxxyyz_xxxyyyyz_0[j] = pb_x * tg_xxyyz_xxxyyyyz_0[j] + fr * tg_xxyyz_xxxyyyyz_1[j] + fl1_fx * (tg_xyyz_xxxyyyyz_0[j] - tg_xyyz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxyyyyz_1[j];

                    tg_xxxyyz_xxxyyyzz_0[j] = pb_x * tg_xxyyz_xxxyyyzz_0[j] + fr * tg_xxyyz_xxxyyyzz_1[j] + fl1_fx * (tg_xyyz_xxxyyyzz_0[j] - tg_xyyz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxyyyzz_1[j];

                    tg_xxxyyz_xxxyyzzz_0[j] = pb_x * tg_xxyyz_xxxyyzzz_0[j] + fr * tg_xxyyz_xxxyyzzz_1[j] + fl1_fx * (tg_xyyz_xxxyyzzz_0[j] - tg_xyyz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxyyzzz_1[j];

                    tg_xxxyyz_xxxyzzzz_0[j] = pb_x * tg_xxyyz_xxxyzzzz_0[j] + fr * tg_xxyyz_xxxyzzzz_1[j] + fl1_fx * (tg_xyyz_xxxyzzzz_0[j] - tg_xyyz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxyzzzz_1[j];

                    tg_xxxyyz_xxxzzzzz_0[j] = pb_x * tg_xxyyz_xxxzzzzz_0[j] + fr * tg_xxyyz_xxxzzzzz_1[j] + fl1_fx * (tg_xyyz_xxxzzzzz_0[j] - tg_xyyz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyz_xxzzzzz_1[j];

                    tg_xxxyyz_xxyyyyyy_0[j] = pb_x * tg_xxyyz_xxyyyyyy_0[j] + fr * tg_xxyyz_xxyyyyyy_1[j] + fl1_fx * (tg_xyyz_xxyyyyyy_0[j] - tg_xyyz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyyyyyy_1[j];

                    tg_xxxyyz_xxyyyyyz_0[j] = pb_x * tg_xxyyz_xxyyyyyz_0[j] + fr * tg_xxyyz_xxyyyyyz_1[j] + fl1_fx * (tg_xyyz_xxyyyyyz_0[j] - tg_xyyz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyyyyyz_1[j];

                    tg_xxxyyz_xxyyyyzz_0[j] = pb_x * tg_xxyyz_xxyyyyzz_0[j] + fr * tg_xxyyz_xxyyyyzz_1[j] + fl1_fx * (tg_xyyz_xxyyyyzz_0[j] - tg_xyyz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyyyyzz_1[j];

                    tg_xxxyyz_xxyyyzzz_0[j] = pb_x * tg_xxyyz_xxyyyzzz_0[j] + fr * tg_xxyyz_xxyyyzzz_1[j] + fl1_fx * (tg_xyyz_xxyyyzzz_0[j] - tg_xyyz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyyyzzz_1[j];

                    tg_xxxyyz_xxyyzzzz_0[j] = pb_x * tg_xxyyz_xxyyzzzz_0[j] + fr * tg_xxyyz_xxyyzzzz_1[j] + fl1_fx * (tg_xyyz_xxyyzzzz_0[j] - tg_xyyz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyyzzzz_1[j];

                    tg_xxxyyz_xxyzzzzz_0[j] = pb_x * tg_xxyyz_xxyzzzzz_0[j] + fr * tg_xxyyz_xxyzzzzz_1[j] + fl1_fx * (tg_xyyz_xxyzzzzz_0[j] - tg_xyyz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xyzzzzz_1[j];

                    tg_xxxyyz_xxzzzzzz_0[j] = pb_x * tg_xxyyz_xxzzzzzz_0[j] + fr * tg_xxyyz_xxzzzzzz_1[j] + fl1_fx * (tg_xyyz_xxzzzzzz_0[j] - tg_xyyz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyz_xzzzzzz_1[j];

                    tg_xxxyyz_xyyyyyyy_0[j] = pb_x * tg_xxyyz_xyyyyyyy_0[j] + fr * tg_xxyyz_xyyyyyyy_1[j] + fl1_fx * (tg_xyyz_xyyyyyyy_0[j] - tg_xyyz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyyyyyy_1[j];

                    tg_xxxyyz_xyyyyyyz_0[j] = pb_x * tg_xxyyz_xyyyyyyz_0[j] + fr * tg_xxyyz_xyyyyyyz_1[j] + fl1_fx * (tg_xyyz_xyyyyyyz_0[j] - tg_xyyz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyyyyyz_1[j];

                    tg_xxxyyz_xyyyyyzz_0[j] = pb_x * tg_xxyyz_xyyyyyzz_0[j] + fr * tg_xxyyz_xyyyyyzz_1[j] + fl1_fx * (tg_xyyz_xyyyyyzz_0[j] - tg_xyyz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyyyyzz_1[j];

                    tg_xxxyyz_xyyyyzzz_0[j] = pb_x * tg_xxyyz_xyyyyzzz_0[j] + fr * tg_xxyyz_xyyyyzzz_1[j] + fl1_fx * (tg_xyyz_xyyyyzzz_0[j] - tg_xyyz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyyyzzz_1[j];

                    tg_xxxyyz_xyyyzzzz_0[j] = pb_x * tg_xxyyz_xyyyzzzz_0[j] + fr * tg_xxyyz_xyyyzzzz_1[j] + fl1_fx * (tg_xyyz_xyyyzzzz_0[j] - tg_xyyz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyyzzzz_1[j];

                    tg_xxxyyz_xyyzzzzz_0[j] = pb_x * tg_xxyyz_xyyzzzzz_0[j] + fr * tg_xxyyz_xyyzzzzz_1[j] + fl1_fx * (tg_xyyz_xyyzzzzz_0[j] - tg_xyyz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yyzzzzz_1[j];

                    tg_xxxyyz_xyzzzzzz_0[j] = pb_x * tg_xxyyz_xyzzzzzz_0[j] + fr * tg_xxyyz_xyzzzzzz_1[j] + fl1_fx * (tg_xyyz_xyzzzzzz_0[j] - tg_xyyz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_yzzzzzz_1[j];

                    tg_xxxyyz_xzzzzzzz_0[j] = pb_x * tg_xxyyz_xzzzzzzz_0[j] + fr * tg_xxyyz_xzzzzzzz_1[j] + fl1_fx * (tg_xyyz_xzzzzzzz_0[j] - tg_xyyz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyz_zzzzzzz_1[j];

                    tg_xxxyyz_yyyyyyyy_0[j] = pb_x * tg_xxyyz_yyyyyyyy_0[j] + fr * tg_xxyyz_yyyyyyyy_1[j] + fl1_fx * (tg_xyyz_yyyyyyyy_0[j] - tg_xyyz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxyyz_yyyyyyyz_0[j] = pb_x * tg_xxyyz_yyyyyyyz_0[j] + fr * tg_xxyyz_yyyyyyyz_1[j] + fl1_fx * (tg_xyyz_yyyyyyyz_0[j] - tg_xyyz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxyyz_yyyyyyzz_0[j] = pb_x * tg_xxyyz_yyyyyyzz_0[j] + fr * tg_xxyyz_yyyyyyzz_1[j] + fl1_fx * (tg_xyyz_yyyyyyzz_0[j] - tg_xyyz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxyyz_yyyyyzzz_0[j] = pb_x * tg_xxyyz_yyyyyzzz_0[j] + fr * tg_xxyyz_yyyyyzzz_1[j] + fl1_fx * (tg_xyyz_yyyyyzzz_0[j] - tg_xyyz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxyyz_yyyyzzzz_0[j] = pb_x * tg_xxyyz_yyyyzzzz_0[j] + fr * tg_xxyyz_yyyyzzzz_1[j] + fl1_fx * (tg_xyyz_yyyyzzzz_0[j] - tg_xyyz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxyyz_yyyzzzzz_0[j] = pb_x * tg_xxyyz_yyyzzzzz_0[j] + fr * tg_xxyyz_yyyzzzzz_1[j] + fl1_fx * (tg_xyyz_yyyzzzzz_0[j] - tg_xyyz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxyyz_yyzzzzzz_0[j] = pb_x * tg_xxyyz_yyzzzzzz_0[j] + fr * tg_xxyyz_yyzzzzzz_1[j] + fl1_fx * (tg_xyyz_yyzzzzzz_0[j] - tg_xyyz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyz_yzzzzzzz_0[j] = pb_x * tg_xxyyz_yzzzzzzz_0[j] + fr * tg_xxyyz_yzzzzzzz_1[j] + fl1_fx * (tg_xyyz_yzzzzzzz_0[j] - tg_xyyz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyz_zzzzzzzz_0[j] = pb_x * tg_xxyyz_zzzzzzzz_0[j] + fr * tg_xxyyz_zzzzzzzz_1[j] + fl1_fx * (tg_xyyz_zzzzzzzz_0[j] - tg_xyyz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyzz_xxxxxxxx_0[j] = pb_x * tg_xxyzz_xxxxxxxx_0[j] + fr * tg_xxyzz_xxxxxxxx_1[j] + fl1_fx * (tg_xyzz_xxxxxxxx_0[j] - tg_xyzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxyzz_xxxxxxx_1[j];

                    tg_xxxyzz_xxxxxxxy_0[j] = pb_x * tg_xxyzz_xxxxxxxy_0[j] + fr * tg_xxyzz_xxxxxxxy_1[j] + fl1_fx * (tg_xyzz_xxxxxxxy_0[j] - tg_xyzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyzz_xxxxxxy_1[j];

                    tg_xxxyzz_xxxxxxxz_0[j] = pb_x * tg_xxyzz_xxxxxxxz_0[j] + fr * tg_xxyzz_xxxxxxxz_1[j] + fl1_fx * (tg_xyzz_xxxxxxxz_0[j] - tg_xyzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyzz_xxxxxxz_1[j];

                    tg_xxxyzz_xxxxxxyy_0[j] = pb_x * tg_xxyzz_xxxxxxyy_0[j] + fr * tg_xxyzz_xxxxxxyy_1[j] + fl1_fx * (tg_xyzz_xxxxxxyy_0[j] - tg_xyzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzz_xxxxxyy_1[j];

                    tg_xxxyzz_xxxxxxyz_0[j] = pb_x * tg_xxyzz_xxxxxxyz_0[j] + fr * tg_xxyzz_xxxxxxyz_1[j] + fl1_fx * (tg_xyzz_xxxxxxyz_0[j] - tg_xyzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzz_xxxxxyz_1[j];

                    tg_xxxyzz_xxxxxxzz_0[j] = pb_x * tg_xxyzz_xxxxxxzz_0[j] + fr * tg_xxyzz_xxxxxxzz_1[j] + fl1_fx * (tg_xyzz_xxxxxxzz_0[j] - tg_xyzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzz_xxxxxzz_1[j];

                    tg_xxxyzz_xxxxxyyy_0[j] = pb_x * tg_xxyzz_xxxxxyyy_0[j] + fr * tg_xxyzz_xxxxxyyy_1[j] + fl1_fx * (tg_xyzz_xxxxxyyy_0[j] - tg_xyzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzz_xxxxyyy_1[j];

                    tg_xxxyzz_xxxxxyyz_0[j] = pb_x * tg_xxyzz_xxxxxyyz_0[j] + fr * tg_xxyzz_xxxxxyyz_1[j] + fl1_fx * (tg_xyzz_xxxxxyyz_0[j] - tg_xyzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzz_xxxxyyz_1[j];

                    tg_xxxyzz_xxxxxyzz_0[j] = pb_x * tg_xxyzz_xxxxxyzz_0[j] + fr * tg_xxyzz_xxxxxyzz_1[j] + fl1_fx * (tg_xyzz_xxxxxyzz_0[j] - tg_xyzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzz_xxxxyzz_1[j];

                    tg_xxxyzz_xxxxxzzz_0[j] = pb_x * tg_xxyzz_xxxxxzzz_0[j] + fr * tg_xxyzz_xxxxxzzz_1[j] + fl1_fx * (tg_xyzz_xxxxxzzz_0[j] - tg_xyzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzz_xxxxzzz_1[j];

                    tg_xxxyzz_xxxxyyyy_0[j] = pb_x * tg_xxyzz_xxxxyyyy_0[j] + fr * tg_xxyzz_xxxxyyyy_1[j] + fl1_fx * (tg_xyzz_xxxxyyyy_0[j] - tg_xyzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzz_xxxyyyy_1[j];

                    tg_xxxyzz_xxxxyyyz_0[j] = pb_x * tg_xxyzz_xxxxyyyz_0[j] + fr * tg_xxyzz_xxxxyyyz_1[j] + fl1_fx * (tg_xyzz_xxxxyyyz_0[j] - tg_xyzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzz_xxxyyyz_1[j];

                    tg_xxxyzz_xxxxyyzz_0[j] = pb_x * tg_xxyzz_xxxxyyzz_0[j] + fr * tg_xxyzz_xxxxyyzz_1[j] + fl1_fx * (tg_xyzz_xxxxyyzz_0[j] - tg_xyzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzz_xxxyyzz_1[j];

                    tg_xxxyzz_xxxxyzzz_0[j] = pb_x * tg_xxyzz_xxxxyzzz_0[j] + fr * tg_xxyzz_xxxxyzzz_1[j] + fl1_fx * (tg_xyzz_xxxxyzzz_0[j] - tg_xyzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzz_xxxyzzz_1[j];

                    tg_xxxyzz_xxxxzzzz_0[j] = pb_x * tg_xxyzz_xxxxzzzz_0[j] + fr * tg_xxyzz_xxxxzzzz_1[j] + fl1_fx * (tg_xyzz_xxxxzzzz_0[j] - tg_xyzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzz_xxxzzzz_1[j];

                    tg_xxxyzz_xxxyyyyy_0[j] = pb_x * tg_xxyzz_xxxyyyyy_0[j] + fr * tg_xxyzz_xxxyyyyy_1[j] + fl1_fx * (tg_xyzz_xxxyyyyy_0[j] - tg_xyzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxyyyyy_1[j];

                    tg_xxxyzz_xxxyyyyz_0[j] = pb_x * tg_xxyzz_xxxyyyyz_0[j] + fr * tg_xxyzz_xxxyyyyz_1[j] + fl1_fx * (tg_xyzz_xxxyyyyz_0[j] - tg_xyzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxyyyyz_1[j];

                    tg_xxxyzz_xxxyyyzz_0[j] = pb_x * tg_xxyzz_xxxyyyzz_0[j] + fr * tg_xxyzz_xxxyyyzz_1[j] + fl1_fx * (tg_xyzz_xxxyyyzz_0[j] - tg_xyzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxyyyzz_1[j];

                    tg_xxxyzz_xxxyyzzz_0[j] = pb_x * tg_xxyzz_xxxyyzzz_0[j] + fr * tg_xxyzz_xxxyyzzz_1[j] + fl1_fx * (tg_xyzz_xxxyyzzz_0[j] - tg_xyzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxyyzzz_1[j];

                    tg_xxxyzz_xxxyzzzz_0[j] = pb_x * tg_xxyzz_xxxyzzzz_0[j] + fr * tg_xxyzz_xxxyzzzz_1[j] + fl1_fx * (tg_xyzz_xxxyzzzz_0[j] - tg_xyzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxyzzzz_1[j];

                    tg_xxxyzz_xxxzzzzz_0[j] = pb_x * tg_xxyzz_xxxzzzzz_0[j] + fr * tg_xxyzz_xxxzzzzz_1[j] + fl1_fx * (tg_xyzz_xxxzzzzz_0[j] - tg_xyzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzz_xxzzzzz_1[j];

                    tg_xxxyzz_xxyyyyyy_0[j] = pb_x * tg_xxyzz_xxyyyyyy_0[j] + fr * tg_xxyzz_xxyyyyyy_1[j] + fl1_fx * (tg_xyzz_xxyyyyyy_0[j] - tg_xyzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyyyyyy_1[j];

                    tg_xxxyzz_xxyyyyyz_0[j] = pb_x * tg_xxyzz_xxyyyyyz_0[j] + fr * tg_xxyzz_xxyyyyyz_1[j] + fl1_fx * (tg_xyzz_xxyyyyyz_0[j] - tg_xyzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyyyyyz_1[j];

                    tg_xxxyzz_xxyyyyzz_0[j] = pb_x * tg_xxyzz_xxyyyyzz_0[j] + fr * tg_xxyzz_xxyyyyzz_1[j] + fl1_fx * (tg_xyzz_xxyyyyzz_0[j] - tg_xyzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyyyyzz_1[j];

                    tg_xxxyzz_xxyyyzzz_0[j] = pb_x * tg_xxyzz_xxyyyzzz_0[j] + fr * tg_xxyzz_xxyyyzzz_1[j] + fl1_fx * (tg_xyzz_xxyyyzzz_0[j] - tg_xyzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyyyzzz_1[j];

                    tg_xxxyzz_xxyyzzzz_0[j] = pb_x * tg_xxyzz_xxyyzzzz_0[j] + fr * tg_xxyzz_xxyyzzzz_1[j] + fl1_fx * (tg_xyzz_xxyyzzzz_0[j] - tg_xyzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyyzzzz_1[j];

                    tg_xxxyzz_xxyzzzzz_0[j] = pb_x * tg_xxyzz_xxyzzzzz_0[j] + fr * tg_xxyzz_xxyzzzzz_1[j] + fl1_fx * (tg_xyzz_xxyzzzzz_0[j] - tg_xyzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xyzzzzz_1[j];

                    tg_xxxyzz_xxzzzzzz_0[j] = pb_x * tg_xxyzz_xxzzzzzz_0[j] + fr * tg_xxyzz_xxzzzzzz_1[j] + fl1_fx * (tg_xyzz_xxzzzzzz_0[j] - tg_xyzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzz_xzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_388_485(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (388,485)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 388); 

                auto tg_xxyzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 389); 

                auto tg_xxyzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 390); 

                auto tg_xxyzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 391); 

                auto tg_xxyzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 392); 

                auto tg_xxyzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 393); 

                auto tg_xxyzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 394); 

                auto tg_xxyzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 395); 

                auto tg_xxyzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 396); 

                auto tg_xxyzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 397); 

                auto tg_xxyzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 398); 

                auto tg_xxyzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 399); 

                auto tg_xxyzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 400); 

                auto tg_xxyzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 401); 

                auto tg_xxyzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 402); 

                auto tg_xxyzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 403); 

                auto tg_xxyzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 404); 

                auto tg_xxzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 405); 

                auto tg_xxzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 406); 

                auto tg_xxzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 407); 

                auto tg_xxzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 408); 

                auto tg_xxzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 409); 

                auto tg_xxzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 410); 

                auto tg_xxzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 411); 

                auto tg_xxzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 412); 

                auto tg_xxzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 413); 

                auto tg_xxzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 414); 

                auto tg_xxzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 415); 

                auto tg_xxzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 416); 

                auto tg_xxzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 417); 

                auto tg_xxzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 418); 

                auto tg_xxzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 419); 

                auto tg_xxzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 420); 

                auto tg_xxzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 421); 

                auto tg_xxzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 422); 

                auto tg_xxzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 423); 

                auto tg_xxzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 424); 

                auto tg_xxzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 425); 

                auto tg_xxzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 426); 

                auto tg_xxzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 427); 

                auto tg_xxzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 428); 

                auto tg_xxzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 429); 

                auto tg_xxzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 430); 

                auto tg_xxzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 431); 

                auto tg_xxzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 432); 

                auto tg_xxzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 433); 

                auto tg_xxzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 434); 

                auto tg_xxzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 435); 

                auto tg_xxzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 436); 

                auto tg_xxzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 437); 

                auto tg_xxzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 438); 

                auto tg_xxzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 439); 

                auto tg_xxzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 440); 

                auto tg_xxzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 441); 

                auto tg_xxzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 442); 

                auto tg_xxzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 443); 

                auto tg_xxzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 444); 

                auto tg_xxzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 445); 

                auto tg_xxzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 446); 

                auto tg_xxzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 447); 

                auto tg_xxzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 448); 

                auto tg_xxzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 449); 

                auto tg_xyyyy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 450); 

                auto tg_xyyyy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 451); 

                auto tg_xyyyy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 452); 

                auto tg_xyyyy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 453); 

                auto tg_xyyyy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 454); 

                auto tg_xyyyy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 455); 

                auto tg_xyyyy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 456); 

                auto tg_xyyyy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 457); 

                auto tg_xyyyy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 458); 

                auto tg_xyyyy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 459); 

                auto tg_xyyyy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 460); 

                auto tg_xyyyy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 461); 

                auto tg_xyyyy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 462); 

                auto tg_xyyyy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 463); 

                auto tg_xyyyy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 464); 

                auto tg_xyyyy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 465); 

                auto tg_xyyyy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 466); 

                auto tg_xyyyy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 467); 

                auto tg_xyyyy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 468); 

                auto tg_xyyyy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 469); 

                auto tg_xyyyy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 470); 

                auto tg_xyyyy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 471); 

                auto tg_xyyyy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 472); 

                auto tg_xyyyy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 473); 

                auto tg_xyyyy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 474); 

                auto tg_xyyyy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 475); 

                auto tg_xyyyy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 476); 

                auto tg_xyyyy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 477); 

                auto tg_xyyyy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 478); 

                auto tg_xyyyy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 479); 

                auto tg_xyyyy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 480); 

                auto tg_xyyyy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 481); 

                auto tg_xyyyy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 482); 

                auto tg_xyyyy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 483); 

                auto tg_xyyyy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 484); 

                auto tg_xxyzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 388); 

                auto tg_xxyzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 389); 

                auto tg_xxyzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 390); 

                auto tg_xxyzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 391); 

                auto tg_xxyzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 392); 

                auto tg_xxyzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 393); 

                auto tg_xxyzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 394); 

                auto tg_xxyzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 395); 

                auto tg_xxyzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 396); 

                auto tg_xxyzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 397); 

                auto tg_xxyzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 398); 

                auto tg_xxyzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 399); 

                auto tg_xxyzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 400); 

                auto tg_xxyzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 401); 

                auto tg_xxyzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 402); 

                auto tg_xxyzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 403); 

                auto tg_xxyzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 404); 

                auto tg_xxzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 405); 

                auto tg_xxzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 406); 

                auto tg_xxzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 407); 

                auto tg_xxzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 408); 

                auto tg_xxzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 409); 

                auto tg_xxzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 410); 

                auto tg_xxzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 411); 

                auto tg_xxzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 412); 

                auto tg_xxzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 413); 

                auto tg_xxzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 414); 

                auto tg_xxzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 415); 

                auto tg_xxzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 416); 

                auto tg_xxzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 417); 

                auto tg_xxzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 418); 

                auto tg_xxzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 419); 

                auto tg_xxzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 420); 

                auto tg_xxzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 421); 

                auto tg_xxzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 422); 

                auto tg_xxzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 423); 

                auto tg_xxzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 424); 

                auto tg_xxzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 425); 

                auto tg_xxzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 426); 

                auto tg_xxzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 427); 

                auto tg_xxzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 428); 

                auto tg_xxzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 429); 

                auto tg_xxzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 430); 

                auto tg_xxzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 431); 

                auto tg_xxzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 432); 

                auto tg_xxzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 433); 

                auto tg_xxzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 434); 

                auto tg_xxzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 435); 

                auto tg_xxzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 436); 

                auto tg_xxzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 437); 

                auto tg_xxzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 438); 

                auto tg_xxzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 439); 

                auto tg_xxzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 440); 

                auto tg_xxzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 441); 

                auto tg_xxzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 442); 

                auto tg_xxzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 443); 

                auto tg_xxzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 444); 

                auto tg_xxzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 445); 

                auto tg_xxzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 446); 

                auto tg_xxzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 447); 

                auto tg_xxzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 448); 

                auto tg_xxzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 449); 

                auto tg_xyyyy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 450); 

                auto tg_xyyyy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 451); 

                auto tg_xyyyy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 452); 

                auto tg_xyyyy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 453); 

                auto tg_xyyyy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 454); 

                auto tg_xyyyy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 455); 

                auto tg_xyyyy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 456); 

                auto tg_xyyyy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 457); 

                auto tg_xyyyy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 458); 

                auto tg_xyyyy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 459); 

                auto tg_xyyyy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 460); 

                auto tg_xyyyy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 461); 

                auto tg_xyyyy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 462); 

                auto tg_xyyyy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 463); 

                auto tg_xyyyy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 464); 

                auto tg_xyyyy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 465); 

                auto tg_xyyyy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 466); 

                auto tg_xyyyy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 467); 

                auto tg_xyyyy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 468); 

                auto tg_xyyyy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 469); 

                auto tg_xyyyy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 470); 

                auto tg_xyyyy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 471); 

                auto tg_xyyyy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 472); 

                auto tg_xyyyy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 473); 

                auto tg_xyyyy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 474); 

                auto tg_xyyyy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 475); 

                auto tg_xyyyy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 476); 

                auto tg_xyyyy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 477); 

                auto tg_xyyyy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 478); 

                auto tg_xyyyy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 479); 

                auto tg_xyyyy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 480); 

                auto tg_xyyyy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 481); 

                auto tg_xyyyy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 482); 

                auto tg_xyyyy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 483); 

                auto tg_xyyyy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 484); 

                auto tg_xyzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 388); 

                auto tg_xyzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 389); 

                auto tg_xyzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 390); 

                auto tg_xyzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 391); 

                auto tg_xyzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 392); 

                auto tg_xyzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 393); 

                auto tg_xyzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 394); 

                auto tg_xyzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 395); 

                auto tg_xyzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 396); 

                auto tg_xyzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 397); 

                auto tg_xyzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 398); 

                auto tg_xyzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 399); 

                auto tg_xyzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 400); 

                auto tg_xyzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 401); 

                auto tg_xyzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 402); 

                auto tg_xyzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 403); 

                auto tg_xyzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 404); 

                auto tg_xzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 405); 

                auto tg_xzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 406); 

                auto tg_xzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 407); 

                auto tg_xzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 408); 

                auto tg_xzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 409); 

                auto tg_xzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 410); 

                auto tg_xzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 411); 

                auto tg_xzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 412); 

                auto tg_xzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 413); 

                auto tg_xzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 414); 

                auto tg_xzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 415); 

                auto tg_xzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 416); 

                auto tg_xzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 417); 

                auto tg_xzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 418); 

                auto tg_xzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 419); 

                auto tg_xzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 420); 

                auto tg_xzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 421); 

                auto tg_xzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 422); 

                auto tg_xzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 423); 

                auto tg_xzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 424); 

                auto tg_xzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 425); 

                auto tg_xzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 426); 

                auto tg_xzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 427); 

                auto tg_xzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 428); 

                auto tg_xzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 429); 

                auto tg_xzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 430); 

                auto tg_xzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 431); 

                auto tg_xzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 432); 

                auto tg_xzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 433); 

                auto tg_xzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 434); 

                auto tg_xzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 435); 

                auto tg_xzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 436); 

                auto tg_xzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 437); 

                auto tg_xzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 438); 

                auto tg_xzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 439); 

                auto tg_xzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 440); 

                auto tg_xzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 441); 

                auto tg_xzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 442); 

                auto tg_xzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 443); 

                auto tg_xzzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 444); 

                auto tg_xzzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 445); 

                auto tg_xzzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 446); 

                auto tg_xzzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 447); 

                auto tg_xzzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 448); 

                auto tg_xzzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 449); 

                auto tg_yyyy_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 450); 

                auto tg_yyyy_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 451); 

                auto tg_yyyy_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 452); 

                auto tg_yyyy_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 453); 

                auto tg_yyyy_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 454); 

                auto tg_yyyy_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 455); 

                auto tg_yyyy_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 456); 

                auto tg_yyyy_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 457); 

                auto tg_yyyy_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 458); 

                auto tg_yyyy_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 459); 

                auto tg_yyyy_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 460); 

                auto tg_yyyy_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 461); 

                auto tg_yyyy_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 462); 

                auto tg_yyyy_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 463); 

                auto tg_yyyy_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 464); 

                auto tg_yyyy_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 465); 

                auto tg_yyyy_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 466); 

                auto tg_yyyy_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 467); 

                auto tg_yyyy_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 468); 

                auto tg_yyyy_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 469); 

                auto tg_yyyy_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 470); 

                auto tg_yyyy_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 471); 

                auto tg_yyyy_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 472); 

                auto tg_yyyy_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 473); 

                auto tg_yyyy_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 474); 

                auto tg_yyyy_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 475); 

                auto tg_yyyy_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 476); 

                auto tg_yyyy_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 477); 

                auto tg_yyyy_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 478); 

                auto tg_yyyy_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 479); 

                auto tg_yyyy_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 480); 

                auto tg_yyyy_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 481); 

                auto tg_yyyy_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 482); 

                auto tg_yyyy_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 483); 

                auto tg_yyyy_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 484); 

                auto tg_xyzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 388); 

                auto tg_xyzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 389); 

                auto tg_xyzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 390); 

                auto tg_xyzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 391); 

                auto tg_xyzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 392); 

                auto tg_xyzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 393); 

                auto tg_xyzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 394); 

                auto tg_xyzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 395); 

                auto tg_xyzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 396); 

                auto tg_xyzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 397); 

                auto tg_xyzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 398); 

                auto tg_xyzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 399); 

                auto tg_xyzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 400); 

                auto tg_xyzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 401); 

                auto tg_xyzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 402); 

                auto tg_xyzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 403); 

                auto tg_xyzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 404); 

                auto tg_xzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 405); 

                auto tg_xzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 406); 

                auto tg_xzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 407); 

                auto tg_xzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 408); 

                auto tg_xzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 409); 

                auto tg_xzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 410); 

                auto tg_xzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 411); 

                auto tg_xzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 412); 

                auto tg_xzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 413); 

                auto tg_xzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 414); 

                auto tg_xzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 415); 

                auto tg_xzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 416); 

                auto tg_xzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 417); 

                auto tg_xzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 418); 

                auto tg_xzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 419); 

                auto tg_xzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 420); 

                auto tg_xzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 421); 

                auto tg_xzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 422); 

                auto tg_xzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 423); 

                auto tg_xzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 424); 

                auto tg_xzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 425); 

                auto tg_xzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 426); 

                auto tg_xzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 427); 

                auto tg_xzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 428); 

                auto tg_xzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 429); 

                auto tg_xzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 430); 

                auto tg_xzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 431); 

                auto tg_xzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 432); 

                auto tg_xzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 433); 

                auto tg_xzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 434); 

                auto tg_xzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 435); 

                auto tg_xzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 436); 

                auto tg_xzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 437); 

                auto tg_xzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 438); 

                auto tg_xzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 439); 

                auto tg_xzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 440); 

                auto tg_xzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 441); 

                auto tg_xzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 442); 

                auto tg_xzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 443); 

                auto tg_xzzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 444); 

                auto tg_xzzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 445); 

                auto tg_xzzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 446); 

                auto tg_xzzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 447); 

                auto tg_xzzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 448); 

                auto tg_xzzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 449); 

                auto tg_yyyy_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 450); 

                auto tg_yyyy_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 451); 

                auto tg_yyyy_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 452); 

                auto tg_yyyy_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 453); 

                auto tg_yyyy_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 454); 

                auto tg_yyyy_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 455); 

                auto tg_yyyy_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 456); 

                auto tg_yyyy_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 457); 

                auto tg_yyyy_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 458); 

                auto tg_yyyy_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 459); 

                auto tg_yyyy_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 460); 

                auto tg_yyyy_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 461); 

                auto tg_yyyy_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 462); 

                auto tg_yyyy_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 463); 

                auto tg_yyyy_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 464); 

                auto tg_yyyy_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 465); 

                auto tg_yyyy_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 466); 

                auto tg_yyyy_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 467); 

                auto tg_yyyy_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 468); 

                auto tg_yyyy_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 469); 

                auto tg_yyyy_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 470); 

                auto tg_yyyy_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 471); 

                auto tg_yyyy_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 472); 

                auto tg_yyyy_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 473); 

                auto tg_yyyy_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 474); 

                auto tg_yyyy_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 475); 

                auto tg_yyyy_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 476); 

                auto tg_yyyy_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 477); 

                auto tg_yyyy_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 478); 

                auto tg_yyyy_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 479); 

                auto tg_yyyy_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 480); 

                auto tg_yyyy_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 481); 

                auto tg_yyyy_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 482); 

                auto tg_yyyy_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 483); 

                auto tg_yyyy_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 484); 

                auto tg_xxyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 316); 

                auto tg_xxyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 317); 

                auto tg_xxyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 318); 

                auto tg_xxyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 319); 

                auto tg_xxyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 320); 

                auto tg_xxyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 321); 

                auto tg_xxyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 322); 

                auto tg_xxyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 323); 

                auto tg_xxzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 324); 

                auto tg_xxzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 325); 

                auto tg_xxzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 326); 

                auto tg_xxzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 327); 

                auto tg_xxzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 328); 

                auto tg_xxzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 329); 

                auto tg_xxzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 330); 

                auto tg_xxzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 331); 

                auto tg_xxzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 332); 

                auto tg_xxzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 333); 

                auto tg_xxzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 334); 

                auto tg_xxzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 335); 

                auto tg_xxzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 336); 

                auto tg_xxzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 337); 

                auto tg_xxzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 338); 

                auto tg_xxzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 339); 

                auto tg_xxzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 340); 

                auto tg_xxzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 341); 

                auto tg_xxzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 342); 

                auto tg_xxzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 343); 

                auto tg_xxzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 344); 

                auto tg_xxzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 345); 

                auto tg_xxzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 346); 

                auto tg_xxzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 347); 

                auto tg_xxzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 348); 

                auto tg_xxzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 349); 

                auto tg_xxzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 350); 

                auto tg_xxzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 351); 

                auto tg_xxzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 352); 

                auto tg_xxzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 353); 

                auto tg_xxzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 354); 

                auto tg_xxzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 355); 

                auto tg_xxzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 356); 

                auto tg_xxzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 357); 

                auto tg_xxzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 358); 

                auto tg_xxzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 359); 

                auto tg_xyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 360); 

                auto tg_xyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 361); 

                auto tg_xyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 362); 

                auto tg_xyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 363); 

                auto tg_xyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 364); 

                auto tg_xyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 365); 

                auto tg_xyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 366); 

                auto tg_xyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 367); 

                auto tg_xyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 368); 

                auto tg_xyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 369); 

                auto tg_xyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 370); 

                auto tg_xyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 371); 

                auto tg_xyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 372); 

                auto tg_xyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 373); 

                auto tg_xyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 374); 

                auto tg_xyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 375); 

                auto tg_xyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 376); 

                auto tg_xyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 377); 

                auto tg_xyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 378); 

                auto tg_xyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 379); 

                auto tg_xyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 380); 

                auto tg_xyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 381); 

                auto tg_xyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 382); 

                auto tg_xyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 383); 

                auto tg_xyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 384); 

                auto tg_xyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 385); 

                auto tg_xyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 386); 

                auto tg_xyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 387); 

                auto tg_xyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 388); 

                auto tg_xyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 389); 

                auto tg_xyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 390); 

                auto tg_xyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 391); 

                auto tg_xyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 392); 

                auto tg_xyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 393); 

                auto tg_xyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 394); 

                // set up pointers to integrals

                auto tg_xxxyzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 388); 

                auto tg_xxxyzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 389); 

                auto tg_xxxyzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 390); 

                auto tg_xxxyzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 391); 

                auto tg_xxxyzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 392); 

                auto tg_xxxyzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 393); 

                auto tg_xxxyzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 394); 

                auto tg_xxxyzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 395); 

                auto tg_xxxyzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 396); 

                auto tg_xxxyzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 397); 

                auto tg_xxxyzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 398); 

                auto tg_xxxyzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 399); 

                auto tg_xxxyzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 400); 

                auto tg_xxxyzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 401); 

                auto tg_xxxyzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 402); 

                auto tg_xxxyzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 403); 

                auto tg_xxxyzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 404); 

                auto tg_xxxzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 405); 

                auto tg_xxxzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 406); 

                auto tg_xxxzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 407); 

                auto tg_xxxzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 408); 

                auto tg_xxxzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 409); 

                auto tg_xxxzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 410); 

                auto tg_xxxzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 411); 

                auto tg_xxxzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 412); 

                auto tg_xxxzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 413); 

                auto tg_xxxzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 414); 

                auto tg_xxxzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 415); 

                auto tg_xxxzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 416); 

                auto tg_xxxzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 417); 

                auto tg_xxxzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 418); 

                auto tg_xxxzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 419); 

                auto tg_xxxzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 420); 

                auto tg_xxxzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 421); 

                auto tg_xxxzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 422); 

                auto tg_xxxzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 423); 

                auto tg_xxxzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 424); 

                auto tg_xxxzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 425); 

                auto tg_xxxzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 426); 

                auto tg_xxxzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 427); 

                auto tg_xxxzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 428); 

                auto tg_xxxzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 429); 

                auto tg_xxxzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 430); 

                auto tg_xxxzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 431); 

                auto tg_xxxzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 432); 

                auto tg_xxxzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 433); 

                auto tg_xxxzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 434); 

                auto tg_xxxzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 435); 

                auto tg_xxxzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 436); 

                auto tg_xxxzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 437); 

                auto tg_xxxzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 438); 

                auto tg_xxxzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 439); 

                auto tg_xxxzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 440); 

                auto tg_xxxzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 441); 

                auto tg_xxxzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 442); 

                auto tg_xxxzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 443); 

                auto tg_xxxzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 444); 

                auto tg_xxxzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 445); 

                auto tg_xxxzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 446); 

                auto tg_xxxzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 447); 

                auto tg_xxxzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 448); 

                auto tg_xxxzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 449); 

                auto tg_xxyyyy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 450); 

                auto tg_xxyyyy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 451); 

                auto tg_xxyyyy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 452); 

                auto tg_xxyyyy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 453); 

                auto tg_xxyyyy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 454); 

                auto tg_xxyyyy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 455); 

                auto tg_xxyyyy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 456); 

                auto tg_xxyyyy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 457); 

                auto tg_xxyyyy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 458); 

                auto tg_xxyyyy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 459); 

                auto tg_xxyyyy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 460); 

                auto tg_xxyyyy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 461); 

                auto tg_xxyyyy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 462); 

                auto tg_xxyyyy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 463); 

                auto tg_xxyyyy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 464); 

                auto tg_xxyyyy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 465); 

                auto tg_xxyyyy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 466); 

                auto tg_xxyyyy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 467); 

                auto tg_xxyyyy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 468); 

                auto tg_xxyyyy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 469); 

                auto tg_xxyyyy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 470); 

                auto tg_xxyyyy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 471); 

                auto tg_xxyyyy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 472); 

                auto tg_xxyyyy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 473); 

                auto tg_xxyyyy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 474); 

                auto tg_xxyyyy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 475); 

                auto tg_xxyyyy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 476); 

                auto tg_xxyyyy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 477); 

                auto tg_xxyyyy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 478); 

                auto tg_xxyyyy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 479); 

                auto tg_xxyyyy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 480); 

                auto tg_xxyyyy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 481); 

                auto tg_xxyyyy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 482); 

                auto tg_xxyyyy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 483); 

                auto tg_xxyyyy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 484); 

                // Batch of Integrals (388,485)

                #pragma omp simd aligned(fxn, fza, tg_xxxyzz_xyyyyyyy_0, tg_xxxyzz_xyyyyyyz_0, \
                                         tg_xxxyzz_xyyyyyzz_0, tg_xxxyzz_xyyyyzzz_0, tg_xxxyzz_xyyyzzzz_0, tg_xxxyzz_xyyzzzzz_0, \
                                         tg_xxxyzz_xyzzzzzz_0, tg_xxxyzz_xzzzzzzz_0, tg_xxxyzz_yyyyyyyy_0, tg_xxxyzz_yyyyyyyz_0, \
                                         tg_xxxyzz_yyyyyyzz_0, tg_xxxyzz_yyyyyzzz_0, tg_xxxyzz_yyyyzzzz_0, tg_xxxyzz_yyyzzzzz_0, \
                                         tg_xxxyzz_yyzzzzzz_0, tg_xxxyzz_yzzzzzzz_0, tg_xxxyzz_zzzzzzzz_0, tg_xxxzzz_xxxxxxxx_0, \
                                         tg_xxxzzz_xxxxxxxy_0, tg_xxxzzz_xxxxxxxz_0, tg_xxxzzz_xxxxxxyy_0, tg_xxxzzz_xxxxxxyz_0, \
                                         tg_xxxzzz_xxxxxxzz_0, tg_xxxzzz_xxxxxyyy_0, tg_xxxzzz_xxxxxyyz_0, tg_xxxzzz_xxxxxyzz_0, \
                                         tg_xxxzzz_xxxxxzzz_0, tg_xxxzzz_xxxxyyyy_0, tg_xxxzzz_xxxxyyyz_0, tg_xxxzzz_xxxxyyzz_0, \
                                         tg_xxxzzz_xxxxyzzz_0, tg_xxxzzz_xxxxzzzz_0, tg_xxxzzz_xxxyyyyy_0, tg_xxxzzz_xxxyyyyz_0, \
                                         tg_xxxzzz_xxxyyyzz_0, tg_xxxzzz_xxxyyzzz_0, tg_xxxzzz_xxxyzzzz_0, tg_xxxzzz_xxxzzzzz_0, \
                                         tg_xxxzzz_xxyyyyyy_0, tg_xxxzzz_xxyyyyyz_0, tg_xxxzzz_xxyyyyzz_0, tg_xxxzzz_xxyyyzzz_0, \
                                         tg_xxxzzz_xxyyzzzz_0, tg_xxxzzz_xxyzzzzz_0, tg_xxxzzz_xxzzzzzz_0, tg_xxxzzz_xyyyyyyy_0, \
                                         tg_xxxzzz_xyyyyyyz_0, tg_xxxzzz_xyyyyyzz_0, tg_xxxzzz_xyyyyzzz_0, tg_xxxzzz_xyyyzzzz_0, \
                                         tg_xxxzzz_xyyzzzzz_0, tg_xxxzzz_xyzzzzzz_0, tg_xxxzzz_xzzzzzzz_0, tg_xxxzzz_yyyyyyyy_0, \
                                         tg_xxxzzz_yyyyyyyz_0, tg_xxxzzz_yyyyyyzz_0, tg_xxxzzz_yyyyyzzz_0, tg_xxxzzz_yyyyzzzz_0, \
                                         tg_xxxzzz_yyyzzzzz_0, tg_xxxzzz_yyzzzzzz_0, tg_xxxzzz_yzzzzzzz_0, tg_xxxzzz_zzzzzzzz_0, \
                                         tg_xxyyyy_xxxxxxxx_0, tg_xxyyyy_xxxxxxxy_0, tg_xxyyyy_xxxxxxxz_0, tg_xxyyyy_xxxxxxyy_0, \
                                         tg_xxyyyy_xxxxxxyz_0, tg_xxyyyy_xxxxxxzz_0, tg_xxyyyy_xxxxxyyy_0, tg_xxyyyy_xxxxxyyz_0, \
                                         tg_xxyyyy_xxxxxyzz_0, tg_xxyyyy_xxxxxzzz_0, tg_xxyyyy_xxxxyyyy_0, tg_xxyyyy_xxxxyyyz_0, \
                                         tg_xxyyyy_xxxxyyzz_0, tg_xxyyyy_xxxxyzzz_0, tg_xxyyyy_xxxxzzzz_0, tg_xxyyyy_xxxyyyyy_0, \
                                         tg_xxyyyy_xxxyyyyz_0, tg_xxyyyy_xxxyyyzz_0, tg_xxyyyy_xxxyyzzz_0, tg_xxyyyy_xxxyzzzz_0, \
                                         tg_xxyyyy_xxxzzzzz_0, tg_xxyyyy_xxyyyyyy_0, tg_xxyyyy_xxyyyyyz_0, tg_xxyyyy_xxyyyyzz_0, \
                                         tg_xxyyyy_xxyyyzzz_0, tg_xxyyyy_xxyyzzzz_0, tg_xxyyyy_xxyzzzzz_0, tg_xxyyyy_xxzzzzzz_0, \
                                         tg_xxyyyy_xyyyyyyy_0, tg_xxyyyy_xyyyyyyz_0, tg_xxyyyy_xyyyyyzz_0, tg_xxyyyy_xyyyyzzz_0, \
                                         tg_xxyyyy_xyyyzzzz_0, tg_xxyyyy_xyyzzzzz_0, tg_xxyyyy_xyzzzzzz_0, tg_xxyzz_xyyyyyyy_0, \
                                         tg_xxyzz_xyyyyyyy_1, tg_xxyzz_xyyyyyyz_0, tg_xxyzz_xyyyyyyz_1, tg_xxyzz_xyyyyyzz_0, \
                                         tg_xxyzz_xyyyyyzz_1, tg_xxyzz_xyyyyzzz_0, tg_xxyzz_xyyyyzzz_1, tg_xxyzz_xyyyzzzz_0, \
                                         tg_xxyzz_xyyyzzzz_1, tg_xxyzz_xyyzzzzz_0, tg_xxyzz_xyyzzzzz_1, tg_xxyzz_xyzzzzzz_0, \
                                         tg_xxyzz_xyzzzzzz_1, tg_xxyzz_xzzzzzzz_0, tg_xxyzz_xzzzzzzz_1, tg_xxyzz_yyyyyyy_1, \
                                         tg_xxyzz_yyyyyyyy_0, tg_xxyzz_yyyyyyyy_1, tg_xxyzz_yyyyyyyz_0, tg_xxyzz_yyyyyyyz_1, \
                                         tg_xxyzz_yyyyyyz_1, tg_xxyzz_yyyyyyzz_0, tg_xxyzz_yyyyyyzz_1, tg_xxyzz_yyyyyzz_1, \
                                         tg_xxyzz_yyyyyzzz_0, tg_xxyzz_yyyyyzzz_1, tg_xxyzz_yyyyzzz_1, tg_xxyzz_yyyyzzzz_0, \
                                         tg_xxyzz_yyyyzzzz_1, tg_xxyzz_yyyzzzz_1, tg_xxyzz_yyyzzzzz_0, tg_xxyzz_yyyzzzzz_1, \
                                         tg_xxyzz_yyzzzzz_1, tg_xxyzz_yyzzzzzz_0, tg_xxyzz_yyzzzzzz_1, tg_xxyzz_yzzzzzz_1, \
                                         tg_xxyzz_yzzzzzzz_0, tg_xxyzz_yzzzzzzz_1, tg_xxyzz_zzzzzzz_1, tg_xxyzz_zzzzzzzz_0, \
                                         tg_xxyzz_zzzzzzzz_1, tg_xxzzz_xxxxxxx_1, tg_xxzzz_xxxxxxxx_0, tg_xxzzz_xxxxxxxx_1, \
                                         tg_xxzzz_xxxxxxxy_0, tg_xxzzz_xxxxxxxy_1, tg_xxzzz_xxxxxxxz_0, tg_xxzzz_xxxxxxxz_1, \
                                         tg_xxzzz_xxxxxxy_1, tg_xxzzz_xxxxxxyy_0, tg_xxzzz_xxxxxxyy_1, tg_xxzzz_xxxxxxyz_0, \
                                         tg_xxzzz_xxxxxxyz_1, tg_xxzzz_xxxxxxz_1, tg_xxzzz_xxxxxxzz_0, tg_xxzzz_xxxxxxzz_1, \
                                         tg_xxzzz_xxxxxyy_1, tg_xxzzz_xxxxxyyy_0, tg_xxzzz_xxxxxyyy_1, tg_xxzzz_xxxxxyyz_0, \
                                         tg_xxzzz_xxxxxyyz_1, tg_xxzzz_xxxxxyz_1, tg_xxzzz_xxxxxyzz_0, tg_xxzzz_xxxxxyzz_1, \
                                         tg_xxzzz_xxxxxzz_1, tg_xxzzz_xxxxxzzz_0, tg_xxzzz_xxxxxzzz_1, tg_xxzzz_xxxxyyy_1, \
                                         tg_xxzzz_xxxxyyyy_0, tg_xxzzz_xxxxyyyy_1, tg_xxzzz_xxxxyyyz_0, tg_xxzzz_xxxxyyyz_1, \
                                         tg_xxzzz_xxxxyyz_1, tg_xxzzz_xxxxyyzz_0, tg_xxzzz_xxxxyyzz_1, tg_xxzzz_xxxxyzz_1, \
                                         tg_xxzzz_xxxxyzzz_0, tg_xxzzz_xxxxyzzz_1, tg_xxzzz_xxxxzzz_1, tg_xxzzz_xxxxzzzz_0, \
                                         tg_xxzzz_xxxxzzzz_1, tg_xxzzz_xxxyyyy_1, tg_xxzzz_xxxyyyyy_0, tg_xxzzz_xxxyyyyy_1, \
                                         tg_xxzzz_xxxyyyyz_0, tg_xxzzz_xxxyyyyz_1, tg_xxzzz_xxxyyyz_1, tg_xxzzz_xxxyyyzz_0, \
                                         tg_xxzzz_xxxyyyzz_1, tg_xxzzz_xxxyyzz_1, tg_xxzzz_xxxyyzzz_0, tg_xxzzz_xxxyyzzz_1, \
                                         tg_xxzzz_xxxyzzz_1, tg_xxzzz_xxxyzzzz_0, tg_xxzzz_xxxyzzzz_1, tg_xxzzz_xxxzzzz_1, \
                                         tg_xxzzz_xxxzzzzz_0, tg_xxzzz_xxxzzzzz_1, tg_xxzzz_xxyyyyy_1, tg_xxzzz_xxyyyyyy_0, \
                                         tg_xxzzz_xxyyyyyy_1, tg_xxzzz_xxyyyyyz_0, tg_xxzzz_xxyyyyyz_1, tg_xxzzz_xxyyyyz_1, \
                                         tg_xxzzz_xxyyyyzz_0, tg_xxzzz_xxyyyyzz_1, tg_xxzzz_xxyyyzz_1, tg_xxzzz_xxyyyzzz_0, \
                                         tg_xxzzz_xxyyyzzz_1, tg_xxzzz_xxyyzzz_1, tg_xxzzz_xxyyzzzz_0, tg_xxzzz_xxyyzzzz_1, \
                                         tg_xxzzz_xxyzzzz_1, tg_xxzzz_xxyzzzzz_0, tg_xxzzz_xxyzzzzz_1, tg_xxzzz_xxzzzzz_1, \
                                         tg_xxzzz_xxzzzzzz_0, tg_xxzzz_xxzzzzzz_1, tg_xxzzz_xyyyyyy_1, tg_xxzzz_xyyyyyyy_0, \
                                         tg_xxzzz_xyyyyyyy_1, tg_xxzzz_xyyyyyyz_0, tg_xxzzz_xyyyyyyz_1, tg_xxzzz_xyyyyyz_1, \
                                         tg_xxzzz_xyyyyyzz_0, tg_xxzzz_xyyyyyzz_1, tg_xxzzz_xyyyyzz_1, tg_xxzzz_xyyyyzzz_0, \
                                         tg_xxzzz_xyyyyzzz_1, tg_xxzzz_xyyyzzz_1, tg_xxzzz_xyyyzzzz_0, tg_xxzzz_xyyyzzzz_1, \
                                         tg_xxzzz_xyyzzzz_1, tg_xxzzz_xyyzzzzz_0, tg_xxzzz_xyyzzzzz_1, tg_xxzzz_xyzzzzz_1, \
                                         tg_xxzzz_xyzzzzzz_0, tg_xxzzz_xyzzzzzz_1, tg_xxzzz_xzzzzzz_1, tg_xxzzz_xzzzzzzz_0, \
                                         tg_xxzzz_xzzzzzzz_1, tg_xxzzz_yyyyyyy_1, tg_xxzzz_yyyyyyyy_0, tg_xxzzz_yyyyyyyy_1, \
                                         tg_xxzzz_yyyyyyyz_0, tg_xxzzz_yyyyyyyz_1, tg_xxzzz_yyyyyyz_1, tg_xxzzz_yyyyyyzz_0, \
                                         tg_xxzzz_yyyyyyzz_1, tg_xxzzz_yyyyyzz_1, tg_xxzzz_yyyyyzzz_0, tg_xxzzz_yyyyyzzz_1, \
                                         tg_xxzzz_yyyyzzz_1, tg_xxzzz_yyyyzzzz_0, tg_xxzzz_yyyyzzzz_1, tg_xxzzz_yyyzzzz_1, \
                                         tg_xxzzz_yyyzzzzz_0, tg_xxzzz_yyyzzzzz_1, tg_xxzzz_yyzzzzz_1, tg_xxzzz_yyzzzzzz_0, \
                                         tg_xxzzz_yyzzzzzz_1, tg_xxzzz_yzzzzzz_1, tg_xxzzz_yzzzzzzz_0, tg_xxzzz_yzzzzzzz_1, \
                                         tg_xxzzz_zzzzzzz_1, tg_xxzzz_zzzzzzzz_0, tg_xxzzz_zzzzzzzz_1, tg_xyyyy_xxxxxxx_1, \
                                         tg_xyyyy_xxxxxxxx_0, tg_xyyyy_xxxxxxxx_1, tg_xyyyy_xxxxxxxy_0, tg_xyyyy_xxxxxxxy_1, \
                                         tg_xyyyy_xxxxxxxz_0, tg_xyyyy_xxxxxxxz_1, tg_xyyyy_xxxxxxy_1, tg_xyyyy_xxxxxxyy_0, \
                                         tg_xyyyy_xxxxxxyy_1, tg_xyyyy_xxxxxxyz_0, tg_xyyyy_xxxxxxyz_1, tg_xyyyy_xxxxxxz_1, \
                                         tg_xyyyy_xxxxxxzz_0, tg_xyyyy_xxxxxxzz_1, tg_xyyyy_xxxxxyy_1, tg_xyyyy_xxxxxyyy_0, \
                                         tg_xyyyy_xxxxxyyy_1, tg_xyyyy_xxxxxyyz_0, tg_xyyyy_xxxxxyyz_1, tg_xyyyy_xxxxxyz_1, \
                                         tg_xyyyy_xxxxxyzz_0, tg_xyyyy_xxxxxyzz_1, tg_xyyyy_xxxxxzz_1, tg_xyyyy_xxxxxzzz_0, \
                                         tg_xyyyy_xxxxxzzz_1, tg_xyyyy_xxxxyyy_1, tg_xyyyy_xxxxyyyy_0, tg_xyyyy_xxxxyyyy_1, \
                                         tg_xyyyy_xxxxyyyz_0, tg_xyyyy_xxxxyyyz_1, tg_xyyyy_xxxxyyz_1, tg_xyyyy_xxxxyyzz_0, \
                                         tg_xyyyy_xxxxyyzz_1, tg_xyyyy_xxxxyzz_1, tg_xyyyy_xxxxyzzz_0, tg_xyyyy_xxxxyzzz_1, \
                                         tg_xyyyy_xxxxzzz_1, tg_xyyyy_xxxxzzzz_0, tg_xyyyy_xxxxzzzz_1, tg_xyyyy_xxxyyyy_1, \
                                         tg_xyyyy_xxxyyyyy_0, tg_xyyyy_xxxyyyyy_1, tg_xyyyy_xxxyyyyz_0, tg_xyyyy_xxxyyyyz_1, \
                                         tg_xyyyy_xxxyyyz_1, tg_xyyyy_xxxyyyzz_0, tg_xyyyy_xxxyyyzz_1, tg_xyyyy_xxxyyzz_1, \
                                         tg_xyyyy_xxxyyzzz_0, tg_xyyyy_xxxyyzzz_1, tg_xyyyy_xxxyzzz_1, tg_xyyyy_xxxyzzzz_0, \
                                         tg_xyyyy_xxxyzzzz_1, tg_xyyyy_xxxzzzz_1, tg_xyyyy_xxxzzzzz_0, tg_xyyyy_xxxzzzzz_1, \
                                         tg_xyyyy_xxyyyyy_1, tg_xyyyy_xxyyyyyy_0, tg_xyyyy_xxyyyyyy_1, tg_xyyyy_xxyyyyyz_0, \
                                         tg_xyyyy_xxyyyyyz_1, tg_xyyyy_xxyyyyz_1, tg_xyyyy_xxyyyyzz_0, tg_xyyyy_xxyyyyzz_1, \
                                         tg_xyyyy_xxyyyzz_1, tg_xyyyy_xxyyyzzz_0, tg_xyyyy_xxyyyzzz_1, tg_xyyyy_xxyyzzz_1, \
                                         tg_xyyyy_xxyyzzzz_0, tg_xyyyy_xxyyzzzz_1, tg_xyyyy_xxyzzzz_1, tg_xyyyy_xxyzzzzz_0, \
                                         tg_xyyyy_xxyzzzzz_1, tg_xyyyy_xxzzzzz_1, tg_xyyyy_xxzzzzzz_0, tg_xyyyy_xxzzzzzz_1, \
                                         tg_xyyyy_xyyyyyy_1, tg_xyyyy_xyyyyyyy_0, tg_xyyyy_xyyyyyyy_1, tg_xyyyy_xyyyyyyz_0, \
                                         tg_xyyyy_xyyyyyyz_1, tg_xyyyy_xyyyyyz_1, tg_xyyyy_xyyyyyzz_0, tg_xyyyy_xyyyyyzz_1, \
                                         tg_xyyyy_xyyyyzz_1, tg_xyyyy_xyyyyzzz_0, tg_xyyyy_xyyyyzzz_1, tg_xyyyy_xyyyzzz_1, \
                                         tg_xyyyy_xyyyzzzz_0, tg_xyyyy_xyyyzzzz_1, tg_xyyyy_xyyzzzz_1, tg_xyyyy_xyyzzzzz_0, \
                                         tg_xyyyy_xyyzzzzz_1, tg_xyyyy_xyzzzzz_1, tg_xyyyy_xyzzzzzz_0, tg_xyyyy_xyzzzzzz_1, \
                                         tg_xyyyy_xzzzzzz_1, tg_xyyyy_yyyyyyy_1, tg_xyyyy_yyyyyyz_1, tg_xyyyy_yyyyyzz_1, \
                                         tg_xyyyy_yyyyzzz_1, tg_xyyyy_yyyzzzz_1, tg_xyyyy_yyzzzzz_1, tg_xyyyy_yzzzzzz_1, \
                                         tg_xyzz_xyyyyyyy_0, tg_xyzz_xyyyyyyy_1, tg_xyzz_xyyyyyyz_0, tg_xyzz_xyyyyyyz_1, \
                                         tg_xyzz_xyyyyyzz_0, tg_xyzz_xyyyyyzz_1, tg_xyzz_xyyyyzzz_0, tg_xyzz_xyyyyzzz_1, \
                                         tg_xyzz_xyyyzzzz_0, tg_xyzz_xyyyzzzz_1, tg_xyzz_xyyzzzzz_0, tg_xyzz_xyyzzzzz_1, \
                                         tg_xyzz_xyzzzzzz_0, tg_xyzz_xyzzzzzz_1, tg_xyzz_xzzzzzzz_0, tg_xyzz_xzzzzzzz_1, \
                                         tg_xyzz_yyyyyyyy_0, tg_xyzz_yyyyyyyy_1, tg_xyzz_yyyyyyyz_0, tg_xyzz_yyyyyyyz_1, \
                                         tg_xyzz_yyyyyyzz_0, tg_xyzz_yyyyyyzz_1, tg_xyzz_yyyyyzzz_0, tg_xyzz_yyyyyzzz_1, \
                                         tg_xyzz_yyyyzzzz_0, tg_xyzz_yyyyzzzz_1, tg_xyzz_yyyzzzzz_0, tg_xyzz_yyyzzzzz_1, \
                                         tg_xyzz_yyzzzzzz_0, tg_xyzz_yyzzzzzz_1, tg_xyzz_yzzzzzzz_0, tg_xyzz_yzzzzzzz_1, \
                                         tg_xyzz_zzzzzzzz_0, tg_xyzz_zzzzzzzz_1, tg_xzzz_xxxxxxxx_0, tg_xzzz_xxxxxxxx_1, \
                                         tg_xzzz_xxxxxxxy_0, tg_xzzz_xxxxxxxy_1, tg_xzzz_xxxxxxxz_0, tg_xzzz_xxxxxxxz_1, \
                                         tg_xzzz_xxxxxxyy_0, tg_xzzz_xxxxxxyy_1, tg_xzzz_xxxxxxyz_0, tg_xzzz_xxxxxxyz_1, \
                                         tg_xzzz_xxxxxxzz_0, tg_xzzz_xxxxxxzz_1, tg_xzzz_xxxxxyyy_0, tg_xzzz_xxxxxyyy_1, \
                                         tg_xzzz_xxxxxyyz_0, tg_xzzz_xxxxxyyz_1, tg_xzzz_xxxxxyzz_0, tg_xzzz_xxxxxyzz_1, \
                                         tg_xzzz_xxxxxzzz_0, tg_xzzz_xxxxxzzz_1, tg_xzzz_xxxxyyyy_0, tg_xzzz_xxxxyyyy_1, \
                                         tg_xzzz_xxxxyyyz_0, tg_xzzz_xxxxyyyz_1, tg_xzzz_xxxxyyzz_0, tg_xzzz_xxxxyyzz_1, \
                                         tg_xzzz_xxxxyzzz_0, tg_xzzz_xxxxyzzz_1, tg_xzzz_xxxxzzzz_0, tg_xzzz_xxxxzzzz_1, \
                                         tg_xzzz_xxxyyyyy_0, tg_xzzz_xxxyyyyy_1, tg_xzzz_xxxyyyyz_0, tg_xzzz_xxxyyyyz_1, \
                                         tg_xzzz_xxxyyyzz_0, tg_xzzz_xxxyyyzz_1, tg_xzzz_xxxyyzzz_0, tg_xzzz_xxxyyzzz_1, \
                                         tg_xzzz_xxxyzzzz_0, tg_xzzz_xxxyzzzz_1, tg_xzzz_xxxzzzzz_0, tg_xzzz_xxxzzzzz_1, \
                                         tg_xzzz_xxyyyyyy_0, tg_xzzz_xxyyyyyy_1, tg_xzzz_xxyyyyyz_0, tg_xzzz_xxyyyyyz_1, \
                                         tg_xzzz_xxyyyyzz_0, tg_xzzz_xxyyyyzz_1, tg_xzzz_xxyyyzzz_0, tg_xzzz_xxyyyzzz_1, \
                                         tg_xzzz_xxyyzzzz_0, tg_xzzz_xxyyzzzz_1, tg_xzzz_xxyzzzzz_0, tg_xzzz_xxyzzzzz_1, \
                                         tg_xzzz_xxzzzzzz_0, tg_xzzz_xxzzzzzz_1, tg_xzzz_xyyyyyyy_0, tg_xzzz_xyyyyyyy_1, \
                                         tg_xzzz_xyyyyyyz_0, tg_xzzz_xyyyyyyz_1, tg_xzzz_xyyyyyzz_0, tg_xzzz_xyyyyyzz_1, \
                                         tg_xzzz_xyyyyzzz_0, tg_xzzz_xyyyyzzz_1, tg_xzzz_xyyyzzzz_0, tg_xzzz_xyyyzzzz_1, \
                                         tg_xzzz_xyyzzzzz_0, tg_xzzz_xyyzzzzz_1, tg_xzzz_xyzzzzzz_0, tg_xzzz_xyzzzzzz_1, \
                                         tg_xzzz_xzzzzzzz_0, tg_xzzz_xzzzzzzz_1, tg_xzzz_yyyyyyyy_0, tg_xzzz_yyyyyyyy_1, \
                                         tg_xzzz_yyyyyyyz_0, tg_xzzz_yyyyyyyz_1, tg_xzzz_yyyyyyzz_0, tg_xzzz_yyyyyyzz_1, \
                                         tg_xzzz_yyyyyzzz_0, tg_xzzz_yyyyyzzz_1, tg_xzzz_yyyyzzzz_0, tg_xzzz_yyyyzzzz_1, \
                                         tg_xzzz_yyyzzzzz_0, tg_xzzz_yyyzzzzz_1, tg_xzzz_yyzzzzzz_0, tg_xzzz_yyzzzzzz_1, \
                                         tg_xzzz_yzzzzzzz_0, tg_xzzz_yzzzzzzz_1, tg_xzzz_zzzzzzzz_0, tg_xzzz_zzzzzzzz_1, \
                                         tg_yyyy_xxxxxxxx_0, tg_yyyy_xxxxxxxx_1, tg_yyyy_xxxxxxxy_0, tg_yyyy_xxxxxxxy_1, \
                                         tg_yyyy_xxxxxxxz_0, tg_yyyy_xxxxxxxz_1, tg_yyyy_xxxxxxyy_0, tg_yyyy_xxxxxxyy_1, \
                                         tg_yyyy_xxxxxxyz_0, tg_yyyy_xxxxxxyz_1, tg_yyyy_xxxxxxzz_0, tg_yyyy_xxxxxxzz_1, \
                                         tg_yyyy_xxxxxyyy_0, tg_yyyy_xxxxxyyy_1, tg_yyyy_xxxxxyyz_0, tg_yyyy_xxxxxyyz_1, \
                                         tg_yyyy_xxxxxyzz_0, tg_yyyy_xxxxxyzz_1, tg_yyyy_xxxxxzzz_0, tg_yyyy_xxxxxzzz_1, \
                                         tg_yyyy_xxxxyyyy_0, tg_yyyy_xxxxyyyy_1, tg_yyyy_xxxxyyyz_0, tg_yyyy_xxxxyyyz_1, \
                                         tg_yyyy_xxxxyyzz_0, tg_yyyy_xxxxyyzz_1, tg_yyyy_xxxxyzzz_0, tg_yyyy_xxxxyzzz_1, \
                                         tg_yyyy_xxxxzzzz_0, tg_yyyy_xxxxzzzz_1, tg_yyyy_xxxyyyyy_0, tg_yyyy_xxxyyyyy_1, \
                                         tg_yyyy_xxxyyyyz_0, tg_yyyy_xxxyyyyz_1, tg_yyyy_xxxyyyzz_0, tg_yyyy_xxxyyyzz_1, \
                                         tg_yyyy_xxxyyzzz_0, tg_yyyy_xxxyyzzz_1, tg_yyyy_xxxyzzzz_0, tg_yyyy_xxxyzzzz_1, \
                                         tg_yyyy_xxxzzzzz_0, tg_yyyy_xxxzzzzz_1, tg_yyyy_xxyyyyyy_0, tg_yyyy_xxyyyyyy_1, \
                                         tg_yyyy_xxyyyyyz_0, tg_yyyy_xxyyyyyz_1, tg_yyyy_xxyyyyzz_0, tg_yyyy_xxyyyyzz_1, \
                                         tg_yyyy_xxyyyzzz_0, tg_yyyy_xxyyyzzz_1, tg_yyyy_xxyyzzzz_0, tg_yyyy_xxyyzzzz_1, \
                                         tg_yyyy_xxyzzzzz_0, tg_yyyy_xxyzzzzz_1, tg_yyyy_xxzzzzzz_0, tg_yyyy_xxzzzzzz_1, \
                                         tg_yyyy_xyyyyyyy_0, tg_yyyy_xyyyyyyy_1, tg_yyyy_xyyyyyyz_0, tg_yyyy_xyyyyyyz_1, \
                                         tg_yyyy_xyyyyyzz_0, tg_yyyy_xyyyyyzz_1, tg_yyyy_xyyyyzzz_0, tg_yyyy_xyyyyzzz_1, \
                                         tg_yyyy_xyyyzzzz_0, tg_yyyy_xyyyzzzz_1, tg_yyyy_xyyzzzzz_0, tg_yyyy_xyyzzzzz_1, \
                                         tg_yyyy_xyzzzzzz_0, tg_yyyy_xyzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyzz_xyyyyyyy_0[j] = pb_x * tg_xxyzz_xyyyyyyy_0[j] + fr * tg_xxyzz_xyyyyyyy_1[j] + fl1_fx * (tg_xyzz_xyyyyyyy_0[j] - tg_xyzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyyyyyy_1[j];

                    tg_xxxyzz_xyyyyyyz_0[j] = pb_x * tg_xxyzz_xyyyyyyz_0[j] + fr * tg_xxyzz_xyyyyyyz_1[j] + fl1_fx * (tg_xyzz_xyyyyyyz_0[j] - tg_xyzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyyyyyz_1[j];

                    tg_xxxyzz_xyyyyyzz_0[j] = pb_x * tg_xxyzz_xyyyyyzz_0[j] + fr * tg_xxyzz_xyyyyyzz_1[j] + fl1_fx * (tg_xyzz_xyyyyyzz_0[j] - tg_xyzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyyyyzz_1[j];

                    tg_xxxyzz_xyyyyzzz_0[j] = pb_x * tg_xxyzz_xyyyyzzz_0[j] + fr * tg_xxyzz_xyyyyzzz_1[j] + fl1_fx * (tg_xyzz_xyyyyzzz_0[j] - tg_xyzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyyyzzz_1[j];

                    tg_xxxyzz_xyyyzzzz_0[j] = pb_x * tg_xxyzz_xyyyzzzz_0[j] + fr * tg_xxyzz_xyyyzzzz_1[j] + fl1_fx * (tg_xyzz_xyyyzzzz_0[j] - tg_xyzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyyzzzz_1[j];

                    tg_xxxyzz_xyyzzzzz_0[j] = pb_x * tg_xxyzz_xyyzzzzz_0[j] + fr * tg_xxyzz_xyyzzzzz_1[j] + fl1_fx * (tg_xyzz_xyyzzzzz_0[j] - tg_xyzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yyzzzzz_1[j];

                    tg_xxxyzz_xyzzzzzz_0[j] = pb_x * tg_xxyzz_xyzzzzzz_0[j] + fr * tg_xxyzz_xyzzzzzz_1[j] + fl1_fx * (tg_xyzz_xyzzzzzz_0[j] - tg_xyzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_yzzzzzz_1[j];

                    tg_xxxyzz_xzzzzzzz_0[j] = pb_x * tg_xxyzz_xzzzzzzz_0[j] + fr * tg_xxyzz_xzzzzzzz_1[j] + fl1_fx * (tg_xyzz_xzzzzzzz_0[j] - tg_xyzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzz_zzzzzzz_1[j];

                    tg_xxxyzz_yyyyyyyy_0[j] = pb_x * tg_xxyzz_yyyyyyyy_0[j] + fr * tg_xxyzz_yyyyyyyy_1[j] + fl1_fx * (tg_xyzz_yyyyyyyy_0[j] - tg_xyzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxyzz_yyyyyyyz_0[j] = pb_x * tg_xxyzz_yyyyyyyz_0[j] + fr * tg_xxyzz_yyyyyyyz_1[j] + fl1_fx * (tg_xyzz_yyyyyyyz_0[j] - tg_xyzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxyzz_yyyyyyzz_0[j] = pb_x * tg_xxyzz_yyyyyyzz_0[j] + fr * tg_xxyzz_yyyyyyzz_1[j] + fl1_fx * (tg_xyzz_yyyyyyzz_0[j] - tg_xyzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxyzz_yyyyyzzz_0[j] = pb_x * tg_xxyzz_yyyyyzzz_0[j] + fr * tg_xxyzz_yyyyyzzz_1[j] + fl1_fx * (tg_xyzz_yyyyyzzz_0[j] - tg_xyzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxyzz_yyyyzzzz_0[j] = pb_x * tg_xxyzz_yyyyzzzz_0[j] + fr * tg_xxyzz_yyyyzzzz_1[j] + fl1_fx * (tg_xyzz_yyyyzzzz_0[j] - tg_xyzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxyzz_yyyzzzzz_0[j] = pb_x * tg_xxyzz_yyyzzzzz_0[j] + fr * tg_xxyzz_yyyzzzzz_1[j] + fl1_fx * (tg_xyzz_yyyzzzzz_0[j] - tg_xyzz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxyzz_yyzzzzzz_0[j] = pb_x * tg_xxyzz_yyzzzzzz_0[j] + fr * tg_xxyzz_yyzzzzzz_1[j] + fl1_fx * (tg_xyzz_yyzzzzzz_0[j] - tg_xyzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxyzz_yzzzzzzz_0[j] = pb_x * tg_xxyzz_yzzzzzzz_0[j] + fr * tg_xxyzz_yzzzzzzz_1[j] + fl1_fx * (tg_xyzz_yzzzzzzz_0[j] - tg_xyzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxyzz_zzzzzzzz_0[j] = pb_x * tg_xxyzz_zzzzzzzz_0[j] + fr * tg_xxyzz_zzzzzzzz_1[j] + fl1_fx * (tg_xyzz_zzzzzzzz_0[j] - tg_xyzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxxzzz_xxxxxxxx_0[j] = pb_x * tg_xxzzz_xxxxxxxx_0[j] + fr * tg_xxzzz_xxxxxxxx_1[j] + fl1_fx * (tg_xzzz_xxxxxxxx_0[j] - tg_xzzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xxzzz_xxxxxxx_1[j];

                    tg_xxxzzz_xxxxxxxy_0[j] = pb_x * tg_xxzzz_xxxxxxxy_0[j] + fr * tg_xxzzz_xxxxxxxy_1[j] + fl1_fx * (tg_xzzz_xxxxxxxy_0[j] - tg_xzzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxzzz_xxxxxxy_1[j];

                    tg_xxxzzz_xxxxxxxz_0[j] = pb_x * tg_xxzzz_xxxxxxxz_0[j] + fr * tg_xxzzz_xxxxxxxz_1[j] + fl1_fx * (tg_xzzz_xxxxxxxz_0[j] - tg_xzzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxzzz_xxxxxxz_1[j];

                    tg_xxxzzz_xxxxxxyy_0[j] = pb_x * tg_xxzzz_xxxxxxyy_0[j] + fr * tg_xxzzz_xxxxxxyy_1[j] + fl1_fx * (tg_xzzz_xxxxxxyy_0[j] - tg_xzzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzz_xxxxxyy_1[j];

                    tg_xxxzzz_xxxxxxyz_0[j] = pb_x * tg_xxzzz_xxxxxxyz_0[j] + fr * tg_xxzzz_xxxxxxyz_1[j] + fl1_fx * (tg_xzzz_xxxxxxyz_0[j] - tg_xzzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzz_xxxxxyz_1[j];

                    tg_xxxzzz_xxxxxxzz_0[j] = pb_x * tg_xxzzz_xxxxxxzz_0[j] + fr * tg_xxzzz_xxxxxxzz_1[j] + fl1_fx * (tg_xzzz_xxxxxxzz_0[j] - tg_xzzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzz_xxxxxzz_1[j];

                    tg_xxxzzz_xxxxxyyy_0[j] = pb_x * tg_xxzzz_xxxxxyyy_0[j] + fr * tg_xxzzz_xxxxxyyy_1[j] + fl1_fx * (tg_xzzz_xxxxxyyy_0[j] - tg_xzzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzz_xxxxyyy_1[j];

                    tg_xxxzzz_xxxxxyyz_0[j] = pb_x * tg_xxzzz_xxxxxyyz_0[j] + fr * tg_xxzzz_xxxxxyyz_1[j] + fl1_fx * (tg_xzzz_xxxxxyyz_0[j] - tg_xzzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzz_xxxxyyz_1[j];

                    tg_xxxzzz_xxxxxyzz_0[j] = pb_x * tg_xxzzz_xxxxxyzz_0[j] + fr * tg_xxzzz_xxxxxyzz_1[j] + fl1_fx * (tg_xzzz_xxxxxyzz_0[j] - tg_xzzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzz_xxxxyzz_1[j];

                    tg_xxxzzz_xxxxxzzz_0[j] = pb_x * tg_xxzzz_xxxxxzzz_0[j] + fr * tg_xxzzz_xxxxxzzz_1[j] + fl1_fx * (tg_xzzz_xxxxxzzz_0[j] - tg_xzzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzz_xxxxzzz_1[j];

                    tg_xxxzzz_xxxxyyyy_0[j] = pb_x * tg_xxzzz_xxxxyyyy_0[j] + fr * tg_xxzzz_xxxxyyyy_1[j] + fl1_fx * (tg_xzzz_xxxxyyyy_0[j] - tg_xzzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzz_xxxyyyy_1[j];

                    tg_xxxzzz_xxxxyyyz_0[j] = pb_x * tg_xxzzz_xxxxyyyz_0[j] + fr * tg_xxzzz_xxxxyyyz_1[j] + fl1_fx * (tg_xzzz_xxxxyyyz_0[j] - tg_xzzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzz_xxxyyyz_1[j];

                    tg_xxxzzz_xxxxyyzz_0[j] = pb_x * tg_xxzzz_xxxxyyzz_0[j] + fr * tg_xxzzz_xxxxyyzz_1[j] + fl1_fx * (tg_xzzz_xxxxyyzz_0[j] - tg_xzzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzz_xxxyyzz_1[j];

                    tg_xxxzzz_xxxxyzzz_0[j] = pb_x * tg_xxzzz_xxxxyzzz_0[j] + fr * tg_xxzzz_xxxxyzzz_1[j] + fl1_fx * (tg_xzzz_xxxxyzzz_0[j] - tg_xzzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzz_xxxyzzz_1[j];

                    tg_xxxzzz_xxxxzzzz_0[j] = pb_x * tg_xxzzz_xxxxzzzz_0[j] + fr * tg_xxzzz_xxxxzzzz_1[j] + fl1_fx * (tg_xzzz_xxxxzzzz_0[j] - tg_xzzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzz_xxxzzzz_1[j];

                    tg_xxxzzz_xxxyyyyy_0[j] = pb_x * tg_xxzzz_xxxyyyyy_0[j] + fr * tg_xxzzz_xxxyyyyy_1[j] + fl1_fx * (tg_xzzz_xxxyyyyy_0[j] - tg_xzzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxyyyyy_1[j];

                    tg_xxxzzz_xxxyyyyz_0[j] = pb_x * tg_xxzzz_xxxyyyyz_0[j] + fr * tg_xxzzz_xxxyyyyz_1[j] + fl1_fx * (tg_xzzz_xxxyyyyz_0[j] - tg_xzzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxyyyyz_1[j];

                    tg_xxxzzz_xxxyyyzz_0[j] = pb_x * tg_xxzzz_xxxyyyzz_0[j] + fr * tg_xxzzz_xxxyyyzz_1[j] + fl1_fx * (tg_xzzz_xxxyyyzz_0[j] - tg_xzzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxyyyzz_1[j];

                    tg_xxxzzz_xxxyyzzz_0[j] = pb_x * tg_xxzzz_xxxyyzzz_0[j] + fr * tg_xxzzz_xxxyyzzz_1[j] + fl1_fx * (tg_xzzz_xxxyyzzz_0[j] - tg_xzzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxyyzzz_1[j];

                    tg_xxxzzz_xxxyzzzz_0[j] = pb_x * tg_xxzzz_xxxyzzzz_0[j] + fr * tg_xxzzz_xxxyzzzz_1[j] + fl1_fx * (tg_xzzz_xxxyzzzz_0[j] - tg_xzzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxyzzzz_1[j];

                    tg_xxxzzz_xxxzzzzz_0[j] = pb_x * tg_xxzzz_xxxzzzzz_0[j] + fr * tg_xxzzz_xxxzzzzz_1[j] + fl1_fx * (tg_xzzz_xxxzzzzz_0[j] - tg_xzzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzz_xxzzzzz_1[j];

                    tg_xxxzzz_xxyyyyyy_0[j] = pb_x * tg_xxzzz_xxyyyyyy_0[j] + fr * tg_xxzzz_xxyyyyyy_1[j] + fl1_fx * (tg_xzzz_xxyyyyyy_0[j] - tg_xzzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyyyyyy_1[j];

                    tg_xxxzzz_xxyyyyyz_0[j] = pb_x * tg_xxzzz_xxyyyyyz_0[j] + fr * tg_xxzzz_xxyyyyyz_1[j] + fl1_fx * (tg_xzzz_xxyyyyyz_0[j] - tg_xzzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyyyyyz_1[j];

                    tg_xxxzzz_xxyyyyzz_0[j] = pb_x * tg_xxzzz_xxyyyyzz_0[j] + fr * tg_xxzzz_xxyyyyzz_1[j] + fl1_fx * (tg_xzzz_xxyyyyzz_0[j] - tg_xzzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyyyyzz_1[j];

                    tg_xxxzzz_xxyyyzzz_0[j] = pb_x * tg_xxzzz_xxyyyzzz_0[j] + fr * tg_xxzzz_xxyyyzzz_1[j] + fl1_fx * (tg_xzzz_xxyyyzzz_0[j] - tg_xzzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyyyzzz_1[j];

                    tg_xxxzzz_xxyyzzzz_0[j] = pb_x * tg_xxzzz_xxyyzzzz_0[j] + fr * tg_xxzzz_xxyyzzzz_1[j] + fl1_fx * (tg_xzzz_xxyyzzzz_0[j] - tg_xzzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyyzzzz_1[j];

                    tg_xxxzzz_xxyzzzzz_0[j] = pb_x * tg_xxzzz_xxyzzzzz_0[j] + fr * tg_xxzzz_xxyzzzzz_1[j] + fl1_fx * (tg_xzzz_xxyzzzzz_0[j] - tg_xzzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xyzzzzz_1[j];

                    tg_xxxzzz_xxzzzzzz_0[j] = pb_x * tg_xxzzz_xxzzzzzz_0[j] + fr * tg_xxzzz_xxzzzzzz_1[j] + fl1_fx * (tg_xzzz_xxzzzzzz_0[j] - tg_xzzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzz_xzzzzzz_1[j];

                    tg_xxxzzz_xyyyyyyy_0[j] = pb_x * tg_xxzzz_xyyyyyyy_0[j] + fr * tg_xxzzz_xyyyyyyy_1[j] + fl1_fx * (tg_xzzz_xyyyyyyy_0[j] - tg_xzzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyyyyyy_1[j];

                    tg_xxxzzz_xyyyyyyz_0[j] = pb_x * tg_xxzzz_xyyyyyyz_0[j] + fr * tg_xxzzz_xyyyyyyz_1[j] + fl1_fx * (tg_xzzz_xyyyyyyz_0[j] - tg_xzzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyyyyyz_1[j];

                    tg_xxxzzz_xyyyyyzz_0[j] = pb_x * tg_xxzzz_xyyyyyzz_0[j] + fr * tg_xxzzz_xyyyyyzz_1[j] + fl1_fx * (tg_xzzz_xyyyyyzz_0[j] - tg_xzzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyyyyzz_1[j];

                    tg_xxxzzz_xyyyyzzz_0[j] = pb_x * tg_xxzzz_xyyyyzzz_0[j] + fr * tg_xxzzz_xyyyyzzz_1[j] + fl1_fx * (tg_xzzz_xyyyyzzz_0[j] - tg_xzzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyyyzzz_1[j];

                    tg_xxxzzz_xyyyzzzz_0[j] = pb_x * tg_xxzzz_xyyyzzzz_0[j] + fr * tg_xxzzz_xyyyzzzz_1[j] + fl1_fx * (tg_xzzz_xyyyzzzz_0[j] - tg_xzzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyyzzzz_1[j];

                    tg_xxxzzz_xyyzzzzz_0[j] = pb_x * tg_xxzzz_xyyzzzzz_0[j] + fr * tg_xxzzz_xyyzzzzz_1[j] + fl1_fx * (tg_xzzz_xyyzzzzz_0[j] - tg_xzzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yyzzzzz_1[j];

                    tg_xxxzzz_xyzzzzzz_0[j] = pb_x * tg_xxzzz_xyzzzzzz_0[j] + fr * tg_xxzzz_xyzzzzzz_1[j] + fl1_fx * (tg_xzzz_xyzzzzzz_0[j] - tg_xzzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_yzzzzzz_1[j];

                    tg_xxxzzz_xzzzzzzz_0[j] = pb_x * tg_xxzzz_xzzzzzzz_0[j] + fr * tg_xxzzz_xzzzzzzz_1[j] + fl1_fx * (tg_xzzz_xzzzzzzz_0[j] - tg_xzzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzz_zzzzzzz_1[j];

                    tg_xxxzzz_yyyyyyyy_0[j] = pb_x * tg_xxzzz_yyyyyyyy_0[j] + fr * tg_xxzzz_yyyyyyyy_1[j] + fl1_fx * (tg_xzzz_yyyyyyyy_0[j] - tg_xzzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxxzzz_yyyyyyyz_0[j] = pb_x * tg_xxzzz_yyyyyyyz_0[j] + fr * tg_xxzzz_yyyyyyyz_1[j] + fl1_fx * (tg_xzzz_yyyyyyyz_0[j] - tg_xzzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxxzzz_yyyyyyzz_0[j] = pb_x * tg_xxzzz_yyyyyyzz_0[j] + fr * tg_xxzzz_yyyyyyzz_1[j] + fl1_fx * (tg_xzzz_yyyyyyzz_0[j] - tg_xzzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxxzzz_yyyyyzzz_0[j] = pb_x * tg_xxzzz_yyyyyzzz_0[j] + fr * tg_xxzzz_yyyyyzzz_1[j] + fl1_fx * (tg_xzzz_yyyyyzzz_0[j] - tg_xzzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxxzzz_yyyyzzzz_0[j] = pb_x * tg_xxzzz_yyyyzzzz_0[j] + fr * tg_xxzzz_yyyyzzzz_1[j] + fl1_fx * (tg_xzzz_yyyyzzzz_0[j] - tg_xzzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxxzzz_yyyzzzzz_0[j] = pb_x * tg_xxzzz_yyyzzzzz_0[j] + fr * tg_xxzzz_yyyzzzzz_1[j] + fl1_fx * (tg_xzzz_yyyzzzzz_0[j] - tg_xzzz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxxzzz_yyzzzzzz_0[j] = pb_x * tg_xxzzz_yyzzzzzz_0[j] + fr * tg_xxzzz_yyzzzzzz_1[j] + fl1_fx * (tg_xzzz_yyzzzzzz_0[j] - tg_xzzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxxzzz_yzzzzzzz_0[j] = pb_x * tg_xxzzz_yzzzzzzz_0[j] + fr * tg_xxzzz_yzzzzzzz_1[j] + fl1_fx * (tg_xzzz_yzzzzzzz_0[j] - tg_xzzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxxzzz_zzzzzzzz_0[j] = pb_x * tg_xxzzz_zzzzzzzz_0[j] + fr * tg_xxzzz_zzzzzzzz_1[j] + fl1_fx * (tg_xzzz_zzzzzzzz_0[j] - tg_xzzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyy_xxxxxxxx_0[j] = pb_x * tg_xyyyy_xxxxxxxx_0[j] + fr * tg_xyyyy_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxxx_0[j] - tg_yyyy_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xyyyy_xxxxxxx_1[j];

                    tg_xxyyyy_xxxxxxxy_0[j] = pb_x * tg_xyyyy_xxxxxxxy_0[j] + fr * tg_xyyyy_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxxy_0[j] - tg_yyyy_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyy_xxxxxxy_1[j];

                    tg_xxyyyy_xxxxxxxz_0[j] = pb_x * tg_xyyyy_xxxxxxxz_0[j] + fr * tg_xyyyy_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxxz_0[j] - tg_yyyy_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyy_xxxxxxz_1[j];

                    tg_xxyyyy_xxxxxxyy_0[j] = pb_x * tg_xyyyy_xxxxxxyy_0[j] + fr * tg_xyyyy_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxyy_0[j] - tg_yyyy_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyy_xxxxxyy_1[j];

                    tg_xxyyyy_xxxxxxyz_0[j] = pb_x * tg_xyyyy_xxxxxxyz_0[j] + fr * tg_xyyyy_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxyz_0[j] - tg_yyyy_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyy_xxxxxyz_1[j];

                    tg_xxyyyy_xxxxxxzz_0[j] = pb_x * tg_xyyyy_xxxxxxzz_0[j] + fr * tg_xyyyy_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxxzz_0[j] - tg_yyyy_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyy_xxxxxzz_1[j];

                    tg_xxyyyy_xxxxxyyy_0[j] = pb_x * tg_xyyyy_xxxxxyyy_0[j] + fr * tg_xyyyy_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxyyy_0[j] - tg_yyyy_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyy_xxxxyyy_1[j];

                    tg_xxyyyy_xxxxxyyz_0[j] = pb_x * tg_xyyyy_xxxxxyyz_0[j] + fr * tg_xyyyy_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxyyz_0[j] - tg_yyyy_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyy_xxxxyyz_1[j];

                    tg_xxyyyy_xxxxxyzz_0[j] = pb_x * tg_xyyyy_xxxxxyzz_0[j] + fr * tg_xyyyy_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxyzz_0[j] - tg_yyyy_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyy_xxxxyzz_1[j];

                    tg_xxyyyy_xxxxxzzz_0[j] = pb_x * tg_xyyyy_xxxxxzzz_0[j] + fr * tg_xyyyy_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxxzzz_0[j] - tg_yyyy_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyy_xxxxzzz_1[j];

                    tg_xxyyyy_xxxxyyyy_0[j] = pb_x * tg_xyyyy_xxxxyyyy_0[j] + fr * tg_xyyyy_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxyyyy_0[j] - tg_yyyy_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyy_xxxyyyy_1[j];

                    tg_xxyyyy_xxxxyyyz_0[j] = pb_x * tg_xyyyy_xxxxyyyz_0[j] + fr * tg_xyyyy_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxyyyz_0[j] - tg_yyyy_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyy_xxxyyyz_1[j];

                    tg_xxyyyy_xxxxyyzz_0[j] = pb_x * tg_xyyyy_xxxxyyzz_0[j] + fr * tg_xyyyy_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxyyzz_0[j] - tg_yyyy_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyy_xxxyyzz_1[j];

                    tg_xxyyyy_xxxxyzzz_0[j] = pb_x * tg_xyyyy_xxxxyzzz_0[j] + fr * tg_xyyyy_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxyzzz_0[j] - tg_yyyy_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyy_xxxyzzz_1[j];

                    tg_xxyyyy_xxxxzzzz_0[j] = pb_x * tg_xyyyy_xxxxzzzz_0[j] + fr * tg_xyyyy_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxxzzzz_0[j] - tg_yyyy_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyy_xxxzzzz_1[j];

                    tg_xxyyyy_xxxyyyyy_0[j] = pb_x * tg_xyyyy_xxxyyyyy_0[j] + fr * tg_xyyyy_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxyyyyy_0[j] - tg_yyyy_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxyyyyy_1[j];

                    tg_xxyyyy_xxxyyyyz_0[j] = pb_x * tg_xyyyy_xxxyyyyz_0[j] + fr * tg_xyyyy_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxyyyyz_0[j] - tg_yyyy_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxyyyyz_1[j];

                    tg_xxyyyy_xxxyyyzz_0[j] = pb_x * tg_xyyyy_xxxyyyzz_0[j] + fr * tg_xyyyy_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxyyyzz_0[j] - tg_yyyy_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxyyyzz_1[j];

                    tg_xxyyyy_xxxyyzzz_0[j] = pb_x * tg_xyyyy_xxxyyzzz_0[j] + fr * tg_xyyyy_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxyyzzz_0[j] - tg_yyyy_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxyyzzz_1[j];

                    tg_xxyyyy_xxxyzzzz_0[j] = pb_x * tg_xyyyy_xxxyzzzz_0[j] + fr * tg_xyyyy_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxyzzzz_0[j] - tg_yyyy_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxyzzzz_1[j];

                    tg_xxyyyy_xxxzzzzz_0[j] = pb_x * tg_xyyyy_xxxzzzzz_0[j] + fr * tg_xyyyy_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxxzzzzz_0[j] - tg_yyyy_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyy_xxzzzzz_1[j];

                    tg_xxyyyy_xxyyyyyy_0[j] = pb_x * tg_xyyyy_xxyyyyyy_0[j] + fr * tg_xyyyy_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyyyyyy_0[j] - tg_yyyy_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyyyyyy_1[j];

                    tg_xxyyyy_xxyyyyyz_0[j] = pb_x * tg_xyyyy_xxyyyyyz_0[j] + fr * tg_xyyyy_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyyyyyz_0[j] - tg_yyyy_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyyyyyz_1[j];

                    tg_xxyyyy_xxyyyyzz_0[j] = pb_x * tg_xyyyy_xxyyyyzz_0[j] + fr * tg_xyyyy_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyyyyzz_0[j] - tg_yyyy_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyyyyzz_1[j];

                    tg_xxyyyy_xxyyyzzz_0[j] = pb_x * tg_xyyyy_xxyyyzzz_0[j] + fr * tg_xyyyy_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyyyzzz_0[j] - tg_yyyy_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyyyzzz_1[j];

                    tg_xxyyyy_xxyyzzzz_0[j] = pb_x * tg_xyyyy_xxyyzzzz_0[j] + fr * tg_xyyyy_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyyzzzz_0[j] - tg_yyyy_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyyzzzz_1[j];

                    tg_xxyyyy_xxyzzzzz_0[j] = pb_x * tg_xyyyy_xxyzzzzz_0[j] + fr * tg_xyyyy_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxyzzzzz_0[j] - tg_yyyy_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xyzzzzz_1[j];

                    tg_xxyyyy_xxzzzzzz_0[j] = pb_x * tg_xyyyy_xxzzzzzz_0[j] + fr * tg_xyyyy_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xxzzzzzz_0[j] - tg_yyyy_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyy_xzzzzzz_1[j];

                    tg_xxyyyy_xyyyyyyy_0[j] = pb_x * tg_xyyyy_xyyyyyyy_0[j] + fr * tg_xyyyy_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyyyyyy_0[j] - tg_yyyy_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyyyyyy_1[j];

                    tg_xxyyyy_xyyyyyyz_0[j] = pb_x * tg_xyyyy_xyyyyyyz_0[j] + fr * tg_xyyyy_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyyyyyz_0[j] - tg_yyyy_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyyyyyz_1[j];

                    tg_xxyyyy_xyyyyyzz_0[j] = pb_x * tg_xyyyy_xyyyyyzz_0[j] + fr * tg_xyyyy_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyyyyzz_0[j] - tg_yyyy_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyyyyzz_1[j];

                    tg_xxyyyy_xyyyyzzz_0[j] = pb_x * tg_xyyyy_xyyyyzzz_0[j] + fr * tg_xyyyy_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyyyzzz_0[j] - tg_yyyy_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyyyzzz_1[j];

                    tg_xxyyyy_xyyyzzzz_0[j] = pb_x * tg_xyyyy_xyyyzzzz_0[j] + fr * tg_xyyyy_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyyzzzz_0[j] - tg_yyyy_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyyzzzz_1[j];

                    tg_xxyyyy_xyyzzzzz_0[j] = pb_x * tg_xyyyy_xyyzzzzz_0[j] + fr * tg_xyyyy_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyyzzzzz_0[j] - tg_yyyy_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yyzzzzz_1[j];

                    tg_xxyyyy_xyzzzzzz_0[j] = pb_x * tg_xyyyy_xyzzzzzz_0[j] + fr * tg_xyyyy_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xyzzzzzz_0[j] - tg_yyyy_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_yzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_485_582(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (485,582)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xyyyy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 485); 

                auto tg_xyyyy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 486); 

                auto tg_xyyyy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 487); 

                auto tg_xyyyy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 488); 

                auto tg_xyyyy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 489); 

                auto tg_xyyyy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 490); 

                auto tg_xyyyy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 491); 

                auto tg_xyyyy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 492); 

                auto tg_xyyyy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 493); 

                auto tg_xyyyy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 494); 

                auto tg_xyyyz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 495); 

                auto tg_xyyyz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 496); 

                auto tg_xyyyz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 497); 

                auto tg_xyyyz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 498); 

                auto tg_xyyyz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 499); 

                auto tg_xyyyz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 500); 

                auto tg_xyyyz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 501); 

                auto tg_xyyyz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 502); 

                auto tg_xyyyz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 503); 

                auto tg_xyyyz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 504); 

                auto tg_xyyyz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 505); 

                auto tg_xyyyz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 506); 

                auto tg_xyyyz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 507); 

                auto tg_xyyyz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 508); 

                auto tg_xyyyz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 509); 

                auto tg_xyyyz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 510); 

                auto tg_xyyyz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 511); 

                auto tg_xyyyz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 512); 

                auto tg_xyyyz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 513); 

                auto tg_xyyyz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 514); 

                auto tg_xyyyz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 515); 

                auto tg_xyyyz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 516); 

                auto tg_xyyyz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 517); 

                auto tg_xyyyz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 518); 

                auto tg_xyyyz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 519); 

                auto tg_xyyyz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 520); 

                auto tg_xyyyz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 521); 

                auto tg_xyyyz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 522); 

                auto tg_xyyyz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 523); 

                auto tg_xyyyz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 524); 

                auto tg_xyyyz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 525); 

                auto tg_xyyyz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 526); 

                auto tg_xyyyz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 527); 

                auto tg_xyyyz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 528); 

                auto tg_xyyyz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 529); 

                auto tg_xyyyz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 530); 

                auto tg_xyyyz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 531); 

                auto tg_xyyyz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 532); 

                auto tg_xyyyz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 533); 

                auto tg_xyyyz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 534); 

                auto tg_xyyyz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 535); 

                auto tg_xyyyz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 536); 

                auto tg_xyyyz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 537); 

                auto tg_xyyyz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 538); 

                auto tg_xyyyz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 539); 

                auto tg_xyyzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 540); 

                auto tg_xyyzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 541); 

                auto tg_xyyzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 542); 

                auto tg_xyyzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 543); 

                auto tg_xyyzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 544); 

                auto tg_xyyzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 545); 

                auto tg_xyyzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 546); 

                auto tg_xyyzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 547); 

                auto tg_xyyzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 548); 

                auto tg_xyyzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 549); 

                auto tg_xyyzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 550); 

                auto tg_xyyzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 551); 

                auto tg_xyyzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 552); 

                auto tg_xyyzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 553); 

                auto tg_xyyzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 554); 

                auto tg_xyyzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 555); 

                auto tg_xyyzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 556); 

                auto tg_xyyzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 557); 

                auto tg_xyyzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 558); 

                auto tg_xyyzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 559); 

                auto tg_xyyzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 560); 

                auto tg_xyyzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 561); 

                auto tg_xyyzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 562); 

                auto tg_xyyzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 563); 

                auto tg_xyyzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 564); 

                auto tg_xyyzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 565); 

                auto tg_xyyzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 566); 

                auto tg_xyyzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 567); 

                auto tg_xyyzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 568); 

                auto tg_xyyzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 569); 

                auto tg_xyyzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 570); 

                auto tg_xyyzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 571); 

                auto tg_xyyzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 572); 

                auto tg_xyyzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 573); 

                auto tg_xyyzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 574); 

                auto tg_xyyzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 575); 

                auto tg_xyyzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 576); 

                auto tg_xyyzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 577); 

                auto tg_xyyzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 578); 

                auto tg_xyyzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 579); 

                auto tg_xyyzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 580); 

                auto tg_xyyzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 581); 

                auto tg_xyyyy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 485); 

                auto tg_xyyyy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 486); 

                auto tg_xyyyy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 487); 

                auto tg_xyyyy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 488); 

                auto tg_xyyyy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 489); 

                auto tg_xyyyy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 490); 

                auto tg_xyyyy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 491); 

                auto tg_xyyyy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 492); 

                auto tg_xyyyy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 493); 

                auto tg_xyyyy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 494); 

                auto tg_xyyyz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 495); 

                auto tg_xyyyz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 496); 

                auto tg_xyyyz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 497); 

                auto tg_xyyyz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 498); 

                auto tg_xyyyz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 499); 

                auto tg_xyyyz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 500); 

                auto tg_xyyyz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 501); 

                auto tg_xyyyz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 502); 

                auto tg_xyyyz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 503); 

                auto tg_xyyyz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 504); 

                auto tg_xyyyz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 505); 

                auto tg_xyyyz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 506); 

                auto tg_xyyyz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 507); 

                auto tg_xyyyz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 508); 

                auto tg_xyyyz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 509); 

                auto tg_xyyyz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 510); 

                auto tg_xyyyz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 511); 

                auto tg_xyyyz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 512); 

                auto tg_xyyyz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 513); 

                auto tg_xyyyz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 514); 

                auto tg_xyyyz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 515); 

                auto tg_xyyyz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 516); 

                auto tg_xyyyz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 517); 

                auto tg_xyyyz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 518); 

                auto tg_xyyyz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 519); 

                auto tg_xyyyz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 520); 

                auto tg_xyyyz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 521); 

                auto tg_xyyyz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 522); 

                auto tg_xyyyz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 523); 

                auto tg_xyyyz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 524); 

                auto tg_xyyyz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 525); 

                auto tg_xyyyz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 526); 

                auto tg_xyyyz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 527); 

                auto tg_xyyyz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 528); 

                auto tg_xyyyz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 529); 

                auto tg_xyyyz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 530); 

                auto tg_xyyyz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 531); 

                auto tg_xyyyz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 532); 

                auto tg_xyyyz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 533); 

                auto tg_xyyyz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 534); 

                auto tg_xyyyz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 535); 

                auto tg_xyyyz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 536); 

                auto tg_xyyyz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 537); 

                auto tg_xyyyz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 538); 

                auto tg_xyyyz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 539); 

                auto tg_xyyzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 540); 

                auto tg_xyyzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 541); 

                auto tg_xyyzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 542); 

                auto tg_xyyzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 543); 

                auto tg_xyyzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 544); 

                auto tg_xyyzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 545); 

                auto tg_xyyzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 546); 

                auto tg_xyyzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 547); 

                auto tg_xyyzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 548); 

                auto tg_xyyzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 549); 

                auto tg_xyyzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 550); 

                auto tg_xyyzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 551); 

                auto tg_xyyzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 552); 

                auto tg_xyyzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 553); 

                auto tg_xyyzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 554); 

                auto tg_xyyzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 555); 

                auto tg_xyyzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 556); 

                auto tg_xyyzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 557); 

                auto tg_xyyzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 558); 

                auto tg_xyyzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 559); 

                auto tg_xyyzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 560); 

                auto tg_xyyzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 561); 

                auto tg_xyyzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 562); 

                auto tg_xyyzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 563); 

                auto tg_xyyzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 564); 

                auto tg_xyyzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 565); 

                auto tg_xyyzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 566); 

                auto tg_xyyzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 567); 

                auto tg_xyyzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 568); 

                auto tg_xyyzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 569); 

                auto tg_xyyzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 570); 

                auto tg_xyyzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 571); 

                auto tg_xyyzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 572); 

                auto tg_xyyzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 573); 

                auto tg_xyyzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 574); 

                auto tg_xyyzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 575); 

                auto tg_xyyzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 576); 

                auto tg_xyyzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 577); 

                auto tg_xyyzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 578); 

                auto tg_xyyzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 579); 

                auto tg_xyyzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 580); 

                auto tg_xyyzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 581); 

                auto tg_yyyy_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 485); 

                auto tg_yyyy_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 486); 

                auto tg_yyyy_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 487); 

                auto tg_yyyy_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 488); 

                auto tg_yyyy_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 489); 

                auto tg_yyyy_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 490); 

                auto tg_yyyy_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 491); 

                auto tg_yyyy_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 492); 

                auto tg_yyyy_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 493); 

                auto tg_yyyy_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 494); 

                auto tg_yyyz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 495); 

                auto tg_yyyz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 496); 

                auto tg_yyyz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 497); 

                auto tg_yyyz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 498); 

                auto tg_yyyz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 499); 

                auto tg_yyyz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 500); 

                auto tg_yyyz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 501); 

                auto tg_yyyz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 502); 

                auto tg_yyyz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 503); 

                auto tg_yyyz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 504); 

                auto tg_yyyz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 505); 

                auto tg_yyyz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 506); 

                auto tg_yyyz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 507); 

                auto tg_yyyz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 508); 

                auto tg_yyyz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 509); 

                auto tg_yyyz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 510); 

                auto tg_yyyz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 511); 

                auto tg_yyyz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 512); 

                auto tg_yyyz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 513); 

                auto tg_yyyz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 514); 

                auto tg_yyyz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 515); 

                auto tg_yyyz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 516); 

                auto tg_yyyz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 517); 

                auto tg_yyyz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 518); 

                auto tg_yyyz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 519); 

                auto tg_yyyz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 520); 

                auto tg_yyyz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 521); 

                auto tg_yyyz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 522); 

                auto tg_yyyz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 523); 

                auto tg_yyyz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 524); 

                auto tg_yyyz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 525); 

                auto tg_yyyz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 526); 

                auto tg_yyyz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 527); 

                auto tg_yyyz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 528); 

                auto tg_yyyz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 529); 

                auto tg_yyyz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 530); 

                auto tg_yyyz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 531); 

                auto tg_yyyz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 532); 

                auto tg_yyyz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 533); 

                auto tg_yyyz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 534); 

                auto tg_yyyz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 535); 

                auto tg_yyyz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 536); 

                auto tg_yyyz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 537); 

                auto tg_yyyz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 538); 

                auto tg_yyyz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 539); 

                auto tg_yyzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 540); 

                auto tg_yyzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 541); 

                auto tg_yyzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 542); 

                auto tg_yyzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 543); 

                auto tg_yyzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 544); 

                auto tg_yyzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 545); 

                auto tg_yyzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 546); 

                auto tg_yyzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 547); 

                auto tg_yyzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 548); 

                auto tg_yyzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 549); 

                auto tg_yyzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 550); 

                auto tg_yyzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 551); 

                auto tg_yyzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 552); 

                auto tg_yyzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 553); 

                auto tg_yyzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 554); 

                auto tg_yyzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 555); 

                auto tg_yyzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 556); 

                auto tg_yyzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 557); 

                auto tg_yyzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 558); 

                auto tg_yyzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 559); 

                auto tg_yyzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 560); 

                auto tg_yyzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 561); 

                auto tg_yyzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 562); 

                auto tg_yyzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 563); 

                auto tg_yyzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 564); 

                auto tg_yyzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 565); 

                auto tg_yyzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 566); 

                auto tg_yyzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 567); 

                auto tg_yyzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 568); 

                auto tg_yyzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 569); 

                auto tg_yyzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 570); 

                auto tg_yyzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 571); 

                auto tg_yyzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 572); 

                auto tg_yyzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 573); 

                auto tg_yyzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 574); 

                auto tg_yyzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 575); 

                auto tg_yyzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 576); 

                auto tg_yyzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 577); 

                auto tg_yyzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 578); 

                auto tg_yyzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 579); 

                auto tg_yyzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 580); 

                auto tg_yyzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 581); 

                auto tg_yyyy_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 485); 

                auto tg_yyyy_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 486); 

                auto tg_yyyy_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 487); 

                auto tg_yyyy_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 488); 

                auto tg_yyyy_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 489); 

                auto tg_yyyy_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 490); 

                auto tg_yyyy_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 491); 

                auto tg_yyyy_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 492); 

                auto tg_yyyy_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 493); 

                auto tg_yyyy_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 494); 

                auto tg_yyyz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 495); 

                auto tg_yyyz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 496); 

                auto tg_yyyz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 497); 

                auto tg_yyyz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 498); 

                auto tg_yyyz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 499); 

                auto tg_yyyz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 500); 

                auto tg_yyyz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 501); 

                auto tg_yyyz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 502); 

                auto tg_yyyz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 503); 

                auto tg_yyyz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 504); 

                auto tg_yyyz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 505); 

                auto tg_yyyz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 506); 

                auto tg_yyyz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 507); 

                auto tg_yyyz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 508); 

                auto tg_yyyz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 509); 

                auto tg_yyyz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 510); 

                auto tg_yyyz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 511); 

                auto tg_yyyz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 512); 

                auto tg_yyyz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 513); 

                auto tg_yyyz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 514); 

                auto tg_yyyz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 515); 

                auto tg_yyyz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 516); 

                auto tg_yyyz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 517); 

                auto tg_yyyz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 518); 

                auto tg_yyyz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 519); 

                auto tg_yyyz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 520); 

                auto tg_yyyz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 521); 

                auto tg_yyyz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 522); 

                auto tg_yyyz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 523); 

                auto tg_yyyz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 524); 

                auto tg_yyyz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 525); 

                auto tg_yyyz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 526); 

                auto tg_yyyz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 527); 

                auto tg_yyyz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 528); 

                auto tg_yyyz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 529); 

                auto tg_yyyz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 530); 

                auto tg_yyyz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 531); 

                auto tg_yyyz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 532); 

                auto tg_yyyz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 533); 

                auto tg_yyyz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 534); 

                auto tg_yyyz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 535); 

                auto tg_yyyz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 536); 

                auto tg_yyyz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 537); 

                auto tg_yyyz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 538); 

                auto tg_yyyz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 539); 

                auto tg_yyzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 540); 

                auto tg_yyzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 541); 

                auto tg_yyzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 542); 

                auto tg_yyzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 543); 

                auto tg_yyzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 544); 

                auto tg_yyzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 545); 

                auto tg_yyzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 546); 

                auto tg_yyzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 547); 

                auto tg_yyzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 548); 

                auto tg_yyzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 549); 

                auto tg_yyzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 550); 

                auto tg_yyzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 551); 

                auto tg_yyzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 552); 

                auto tg_yyzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 553); 

                auto tg_yyzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 554); 

                auto tg_yyzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 555); 

                auto tg_yyzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 556); 

                auto tg_yyzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 557); 

                auto tg_yyzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 558); 

                auto tg_yyzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 559); 

                auto tg_yyzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 560); 

                auto tg_yyzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 561); 

                auto tg_yyzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 562); 

                auto tg_yyzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 563); 

                auto tg_yyzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 564); 

                auto tg_yyzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 565); 

                auto tg_yyzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 566); 

                auto tg_yyzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 567); 

                auto tg_yyzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 568); 

                auto tg_yyzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 569); 

                auto tg_yyzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 570); 

                auto tg_yyzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 571); 

                auto tg_yyzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 572); 

                auto tg_yyzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 573); 

                auto tg_yyzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 574); 

                auto tg_yyzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 575); 

                auto tg_yyzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 576); 

                auto tg_yyzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 577); 

                auto tg_yyzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 578); 

                auto tg_yyzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 579); 

                auto tg_yyzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 580); 

                auto tg_yyzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 581); 

                auto tg_xyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 395); 

                auto tg_xyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 396); 

                auto tg_xyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 397); 

                auto tg_xyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 398); 

                auto tg_xyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 399); 

                auto tg_xyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 400); 

                auto tg_xyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 401); 

                auto tg_xyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 402); 

                auto tg_xyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 403); 

                auto tg_xyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 404); 

                auto tg_xyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 405); 

                auto tg_xyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 406); 

                auto tg_xyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 407); 

                auto tg_xyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 408); 

                auto tg_xyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 409); 

                auto tg_xyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 410); 

                auto tg_xyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 411); 

                auto tg_xyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 412); 

                auto tg_xyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 413); 

                auto tg_xyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 414); 

                auto tg_xyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 415); 

                auto tg_xyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 416); 

                auto tg_xyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 417); 

                auto tg_xyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 418); 

                auto tg_xyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 419); 

                auto tg_xyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 420); 

                auto tg_xyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 421); 

                auto tg_xyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 422); 

                auto tg_xyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 423); 

                auto tg_xyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 424); 

                auto tg_xyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 425); 

                auto tg_xyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 426); 

                auto tg_xyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 427); 

                auto tg_xyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 428); 

                auto tg_xyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 429); 

                auto tg_xyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 430); 

                auto tg_xyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 431); 

                auto tg_xyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 432); 

                auto tg_xyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 433); 

                auto tg_xyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 434); 

                auto tg_xyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 435); 

                auto tg_xyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 436); 

                auto tg_xyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 437); 

                auto tg_xyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 438); 

                auto tg_xyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 439); 

                auto tg_xyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 440); 

                auto tg_xyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 441); 

                auto tg_xyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 442); 

                auto tg_xyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 443); 

                auto tg_xyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 444); 

                auto tg_xyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 445); 

                auto tg_xyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 446); 

                auto tg_xyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 447); 

                auto tg_xyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 448); 

                auto tg_xyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 449); 

                auto tg_xyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 450); 

                auto tg_xyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 451); 

                auto tg_xyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 452); 

                auto tg_xyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 453); 

                auto tg_xyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 454); 

                auto tg_xyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 455); 

                auto tg_xyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 456); 

                auto tg_xyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 457); 

                auto tg_xyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 458); 

                auto tg_xyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 459); 

                auto tg_xyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 460); 

                auto tg_xyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 461); 

                auto tg_xyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 462); 

                auto tg_xyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 463); 

                auto tg_xyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 464); 

                auto tg_xyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 465); 

                auto tg_xyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 466); 

                auto tg_xyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 467); 

                // set up pointers to integrals

                auto tg_xxyyyy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 485); 

                auto tg_xxyyyy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 486); 

                auto tg_xxyyyy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 487); 

                auto tg_xxyyyy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 488); 

                auto tg_xxyyyy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 489); 

                auto tg_xxyyyy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 490); 

                auto tg_xxyyyy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 491); 

                auto tg_xxyyyy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 492); 

                auto tg_xxyyyy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 493); 

                auto tg_xxyyyy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 494); 

                auto tg_xxyyyz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 495); 

                auto tg_xxyyyz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 496); 

                auto tg_xxyyyz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 497); 

                auto tg_xxyyyz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 498); 

                auto tg_xxyyyz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 499); 

                auto tg_xxyyyz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 500); 

                auto tg_xxyyyz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 501); 

                auto tg_xxyyyz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 502); 

                auto tg_xxyyyz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 503); 

                auto tg_xxyyyz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 504); 

                auto tg_xxyyyz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 505); 

                auto tg_xxyyyz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 506); 

                auto tg_xxyyyz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 507); 

                auto tg_xxyyyz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 508); 

                auto tg_xxyyyz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 509); 

                auto tg_xxyyyz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 510); 

                auto tg_xxyyyz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 511); 

                auto tg_xxyyyz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 512); 

                auto tg_xxyyyz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 513); 

                auto tg_xxyyyz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 514); 

                auto tg_xxyyyz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 515); 

                auto tg_xxyyyz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 516); 

                auto tg_xxyyyz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 517); 

                auto tg_xxyyyz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 518); 

                auto tg_xxyyyz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 519); 

                auto tg_xxyyyz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 520); 

                auto tg_xxyyyz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 521); 

                auto tg_xxyyyz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 522); 

                auto tg_xxyyyz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 523); 

                auto tg_xxyyyz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 524); 

                auto tg_xxyyyz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 525); 

                auto tg_xxyyyz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 526); 

                auto tg_xxyyyz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 527); 

                auto tg_xxyyyz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 528); 

                auto tg_xxyyyz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 529); 

                auto tg_xxyyyz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 530); 

                auto tg_xxyyyz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 531); 

                auto tg_xxyyyz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 532); 

                auto tg_xxyyyz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 533); 

                auto tg_xxyyyz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 534); 

                auto tg_xxyyyz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 535); 

                auto tg_xxyyyz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 536); 

                auto tg_xxyyyz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 537); 

                auto tg_xxyyyz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 538); 

                auto tg_xxyyyz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 539); 

                auto tg_xxyyzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 540); 

                auto tg_xxyyzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 541); 

                auto tg_xxyyzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 542); 

                auto tg_xxyyzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 543); 

                auto tg_xxyyzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 544); 

                auto tg_xxyyzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 545); 

                auto tg_xxyyzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 546); 

                auto tg_xxyyzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 547); 

                auto tg_xxyyzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 548); 

                auto tg_xxyyzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 549); 

                auto tg_xxyyzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 550); 

                auto tg_xxyyzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 551); 

                auto tg_xxyyzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 552); 

                auto tg_xxyyzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 553); 

                auto tg_xxyyzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 554); 

                auto tg_xxyyzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 555); 

                auto tg_xxyyzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 556); 

                auto tg_xxyyzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 557); 

                auto tg_xxyyzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 558); 

                auto tg_xxyyzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 559); 

                auto tg_xxyyzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 560); 

                auto tg_xxyyzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 561); 

                auto tg_xxyyzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 562); 

                auto tg_xxyyzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 563); 

                auto tg_xxyyzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 564); 

                auto tg_xxyyzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 565); 

                auto tg_xxyyzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 566); 

                auto tg_xxyyzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 567); 

                auto tg_xxyyzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 568); 

                auto tg_xxyyzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 569); 

                auto tg_xxyyzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 570); 

                auto tg_xxyyzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 571); 

                auto tg_xxyyzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 572); 

                auto tg_xxyyzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 573); 

                auto tg_xxyyzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 574); 

                auto tg_xxyyzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 575); 

                auto tg_xxyyzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 576); 

                auto tg_xxyyzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 577); 

                auto tg_xxyyzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 578); 

                auto tg_xxyyzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 579); 

                auto tg_xxyyzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 580); 

                auto tg_xxyyzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 581); 

                // Batch of Integrals (485,582)

                #pragma omp simd aligned(fxn, fza, tg_xxyyyy_xzzzzzzz_0, tg_xxyyyy_yyyyyyyy_0, \
                                         tg_xxyyyy_yyyyyyyz_0, tg_xxyyyy_yyyyyyzz_0, tg_xxyyyy_yyyyyzzz_0, tg_xxyyyy_yyyyzzzz_0, \
                                         tg_xxyyyy_yyyzzzzz_0, tg_xxyyyy_yyzzzzzz_0, tg_xxyyyy_yzzzzzzz_0, tg_xxyyyy_zzzzzzzz_0, \
                                         tg_xxyyyz_xxxxxxxx_0, tg_xxyyyz_xxxxxxxy_0, tg_xxyyyz_xxxxxxxz_0, tg_xxyyyz_xxxxxxyy_0, \
                                         tg_xxyyyz_xxxxxxyz_0, tg_xxyyyz_xxxxxxzz_0, tg_xxyyyz_xxxxxyyy_0, tg_xxyyyz_xxxxxyyz_0, \
                                         tg_xxyyyz_xxxxxyzz_0, tg_xxyyyz_xxxxxzzz_0, tg_xxyyyz_xxxxyyyy_0, tg_xxyyyz_xxxxyyyz_0, \
                                         tg_xxyyyz_xxxxyyzz_0, tg_xxyyyz_xxxxyzzz_0, tg_xxyyyz_xxxxzzzz_0, tg_xxyyyz_xxxyyyyy_0, \
                                         tg_xxyyyz_xxxyyyyz_0, tg_xxyyyz_xxxyyyzz_0, tg_xxyyyz_xxxyyzzz_0, tg_xxyyyz_xxxyzzzz_0, \
                                         tg_xxyyyz_xxxzzzzz_0, tg_xxyyyz_xxyyyyyy_0, tg_xxyyyz_xxyyyyyz_0, tg_xxyyyz_xxyyyyzz_0, \
                                         tg_xxyyyz_xxyyyzzz_0, tg_xxyyyz_xxyyzzzz_0, tg_xxyyyz_xxyzzzzz_0, tg_xxyyyz_xxzzzzzz_0, \
                                         tg_xxyyyz_xyyyyyyy_0, tg_xxyyyz_xyyyyyyz_0, tg_xxyyyz_xyyyyyzz_0, tg_xxyyyz_xyyyyzzz_0, \
                                         tg_xxyyyz_xyyyzzzz_0, tg_xxyyyz_xyyzzzzz_0, tg_xxyyyz_xyzzzzzz_0, tg_xxyyyz_xzzzzzzz_0, \
                                         tg_xxyyyz_yyyyyyyy_0, tg_xxyyyz_yyyyyyyz_0, tg_xxyyyz_yyyyyyzz_0, tg_xxyyyz_yyyyyzzz_0, \
                                         tg_xxyyyz_yyyyzzzz_0, tg_xxyyyz_yyyzzzzz_0, tg_xxyyyz_yyzzzzzz_0, tg_xxyyyz_yzzzzzzz_0, \
                                         tg_xxyyyz_zzzzzzzz_0, tg_xxyyzz_xxxxxxxx_0, tg_xxyyzz_xxxxxxxy_0, tg_xxyyzz_xxxxxxxz_0, \
                                         tg_xxyyzz_xxxxxxyy_0, tg_xxyyzz_xxxxxxyz_0, tg_xxyyzz_xxxxxxzz_0, tg_xxyyzz_xxxxxyyy_0, \
                                         tg_xxyyzz_xxxxxyyz_0, tg_xxyyzz_xxxxxyzz_0, tg_xxyyzz_xxxxxzzz_0, tg_xxyyzz_xxxxyyyy_0, \
                                         tg_xxyyzz_xxxxyyyz_0, tg_xxyyzz_xxxxyyzz_0, tg_xxyyzz_xxxxyzzz_0, tg_xxyyzz_xxxxzzzz_0, \
                                         tg_xxyyzz_xxxyyyyy_0, tg_xxyyzz_xxxyyyyz_0, tg_xxyyzz_xxxyyyzz_0, tg_xxyyzz_xxxyyzzz_0, \
                                         tg_xxyyzz_xxxyzzzz_0, tg_xxyyzz_xxxzzzzz_0, tg_xxyyzz_xxyyyyyy_0, tg_xxyyzz_xxyyyyyz_0, \
                                         tg_xxyyzz_xxyyyyzz_0, tg_xxyyzz_xxyyyzzz_0, tg_xxyyzz_xxyyzzzz_0, tg_xxyyzz_xxyzzzzz_0, \
                                         tg_xxyyzz_xxzzzzzz_0, tg_xxyyzz_xyyyyyyy_0, tg_xxyyzz_xyyyyyyz_0, tg_xxyyzz_xyyyyyzz_0, \
                                         tg_xxyyzz_xyyyyzzz_0, tg_xxyyzz_xyyyzzzz_0, tg_xxyyzz_xyyzzzzz_0, tg_xxyyzz_xyzzzzzz_0, \
                                         tg_xxyyzz_xzzzzzzz_0, tg_xxyyzz_yyyyyyyy_0, tg_xxyyzz_yyyyyyyz_0, tg_xxyyzz_yyyyyyzz_0, \
                                         tg_xxyyzz_yyyyyzzz_0, tg_xxyyzz_yyyyzzzz_0, tg_xxyyzz_yyyzzzzz_0, tg_xyyyy_xzzzzzzz_0, \
                                         tg_xyyyy_xzzzzzzz_1, tg_xyyyy_yyyyyyyy_0, tg_xyyyy_yyyyyyyy_1, tg_xyyyy_yyyyyyyz_0, \
                                         tg_xyyyy_yyyyyyyz_1, tg_xyyyy_yyyyyyzz_0, tg_xyyyy_yyyyyyzz_1, tg_xyyyy_yyyyyzzz_0, \
                                         tg_xyyyy_yyyyyzzz_1, tg_xyyyy_yyyyzzzz_0, tg_xyyyy_yyyyzzzz_1, tg_xyyyy_yyyzzzzz_0, \
                                         tg_xyyyy_yyyzzzzz_1, tg_xyyyy_yyzzzzzz_0, tg_xyyyy_yyzzzzzz_1, tg_xyyyy_yzzzzzzz_0, \
                                         tg_xyyyy_yzzzzzzz_1, tg_xyyyy_zzzzzzz_1, tg_xyyyy_zzzzzzzz_0, tg_xyyyy_zzzzzzzz_1, \
                                         tg_xyyyz_xxxxxxx_1, tg_xyyyz_xxxxxxxx_0, tg_xyyyz_xxxxxxxx_1, tg_xyyyz_xxxxxxxy_0, \
                                         tg_xyyyz_xxxxxxxy_1, tg_xyyyz_xxxxxxxz_0, tg_xyyyz_xxxxxxxz_1, tg_xyyyz_xxxxxxy_1, \
                                         tg_xyyyz_xxxxxxyy_0, tg_xyyyz_xxxxxxyy_1, tg_xyyyz_xxxxxxyz_0, tg_xyyyz_xxxxxxyz_1, \
                                         tg_xyyyz_xxxxxxz_1, tg_xyyyz_xxxxxxzz_0, tg_xyyyz_xxxxxxzz_1, tg_xyyyz_xxxxxyy_1, \
                                         tg_xyyyz_xxxxxyyy_0, tg_xyyyz_xxxxxyyy_1, tg_xyyyz_xxxxxyyz_0, tg_xyyyz_xxxxxyyz_1, \
                                         tg_xyyyz_xxxxxyz_1, tg_xyyyz_xxxxxyzz_0, tg_xyyyz_xxxxxyzz_1, tg_xyyyz_xxxxxzz_1, \
                                         tg_xyyyz_xxxxxzzz_0, tg_xyyyz_xxxxxzzz_1, tg_xyyyz_xxxxyyy_1, tg_xyyyz_xxxxyyyy_0, \
                                         tg_xyyyz_xxxxyyyy_1, tg_xyyyz_xxxxyyyz_0, tg_xyyyz_xxxxyyyz_1, tg_xyyyz_xxxxyyz_1, \
                                         tg_xyyyz_xxxxyyzz_0, tg_xyyyz_xxxxyyzz_1, tg_xyyyz_xxxxyzz_1, tg_xyyyz_xxxxyzzz_0, \
                                         tg_xyyyz_xxxxyzzz_1, tg_xyyyz_xxxxzzz_1, tg_xyyyz_xxxxzzzz_0, tg_xyyyz_xxxxzzzz_1, \
                                         tg_xyyyz_xxxyyyy_1, tg_xyyyz_xxxyyyyy_0, tg_xyyyz_xxxyyyyy_1, tg_xyyyz_xxxyyyyz_0, \
                                         tg_xyyyz_xxxyyyyz_1, tg_xyyyz_xxxyyyz_1, tg_xyyyz_xxxyyyzz_0, tg_xyyyz_xxxyyyzz_1, \
                                         tg_xyyyz_xxxyyzz_1, tg_xyyyz_xxxyyzzz_0, tg_xyyyz_xxxyyzzz_1, tg_xyyyz_xxxyzzz_1, \
                                         tg_xyyyz_xxxyzzzz_0, tg_xyyyz_xxxyzzzz_1, tg_xyyyz_xxxzzzz_1, tg_xyyyz_xxxzzzzz_0, \
                                         tg_xyyyz_xxxzzzzz_1, tg_xyyyz_xxyyyyy_1, tg_xyyyz_xxyyyyyy_0, tg_xyyyz_xxyyyyyy_1, \
                                         tg_xyyyz_xxyyyyyz_0, tg_xyyyz_xxyyyyyz_1, tg_xyyyz_xxyyyyz_1, tg_xyyyz_xxyyyyzz_0, \
                                         tg_xyyyz_xxyyyyzz_1, tg_xyyyz_xxyyyzz_1, tg_xyyyz_xxyyyzzz_0, tg_xyyyz_xxyyyzzz_1, \
                                         tg_xyyyz_xxyyzzz_1, tg_xyyyz_xxyyzzzz_0, tg_xyyyz_xxyyzzzz_1, tg_xyyyz_xxyzzzz_1, \
                                         tg_xyyyz_xxyzzzzz_0, tg_xyyyz_xxyzzzzz_1, tg_xyyyz_xxzzzzz_1, tg_xyyyz_xxzzzzzz_0, \
                                         tg_xyyyz_xxzzzzzz_1, tg_xyyyz_xyyyyyy_1, tg_xyyyz_xyyyyyyy_0, tg_xyyyz_xyyyyyyy_1, \
                                         tg_xyyyz_xyyyyyyz_0, tg_xyyyz_xyyyyyyz_1, tg_xyyyz_xyyyyyz_1, tg_xyyyz_xyyyyyzz_0, \
                                         tg_xyyyz_xyyyyyzz_1, tg_xyyyz_xyyyyzz_1, tg_xyyyz_xyyyyzzz_0, tg_xyyyz_xyyyyzzz_1, \
                                         tg_xyyyz_xyyyzzz_1, tg_xyyyz_xyyyzzzz_0, tg_xyyyz_xyyyzzzz_1, tg_xyyyz_xyyzzzz_1, \
                                         tg_xyyyz_xyyzzzzz_0, tg_xyyyz_xyyzzzzz_1, tg_xyyyz_xyzzzzz_1, tg_xyyyz_xyzzzzzz_0, \
                                         tg_xyyyz_xyzzzzzz_1, tg_xyyyz_xzzzzzz_1, tg_xyyyz_xzzzzzzz_0, tg_xyyyz_xzzzzzzz_1, \
                                         tg_xyyyz_yyyyyyy_1, tg_xyyyz_yyyyyyyy_0, tg_xyyyz_yyyyyyyy_1, tg_xyyyz_yyyyyyyz_0, \
                                         tg_xyyyz_yyyyyyyz_1, tg_xyyyz_yyyyyyz_1, tg_xyyyz_yyyyyyzz_0, tg_xyyyz_yyyyyyzz_1, \
                                         tg_xyyyz_yyyyyzz_1, tg_xyyyz_yyyyyzzz_0, tg_xyyyz_yyyyyzzz_1, tg_xyyyz_yyyyzzz_1, \
                                         tg_xyyyz_yyyyzzzz_0, tg_xyyyz_yyyyzzzz_1, tg_xyyyz_yyyzzzz_1, tg_xyyyz_yyyzzzzz_0, \
                                         tg_xyyyz_yyyzzzzz_1, tg_xyyyz_yyzzzzz_1, tg_xyyyz_yyzzzzzz_0, tg_xyyyz_yyzzzzzz_1, \
                                         tg_xyyyz_yzzzzzz_1, tg_xyyyz_yzzzzzzz_0, tg_xyyyz_yzzzzzzz_1, tg_xyyyz_zzzzzzz_1, \
                                         tg_xyyyz_zzzzzzzz_0, tg_xyyyz_zzzzzzzz_1, tg_xyyzz_xxxxxxx_1, tg_xyyzz_xxxxxxxx_0, \
                                         tg_xyyzz_xxxxxxxx_1, tg_xyyzz_xxxxxxxy_0, tg_xyyzz_xxxxxxxy_1, tg_xyyzz_xxxxxxxz_0, \
                                         tg_xyyzz_xxxxxxxz_1, tg_xyyzz_xxxxxxy_1, tg_xyyzz_xxxxxxyy_0, tg_xyyzz_xxxxxxyy_1, \
                                         tg_xyyzz_xxxxxxyz_0, tg_xyyzz_xxxxxxyz_1, tg_xyyzz_xxxxxxz_1, tg_xyyzz_xxxxxxzz_0, \
                                         tg_xyyzz_xxxxxxzz_1, tg_xyyzz_xxxxxyy_1, tg_xyyzz_xxxxxyyy_0, tg_xyyzz_xxxxxyyy_1, \
                                         tg_xyyzz_xxxxxyyz_0, tg_xyyzz_xxxxxyyz_1, tg_xyyzz_xxxxxyz_1, tg_xyyzz_xxxxxyzz_0, \
                                         tg_xyyzz_xxxxxyzz_1, tg_xyyzz_xxxxxzz_1, tg_xyyzz_xxxxxzzz_0, tg_xyyzz_xxxxxzzz_1, \
                                         tg_xyyzz_xxxxyyy_1, tg_xyyzz_xxxxyyyy_0, tg_xyyzz_xxxxyyyy_1, tg_xyyzz_xxxxyyyz_0, \
                                         tg_xyyzz_xxxxyyyz_1, tg_xyyzz_xxxxyyz_1, tg_xyyzz_xxxxyyzz_0, tg_xyyzz_xxxxyyzz_1, \
                                         tg_xyyzz_xxxxyzz_1, tg_xyyzz_xxxxyzzz_0, tg_xyyzz_xxxxyzzz_1, tg_xyyzz_xxxxzzz_1, \
                                         tg_xyyzz_xxxxzzzz_0, tg_xyyzz_xxxxzzzz_1, tg_xyyzz_xxxyyyy_1, tg_xyyzz_xxxyyyyy_0, \
                                         tg_xyyzz_xxxyyyyy_1, tg_xyyzz_xxxyyyyz_0, tg_xyyzz_xxxyyyyz_1, tg_xyyzz_xxxyyyz_1, \
                                         tg_xyyzz_xxxyyyzz_0, tg_xyyzz_xxxyyyzz_1, tg_xyyzz_xxxyyzz_1, tg_xyyzz_xxxyyzzz_0, \
                                         tg_xyyzz_xxxyyzzz_1, tg_xyyzz_xxxyzzz_1, tg_xyyzz_xxxyzzzz_0, tg_xyyzz_xxxyzzzz_1, \
                                         tg_xyyzz_xxxzzzz_1, tg_xyyzz_xxxzzzzz_0, tg_xyyzz_xxxzzzzz_1, tg_xyyzz_xxyyyyy_1, \
                                         tg_xyyzz_xxyyyyyy_0, tg_xyyzz_xxyyyyyy_1, tg_xyyzz_xxyyyyyz_0, tg_xyyzz_xxyyyyyz_1, \
                                         tg_xyyzz_xxyyyyz_1, tg_xyyzz_xxyyyyzz_0, tg_xyyzz_xxyyyyzz_1, tg_xyyzz_xxyyyzz_1, \
                                         tg_xyyzz_xxyyyzzz_0, tg_xyyzz_xxyyyzzz_1, tg_xyyzz_xxyyzzz_1, tg_xyyzz_xxyyzzzz_0, \
                                         tg_xyyzz_xxyyzzzz_1, tg_xyyzz_xxyzzzz_1, tg_xyyzz_xxyzzzzz_0, tg_xyyzz_xxyzzzzz_1, \
                                         tg_xyyzz_xxzzzzz_1, tg_xyyzz_xxzzzzzz_0, tg_xyyzz_xxzzzzzz_1, tg_xyyzz_xyyyyyy_1, \
                                         tg_xyyzz_xyyyyyyy_0, tg_xyyzz_xyyyyyyy_1, tg_xyyzz_xyyyyyyz_0, tg_xyyzz_xyyyyyyz_1, \
                                         tg_xyyzz_xyyyyyz_1, tg_xyyzz_xyyyyyzz_0, tg_xyyzz_xyyyyyzz_1, tg_xyyzz_xyyyyzz_1, \
                                         tg_xyyzz_xyyyyzzz_0, tg_xyyzz_xyyyyzzz_1, tg_xyyzz_xyyyzzz_1, tg_xyyzz_xyyyzzzz_0, \
                                         tg_xyyzz_xyyyzzzz_1, tg_xyyzz_xyyzzzz_1, tg_xyyzz_xyyzzzzz_0, tg_xyyzz_xyyzzzzz_1, \
                                         tg_xyyzz_xyzzzzz_1, tg_xyyzz_xyzzzzzz_0, tg_xyyzz_xyzzzzzz_1, tg_xyyzz_xzzzzzz_1, \
                                         tg_xyyzz_xzzzzzzz_0, tg_xyyzz_xzzzzzzz_1, tg_xyyzz_yyyyyyy_1, tg_xyyzz_yyyyyyyy_0, \
                                         tg_xyyzz_yyyyyyyy_1, tg_xyyzz_yyyyyyyz_0, tg_xyyzz_yyyyyyyz_1, tg_xyyzz_yyyyyyz_1, \
                                         tg_xyyzz_yyyyyyzz_0, tg_xyyzz_yyyyyyzz_1, tg_xyyzz_yyyyyzz_1, tg_xyyzz_yyyyyzzz_0, \
                                         tg_xyyzz_yyyyyzzz_1, tg_xyyzz_yyyyzzz_1, tg_xyyzz_yyyyzzzz_0, tg_xyyzz_yyyyzzzz_1, \
                                         tg_xyyzz_yyyzzzz_1, tg_xyyzz_yyyzzzzz_0, tg_xyyzz_yyyzzzzz_1, tg_xyyzz_yyzzzzz_1, \
                                         tg_xyyzz_yzzzzzz_1, tg_xyyzz_zzzzzzz_1, tg_yyyy_xzzzzzzz_0, tg_yyyy_xzzzzzzz_1, \
                                         tg_yyyy_yyyyyyyy_0, tg_yyyy_yyyyyyyy_1, tg_yyyy_yyyyyyyz_0, tg_yyyy_yyyyyyyz_1, \
                                         tg_yyyy_yyyyyyzz_0, tg_yyyy_yyyyyyzz_1, tg_yyyy_yyyyyzzz_0, tg_yyyy_yyyyyzzz_1, \
                                         tg_yyyy_yyyyzzzz_0, tg_yyyy_yyyyzzzz_1, tg_yyyy_yyyzzzzz_0, tg_yyyy_yyyzzzzz_1, \
                                         tg_yyyy_yyzzzzzz_0, tg_yyyy_yyzzzzzz_1, tg_yyyy_yzzzzzzz_0, tg_yyyy_yzzzzzzz_1, \
                                         tg_yyyy_zzzzzzzz_0, tg_yyyy_zzzzzzzz_1, tg_yyyz_xxxxxxxx_0, tg_yyyz_xxxxxxxx_1, \
                                         tg_yyyz_xxxxxxxy_0, tg_yyyz_xxxxxxxy_1, tg_yyyz_xxxxxxxz_0, tg_yyyz_xxxxxxxz_1, \
                                         tg_yyyz_xxxxxxyy_0, tg_yyyz_xxxxxxyy_1, tg_yyyz_xxxxxxyz_0, tg_yyyz_xxxxxxyz_1, \
                                         tg_yyyz_xxxxxxzz_0, tg_yyyz_xxxxxxzz_1, tg_yyyz_xxxxxyyy_0, tg_yyyz_xxxxxyyy_1, \
                                         tg_yyyz_xxxxxyyz_0, tg_yyyz_xxxxxyyz_1, tg_yyyz_xxxxxyzz_0, tg_yyyz_xxxxxyzz_1, \
                                         tg_yyyz_xxxxxzzz_0, tg_yyyz_xxxxxzzz_1, tg_yyyz_xxxxyyyy_0, tg_yyyz_xxxxyyyy_1, \
                                         tg_yyyz_xxxxyyyz_0, tg_yyyz_xxxxyyyz_1, tg_yyyz_xxxxyyzz_0, tg_yyyz_xxxxyyzz_1, \
                                         tg_yyyz_xxxxyzzz_0, tg_yyyz_xxxxyzzz_1, tg_yyyz_xxxxzzzz_0, tg_yyyz_xxxxzzzz_1, \
                                         tg_yyyz_xxxyyyyy_0, tg_yyyz_xxxyyyyy_1, tg_yyyz_xxxyyyyz_0, tg_yyyz_xxxyyyyz_1, \
                                         tg_yyyz_xxxyyyzz_0, tg_yyyz_xxxyyyzz_1, tg_yyyz_xxxyyzzz_0, tg_yyyz_xxxyyzzz_1, \
                                         tg_yyyz_xxxyzzzz_0, tg_yyyz_xxxyzzzz_1, tg_yyyz_xxxzzzzz_0, tg_yyyz_xxxzzzzz_1, \
                                         tg_yyyz_xxyyyyyy_0, tg_yyyz_xxyyyyyy_1, tg_yyyz_xxyyyyyz_0, tg_yyyz_xxyyyyyz_1, \
                                         tg_yyyz_xxyyyyzz_0, tg_yyyz_xxyyyyzz_1, tg_yyyz_xxyyyzzz_0, tg_yyyz_xxyyyzzz_1, \
                                         tg_yyyz_xxyyzzzz_0, tg_yyyz_xxyyzzzz_1, tg_yyyz_xxyzzzzz_0, tg_yyyz_xxyzzzzz_1, \
                                         tg_yyyz_xxzzzzzz_0, tg_yyyz_xxzzzzzz_1, tg_yyyz_xyyyyyyy_0, tg_yyyz_xyyyyyyy_1, \
                                         tg_yyyz_xyyyyyyz_0, tg_yyyz_xyyyyyyz_1, tg_yyyz_xyyyyyzz_0, tg_yyyz_xyyyyyzz_1, \
                                         tg_yyyz_xyyyyzzz_0, tg_yyyz_xyyyyzzz_1, tg_yyyz_xyyyzzzz_0, tg_yyyz_xyyyzzzz_1, \
                                         tg_yyyz_xyyzzzzz_0, tg_yyyz_xyyzzzzz_1, tg_yyyz_xyzzzzzz_0, tg_yyyz_xyzzzzzz_1, \
                                         tg_yyyz_xzzzzzzz_0, tg_yyyz_xzzzzzzz_1, tg_yyyz_yyyyyyyy_0, tg_yyyz_yyyyyyyy_1, \
                                         tg_yyyz_yyyyyyyz_0, tg_yyyz_yyyyyyyz_1, tg_yyyz_yyyyyyzz_0, tg_yyyz_yyyyyyzz_1, \
                                         tg_yyyz_yyyyyzzz_0, tg_yyyz_yyyyyzzz_1, tg_yyyz_yyyyzzzz_0, tg_yyyz_yyyyzzzz_1, \
                                         tg_yyyz_yyyzzzzz_0, tg_yyyz_yyyzzzzz_1, tg_yyyz_yyzzzzzz_0, tg_yyyz_yyzzzzzz_1, \
                                         tg_yyyz_yzzzzzzz_0, tg_yyyz_yzzzzzzz_1, tg_yyyz_zzzzzzzz_0, tg_yyyz_zzzzzzzz_1, \
                                         tg_yyzz_xxxxxxxx_0, tg_yyzz_xxxxxxxx_1, tg_yyzz_xxxxxxxy_0, tg_yyzz_xxxxxxxy_1, \
                                         tg_yyzz_xxxxxxxz_0, tg_yyzz_xxxxxxxz_1, tg_yyzz_xxxxxxyy_0, tg_yyzz_xxxxxxyy_1, \
                                         tg_yyzz_xxxxxxyz_0, tg_yyzz_xxxxxxyz_1, tg_yyzz_xxxxxxzz_0, tg_yyzz_xxxxxxzz_1, \
                                         tg_yyzz_xxxxxyyy_0, tg_yyzz_xxxxxyyy_1, tg_yyzz_xxxxxyyz_0, tg_yyzz_xxxxxyyz_1, \
                                         tg_yyzz_xxxxxyzz_0, tg_yyzz_xxxxxyzz_1, tg_yyzz_xxxxxzzz_0, tg_yyzz_xxxxxzzz_1, \
                                         tg_yyzz_xxxxyyyy_0, tg_yyzz_xxxxyyyy_1, tg_yyzz_xxxxyyyz_0, tg_yyzz_xxxxyyyz_1, \
                                         tg_yyzz_xxxxyyzz_0, tg_yyzz_xxxxyyzz_1, tg_yyzz_xxxxyzzz_0, tg_yyzz_xxxxyzzz_1, \
                                         tg_yyzz_xxxxzzzz_0, tg_yyzz_xxxxzzzz_1, tg_yyzz_xxxyyyyy_0, tg_yyzz_xxxyyyyy_1, \
                                         tg_yyzz_xxxyyyyz_0, tg_yyzz_xxxyyyyz_1, tg_yyzz_xxxyyyzz_0, tg_yyzz_xxxyyyzz_1, \
                                         tg_yyzz_xxxyyzzz_0, tg_yyzz_xxxyyzzz_1, tg_yyzz_xxxyzzzz_0, tg_yyzz_xxxyzzzz_1, \
                                         tg_yyzz_xxxzzzzz_0, tg_yyzz_xxxzzzzz_1, tg_yyzz_xxyyyyyy_0, tg_yyzz_xxyyyyyy_1, \
                                         tg_yyzz_xxyyyyyz_0, tg_yyzz_xxyyyyyz_1, tg_yyzz_xxyyyyzz_0, tg_yyzz_xxyyyyzz_1, \
                                         tg_yyzz_xxyyyzzz_0, tg_yyzz_xxyyyzzz_1, tg_yyzz_xxyyzzzz_0, tg_yyzz_xxyyzzzz_1, \
                                         tg_yyzz_xxyzzzzz_0, tg_yyzz_xxyzzzzz_1, tg_yyzz_xxzzzzzz_0, tg_yyzz_xxzzzzzz_1, \
                                         tg_yyzz_xyyyyyyy_0, tg_yyzz_xyyyyyyy_1, tg_yyzz_xyyyyyyz_0, tg_yyzz_xyyyyyyz_1, \
                                         tg_yyzz_xyyyyyzz_0, tg_yyzz_xyyyyyzz_1, tg_yyzz_xyyyyzzz_0, tg_yyzz_xyyyyzzz_1, \
                                         tg_yyzz_xyyyzzzz_0, tg_yyzz_xyyyzzzz_1, tg_yyzz_xyyzzzzz_0, tg_yyzz_xyyzzzzz_1, \
                                         tg_yyzz_xyzzzzzz_0, tg_yyzz_xyzzzzzz_1, tg_yyzz_xzzzzzzz_0, tg_yyzz_xzzzzzzz_1, \
                                         tg_yyzz_yyyyyyyy_0, tg_yyzz_yyyyyyyy_1, tg_yyzz_yyyyyyyz_0, tg_yyzz_yyyyyyyz_1, \
                                         tg_yyzz_yyyyyyzz_0, tg_yyzz_yyyyyyzz_1, tg_yyzz_yyyyyzzz_0, tg_yyzz_yyyyyzzz_1, \
                                         tg_yyzz_yyyyzzzz_0, tg_yyzz_yyyyzzzz_1, tg_yyzz_yyyzzzzz_0, tg_yyzz_yyyzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxyyyy_xzzzzzzz_0[j] = pb_x * tg_xyyyy_xzzzzzzz_0[j] + fr * tg_xyyyy_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_xzzzzzzz_0[j] - tg_yyyy_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyy_zzzzzzz_1[j];

                    tg_xxyyyy_yyyyyyyy_0[j] = pb_x * tg_xyyyy_yyyyyyyy_0[j] + fr * tg_xyyyy_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyyyyyy_0[j] - tg_yyyy_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxyyyy_yyyyyyyz_0[j] = pb_x * tg_xyyyy_yyyyyyyz_0[j] + fr * tg_xyyyy_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyyyyyz_0[j] - tg_yyyy_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxyyyy_yyyyyyzz_0[j] = pb_x * tg_xyyyy_yyyyyyzz_0[j] + fr * tg_xyyyy_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyyyyzz_0[j] - tg_yyyy_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxyyyy_yyyyyzzz_0[j] = pb_x * tg_xyyyy_yyyyyzzz_0[j] + fr * tg_xyyyy_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyyyzzz_0[j] - tg_yyyy_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxyyyy_yyyyzzzz_0[j] = pb_x * tg_xyyyy_yyyyzzzz_0[j] + fr * tg_xyyyy_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyyzzzz_0[j] - tg_yyyy_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxyyyy_yyyzzzzz_0[j] = pb_x * tg_xyyyy_yyyzzzzz_0[j] + fr * tg_xyyyy_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyyzzzzz_0[j] - tg_yyyy_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxyyyy_yyzzzzzz_0[j] = pb_x * tg_xyyyy_yyzzzzzz_0[j] + fr * tg_xyyyy_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yyzzzzzz_0[j] - tg_yyyy_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyy_yzzzzzzz_0[j] = pb_x * tg_xyyyy_yzzzzzzz_0[j] + fr * tg_xyyyy_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_yzzzzzzz_0[j] - tg_yyyy_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyy_zzzzzzzz_0[j] = pb_x * tg_xyyyy_zzzzzzzz_0[j] + fr * tg_xyyyy_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyy_zzzzzzzz_0[j] - tg_yyyy_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyz_xxxxxxxx_0[j] = pb_x * tg_xyyyz_xxxxxxxx_0[j] + fr * tg_xyyyz_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxxx_0[j] - tg_yyyz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xyyyz_xxxxxxx_1[j];

                    tg_xxyyyz_xxxxxxxy_0[j] = pb_x * tg_xyyyz_xxxxxxxy_0[j] + fr * tg_xyyyz_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxxy_0[j] - tg_yyyz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyz_xxxxxxy_1[j];

                    tg_xxyyyz_xxxxxxxz_0[j] = pb_x * tg_xyyyz_xxxxxxxz_0[j] + fr * tg_xyyyz_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxxz_0[j] - tg_yyyz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyz_xxxxxxz_1[j];

                    tg_xxyyyz_xxxxxxyy_0[j] = pb_x * tg_xyyyz_xxxxxxyy_0[j] + fr * tg_xyyyz_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxyy_0[j] - tg_yyyz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyz_xxxxxyy_1[j];

                    tg_xxyyyz_xxxxxxyz_0[j] = pb_x * tg_xyyyz_xxxxxxyz_0[j] + fr * tg_xyyyz_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxyz_0[j] - tg_yyyz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyz_xxxxxyz_1[j];

                    tg_xxyyyz_xxxxxxzz_0[j] = pb_x * tg_xyyyz_xxxxxxzz_0[j] + fr * tg_xyyyz_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxxzz_0[j] - tg_yyyz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyz_xxxxxzz_1[j];

                    tg_xxyyyz_xxxxxyyy_0[j] = pb_x * tg_xyyyz_xxxxxyyy_0[j] + fr * tg_xyyyz_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxyyy_0[j] - tg_yyyz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyz_xxxxyyy_1[j];

                    tg_xxyyyz_xxxxxyyz_0[j] = pb_x * tg_xyyyz_xxxxxyyz_0[j] + fr * tg_xyyyz_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxyyz_0[j] - tg_yyyz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyz_xxxxyyz_1[j];

                    tg_xxyyyz_xxxxxyzz_0[j] = pb_x * tg_xyyyz_xxxxxyzz_0[j] + fr * tg_xyyyz_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxyzz_0[j] - tg_yyyz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyz_xxxxyzz_1[j];

                    tg_xxyyyz_xxxxxzzz_0[j] = pb_x * tg_xyyyz_xxxxxzzz_0[j] + fr * tg_xyyyz_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxxzzz_0[j] - tg_yyyz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyz_xxxxzzz_1[j];

                    tg_xxyyyz_xxxxyyyy_0[j] = pb_x * tg_xyyyz_xxxxyyyy_0[j] + fr * tg_xyyyz_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxyyyy_0[j] - tg_yyyz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyz_xxxyyyy_1[j];

                    tg_xxyyyz_xxxxyyyz_0[j] = pb_x * tg_xyyyz_xxxxyyyz_0[j] + fr * tg_xyyyz_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxyyyz_0[j] - tg_yyyz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyz_xxxyyyz_1[j];

                    tg_xxyyyz_xxxxyyzz_0[j] = pb_x * tg_xyyyz_xxxxyyzz_0[j] + fr * tg_xyyyz_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxyyzz_0[j] - tg_yyyz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyz_xxxyyzz_1[j];

                    tg_xxyyyz_xxxxyzzz_0[j] = pb_x * tg_xyyyz_xxxxyzzz_0[j] + fr * tg_xyyyz_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxyzzz_0[j] - tg_yyyz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyz_xxxyzzz_1[j];

                    tg_xxyyyz_xxxxzzzz_0[j] = pb_x * tg_xyyyz_xxxxzzzz_0[j] + fr * tg_xyyyz_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxxzzzz_0[j] - tg_yyyz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyz_xxxzzzz_1[j];

                    tg_xxyyyz_xxxyyyyy_0[j] = pb_x * tg_xyyyz_xxxyyyyy_0[j] + fr * tg_xyyyz_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxyyyyy_0[j] - tg_yyyz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxyyyyy_1[j];

                    tg_xxyyyz_xxxyyyyz_0[j] = pb_x * tg_xyyyz_xxxyyyyz_0[j] + fr * tg_xyyyz_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxyyyyz_0[j] - tg_yyyz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxyyyyz_1[j];

                    tg_xxyyyz_xxxyyyzz_0[j] = pb_x * tg_xyyyz_xxxyyyzz_0[j] + fr * tg_xyyyz_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxyyyzz_0[j] - tg_yyyz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxyyyzz_1[j];

                    tg_xxyyyz_xxxyyzzz_0[j] = pb_x * tg_xyyyz_xxxyyzzz_0[j] + fr * tg_xyyyz_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxyyzzz_0[j] - tg_yyyz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxyyzzz_1[j];

                    tg_xxyyyz_xxxyzzzz_0[j] = pb_x * tg_xyyyz_xxxyzzzz_0[j] + fr * tg_xyyyz_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxyzzzz_0[j] - tg_yyyz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxyzzzz_1[j];

                    tg_xxyyyz_xxxzzzzz_0[j] = pb_x * tg_xyyyz_xxxzzzzz_0[j] + fr * tg_xyyyz_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxxzzzzz_0[j] - tg_yyyz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyz_xxzzzzz_1[j];

                    tg_xxyyyz_xxyyyyyy_0[j] = pb_x * tg_xyyyz_xxyyyyyy_0[j] + fr * tg_xyyyz_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyyyyyy_0[j] - tg_yyyz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyyyyyy_1[j];

                    tg_xxyyyz_xxyyyyyz_0[j] = pb_x * tg_xyyyz_xxyyyyyz_0[j] + fr * tg_xyyyz_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyyyyyz_0[j] - tg_yyyz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyyyyyz_1[j];

                    tg_xxyyyz_xxyyyyzz_0[j] = pb_x * tg_xyyyz_xxyyyyzz_0[j] + fr * tg_xyyyz_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyyyyzz_0[j] - tg_yyyz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyyyyzz_1[j];

                    tg_xxyyyz_xxyyyzzz_0[j] = pb_x * tg_xyyyz_xxyyyzzz_0[j] + fr * tg_xyyyz_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyyyzzz_0[j] - tg_yyyz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyyyzzz_1[j];

                    tg_xxyyyz_xxyyzzzz_0[j] = pb_x * tg_xyyyz_xxyyzzzz_0[j] + fr * tg_xyyyz_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyyzzzz_0[j] - tg_yyyz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyyzzzz_1[j];

                    tg_xxyyyz_xxyzzzzz_0[j] = pb_x * tg_xyyyz_xxyzzzzz_0[j] + fr * tg_xyyyz_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxyzzzzz_0[j] - tg_yyyz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xyzzzzz_1[j];

                    tg_xxyyyz_xxzzzzzz_0[j] = pb_x * tg_xyyyz_xxzzzzzz_0[j] + fr * tg_xyyyz_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xxzzzzzz_0[j] - tg_yyyz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyz_xzzzzzz_1[j];

                    tg_xxyyyz_xyyyyyyy_0[j] = pb_x * tg_xyyyz_xyyyyyyy_0[j] + fr * tg_xyyyz_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyyyyyy_0[j] - tg_yyyz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyyyyyy_1[j];

                    tg_xxyyyz_xyyyyyyz_0[j] = pb_x * tg_xyyyz_xyyyyyyz_0[j] + fr * tg_xyyyz_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyyyyyz_0[j] - tg_yyyz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyyyyyz_1[j];

                    tg_xxyyyz_xyyyyyzz_0[j] = pb_x * tg_xyyyz_xyyyyyzz_0[j] + fr * tg_xyyyz_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyyyyzz_0[j] - tg_yyyz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyyyyzz_1[j];

                    tg_xxyyyz_xyyyyzzz_0[j] = pb_x * tg_xyyyz_xyyyyzzz_0[j] + fr * tg_xyyyz_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyyyzzz_0[j] - tg_yyyz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyyyzzz_1[j];

                    tg_xxyyyz_xyyyzzzz_0[j] = pb_x * tg_xyyyz_xyyyzzzz_0[j] + fr * tg_xyyyz_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyyzzzz_0[j] - tg_yyyz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyyzzzz_1[j];

                    tg_xxyyyz_xyyzzzzz_0[j] = pb_x * tg_xyyyz_xyyzzzzz_0[j] + fr * tg_xyyyz_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyyzzzzz_0[j] - tg_yyyz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yyzzzzz_1[j];

                    tg_xxyyyz_xyzzzzzz_0[j] = pb_x * tg_xyyyz_xyzzzzzz_0[j] + fr * tg_xyyyz_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xyzzzzzz_0[j] - tg_yyyz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_yzzzzzz_1[j];

                    tg_xxyyyz_xzzzzzzz_0[j] = pb_x * tg_xyyyz_xzzzzzzz_0[j] + fr * tg_xyyyz_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_xzzzzzzz_0[j] - tg_yyyz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyz_zzzzzzz_1[j];

                    tg_xxyyyz_yyyyyyyy_0[j] = pb_x * tg_xyyyz_yyyyyyyy_0[j] + fr * tg_xyyyz_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyyyyyy_0[j] - tg_yyyz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxyyyz_yyyyyyyz_0[j] = pb_x * tg_xyyyz_yyyyyyyz_0[j] + fr * tg_xyyyz_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyyyyyz_0[j] - tg_yyyz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxyyyz_yyyyyyzz_0[j] = pb_x * tg_xyyyz_yyyyyyzz_0[j] + fr * tg_xyyyz_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyyyyzz_0[j] - tg_yyyz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxyyyz_yyyyyzzz_0[j] = pb_x * tg_xyyyz_yyyyyzzz_0[j] + fr * tg_xyyyz_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyyyzzz_0[j] - tg_yyyz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxyyyz_yyyyzzzz_0[j] = pb_x * tg_xyyyz_yyyyzzzz_0[j] + fr * tg_xyyyz_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyyzzzz_0[j] - tg_yyyz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxyyyz_yyyzzzzz_0[j] = pb_x * tg_xyyyz_yyyzzzzz_0[j] + fr * tg_xyyyz_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyyzzzzz_0[j] - tg_yyyz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxyyyz_yyzzzzzz_0[j] = pb_x * tg_xyyyz_yyzzzzzz_0[j] + fr * tg_xyyyz_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yyzzzzzz_0[j] - tg_yyyz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyz_yzzzzzzz_0[j] = pb_x * tg_xyyyz_yzzzzzzz_0[j] + fr * tg_xyyyz_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_yzzzzzzz_0[j] - tg_yyyz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyz_zzzzzzzz_0[j] = pb_x * tg_xyyyz_zzzzzzzz_0[j] + fr * tg_xyyyz_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyz_zzzzzzzz_0[j] - tg_yyyz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyzz_xxxxxxxx_0[j] = pb_x * tg_xyyzz_xxxxxxxx_0[j] + fr * tg_xyyzz_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxxx_0[j] - tg_yyzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xyyzz_xxxxxxx_1[j];

                    tg_xxyyzz_xxxxxxxy_0[j] = pb_x * tg_xyyzz_xxxxxxxy_0[j] + fr * tg_xyyzz_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxxy_0[j] - tg_yyzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyzz_xxxxxxy_1[j];

                    tg_xxyyzz_xxxxxxxz_0[j] = pb_x * tg_xyyzz_xxxxxxxz_0[j] + fr * tg_xyyzz_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxxz_0[j] - tg_yyzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyzz_xxxxxxz_1[j];

                    tg_xxyyzz_xxxxxxyy_0[j] = pb_x * tg_xyyzz_xxxxxxyy_0[j] + fr * tg_xyyzz_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxyy_0[j] - tg_yyzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzz_xxxxxyy_1[j];

                    tg_xxyyzz_xxxxxxyz_0[j] = pb_x * tg_xyyzz_xxxxxxyz_0[j] + fr * tg_xyyzz_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxyz_0[j] - tg_yyzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzz_xxxxxyz_1[j];

                    tg_xxyyzz_xxxxxxzz_0[j] = pb_x * tg_xyyzz_xxxxxxzz_0[j] + fr * tg_xyyzz_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxxzz_0[j] - tg_yyzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzz_xxxxxzz_1[j];

                    tg_xxyyzz_xxxxxyyy_0[j] = pb_x * tg_xyyzz_xxxxxyyy_0[j] + fr * tg_xyyzz_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxyyy_0[j] - tg_yyzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzz_xxxxyyy_1[j];

                    tg_xxyyzz_xxxxxyyz_0[j] = pb_x * tg_xyyzz_xxxxxyyz_0[j] + fr * tg_xyyzz_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxyyz_0[j] - tg_yyzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzz_xxxxyyz_1[j];

                    tg_xxyyzz_xxxxxyzz_0[j] = pb_x * tg_xyyzz_xxxxxyzz_0[j] + fr * tg_xyyzz_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxyzz_0[j] - tg_yyzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzz_xxxxyzz_1[j];

                    tg_xxyyzz_xxxxxzzz_0[j] = pb_x * tg_xyyzz_xxxxxzzz_0[j] + fr * tg_xyyzz_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxxzzz_0[j] - tg_yyzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzz_xxxxzzz_1[j];

                    tg_xxyyzz_xxxxyyyy_0[j] = pb_x * tg_xyyzz_xxxxyyyy_0[j] + fr * tg_xyyzz_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxyyyy_0[j] - tg_yyzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzz_xxxyyyy_1[j];

                    tg_xxyyzz_xxxxyyyz_0[j] = pb_x * tg_xyyzz_xxxxyyyz_0[j] + fr * tg_xyyzz_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxyyyz_0[j] - tg_yyzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzz_xxxyyyz_1[j];

                    tg_xxyyzz_xxxxyyzz_0[j] = pb_x * tg_xyyzz_xxxxyyzz_0[j] + fr * tg_xyyzz_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxyyzz_0[j] - tg_yyzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzz_xxxyyzz_1[j];

                    tg_xxyyzz_xxxxyzzz_0[j] = pb_x * tg_xyyzz_xxxxyzzz_0[j] + fr * tg_xyyzz_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxyzzz_0[j] - tg_yyzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzz_xxxyzzz_1[j];

                    tg_xxyyzz_xxxxzzzz_0[j] = pb_x * tg_xyyzz_xxxxzzzz_0[j] + fr * tg_xyyzz_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxxzzzz_0[j] - tg_yyzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzz_xxxzzzz_1[j];

                    tg_xxyyzz_xxxyyyyy_0[j] = pb_x * tg_xyyzz_xxxyyyyy_0[j] + fr * tg_xyyzz_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxyyyyy_0[j] - tg_yyzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxyyyyy_1[j];

                    tg_xxyyzz_xxxyyyyz_0[j] = pb_x * tg_xyyzz_xxxyyyyz_0[j] + fr * tg_xyyzz_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxyyyyz_0[j] - tg_yyzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxyyyyz_1[j];

                    tg_xxyyzz_xxxyyyzz_0[j] = pb_x * tg_xyyzz_xxxyyyzz_0[j] + fr * tg_xyyzz_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxyyyzz_0[j] - tg_yyzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxyyyzz_1[j];

                    tg_xxyyzz_xxxyyzzz_0[j] = pb_x * tg_xyyzz_xxxyyzzz_0[j] + fr * tg_xyyzz_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxyyzzz_0[j] - tg_yyzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxyyzzz_1[j];

                    tg_xxyyzz_xxxyzzzz_0[j] = pb_x * tg_xyyzz_xxxyzzzz_0[j] + fr * tg_xyyzz_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxyzzzz_0[j] - tg_yyzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxyzzzz_1[j];

                    tg_xxyyzz_xxxzzzzz_0[j] = pb_x * tg_xyyzz_xxxzzzzz_0[j] + fr * tg_xyyzz_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxxzzzzz_0[j] - tg_yyzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzz_xxzzzzz_1[j];

                    tg_xxyyzz_xxyyyyyy_0[j] = pb_x * tg_xyyzz_xxyyyyyy_0[j] + fr * tg_xyyzz_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyyyyyy_0[j] - tg_yyzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyyyyyy_1[j];

                    tg_xxyyzz_xxyyyyyz_0[j] = pb_x * tg_xyyzz_xxyyyyyz_0[j] + fr * tg_xyyzz_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyyyyyz_0[j] - tg_yyzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyyyyyz_1[j];

                    tg_xxyyzz_xxyyyyzz_0[j] = pb_x * tg_xyyzz_xxyyyyzz_0[j] + fr * tg_xyyzz_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyyyyzz_0[j] - tg_yyzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyyyyzz_1[j];

                    tg_xxyyzz_xxyyyzzz_0[j] = pb_x * tg_xyyzz_xxyyyzzz_0[j] + fr * tg_xyyzz_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyyyzzz_0[j] - tg_yyzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyyyzzz_1[j];

                    tg_xxyyzz_xxyyzzzz_0[j] = pb_x * tg_xyyzz_xxyyzzzz_0[j] + fr * tg_xyyzz_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyyzzzz_0[j] - tg_yyzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyyzzzz_1[j];

                    tg_xxyyzz_xxyzzzzz_0[j] = pb_x * tg_xyyzz_xxyzzzzz_0[j] + fr * tg_xyyzz_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxyzzzzz_0[j] - tg_yyzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xyzzzzz_1[j];

                    tg_xxyyzz_xxzzzzzz_0[j] = pb_x * tg_xyyzz_xxzzzzzz_0[j] + fr * tg_xyyzz_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xxzzzzzz_0[j] - tg_yyzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzz_xzzzzzz_1[j];

                    tg_xxyyzz_xyyyyyyy_0[j] = pb_x * tg_xyyzz_xyyyyyyy_0[j] + fr * tg_xyyzz_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyyyyyy_0[j] - tg_yyzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyyyyyy_1[j];

                    tg_xxyyzz_xyyyyyyz_0[j] = pb_x * tg_xyyzz_xyyyyyyz_0[j] + fr * tg_xyyzz_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyyyyyz_0[j] - tg_yyzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyyyyyz_1[j];

                    tg_xxyyzz_xyyyyyzz_0[j] = pb_x * tg_xyyzz_xyyyyyzz_0[j] + fr * tg_xyyzz_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyyyyzz_0[j] - tg_yyzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyyyyzz_1[j];

                    tg_xxyyzz_xyyyyzzz_0[j] = pb_x * tg_xyyzz_xyyyyzzz_0[j] + fr * tg_xyyzz_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyyyzzz_0[j] - tg_yyzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyyyzzz_1[j];

                    tg_xxyyzz_xyyyzzzz_0[j] = pb_x * tg_xyyzz_xyyyzzzz_0[j] + fr * tg_xyyzz_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyyzzzz_0[j] - tg_yyzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyyzzzz_1[j];

                    tg_xxyyzz_xyyzzzzz_0[j] = pb_x * tg_xyyzz_xyyzzzzz_0[j] + fr * tg_xyyzz_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyyzzzzz_0[j] - tg_yyzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yyzzzzz_1[j];

                    tg_xxyyzz_xyzzzzzz_0[j] = pb_x * tg_xyyzz_xyzzzzzz_0[j] + fr * tg_xyyzz_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xyzzzzzz_0[j] - tg_yyzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_yzzzzzz_1[j];

                    tg_xxyyzz_xzzzzzzz_0[j] = pb_x * tg_xyyzz_xzzzzzzz_0[j] + fr * tg_xyyzz_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_xzzzzzzz_0[j] - tg_yyzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzz_zzzzzzz_1[j];

                    tg_xxyyzz_yyyyyyyy_0[j] = pb_x * tg_xyyzz_yyyyyyyy_0[j] + fr * tg_xyyzz_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyyyyyy_0[j] - tg_yyzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxyyzz_yyyyyyyz_0[j] = pb_x * tg_xyyzz_yyyyyyyz_0[j] + fr * tg_xyyzz_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyyyyyz_0[j] - tg_yyzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxyyzz_yyyyyyzz_0[j] = pb_x * tg_xyyzz_yyyyyyzz_0[j] + fr * tg_xyyzz_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyyyyzz_0[j] - tg_yyzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxyyzz_yyyyyzzz_0[j] = pb_x * tg_xyyzz_yyyyyzzz_0[j] + fr * tg_xyyzz_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyyyzzz_0[j] - tg_yyzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxyyzz_yyyyzzzz_0[j] = pb_x * tg_xyyzz_yyyyzzzz_0[j] + fr * tg_xyyzz_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyyzzzz_0[j] - tg_yyzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxyyzz_yyyzzzzz_0[j] = pb_x * tg_xyyzz_yyyzzzzz_0[j] + fr * tg_xyyzz_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyyzzzzz_0[j] - tg_yyzz_yyyzzzzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_582_679(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (582,679)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xyyzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 582); 

                auto tg_xyyzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 583); 

                auto tg_xyyzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 584); 

                auto tg_xyzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 585); 

                auto tg_xyzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 586); 

                auto tg_xyzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 587); 

                auto tg_xyzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 588); 

                auto tg_xyzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 589); 

                auto tg_xyzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 590); 

                auto tg_xyzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 591); 

                auto tg_xyzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 592); 

                auto tg_xyzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 593); 

                auto tg_xyzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 594); 

                auto tg_xyzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 595); 

                auto tg_xyzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 596); 

                auto tg_xyzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 597); 

                auto tg_xyzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 598); 

                auto tg_xyzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 599); 

                auto tg_xyzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 600); 

                auto tg_xyzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 601); 

                auto tg_xyzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 602); 

                auto tg_xyzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 603); 

                auto tg_xyzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 604); 

                auto tg_xyzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 605); 

                auto tg_xyzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 606); 

                auto tg_xyzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 607); 

                auto tg_xyzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 608); 

                auto tg_xyzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 609); 

                auto tg_xyzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 610); 

                auto tg_xyzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 611); 

                auto tg_xyzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 612); 

                auto tg_xyzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 613); 

                auto tg_xyzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 614); 

                auto tg_xyzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 615); 

                auto tg_xyzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 616); 

                auto tg_xyzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 617); 

                auto tg_xyzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 618); 

                auto tg_xyzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 619); 

                auto tg_xyzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 620); 

                auto tg_xyzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 621); 

                auto tg_xyzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 622); 

                auto tg_xyzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 623); 

                auto tg_xyzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 624); 

                auto tg_xyzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 625); 

                auto tg_xyzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 626); 

                auto tg_xyzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 627); 

                auto tg_xyzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 628); 

                auto tg_xyzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 629); 

                auto tg_xzzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 630); 

                auto tg_xzzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 631); 

                auto tg_xzzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 632); 

                auto tg_xzzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 633); 

                auto tg_xzzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 634); 

                auto tg_xzzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 635); 

                auto tg_xzzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 636); 

                auto tg_xzzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 637); 

                auto tg_xzzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 638); 

                auto tg_xzzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 639); 

                auto tg_xzzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 640); 

                auto tg_xzzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 641); 

                auto tg_xzzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 642); 

                auto tg_xzzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 643); 

                auto tg_xzzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 644); 

                auto tg_xzzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 645); 

                auto tg_xzzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 646); 

                auto tg_xzzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 647); 

                auto tg_xzzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 648); 

                auto tg_xzzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 649); 

                auto tg_xzzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 650); 

                auto tg_xzzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 651); 

                auto tg_xzzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 652); 

                auto tg_xzzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 653); 

                auto tg_xzzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 654); 

                auto tg_xzzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 655); 

                auto tg_xzzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 656); 

                auto tg_xzzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 657); 

                auto tg_xzzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 658); 

                auto tg_xzzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 659); 

                auto tg_xzzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 660); 

                auto tg_xzzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 661); 

                auto tg_xzzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 662); 

                auto tg_xzzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 663); 

                auto tg_xzzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 664); 

                auto tg_xzzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 665); 

                auto tg_xzzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 666); 

                auto tg_xzzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 667); 

                auto tg_xzzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 668); 

                auto tg_xzzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 669); 

                auto tg_xzzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 670); 

                auto tg_xzzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 671); 

                auto tg_xzzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 672); 

                auto tg_xzzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 673); 

                auto tg_xzzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 674); 

                auto tg_yyyyy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 675); 

                auto tg_yyyyy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 676); 

                auto tg_yyyyy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 677); 

                auto tg_yyyyy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 678); 

                auto tg_xyyzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 582); 

                auto tg_xyyzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 583); 

                auto tg_xyyzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 584); 

                auto tg_xyzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 585); 

                auto tg_xyzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 586); 

                auto tg_xyzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 587); 

                auto tg_xyzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 588); 

                auto tg_xyzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 589); 

                auto tg_xyzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 590); 

                auto tg_xyzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 591); 

                auto tg_xyzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 592); 

                auto tg_xyzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 593); 

                auto tg_xyzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 594); 

                auto tg_xyzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 595); 

                auto tg_xyzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 596); 

                auto tg_xyzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 597); 

                auto tg_xyzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 598); 

                auto tg_xyzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 599); 

                auto tg_xyzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 600); 

                auto tg_xyzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 601); 

                auto tg_xyzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 602); 

                auto tg_xyzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 603); 

                auto tg_xyzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 604); 

                auto tg_xyzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 605); 

                auto tg_xyzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 606); 

                auto tg_xyzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 607); 

                auto tg_xyzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 608); 

                auto tg_xyzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 609); 

                auto tg_xyzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 610); 

                auto tg_xyzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 611); 

                auto tg_xyzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 612); 

                auto tg_xyzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 613); 

                auto tg_xyzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 614); 

                auto tg_xyzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 615); 

                auto tg_xyzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 616); 

                auto tg_xyzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 617); 

                auto tg_xyzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 618); 

                auto tg_xyzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 619); 

                auto tg_xyzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 620); 

                auto tg_xyzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 621); 

                auto tg_xyzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 622); 

                auto tg_xyzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 623); 

                auto tg_xyzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 624); 

                auto tg_xyzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 625); 

                auto tg_xyzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 626); 

                auto tg_xyzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 627); 

                auto tg_xyzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 628); 

                auto tg_xyzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 629); 

                auto tg_xzzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 630); 

                auto tg_xzzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 631); 

                auto tg_xzzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 632); 

                auto tg_xzzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 633); 

                auto tg_xzzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 634); 

                auto tg_xzzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 635); 

                auto tg_xzzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 636); 

                auto tg_xzzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 637); 

                auto tg_xzzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 638); 

                auto tg_xzzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 639); 

                auto tg_xzzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 640); 

                auto tg_xzzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 641); 

                auto tg_xzzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 642); 

                auto tg_xzzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 643); 

                auto tg_xzzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 644); 

                auto tg_xzzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 645); 

                auto tg_xzzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 646); 

                auto tg_xzzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 647); 

                auto tg_xzzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 648); 

                auto tg_xzzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 649); 

                auto tg_xzzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 650); 

                auto tg_xzzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 651); 

                auto tg_xzzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 652); 

                auto tg_xzzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 653); 

                auto tg_xzzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 654); 

                auto tg_xzzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 655); 

                auto tg_xzzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 656); 

                auto tg_xzzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 657); 

                auto tg_xzzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 658); 

                auto tg_xzzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 659); 

                auto tg_xzzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 660); 

                auto tg_xzzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 661); 

                auto tg_xzzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 662); 

                auto tg_xzzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 663); 

                auto tg_xzzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 664); 

                auto tg_xzzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 665); 

                auto tg_xzzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 666); 

                auto tg_xzzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 667); 

                auto tg_xzzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 668); 

                auto tg_xzzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 669); 

                auto tg_xzzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 670); 

                auto tg_xzzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 671); 

                auto tg_xzzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 672); 

                auto tg_xzzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 673); 

                auto tg_xzzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 674); 

                auto tg_yyyyy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 675); 

                auto tg_yyyyy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 676); 

                auto tg_yyyyy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 677); 

                auto tg_yyyyy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 678); 

                auto tg_yyzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 582); 

                auto tg_yyzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 583); 

                auto tg_yyzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 584); 

                auto tg_yzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 585); 

                auto tg_yzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 586); 

                auto tg_yzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 587); 

                auto tg_yzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 588); 

                auto tg_yzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 589); 

                auto tg_yzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 590); 

                auto tg_yzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 591); 

                auto tg_yzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 592); 

                auto tg_yzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 593); 

                auto tg_yzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 594); 

                auto tg_yzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 595); 

                auto tg_yzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 596); 

                auto tg_yzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 597); 

                auto tg_yzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 598); 

                auto tg_yzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 599); 

                auto tg_yzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 600); 

                auto tg_yzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 601); 

                auto tg_yzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 602); 

                auto tg_yzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 603); 

                auto tg_yzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 604); 

                auto tg_yzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 605); 

                auto tg_yzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 606); 

                auto tg_yzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 607); 

                auto tg_yzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 608); 

                auto tg_yzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 609); 

                auto tg_yzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 610); 

                auto tg_yzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 611); 

                auto tg_yzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 612); 

                auto tg_yzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 613); 

                auto tg_yzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 614); 

                auto tg_yzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 615); 

                auto tg_yzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 616); 

                auto tg_yzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 617); 

                auto tg_yzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 618); 

                auto tg_yzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 619); 

                auto tg_yzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 620); 

                auto tg_yzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 621); 

                auto tg_yzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 622); 

                auto tg_yzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 623); 

                auto tg_yzzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 624); 

                auto tg_yzzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 625); 

                auto tg_yzzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 626); 

                auto tg_yzzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 627); 

                auto tg_yzzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 628); 

                auto tg_yzzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 629); 

                auto tg_zzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 668); 

                auto tg_zzzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 669); 

                auto tg_zzzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 670); 

                auto tg_zzzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 671); 

                auto tg_zzzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 672); 

                auto tg_zzzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 673); 

                auto tg_zzzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 674); 

                auto tg_yyzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 582); 

                auto tg_yyzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 583); 

                auto tg_yyzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 584); 

                auto tg_yzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 585); 

                auto tg_yzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 586); 

                auto tg_yzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 587); 

                auto tg_yzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 588); 

                auto tg_yzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 589); 

                auto tg_yzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 590); 

                auto tg_yzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 591); 

                auto tg_yzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 592); 

                auto tg_yzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 593); 

                auto tg_yzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 594); 

                auto tg_yzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 595); 

                auto tg_yzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 596); 

                auto tg_yzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 597); 

                auto tg_yzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 598); 

                auto tg_yzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 599); 

                auto tg_yzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 600); 

                auto tg_yzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 601); 

                auto tg_yzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 602); 

                auto tg_yzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 603); 

                auto tg_yzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 604); 

                auto tg_yzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 605); 

                auto tg_yzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 606); 

                auto tg_yzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 607); 

                auto tg_yzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 608); 

                auto tg_yzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 609); 

                auto tg_yzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 610); 

                auto tg_yzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 611); 

                auto tg_yzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 612); 

                auto tg_yzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 613); 

                auto tg_yzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 614); 

                auto tg_yzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 615); 

                auto tg_yzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 616); 

                auto tg_yzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 617); 

                auto tg_yzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 618); 

                auto tg_yzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 619); 

                auto tg_yzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 620); 

                auto tg_yzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 621); 

                auto tg_yzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 622); 

                auto tg_yzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 623); 

                auto tg_yzzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 624); 

                auto tg_yzzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 625); 

                auto tg_yzzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 626); 

                auto tg_yzzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 627); 

                auto tg_yzzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 628); 

                auto tg_yzzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 629); 

                auto tg_zzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 668); 

                auto tg_zzzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 669); 

                auto tg_zzzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 670); 

                auto tg_zzzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 671); 

                auto tg_zzzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 672); 

                auto tg_zzzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 673); 

                auto tg_zzzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 674); 

                auto tg_xyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 468); 

                auto tg_xyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 469); 

                auto tg_xyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 470); 

                auto tg_xyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 471); 

                auto tg_xyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 472); 

                auto tg_xyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 473); 

                auto tg_xyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 474); 

                auto tg_xyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 475); 

                auto tg_xyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 476); 

                auto tg_xyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 477); 

                auto tg_xyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 478); 

                auto tg_xyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 479); 

                auto tg_xyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 480); 

                auto tg_xyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 481); 

                auto tg_xyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 482); 

                auto tg_xyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 483); 

                auto tg_xyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 484); 

                auto tg_xyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 485); 

                auto tg_xyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 486); 

                auto tg_xyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 487); 

                auto tg_xyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 488); 

                auto tg_xyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 489); 

                auto tg_xyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 490); 

                auto tg_xyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 491); 

                auto tg_xyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 492); 

                auto tg_xyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 493); 

                auto tg_xyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 494); 

                auto tg_xyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 495); 

                auto tg_xyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 496); 

                auto tg_xyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 497); 

                auto tg_xyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 498); 

                auto tg_xyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 499); 

                auto tg_xyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 500); 

                auto tg_xyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 501); 

                auto tg_xyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 502); 

                auto tg_xyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 503); 

                auto tg_xzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 504); 

                auto tg_xzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 505); 

                auto tg_xzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 506); 

                auto tg_xzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 507); 

                auto tg_xzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 508); 

                auto tg_xzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 509); 

                auto tg_xzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 510); 

                auto tg_xzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 511); 

                auto tg_xzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 512); 

                auto tg_xzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 513); 

                auto tg_xzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 514); 

                auto tg_xzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 515); 

                auto tg_xzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 516); 

                auto tg_xzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 517); 

                auto tg_xzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 518); 

                auto tg_xzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 519); 

                auto tg_xzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 520); 

                auto tg_xzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 521); 

                auto tg_xzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 522); 

                auto tg_xzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 523); 

                auto tg_xzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 524); 

                auto tg_xzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 525); 

                auto tg_xzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 526); 

                auto tg_xzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 527); 

                auto tg_xzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 528); 

                auto tg_xzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 529); 

                auto tg_xzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 530); 

                auto tg_xzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 531); 

                auto tg_xzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 532); 

                auto tg_xzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 533); 

                auto tg_xzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 534); 

                auto tg_xzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 535); 

                auto tg_xzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 536); 

                auto tg_xzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 537); 

                auto tg_xzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 538); 

                auto tg_xzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 539); 

                auto tg_yyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 543); 

                // set up pointers to integrals

                auto tg_xxyyzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 582); 

                auto tg_xxyyzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 583); 

                auto tg_xxyyzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 584); 

                auto tg_xxyzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 585); 

                auto tg_xxyzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 586); 

                auto tg_xxyzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 587); 

                auto tg_xxyzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 588); 

                auto tg_xxyzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 589); 

                auto tg_xxyzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 590); 

                auto tg_xxyzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 591); 

                auto tg_xxyzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 592); 

                auto tg_xxyzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 593); 

                auto tg_xxyzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 594); 

                auto tg_xxyzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 595); 

                auto tg_xxyzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 596); 

                auto tg_xxyzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 597); 

                auto tg_xxyzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 598); 

                auto tg_xxyzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 599); 

                auto tg_xxyzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 600); 

                auto tg_xxyzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 601); 

                auto tg_xxyzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 602); 

                auto tg_xxyzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 603); 

                auto tg_xxyzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 604); 

                auto tg_xxyzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 605); 

                auto tg_xxyzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 606); 

                auto tg_xxyzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 607); 

                auto tg_xxyzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 608); 

                auto tg_xxyzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 609); 

                auto tg_xxyzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 610); 

                auto tg_xxyzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 611); 

                auto tg_xxyzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 612); 

                auto tg_xxyzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 613); 

                auto tg_xxyzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 614); 

                auto tg_xxyzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 615); 

                auto tg_xxyzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 616); 

                auto tg_xxyzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 617); 

                auto tg_xxyzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 618); 

                auto tg_xxyzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 619); 

                auto tg_xxyzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 620); 

                auto tg_xxyzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 621); 

                auto tg_xxyzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 622); 

                auto tg_xxyzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 623); 

                auto tg_xxyzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 624); 

                auto tg_xxyzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 625); 

                auto tg_xxyzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 626); 

                auto tg_xxyzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 627); 

                auto tg_xxyzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 628); 

                auto tg_xxyzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 629); 

                auto tg_xxzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 630); 

                auto tg_xxzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 631); 

                auto tg_xxzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 632); 

                auto tg_xxzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 633); 

                auto tg_xxzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 634); 

                auto tg_xxzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 635); 

                auto tg_xxzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 636); 

                auto tg_xxzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 637); 

                auto tg_xxzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 638); 

                auto tg_xxzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 639); 

                auto tg_xxzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 640); 

                auto tg_xxzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 641); 

                auto tg_xxzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 642); 

                auto tg_xxzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 643); 

                auto tg_xxzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 644); 

                auto tg_xxzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 645); 

                auto tg_xxzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 646); 

                auto tg_xxzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 647); 

                auto tg_xxzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 648); 

                auto tg_xxzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 649); 

                auto tg_xxzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 650); 

                auto tg_xxzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 651); 

                auto tg_xxzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 652); 

                auto tg_xxzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 653); 

                auto tg_xxzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 654); 

                auto tg_xxzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 655); 

                auto tg_xxzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 656); 

                auto tg_xxzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 657); 

                auto tg_xxzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 658); 

                auto tg_xxzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 659); 

                auto tg_xxzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 660); 

                auto tg_xxzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 661); 

                auto tg_xxzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 662); 

                auto tg_xxzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 663); 

                auto tg_xxzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 664); 

                auto tg_xxzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 665); 

                auto tg_xxzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 666); 

                auto tg_xxzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 667); 

                auto tg_xxzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 668); 

                auto tg_xxzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 669); 

                auto tg_xxzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 670); 

                auto tg_xxzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 671); 

                auto tg_xxzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 672); 

                auto tg_xxzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 673); 

                auto tg_xxzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 674); 

                auto tg_xyyyyy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 675); 

                auto tg_xyyyyy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 676); 

                auto tg_xyyyyy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 677); 

                auto tg_xyyyyy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 678); 

                // Batch of Integrals (582,679)

                #pragma omp simd aligned(fxn, fza, tg_xxyyzz_yyzzzzzz_0, tg_xxyyzz_yzzzzzzz_0, \
                                         tg_xxyyzz_zzzzzzzz_0, tg_xxyzzz_xxxxxxxx_0, tg_xxyzzz_xxxxxxxy_0, tg_xxyzzz_xxxxxxxz_0, \
                                         tg_xxyzzz_xxxxxxyy_0, tg_xxyzzz_xxxxxxyz_0, tg_xxyzzz_xxxxxxzz_0, tg_xxyzzz_xxxxxyyy_0, \
                                         tg_xxyzzz_xxxxxyyz_0, tg_xxyzzz_xxxxxyzz_0, tg_xxyzzz_xxxxxzzz_0, tg_xxyzzz_xxxxyyyy_0, \
                                         tg_xxyzzz_xxxxyyyz_0, tg_xxyzzz_xxxxyyzz_0, tg_xxyzzz_xxxxyzzz_0, tg_xxyzzz_xxxxzzzz_0, \
                                         tg_xxyzzz_xxxyyyyy_0, tg_xxyzzz_xxxyyyyz_0, tg_xxyzzz_xxxyyyzz_0, tg_xxyzzz_xxxyyzzz_0, \
                                         tg_xxyzzz_xxxyzzzz_0, tg_xxyzzz_xxxzzzzz_0, tg_xxyzzz_xxyyyyyy_0, tg_xxyzzz_xxyyyyyz_0, \
                                         tg_xxyzzz_xxyyyyzz_0, tg_xxyzzz_xxyyyzzz_0, tg_xxyzzz_xxyyzzzz_0, tg_xxyzzz_xxyzzzzz_0, \
                                         tg_xxyzzz_xxzzzzzz_0, tg_xxyzzz_xyyyyyyy_0, tg_xxyzzz_xyyyyyyz_0, tg_xxyzzz_xyyyyyzz_0, \
                                         tg_xxyzzz_xyyyyzzz_0, tg_xxyzzz_xyyyzzzz_0, tg_xxyzzz_xyyzzzzz_0, tg_xxyzzz_xyzzzzzz_0, \
                                         tg_xxyzzz_xzzzzzzz_0, tg_xxyzzz_yyyyyyyy_0, tg_xxyzzz_yyyyyyyz_0, tg_xxyzzz_yyyyyyzz_0, \
                                         tg_xxyzzz_yyyyyzzz_0, tg_xxyzzz_yyyyzzzz_0, tg_xxyzzz_yyyzzzzz_0, tg_xxyzzz_yyzzzzzz_0, \
                                         tg_xxyzzz_yzzzzzzz_0, tg_xxyzzz_zzzzzzzz_0, tg_xxzzzz_xxxxxxxx_0, tg_xxzzzz_xxxxxxxy_0, \
                                         tg_xxzzzz_xxxxxxxz_0, tg_xxzzzz_xxxxxxyy_0, tg_xxzzzz_xxxxxxyz_0, tg_xxzzzz_xxxxxxzz_0, \
                                         tg_xxzzzz_xxxxxyyy_0, tg_xxzzzz_xxxxxyyz_0, tg_xxzzzz_xxxxxyzz_0, tg_xxzzzz_xxxxxzzz_0, \
                                         tg_xxzzzz_xxxxyyyy_0, tg_xxzzzz_xxxxyyyz_0, tg_xxzzzz_xxxxyyzz_0, tg_xxzzzz_xxxxyzzz_0, \
                                         tg_xxzzzz_xxxxzzzz_0, tg_xxzzzz_xxxyyyyy_0, tg_xxzzzz_xxxyyyyz_0, tg_xxzzzz_xxxyyyzz_0, \
                                         tg_xxzzzz_xxxyyzzz_0, tg_xxzzzz_xxxyzzzz_0, tg_xxzzzz_xxxzzzzz_0, tg_xxzzzz_xxyyyyyy_0, \
                                         tg_xxzzzz_xxyyyyyz_0, tg_xxzzzz_xxyyyyzz_0, tg_xxzzzz_xxyyyzzz_0, tg_xxzzzz_xxyyzzzz_0, \
                                         tg_xxzzzz_xxyzzzzz_0, tg_xxzzzz_xxzzzzzz_0, tg_xxzzzz_xyyyyyyy_0, tg_xxzzzz_xyyyyyyz_0, \
                                         tg_xxzzzz_xyyyyyzz_0, tg_xxzzzz_xyyyyzzz_0, tg_xxzzzz_xyyyzzzz_0, tg_xxzzzz_xyyzzzzz_0, \
                                         tg_xxzzzz_xyzzzzzz_0, tg_xxzzzz_xzzzzzzz_0, tg_xxzzzz_yyyyyyyy_0, tg_xxzzzz_yyyyyyyz_0, \
                                         tg_xxzzzz_yyyyyyzz_0, tg_xxzzzz_yyyyyzzz_0, tg_xxzzzz_yyyyzzzz_0, tg_xxzzzz_yyyzzzzz_0, \
                                         tg_xxzzzz_yyzzzzzz_0, tg_xxzzzz_yzzzzzzz_0, tg_xxzzzz_zzzzzzzz_0, tg_xyyyyy_xxxxxxxx_0, \
                                         tg_xyyyyy_xxxxxxxy_0, tg_xyyyyy_xxxxxxxz_0, tg_xyyyyy_xxxxxxyy_0, tg_xyyzz_yyzzzzzz_0, \
                                         tg_xyyzz_yyzzzzzz_1, tg_xyyzz_yzzzzzzz_0, tg_xyyzz_yzzzzzzz_1, tg_xyyzz_zzzzzzzz_0, \
                                         tg_xyyzz_zzzzzzzz_1, tg_xyzzz_xxxxxxx_1, tg_xyzzz_xxxxxxxx_0, tg_xyzzz_xxxxxxxx_1, \
                                         tg_xyzzz_xxxxxxxy_0, tg_xyzzz_xxxxxxxy_1, tg_xyzzz_xxxxxxxz_0, tg_xyzzz_xxxxxxxz_1, \
                                         tg_xyzzz_xxxxxxy_1, tg_xyzzz_xxxxxxyy_0, tg_xyzzz_xxxxxxyy_1, tg_xyzzz_xxxxxxyz_0, \
                                         tg_xyzzz_xxxxxxyz_1, tg_xyzzz_xxxxxxz_1, tg_xyzzz_xxxxxxzz_0, tg_xyzzz_xxxxxxzz_1, \
                                         tg_xyzzz_xxxxxyy_1, tg_xyzzz_xxxxxyyy_0, tg_xyzzz_xxxxxyyy_1, tg_xyzzz_xxxxxyyz_0, \
                                         tg_xyzzz_xxxxxyyz_1, tg_xyzzz_xxxxxyz_1, tg_xyzzz_xxxxxyzz_0, tg_xyzzz_xxxxxyzz_1, \
                                         tg_xyzzz_xxxxxzz_1, tg_xyzzz_xxxxxzzz_0, tg_xyzzz_xxxxxzzz_1, tg_xyzzz_xxxxyyy_1, \
                                         tg_xyzzz_xxxxyyyy_0, tg_xyzzz_xxxxyyyy_1, tg_xyzzz_xxxxyyyz_0, tg_xyzzz_xxxxyyyz_1, \
                                         tg_xyzzz_xxxxyyz_1, tg_xyzzz_xxxxyyzz_0, tg_xyzzz_xxxxyyzz_1, tg_xyzzz_xxxxyzz_1, \
                                         tg_xyzzz_xxxxyzzz_0, tg_xyzzz_xxxxyzzz_1, tg_xyzzz_xxxxzzz_1, tg_xyzzz_xxxxzzzz_0, \
                                         tg_xyzzz_xxxxzzzz_1, tg_xyzzz_xxxyyyy_1, tg_xyzzz_xxxyyyyy_0, tg_xyzzz_xxxyyyyy_1, \
                                         tg_xyzzz_xxxyyyyz_0, tg_xyzzz_xxxyyyyz_1, tg_xyzzz_xxxyyyz_1, tg_xyzzz_xxxyyyzz_0, \
                                         tg_xyzzz_xxxyyyzz_1, tg_xyzzz_xxxyyzz_1, tg_xyzzz_xxxyyzzz_0, tg_xyzzz_xxxyyzzz_1, \
                                         tg_xyzzz_xxxyzzz_1, tg_xyzzz_xxxyzzzz_0, tg_xyzzz_xxxyzzzz_1, tg_xyzzz_xxxzzzz_1, \
                                         tg_xyzzz_xxxzzzzz_0, tg_xyzzz_xxxzzzzz_1, tg_xyzzz_xxyyyyy_1, tg_xyzzz_xxyyyyyy_0, \
                                         tg_xyzzz_xxyyyyyy_1, tg_xyzzz_xxyyyyyz_0, tg_xyzzz_xxyyyyyz_1, tg_xyzzz_xxyyyyz_1, \
                                         tg_xyzzz_xxyyyyzz_0, tg_xyzzz_xxyyyyzz_1, tg_xyzzz_xxyyyzz_1, tg_xyzzz_xxyyyzzz_0, \
                                         tg_xyzzz_xxyyyzzz_1, tg_xyzzz_xxyyzzz_1, tg_xyzzz_xxyyzzzz_0, tg_xyzzz_xxyyzzzz_1, \
                                         tg_xyzzz_xxyzzzz_1, tg_xyzzz_xxyzzzzz_0, tg_xyzzz_xxyzzzzz_1, tg_xyzzz_xxzzzzz_1, \
                                         tg_xyzzz_xxzzzzzz_0, tg_xyzzz_xxzzzzzz_1, tg_xyzzz_xyyyyyy_1, tg_xyzzz_xyyyyyyy_0, \
                                         tg_xyzzz_xyyyyyyy_1, tg_xyzzz_xyyyyyyz_0, tg_xyzzz_xyyyyyyz_1, tg_xyzzz_xyyyyyz_1, \
                                         tg_xyzzz_xyyyyyzz_0, tg_xyzzz_xyyyyyzz_1, tg_xyzzz_xyyyyzz_1, tg_xyzzz_xyyyyzzz_0, \
                                         tg_xyzzz_xyyyyzzz_1, tg_xyzzz_xyyyzzz_1, tg_xyzzz_xyyyzzzz_0, tg_xyzzz_xyyyzzzz_1, \
                                         tg_xyzzz_xyyzzzz_1, tg_xyzzz_xyyzzzzz_0, tg_xyzzz_xyyzzzzz_1, tg_xyzzz_xyzzzzz_1, \
                                         tg_xyzzz_xyzzzzzz_0, tg_xyzzz_xyzzzzzz_1, tg_xyzzz_xzzzzzz_1, tg_xyzzz_xzzzzzzz_0, \
                                         tg_xyzzz_xzzzzzzz_1, tg_xyzzz_yyyyyyy_1, tg_xyzzz_yyyyyyyy_0, tg_xyzzz_yyyyyyyy_1, \
                                         tg_xyzzz_yyyyyyyz_0, tg_xyzzz_yyyyyyyz_1, tg_xyzzz_yyyyyyz_1, tg_xyzzz_yyyyyyzz_0, \
                                         tg_xyzzz_yyyyyyzz_1, tg_xyzzz_yyyyyzz_1, tg_xyzzz_yyyyyzzz_0, tg_xyzzz_yyyyyzzz_1, \
                                         tg_xyzzz_yyyyzzz_1, tg_xyzzz_yyyyzzzz_0, tg_xyzzz_yyyyzzzz_1, tg_xyzzz_yyyzzzz_1, \
                                         tg_xyzzz_yyyzzzzz_0, tg_xyzzz_yyyzzzzz_1, tg_xyzzz_yyzzzzz_1, tg_xyzzz_yyzzzzzz_0, \
                                         tg_xyzzz_yyzzzzzz_1, tg_xyzzz_yzzzzzz_1, tg_xyzzz_yzzzzzzz_0, tg_xyzzz_yzzzzzzz_1, \
                                         tg_xyzzz_zzzzzzz_1, tg_xyzzz_zzzzzzzz_0, tg_xyzzz_zzzzzzzz_1, tg_xzzzz_xxxxxxx_1, \
                                         tg_xzzzz_xxxxxxxx_0, tg_xzzzz_xxxxxxxx_1, tg_xzzzz_xxxxxxxy_0, tg_xzzzz_xxxxxxxy_1, \
                                         tg_xzzzz_xxxxxxxz_0, tg_xzzzz_xxxxxxxz_1, tg_xzzzz_xxxxxxy_1, tg_xzzzz_xxxxxxyy_0, \
                                         tg_xzzzz_xxxxxxyy_1, tg_xzzzz_xxxxxxyz_0, tg_xzzzz_xxxxxxyz_1, tg_xzzzz_xxxxxxz_1, \
                                         tg_xzzzz_xxxxxxzz_0, tg_xzzzz_xxxxxxzz_1, tg_xzzzz_xxxxxyy_1, tg_xzzzz_xxxxxyyy_0, \
                                         tg_xzzzz_xxxxxyyy_1, tg_xzzzz_xxxxxyyz_0, tg_xzzzz_xxxxxyyz_1, tg_xzzzz_xxxxxyz_1, \
                                         tg_xzzzz_xxxxxyzz_0, tg_xzzzz_xxxxxyzz_1, tg_xzzzz_xxxxxzz_1, tg_xzzzz_xxxxxzzz_0, \
                                         tg_xzzzz_xxxxxzzz_1, tg_xzzzz_xxxxyyy_1, tg_xzzzz_xxxxyyyy_0, tg_xzzzz_xxxxyyyy_1, \
                                         tg_xzzzz_xxxxyyyz_0, tg_xzzzz_xxxxyyyz_1, tg_xzzzz_xxxxyyz_1, tg_xzzzz_xxxxyyzz_0, \
                                         tg_xzzzz_xxxxyyzz_1, tg_xzzzz_xxxxyzz_1, tg_xzzzz_xxxxyzzz_0, tg_xzzzz_xxxxyzzz_1, \
                                         tg_xzzzz_xxxxzzz_1, tg_xzzzz_xxxxzzzz_0, tg_xzzzz_xxxxzzzz_1, tg_xzzzz_xxxyyyy_1, \
                                         tg_xzzzz_xxxyyyyy_0, tg_xzzzz_xxxyyyyy_1, tg_xzzzz_xxxyyyyz_0, tg_xzzzz_xxxyyyyz_1, \
                                         tg_xzzzz_xxxyyyz_1, tg_xzzzz_xxxyyyzz_0, tg_xzzzz_xxxyyyzz_1, tg_xzzzz_xxxyyzz_1, \
                                         tg_xzzzz_xxxyyzzz_0, tg_xzzzz_xxxyyzzz_1, tg_xzzzz_xxxyzzz_1, tg_xzzzz_xxxyzzzz_0, \
                                         tg_xzzzz_xxxyzzzz_1, tg_xzzzz_xxxzzzz_1, tg_xzzzz_xxxzzzzz_0, tg_xzzzz_xxxzzzzz_1, \
                                         tg_xzzzz_xxyyyyy_1, tg_xzzzz_xxyyyyyy_0, tg_xzzzz_xxyyyyyy_1, tg_xzzzz_xxyyyyyz_0, \
                                         tg_xzzzz_xxyyyyyz_1, tg_xzzzz_xxyyyyz_1, tg_xzzzz_xxyyyyzz_0, tg_xzzzz_xxyyyyzz_1, \
                                         tg_xzzzz_xxyyyzz_1, tg_xzzzz_xxyyyzzz_0, tg_xzzzz_xxyyyzzz_1, tg_xzzzz_xxyyzzz_1, \
                                         tg_xzzzz_xxyyzzzz_0, tg_xzzzz_xxyyzzzz_1, tg_xzzzz_xxyzzzz_1, tg_xzzzz_xxyzzzzz_0, \
                                         tg_xzzzz_xxyzzzzz_1, tg_xzzzz_xxzzzzz_1, tg_xzzzz_xxzzzzzz_0, tg_xzzzz_xxzzzzzz_1, \
                                         tg_xzzzz_xyyyyyy_1, tg_xzzzz_xyyyyyyy_0, tg_xzzzz_xyyyyyyy_1, tg_xzzzz_xyyyyyyz_0, \
                                         tg_xzzzz_xyyyyyyz_1, tg_xzzzz_xyyyyyz_1, tg_xzzzz_xyyyyyzz_0, tg_xzzzz_xyyyyyzz_1, \
                                         tg_xzzzz_xyyyyzz_1, tg_xzzzz_xyyyyzzz_0, tg_xzzzz_xyyyyzzz_1, tg_xzzzz_xyyyzzz_1, \
                                         tg_xzzzz_xyyyzzzz_0, tg_xzzzz_xyyyzzzz_1, tg_xzzzz_xyyzzzz_1, tg_xzzzz_xyyzzzzz_0, \
                                         tg_xzzzz_xyyzzzzz_1, tg_xzzzz_xyzzzzz_1, tg_xzzzz_xyzzzzzz_0, tg_xzzzz_xyzzzzzz_1, \
                                         tg_xzzzz_xzzzzzz_1, tg_xzzzz_xzzzzzzz_0, tg_xzzzz_xzzzzzzz_1, tg_xzzzz_yyyyyyy_1, \
                                         tg_xzzzz_yyyyyyyy_0, tg_xzzzz_yyyyyyyy_1, tg_xzzzz_yyyyyyyz_0, tg_xzzzz_yyyyyyyz_1, \
                                         tg_xzzzz_yyyyyyz_1, tg_xzzzz_yyyyyyzz_0, tg_xzzzz_yyyyyyzz_1, tg_xzzzz_yyyyyzz_1, \
                                         tg_xzzzz_yyyyyzzz_0, tg_xzzzz_yyyyyzzz_1, tg_xzzzz_yyyyzzz_1, tg_xzzzz_yyyyzzzz_0, \
                                         tg_xzzzz_yyyyzzzz_1, tg_xzzzz_yyyzzzz_1, tg_xzzzz_yyyzzzzz_0, tg_xzzzz_yyyzzzzz_1, \
                                         tg_xzzzz_yyzzzzz_1, tg_xzzzz_yyzzzzzz_0, tg_xzzzz_yyzzzzzz_1, tg_xzzzz_yzzzzzz_1, \
                                         tg_xzzzz_yzzzzzzz_0, tg_xzzzz_yzzzzzzz_1, tg_xzzzz_zzzzzzz_1, tg_xzzzz_zzzzzzzz_0, \
                                         tg_xzzzz_zzzzzzzz_1, tg_yyyyy_xxxxxxx_1, tg_yyyyy_xxxxxxxx_0, tg_yyyyy_xxxxxxxx_1, \
                                         tg_yyyyy_xxxxxxxy_0, tg_yyyyy_xxxxxxxy_1, tg_yyyyy_xxxxxxxz_0, tg_yyyyy_xxxxxxxz_1, \
                                         tg_yyyyy_xxxxxxy_1, tg_yyyyy_xxxxxxyy_0, tg_yyyyy_xxxxxxyy_1, tg_yyyyy_xxxxxxz_1, \
                                         tg_yyyyy_xxxxxyy_1, tg_yyzz_yyzzzzzz_0, tg_yyzz_yyzzzzzz_1, tg_yyzz_yzzzzzzz_0, \
                                         tg_yyzz_yzzzzzzz_1, tg_yyzz_zzzzzzzz_0, tg_yyzz_zzzzzzzz_1, tg_yzzz_xxxxxxxx_0, \
                                         tg_yzzz_xxxxxxxx_1, tg_yzzz_xxxxxxxy_0, tg_yzzz_xxxxxxxy_1, tg_yzzz_xxxxxxxz_0, \
                                         tg_yzzz_xxxxxxxz_1, tg_yzzz_xxxxxxyy_0, tg_yzzz_xxxxxxyy_1, tg_yzzz_xxxxxxyz_0, \
                                         tg_yzzz_xxxxxxyz_1, tg_yzzz_xxxxxxzz_0, tg_yzzz_xxxxxxzz_1, tg_yzzz_xxxxxyyy_0, \
                                         tg_yzzz_xxxxxyyy_1, tg_yzzz_xxxxxyyz_0, tg_yzzz_xxxxxyyz_1, tg_yzzz_xxxxxyzz_0, \
                                         tg_yzzz_xxxxxyzz_1, tg_yzzz_xxxxxzzz_0, tg_yzzz_xxxxxzzz_1, tg_yzzz_xxxxyyyy_0, \
                                         tg_yzzz_xxxxyyyy_1, tg_yzzz_xxxxyyyz_0, tg_yzzz_xxxxyyyz_1, tg_yzzz_xxxxyyzz_0, \
                                         tg_yzzz_xxxxyyzz_1, tg_yzzz_xxxxyzzz_0, tg_yzzz_xxxxyzzz_1, tg_yzzz_xxxxzzzz_0, \
                                         tg_yzzz_xxxxzzzz_1, tg_yzzz_xxxyyyyy_0, tg_yzzz_xxxyyyyy_1, tg_yzzz_xxxyyyyz_0, \
                                         tg_yzzz_xxxyyyyz_1, tg_yzzz_xxxyyyzz_0, tg_yzzz_xxxyyyzz_1, tg_yzzz_xxxyyzzz_0, \
                                         tg_yzzz_xxxyyzzz_1, tg_yzzz_xxxyzzzz_0, tg_yzzz_xxxyzzzz_1, tg_yzzz_xxxzzzzz_0, \
                                         tg_yzzz_xxxzzzzz_1, tg_yzzz_xxyyyyyy_0, tg_yzzz_xxyyyyyy_1, tg_yzzz_xxyyyyyz_0, \
                                         tg_yzzz_xxyyyyyz_1, tg_yzzz_xxyyyyzz_0, tg_yzzz_xxyyyyzz_1, tg_yzzz_xxyyyzzz_0, \
                                         tg_yzzz_xxyyyzzz_1, tg_yzzz_xxyyzzzz_0, tg_yzzz_xxyyzzzz_1, tg_yzzz_xxyzzzzz_0, \
                                         tg_yzzz_xxyzzzzz_1, tg_yzzz_xxzzzzzz_0, tg_yzzz_xxzzzzzz_1, tg_yzzz_xyyyyyyy_0, \
                                         tg_yzzz_xyyyyyyy_1, tg_yzzz_xyyyyyyz_0, tg_yzzz_xyyyyyyz_1, tg_yzzz_xyyyyyzz_0, \
                                         tg_yzzz_xyyyyyzz_1, tg_yzzz_xyyyyzzz_0, tg_yzzz_xyyyyzzz_1, tg_yzzz_xyyyzzzz_0, \
                                         tg_yzzz_xyyyzzzz_1, tg_yzzz_xyyzzzzz_0, tg_yzzz_xyyzzzzz_1, tg_yzzz_xyzzzzzz_0, \
                                         tg_yzzz_xyzzzzzz_1, tg_yzzz_xzzzzzzz_0, tg_yzzz_xzzzzzzz_1, tg_yzzz_yyyyyyyy_0, \
                                         tg_yzzz_yyyyyyyy_1, tg_yzzz_yyyyyyyz_0, tg_yzzz_yyyyyyyz_1, tg_yzzz_yyyyyyzz_0, \
                                         tg_yzzz_yyyyyyzz_1, tg_yzzz_yyyyyzzz_0, tg_yzzz_yyyyyzzz_1, tg_yzzz_yyyyzzzz_0, \
                                         tg_yzzz_yyyyzzzz_1, tg_yzzz_yyyzzzzz_0, tg_yzzz_yyyzzzzz_1, tg_yzzz_yyzzzzzz_0, \
                                         tg_yzzz_yyzzzzzz_1, tg_yzzz_yzzzzzzz_0, tg_yzzz_yzzzzzzz_1, tg_yzzz_zzzzzzzz_0, \
                                         tg_yzzz_zzzzzzzz_1, tg_zzzz_xxxxxxxx_0, tg_zzzz_xxxxxxxx_1, tg_zzzz_xxxxxxxy_0, \
                                         tg_zzzz_xxxxxxxy_1, tg_zzzz_xxxxxxxz_0, tg_zzzz_xxxxxxxz_1, tg_zzzz_xxxxxxyy_0, \
                                         tg_zzzz_xxxxxxyy_1, tg_zzzz_xxxxxxyz_0, tg_zzzz_xxxxxxyz_1, tg_zzzz_xxxxxxzz_0, \
                                         tg_zzzz_xxxxxxzz_1, tg_zzzz_xxxxxyyy_0, tg_zzzz_xxxxxyyy_1, tg_zzzz_xxxxxyyz_0, \
                                         tg_zzzz_xxxxxyyz_1, tg_zzzz_xxxxxyzz_0, tg_zzzz_xxxxxyzz_1, tg_zzzz_xxxxxzzz_0, \
                                         tg_zzzz_xxxxxzzz_1, tg_zzzz_xxxxyyyy_0, tg_zzzz_xxxxyyyy_1, tg_zzzz_xxxxyyyz_0, \
                                         tg_zzzz_xxxxyyyz_1, tg_zzzz_xxxxyyzz_0, tg_zzzz_xxxxyyzz_1, tg_zzzz_xxxxyzzz_0, \
                                         tg_zzzz_xxxxyzzz_1, tg_zzzz_xxxxzzzz_0, tg_zzzz_xxxxzzzz_1, tg_zzzz_xxxyyyyy_0, \
                                         tg_zzzz_xxxyyyyy_1, tg_zzzz_xxxyyyyz_0, tg_zzzz_xxxyyyyz_1, tg_zzzz_xxxyyyzz_0, \
                                         tg_zzzz_xxxyyyzz_1, tg_zzzz_xxxyyzzz_0, tg_zzzz_xxxyyzzz_1, tg_zzzz_xxxyzzzz_0, \
                                         tg_zzzz_xxxyzzzz_1, tg_zzzz_xxxzzzzz_0, tg_zzzz_xxxzzzzz_1, tg_zzzz_xxyyyyyy_0, \
                                         tg_zzzz_xxyyyyyy_1, tg_zzzz_xxyyyyyz_0, tg_zzzz_xxyyyyyz_1, tg_zzzz_xxyyyyzz_0, \
                                         tg_zzzz_xxyyyyzz_1, tg_zzzz_xxyyyzzz_0, tg_zzzz_xxyyyzzz_1, tg_zzzz_xxyyzzzz_0, \
                                         tg_zzzz_xxyyzzzz_1, tg_zzzz_xxyzzzzz_0, tg_zzzz_xxyzzzzz_1, tg_zzzz_xxzzzzzz_0, \
                                         tg_zzzz_xxzzzzzz_1, tg_zzzz_xyyyyyyy_0, tg_zzzz_xyyyyyyy_1, tg_zzzz_xyyyyyyz_0, \
                                         tg_zzzz_xyyyyyyz_1, tg_zzzz_xyyyyyzz_0, tg_zzzz_xyyyyyzz_1, tg_zzzz_xyyyyzzz_0, \
                                         tg_zzzz_xyyyyzzz_1, tg_zzzz_xyyyzzzz_0, tg_zzzz_xyyyzzzz_1, tg_zzzz_xyyzzzzz_0, \
                                         tg_zzzz_xyyzzzzz_1, tg_zzzz_xyzzzzzz_0, tg_zzzz_xyzzzzzz_1, tg_zzzz_xzzzzzzz_0, \
                                         tg_zzzz_xzzzzzzz_1, tg_zzzz_yyyyyyyy_0, tg_zzzz_yyyyyyyy_1, tg_zzzz_yyyyyyyz_0, \
                                         tg_zzzz_yyyyyyyz_1, tg_zzzz_yyyyyyzz_0, tg_zzzz_yyyyyyzz_1, tg_zzzz_yyyyyzzz_0, \
                                         tg_zzzz_yyyyyzzz_1, tg_zzzz_yyyyzzzz_0, tg_zzzz_yyyyzzzz_1, tg_zzzz_yyyzzzzz_0, \
                                         tg_zzzz_yyyzzzzz_1, tg_zzzz_yyzzzzzz_0, tg_zzzz_yyzzzzzz_1, tg_zzzz_yzzzzzzz_0, \
                                         tg_zzzz_yzzzzzzz_1, tg_zzzz_zzzzzzzz_0, tg_zzzz_zzzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxyyzz_yyzzzzzz_0[j] = pb_x * tg_xyyzz_yyzzzzzz_0[j] + fr * tg_xyyzz_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yyzzzzzz_0[j] - tg_yyzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxyyzz_yzzzzzzz_0[j] = pb_x * tg_xyyzz_yzzzzzzz_0[j] + fr * tg_xyyzz_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_yzzzzzzz_0[j] - tg_yyzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxyyzz_zzzzzzzz_0[j] = pb_x * tg_xyyzz_zzzzzzzz_0[j] + fr * tg_xyyzz_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzz_zzzzzzzz_0[j] - tg_yyzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxyzzz_xxxxxxxx_0[j] = pb_x * tg_xyzzz_xxxxxxxx_0[j] + fr * tg_xyzzz_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxxx_0[j] - tg_yzzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xyzzz_xxxxxxx_1[j];

                    tg_xxyzzz_xxxxxxxy_0[j] = pb_x * tg_xyzzz_xxxxxxxy_0[j] + fr * tg_xyzzz_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxxy_0[j] - tg_yzzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyzzz_xxxxxxy_1[j];

                    tg_xxyzzz_xxxxxxxz_0[j] = pb_x * tg_xyzzz_xxxxxxxz_0[j] + fr * tg_xyzzz_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxxz_0[j] - tg_yzzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyzzz_xxxxxxz_1[j];

                    tg_xxyzzz_xxxxxxyy_0[j] = pb_x * tg_xyzzz_xxxxxxyy_0[j] + fr * tg_xyzzz_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxyy_0[j] - tg_yzzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzz_xxxxxyy_1[j];

                    tg_xxyzzz_xxxxxxyz_0[j] = pb_x * tg_xyzzz_xxxxxxyz_0[j] + fr * tg_xyzzz_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxyz_0[j] - tg_yzzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzz_xxxxxyz_1[j];

                    tg_xxyzzz_xxxxxxzz_0[j] = pb_x * tg_xyzzz_xxxxxxzz_0[j] + fr * tg_xyzzz_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxxzz_0[j] - tg_yzzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzz_xxxxxzz_1[j];

                    tg_xxyzzz_xxxxxyyy_0[j] = pb_x * tg_xyzzz_xxxxxyyy_0[j] + fr * tg_xyzzz_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxyyy_0[j] - tg_yzzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzz_xxxxyyy_1[j];

                    tg_xxyzzz_xxxxxyyz_0[j] = pb_x * tg_xyzzz_xxxxxyyz_0[j] + fr * tg_xyzzz_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxyyz_0[j] - tg_yzzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzz_xxxxyyz_1[j];

                    tg_xxyzzz_xxxxxyzz_0[j] = pb_x * tg_xyzzz_xxxxxyzz_0[j] + fr * tg_xyzzz_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxyzz_0[j] - tg_yzzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzz_xxxxyzz_1[j];

                    tg_xxyzzz_xxxxxzzz_0[j] = pb_x * tg_xyzzz_xxxxxzzz_0[j] + fr * tg_xyzzz_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxxzzz_0[j] - tg_yzzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzz_xxxxzzz_1[j];

                    tg_xxyzzz_xxxxyyyy_0[j] = pb_x * tg_xyzzz_xxxxyyyy_0[j] + fr * tg_xyzzz_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxyyyy_0[j] - tg_yzzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzz_xxxyyyy_1[j];

                    tg_xxyzzz_xxxxyyyz_0[j] = pb_x * tg_xyzzz_xxxxyyyz_0[j] + fr * tg_xyzzz_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxyyyz_0[j] - tg_yzzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzz_xxxyyyz_1[j];

                    tg_xxyzzz_xxxxyyzz_0[j] = pb_x * tg_xyzzz_xxxxyyzz_0[j] + fr * tg_xyzzz_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxyyzz_0[j] - tg_yzzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzz_xxxyyzz_1[j];

                    tg_xxyzzz_xxxxyzzz_0[j] = pb_x * tg_xyzzz_xxxxyzzz_0[j] + fr * tg_xyzzz_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxyzzz_0[j] - tg_yzzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzz_xxxyzzz_1[j];

                    tg_xxyzzz_xxxxzzzz_0[j] = pb_x * tg_xyzzz_xxxxzzzz_0[j] + fr * tg_xyzzz_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxxzzzz_0[j] - tg_yzzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzz_xxxzzzz_1[j];

                    tg_xxyzzz_xxxyyyyy_0[j] = pb_x * tg_xyzzz_xxxyyyyy_0[j] + fr * tg_xyzzz_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxyyyyy_0[j] - tg_yzzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxyyyyy_1[j];

                    tg_xxyzzz_xxxyyyyz_0[j] = pb_x * tg_xyzzz_xxxyyyyz_0[j] + fr * tg_xyzzz_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxyyyyz_0[j] - tg_yzzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxyyyyz_1[j];

                    tg_xxyzzz_xxxyyyzz_0[j] = pb_x * tg_xyzzz_xxxyyyzz_0[j] + fr * tg_xyzzz_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxyyyzz_0[j] - tg_yzzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxyyyzz_1[j];

                    tg_xxyzzz_xxxyyzzz_0[j] = pb_x * tg_xyzzz_xxxyyzzz_0[j] + fr * tg_xyzzz_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxyyzzz_0[j] - tg_yzzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxyyzzz_1[j];

                    tg_xxyzzz_xxxyzzzz_0[j] = pb_x * tg_xyzzz_xxxyzzzz_0[j] + fr * tg_xyzzz_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxyzzzz_0[j] - tg_yzzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxyzzzz_1[j];

                    tg_xxyzzz_xxxzzzzz_0[j] = pb_x * tg_xyzzz_xxxzzzzz_0[j] + fr * tg_xyzzz_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxxzzzzz_0[j] - tg_yzzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzz_xxzzzzz_1[j];

                    tg_xxyzzz_xxyyyyyy_0[j] = pb_x * tg_xyzzz_xxyyyyyy_0[j] + fr * tg_xyzzz_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyyyyyy_0[j] - tg_yzzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyyyyyy_1[j];

                    tg_xxyzzz_xxyyyyyz_0[j] = pb_x * tg_xyzzz_xxyyyyyz_0[j] + fr * tg_xyzzz_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyyyyyz_0[j] - tg_yzzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyyyyyz_1[j];

                    tg_xxyzzz_xxyyyyzz_0[j] = pb_x * tg_xyzzz_xxyyyyzz_0[j] + fr * tg_xyzzz_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyyyyzz_0[j] - tg_yzzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyyyyzz_1[j];

                    tg_xxyzzz_xxyyyzzz_0[j] = pb_x * tg_xyzzz_xxyyyzzz_0[j] + fr * tg_xyzzz_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyyyzzz_0[j] - tg_yzzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyyyzzz_1[j];

                    tg_xxyzzz_xxyyzzzz_0[j] = pb_x * tg_xyzzz_xxyyzzzz_0[j] + fr * tg_xyzzz_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyyzzzz_0[j] - tg_yzzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyyzzzz_1[j];

                    tg_xxyzzz_xxyzzzzz_0[j] = pb_x * tg_xyzzz_xxyzzzzz_0[j] + fr * tg_xyzzz_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxyzzzzz_0[j] - tg_yzzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xyzzzzz_1[j];

                    tg_xxyzzz_xxzzzzzz_0[j] = pb_x * tg_xyzzz_xxzzzzzz_0[j] + fr * tg_xyzzz_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xxzzzzzz_0[j] - tg_yzzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzz_xzzzzzz_1[j];

                    tg_xxyzzz_xyyyyyyy_0[j] = pb_x * tg_xyzzz_xyyyyyyy_0[j] + fr * tg_xyzzz_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyyyyyy_0[j] - tg_yzzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyyyyyy_1[j];

                    tg_xxyzzz_xyyyyyyz_0[j] = pb_x * tg_xyzzz_xyyyyyyz_0[j] + fr * tg_xyzzz_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyyyyyz_0[j] - tg_yzzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyyyyyz_1[j];

                    tg_xxyzzz_xyyyyyzz_0[j] = pb_x * tg_xyzzz_xyyyyyzz_0[j] + fr * tg_xyzzz_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyyyyzz_0[j] - tg_yzzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyyyyzz_1[j];

                    tg_xxyzzz_xyyyyzzz_0[j] = pb_x * tg_xyzzz_xyyyyzzz_0[j] + fr * tg_xyzzz_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyyyzzz_0[j] - tg_yzzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyyyzzz_1[j];

                    tg_xxyzzz_xyyyzzzz_0[j] = pb_x * tg_xyzzz_xyyyzzzz_0[j] + fr * tg_xyzzz_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyyzzzz_0[j] - tg_yzzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyyzzzz_1[j];

                    tg_xxyzzz_xyyzzzzz_0[j] = pb_x * tg_xyzzz_xyyzzzzz_0[j] + fr * tg_xyzzz_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyyzzzzz_0[j] - tg_yzzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yyzzzzz_1[j];

                    tg_xxyzzz_xyzzzzzz_0[j] = pb_x * tg_xyzzz_xyzzzzzz_0[j] + fr * tg_xyzzz_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xyzzzzzz_0[j] - tg_yzzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_yzzzzzz_1[j];

                    tg_xxyzzz_xzzzzzzz_0[j] = pb_x * tg_xyzzz_xzzzzzzz_0[j] + fr * tg_xyzzz_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_xzzzzzzz_0[j] - tg_yzzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzz_zzzzzzz_1[j];

                    tg_xxyzzz_yyyyyyyy_0[j] = pb_x * tg_xyzzz_yyyyyyyy_0[j] + fr * tg_xyzzz_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyyyyyy_0[j] - tg_yzzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxyzzz_yyyyyyyz_0[j] = pb_x * tg_xyzzz_yyyyyyyz_0[j] + fr * tg_xyzzz_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyyyyyz_0[j] - tg_yzzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxyzzz_yyyyyyzz_0[j] = pb_x * tg_xyzzz_yyyyyyzz_0[j] + fr * tg_xyzzz_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyyyyzz_0[j] - tg_yzzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxyzzz_yyyyyzzz_0[j] = pb_x * tg_xyzzz_yyyyyzzz_0[j] + fr * tg_xyzzz_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyyyzzz_0[j] - tg_yzzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxyzzz_yyyyzzzz_0[j] = pb_x * tg_xyzzz_yyyyzzzz_0[j] + fr * tg_xyzzz_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyyzzzz_0[j] - tg_yzzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxyzzz_yyyzzzzz_0[j] = pb_x * tg_xyzzz_yyyzzzzz_0[j] + fr * tg_xyzzz_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyyzzzzz_0[j] - tg_yzzz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxyzzz_yyzzzzzz_0[j] = pb_x * tg_xyzzz_yyzzzzzz_0[j] + fr * tg_xyzzz_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yyzzzzzz_0[j] - tg_yzzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxyzzz_yzzzzzzz_0[j] = pb_x * tg_xyzzz_yzzzzzzz_0[j] + fr * tg_xyzzz_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_yzzzzzzz_0[j] - tg_yzzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxyzzz_zzzzzzzz_0[j] = pb_x * tg_xyzzz_zzzzzzzz_0[j] + fr * tg_xyzzz_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzz_zzzzzzzz_0[j] - tg_yzzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xxzzzz_xxxxxxxx_0[j] = pb_x * tg_xzzzz_xxxxxxxx_0[j] + fr * tg_xzzzz_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxx_0[j] - tg_zzzz_xxxxxxxx_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_xzzzz_xxxxxxx_1[j];

                    tg_xxzzzz_xxxxxxxy_0[j] = pb_x * tg_xzzzz_xxxxxxxy_0[j] + fr * tg_xzzzz_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxy_0[j] - tg_zzzz_xxxxxxxy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xzzzz_xxxxxxy_1[j];

                    tg_xxzzzz_xxxxxxxz_0[j] = pb_x * tg_xzzzz_xxxxxxxz_0[j] + fr * tg_xzzzz_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxz_0[j] - tg_zzzz_xxxxxxxz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xzzzz_xxxxxxz_1[j];

                    tg_xxzzzz_xxxxxxyy_0[j] = pb_x * tg_xzzzz_xxxxxxyy_0[j] + fr * tg_xzzzz_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxyy_0[j] - tg_zzzz_xxxxxxyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzz_xxxxxyy_1[j];

                    tg_xxzzzz_xxxxxxyz_0[j] = pb_x * tg_xzzzz_xxxxxxyz_0[j] + fr * tg_xzzzz_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxyz_0[j] - tg_zzzz_xxxxxxyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzz_xxxxxyz_1[j];

                    tg_xxzzzz_xxxxxxzz_0[j] = pb_x * tg_xzzzz_xxxxxxzz_0[j] + fr * tg_xzzzz_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxzz_0[j] - tg_zzzz_xxxxxxzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzz_xxxxxzz_1[j];

                    tg_xxzzzz_xxxxxyyy_0[j] = pb_x * tg_xzzzz_xxxxxyyy_0[j] + fr * tg_xzzzz_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyyy_0[j] - tg_zzzz_xxxxxyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzz_xxxxyyy_1[j];

                    tg_xxzzzz_xxxxxyyz_0[j] = pb_x * tg_xzzzz_xxxxxyyz_0[j] + fr * tg_xzzzz_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyyz_0[j] - tg_zzzz_xxxxxyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzz_xxxxyyz_1[j];

                    tg_xxzzzz_xxxxxyzz_0[j] = pb_x * tg_xzzzz_xxxxxyzz_0[j] + fr * tg_xzzzz_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyzz_0[j] - tg_zzzz_xxxxxyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzz_xxxxyzz_1[j];

                    tg_xxzzzz_xxxxxzzz_0[j] = pb_x * tg_xzzzz_xxxxxzzz_0[j] + fr * tg_xzzzz_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxzzz_0[j] - tg_zzzz_xxxxxzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzz_xxxxzzz_1[j];

                    tg_xxzzzz_xxxxyyyy_0[j] = pb_x * tg_xzzzz_xxxxyyyy_0[j] + fr * tg_xzzzz_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyyy_0[j] - tg_zzzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzz_xxxyyyy_1[j];

                    tg_xxzzzz_xxxxyyyz_0[j] = pb_x * tg_xzzzz_xxxxyyyz_0[j] + fr * tg_xzzzz_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyyz_0[j] - tg_zzzz_xxxxyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzz_xxxyyyz_1[j];

                    tg_xxzzzz_xxxxyyzz_0[j] = pb_x * tg_xzzzz_xxxxyyzz_0[j] + fr * tg_xzzzz_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyzz_0[j] - tg_zzzz_xxxxyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzz_xxxyyzz_1[j];

                    tg_xxzzzz_xxxxyzzz_0[j] = pb_x * tg_xzzzz_xxxxyzzz_0[j] + fr * tg_xzzzz_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyzzz_0[j] - tg_zzzz_xxxxyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzz_xxxyzzz_1[j];

                    tg_xxzzzz_xxxxzzzz_0[j] = pb_x * tg_xzzzz_xxxxzzzz_0[j] + fr * tg_xzzzz_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxzzzz_0[j] - tg_zzzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzz_xxxzzzz_1[j];

                    tg_xxzzzz_xxxyyyyy_0[j] = pb_x * tg_xzzzz_xxxyyyyy_0[j] + fr * tg_xzzzz_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyyy_0[j] - tg_zzzz_xxxyyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxyyyyy_1[j];

                    tg_xxzzzz_xxxyyyyz_0[j] = pb_x * tg_xzzzz_xxxyyyyz_0[j] + fr * tg_xzzzz_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyyz_0[j] - tg_zzzz_xxxyyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxyyyyz_1[j];

                    tg_xxzzzz_xxxyyyzz_0[j] = pb_x * tg_xzzzz_xxxyyyzz_0[j] + fr * tg_xzzzz_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyzz_0[j] - tg_zzzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxyyyzz_1[j];

                    tg_xxzzzz_xxxyyzzz_0[j] = pb_x * tg_xzzzz_xxxyyzzz_0[j] + fr * tg_xzzzz_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyzzz_0[j] - tg_zzzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxyyzzz_1[j];

                    tg_xxzzzz_xxxyzzzz_0[j] = pb_x * tg_xzzzz_xxxyzzzz_0[j] + fr * tg_xzzzz_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyzzzz_0[j] - tg_zzzz_xxxyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxyzzzz_1[j];

                    tg_xxzzzz_xxxzzzzz_0[j] = pb_x * tg_xzzzz_xxxzzzzz_0[j] + fr * tg_xzzzz_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxzzzzz_0[j] - tg_zzzz_xxxzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzz_xxzzzzz_1[j];

                    tg_xxzzzz_xxyyyyyy_0[j] = pb_x * tg_xzzzz_xxyyyyyy_0[j] + fr * tg_xzzzz_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyyy_0[j] - tg_zzzz_xxyyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyyyyyy_1[j];

                    tg_xxzzzz_xxyyyyyz_0[j] = pb_x * tg_xzzzz_xxyyyyyz_0[j] + fr * tg_xzzzz_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyyz_0[j] - tg_zzzz_xxyyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyyyyyz_1[j];

                    tg_xxzzzz_xxyyyyzz_0[j] = pb_x * tg_xzzzz_xxyyyyzz_0[j] + fr * tg_xzzzz_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyzz_0[j] - tg_zzzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyyyyzz_1[j];

                    tg_xxzzzz_xxyyyzzz_0[j] = pb_x * tg_xzzzz_xxyyyzzz_0[j] + fr * tg_xzzzz_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyzzz_0[j] - tg_zzzz_xxyyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyyyzzz_1[j];

                    tg_xxzzzz_xxyyzzzz_0[j] = pb_x * tg_xzzzz_xxyyzzzz_0[j] + fr * tg_xzzzz_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyzzzz_0[j] - tg_zzzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyyzzzz_1[j];

                    tg_xxzzzz_xxyzzzzz_0[j] = pb_x * tg_xzzzz_xxyzzzzz_0[j] + fr * tg_xzzzz_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyzzzzz_0[j] - tg_zzzz_xxyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xyzzzzz_1[j];

                    tg_xxzzzz_xxzzzzzz_0[j] = pb_x * tg_xzzzz_xxzzzzzz_0[j] + fr * tg_xzzzz_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxzzzzzz_0[j] - tg_zzzz_xxzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzz_xzzzzzz_1[j];

                    tg_xxzzzz_xyyyyyyy_0[j] = pb_x * tg_xzzzz_xyyyyyyy_0[j] + fr * tg_xzzzz_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyyy_0[j] - tg_zzzz_xyyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyyyyyy_1[j];

                    tg_xxzzzz_xyyyyyyz_0[j] = pb_x * tg_xzzzz_xyyyyyyz_0[j] + fr * tg_xzzzz_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyyz_0[j] - tg_zzzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyyyyyz_1[j];

                    tg_xxzzzz_xyyyyyzz_0[j] = pb_x * tg_xzzzz_xyyyyyzz_0[j] + fr * tg_xzzzz_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyzz_0[j] - tg_zzzz_xyyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyyyyzz_1[j];

                    tg_xxzzzz_xyyyyzzz_0[j] = pb_x * tg_xzzzz_xyyyyzzz_0[j] + fr * tg_xzzzz_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyzzz_0[j] - tg_zzzz_xyyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyyyzzz_1[j];

                    tg_xxzzzz_xyyyzzzz_0[j] = pb_x * tg_xzzzz_xyyyzzzz_0[j] + fr * tg_xzzzz_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyzzzz_0[j] - tg_zzzz_xyyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyyzzzz_1[j];

                    tg_xxzzzz_xyyzzzzz_0[j] = pb_x * tg_xzzzz_xyyzzzzz_0[j] + fr * tg_xzzzz_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyzzzzz_0[j] - tg_zzzz_xyyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yyzzzzz_1[j];

                    tg_xxzzzz_xyzzzzzz_0[j] = pb_x * tg_xzzzz_xyzzzzzz_0[j] + fr * tg_xzzzz_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyzzzzzz_0[j] - tg_zzzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_yzzzzzz_1[j];

                    tg_xxzzzz_xzzzzzzz_0[j] = pb_x * tg_xzzzz_xzzzzzzz_0[j] + fr * tg_xzzzz_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xzzzzzzz_0[j] - tg_zzzz_xzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzz_zzzzzzz_1[j];

                    tg_xxzzzz_yyyyyyyy_0[j] = pb_x * tg_xzzzz_yyyyyyyy_0[j] + fr * tg_xzzzz_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyyy_0[j] - tg_zzzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_xxzzzz_yyyyyyyz_0[j] = pb_x * tg_xzzzz_yyyyyyyz_0[j] + fr * tg_xzzzz_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyyz_0[j] - tg_zzzz_yyyyyyyz_1[j] * fl1_fza);

                    tg_xxzzzz_yyyyyyzz_0[j] = pb_x * tg_xzzzz_yyyyyyzz_0[j] + fr * tg_xzzzz_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyzz_0[j] - tg_zzzz_yyyyyyzz_1[j] * fl1_fza);

                    tg_xxzzzz_yyyyyzzz_0[j] = pb_x * tg_xzzzz_yyyyyzzz_0[j] + fr * tg_xzzzz_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyzzz_0[j] - tg_zzzz_yyyyyzzz_1[j] * fl1_fza);

                    tg_xxzzzz_yyyyzzzz_0[j] = pb_x * tg_xzzzz_yyyyzzzz_0[j] + fr * tg_xzzzz_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyzzzz_0[j] - tg_zzzz_yyyyzzzz_1[j] * fl1_fza);

                    tg_xxzzzz_yyyzzzzz_0[j] = pb_x * tg_xzzzz_yyyzzzzz_0[j] + fr * tg_xzzzz_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyzzzzz_0[j] - tg_zzzz_yyyzzzzz_1[j] * fl1_fza);

                    tg_xxzzzz_yyzzzzzz_0[j] = pb_x * tg_xzzzz_yyzzzzzz_0[j] + fr * tg_xzzzz_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyzzzzzz_0[j] - tg_zzzz_yyzzzzzz_1[j] * fl1_fza);

                    tg_xxzzzz_yzzzzzzz_0[j] = pb_x * tg_xzzzz_yzzzzzzz_0[j] + fr * tg_xzzzz_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yzzzzzzz_0[j] - tg_zzzz_yzzzzzzz_1[j] * fl1_fza);

                    tg_xxzzzz_zzzzzzzz_0[j] = pb_x * tg_xzzzz_zzzzzzzz_0[j] + fr * tg_xzzzz_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_zzzzzzzz_0[j] - tg_zzzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_xyyyyy_xxxxxxxx_0[j] = pb_x * tg_yyyyy_xxxxxxxx_0[j] + fr * tg_yyyyy_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_yyyyy_xxxxxxx_1[j];

                    tg_xyyyyy_xxxxxxxy_0[j] = pb_x * tg_yyyyy_xxxxxxxy_0[j] + fr * tg_yyyyy_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_yyyyy_xxxxxxy_1[j];

                    tg_xyyyyy_xxxxxxxz_0[j] = pb_x * tg_yyyyy_xxxxxxxz_0[j] + fr * tg_yyyyy_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_yyyyy_xxxxxxz_1[j];

                    tg_xyyyyy_xxxxxxyy_0[j] = pb_x * tg_yyyyy_xxxxxxyy_0[j] + fr * tg_yyyyy_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_yyyyy_xxxxxyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_679_776(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (679,776)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_yyyyy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 679); 

                auto tg_yyyyy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 680); 

                auto tg_yyyyy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 681); 

                auto tg_yyyyy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 682); 

                auto tg_yyyyy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 683); 

                auto tg_yyyyy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 684); 

                auto tg_yyyyy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 685); 

                auto tg_yyyyy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 686); 

                auto tg_yyyyy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 687); 

                auto tg_yyyyy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 688); 

                auto tg_yyyyy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 689); 

                auto tg_yyyyy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 690); 

                auto tg_yyyyy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 691); 

                auto tg_yyyyy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 692); 

                auto tg_yyyyy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 693); 

                auto tg_yyyyy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 694); 

                auto tg_yyyyy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 695); 

                auto tg_yyyyy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 696); 

                auto tg_yyyyy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 697); 

                auto tg_yyyyy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 698); 

                auto tg_yyyyy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 699); 

                auto tg_yyyyy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 700); 

                auto tg_yyyyy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 701); 

                auto tg_yyyyy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 702); 

                auto tg_yyyyy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 703); 

                auto tg_yyyyy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 704); 

                auto tg_yyyyy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 705); 

                auto tg_yyyyy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 706); 

                auto tg_yyyyy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 707); 

                auto tg_yyyyy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 708); 

                auto tg_yyyyy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 709); 

                auto tg_yyyyy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 710); 

                auto tg_yyyyy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 711); 

                auto tg_yyyyy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 712); 

                auto tg_yyyyy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 713); 

                auto tg_yyyyy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 714); 

                auto tg_yyyyy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 715); 

                auto tg_yyyyy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 716); 

                auto tg_yyyyy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 717); 

                auto tg_yyyyy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 718); 

                auto tg_yyyyy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 719); 

                auto tg_yyyyz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 720); 

                auto tg_yyyyz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 721); 

                auto tg_yyyyz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 722); 

                auto tg_yyyyz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 723); 

                auto tg_yyyyz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 724); 

                auto tg_yyyyz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 725); 

                auto tg_yyyyz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 726); 

                auto tg_yyyyz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 727); 

                auto tg_yyyyz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 728); 

                auto tg_yyyyz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 729); 

                auto tg_yyyyz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 730); 

                auto tg_yyyyz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 731); 

                auto tg_yyyyz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 732); 

                auto tg_yyyyz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 733); 

                auto tg_yyyyz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 734); 

                auto tg_yyyyz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 735); 

                auto tg_yyyyz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 736); 

                auto tg_yyyyz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 737); 

                auto tg_yyyyz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 738); 

                auto tg_yyyyz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 739); 

                auto tg_yyyyz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 740); 

                auto tg_yyyyz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 741); 

                auto tg_yyyyz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 742); 

                auto tg_yyyyz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 743); 

                auto tg_yyyyz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 744); 

                auto tg_yyyyz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 745); 

                auto tg_yyyyz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 746); 

                auto tg_yyyyz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 747); 

                auto tg_yyyyz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 748); 

                auto tg_yyyyz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 749); 

                auto tg_yyyyz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 750); 

                auto tg_yyyyz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 751); 

                auto tg_yyyyz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 752); 

                auto tg_yyyyz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 753); 

                auto tg_yyyyz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 754); 

                auto tg_yyyyz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 755); 

                auto tg_yyyyz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 756); 

                auto tg_yyyyz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 757); 

                auto tg_yyyyz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 758); 

                auto tg_yyyyz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 759); 

                auto tg_yyyyz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 760); 

                auto tg_yyyyz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 761); 

                auto tg_yyyyz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 762); 

                auto tg_yyyyz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 763); 

                auto tg_yyyyz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 764); 

                auto tg_yyyzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 765); 

                auto tg_yyyzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 766); 

                auto tg_yyyzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 767); 

                auto tg_yyyzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 768); 

                auto tg_yyyzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 769); 

                auto tg_yyyzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 770); 

                auto tg_yyyzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 771); 

                auto tg_yyyzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 772); 

                auto tg_yyyzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 773); 

                auto tg_yyyzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 774); 

                auto tg_yyyzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 775); 

                auto tg_yyyyy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 679); 

                auto tg_yyyyy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 680); 

                auto tg_yyyyy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 681); 

                auto tg_yyyyy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 682); 

                auto tg_yyyyy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 683); 

                auto tg_yyyyy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 684); 

                auto tg_yyyyy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 685); 

                auto tg_yyyyy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 686); 

                auto tg_yyyyy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 687); 

                auto tg_yyyyy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 688); 

                auto tg_yyyyy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 689); 

                auto tg_yyyyy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 690); 

                auto tg_yyyyy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 691); 

                auto tg_yyyyy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 692); 

                auto tg_yyyyy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 693); 

                auto tg_yyyyy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 694); 

                auto tg_yyyyy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 695); 

                auto tg_yyyyy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 696); 

                auto tg_yyyyy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 697); 

                auto tg_yyyyy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 698); 

                auto tg_yyyyy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 699); 

                auto tg_yyyyy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 700); 

                auto tg_yyyyy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 701); 

                auto tg_yyyyy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 702); 

                auto tg_yyyyy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 703); 

                auto tg_yyyyy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 704); 

                auto tg_yyyyy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 705); 

                auto tg_yyyyy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 706); 

                auto tg_yyyyy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 707); 

                auto tg_yyyyy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 708); 

                auto tg_yyyyy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 709); 

                auto tg_yyyyy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 710); 

                auto tg_yyyyy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 711); 

                auto tg_yyyyy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 712); 

                auto tg_yyyyy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 713); 

                auto tg_yyyyy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 714); 

                auto tg_yyyyy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 715); 

                auto tg_yyyyy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 716); 

                auto tg_yyyyy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 717); 

                auto tg_yyyyy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 718); 

                auto tg_yyyyy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 719); 

                auto tg_yyyyz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 720); 

                auto tg_yyyyz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 721); 

                auto tg_yyyyz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 722); 

                auto tg_yyyyz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 723); 

                auto tg_yyyyz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 724); 

                auto tg_yyyyz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 725); 

                auto tg_yyyyz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 726); 

                auto tg_yyyyz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 727); 

                auto tg_yyyyz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 728); 

                auto tg_yyyyz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 729); 

                auto tg_yyyyz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 730); 

                auto tg_yyyyz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 731); 

                auto tg_yyyyz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 732); 

                auto tg_yyyyz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 733); 

                auto tg_yyyyz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 734); 

                auto tg_yyyyz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 735); 

                auto tg_yyyyz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 736); 

                auto tg_yyyyz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 737); 

                auto tg_yyyyz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 738); 

                auto tg_yyyyz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 739); 

                auto tg_yyyyz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 740); 

                auto tg_yyyyz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 741); 

                auto tg_yyyyz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 742); 

                auto tg_yyyyz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 743); 

                auto tg_yyyyz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 744); 

                auto tg_yyyyz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 745); 

                auto tg_yyyyz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 746); 

                auto tg_yyyyz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 747); 

                auto tg_yyyyz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 748); 

                auto tg_yyyyz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 749); 

                auto tg_yyyyz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 750); 

                auto tg_yyyyz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 751); 

                auto tg_yyyyz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 752); 

                auto tg_yyyyz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 753); 

                auto tg_yyyyz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 754); 

                auto tg_yyyyz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 755); 

                auto tg_yyyyz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 756); 

                auto tg_yyyyz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 757); 

                auto tg_yyyyz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 758); 

                auto tg_yyyyz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 759); 

                auto tg_yyyyz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 760); 

                auto tg_yyyyz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 761); 

                auto tg_yyyyz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 762); 

                auto tg_yyyyz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 763); 

                auto tg_yyyyz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 764); 

                auto tg_yyyzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 765); 

                auto tg_yyyzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 766); 

                auto tg_yyyzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 767); 

                auto tg_yyyzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 768); 

                auto tg_yyyzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 769); 

                auto tg_yyyzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 770); 

                auto tg_yyyzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 771); 

                auto tg_yyyzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 772); 

                auto tg_yyyzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 773); 

                auto tg_yyyzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 774); 

                auto tg_yyyzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 775); 

                auto tg_yyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 558); 

                auto tg_yyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 599); 

                auto tg_yyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 622); 

                // set up pointers to integrals

                auto tg_xyyyyy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 679); 

                auto tg_xyyyyy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 680); 

                auto tg_xyyyyy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 681); 

                auto tg_xyyyyy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 682); 

                auto tg_xyyyyy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 683); 

                auto tg_xyyyyy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 684); 

                auto tg_xyyyyy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 685); 

                auto tg_xyyyyy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 686); 

                auto tg_xyyyyy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 687); 

                auto tg_xyyyyy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 688); 

                auto tg_xyyyyy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 689); 

                auto tg_xyyyyy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 690); 

                auto tg_xyyyyy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 691); 

                auto tg_xyyyyy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 692); 

                auto tg_xyyyyy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 693); 

                auto tg_xyyyyy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 694); 

                auto tg_xyyyyy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 695); 

                auto tg_xyyyyy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 696); 

                auto tg_xyyyyy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 697); 

                auto tg_xyyyyy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 698); 

                auto tg_xyyyyy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 699); 

                auto tg_xyyyyy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 700); 

                auto tg_xyyyyy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 701); 

                auto tg_xyyyyy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 702); 

                auto tg_xyyyyy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 703); 

                auto tg_xyyyyy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 704); 

                auto tg_xyyyyy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 705); 

                auto tg_xyyyyy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 706); 

                auto tg_xyyyyy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 707); 

                auto tg_xyyyyy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 708); 

                auto tg_xyyyyy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 709); 

                auto tg_xyyyyy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 710); 

                auto tg_xyyyyy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 711); 

                auto tg_xyyyyy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 712); 

                auto tg_xyyyyy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 713); 

                auto tg_xyyyyy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 714); 

                auto tg_xyyyyy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 715); 

                auto tg_xyyyyy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 716); 

                auto tg_xyyyyy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 717); 

                auto tg_xyyyyy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 718); 

                auto tg_xyyyyy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 719); 

                auto tg_xyyyyz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 720); 

                auto tg_xyyyyz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 721); 

                auto tg_xyyyyz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 722); 

                auto tg_xyyyyz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 723); 

                auto tg_xyyyyz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 724); 

                auto tg_xyyyyz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 725); 

                auto tg_xyyyyz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 726); 

                auto tg_xyyyyz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 727); 

                auto tg_xyyyyz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 728); 

                auto tg_xyyyyz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 729); 

                auto tg_xyyyyz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 730); 

                auto tg_xyyyyz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 731); 

                auto tg_xyyyyz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 732); 

                auto tg_xyyyyz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 733); 

                auto tg_xyyyyz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 734); 

                auto tg_xyyyyz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 735); 

                auto tg_xyyyyz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 736); 

                auto tg_xyyyyz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 737); 

                auto tg_xyyyyz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 738); 

                auto tg_xyyyyz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 739); 

                auto tg_xyyyyz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 740); 

                auto tg_xyyyyz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 741); 

                auto tg_xyyyyz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 742); 

                auto tg_xyyyyz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 743); 

                auto tg_xyyyyz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 744); 

                auto tg_xyyyyz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 745); 

                auto tg_xyyyyz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 746); 

                auto tg_xyyyyz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 747); 

                auto tg_xyyyyz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 748); 

                auto tg_xyyyyz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 749); 

                auto tg_xyyyyz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 750); 

                auto tg_xyyyyz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 751); 

                auto tg_xyyyyz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 752); 

                auto tg_xyyyyz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 753); 

                auto tg_xyyyyz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 754); 

                auto tg_xyyyyz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 755); 

                auto tg_xyyyyz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 756); 

                auto tg_xyyyyz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 757); 

                auto tg_xyyyyz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 758); 

                auto tg_xyyyyz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 759); 

                auto tg_xyyyyz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 760); 

                auto tg_xyyyyz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 761); 

                auto tg_xyyyyz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 762); 

                auto tg_xyyyyz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 763); 

                auto tg_xyyyyz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 764); 

                auto tg_xyyyzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 765); 

                auto tg_xyyyzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 766); 

                auto tg_xyyyzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 767); 

                auto tg_xyyyzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 768); 

                auto tg_xyyyzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 769); 

                auto tg_xyyyzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 770); 

                auto tg_xyyyzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 771); 

                auto tg_xyyyzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 772); 

                auto tg_xyyyzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 773); 

                auto tg_xyyyzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 774); 

                auto tg_xyyyzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 775); 

                // Batch of Integrals (679,776)

                #pragma omp simd aligned(fxn, tg_xyyyyy_xxxxxxyz_0, tg_xyyyyy_xxxxxxzz_0, \
                                         tg_xyyyyy_xxxxxyyy_0, tg_xyyyyy_xxxxxyyz_0, tg_xyyyyy_xxxxxyzz_0, tg_xyyyyy_xxxxxzzz_0, \
                                         tg_xyyyyy_xxxxyyyy_0, tg_xyyyyy_xxxxyyyz_0, tg_xyyyyy_xxxxyyzz_0, tg_xyyyyy_xxxxyzzz_0, \
                                         tg_xyyyyy_xxxxzzzz_0, tg_xyyyyy_xxxyyyyy_0, tg_xyyyyy_xxxyyyyz_0, tg_xyyyyy_xxxyyyzz_0, \
                                         tg_xyyyyy_xxxyyzzz_0, tg_xyyyyy_xxxyzzzz_0, tg_xyyyyy_xxxzzzzz_0, tg_xyyyyy_xxyyyyyy_0, \
                                         tg_xyyyyy_xxyyyyyz_0, tg_xyyyyy_xxyyyyzz_0, tg_xyyyyy_xxyyyzzz_0, tg_xyyyyy_xxyyzzzz_0, \
                                         tg_xyyyyy_xxyzzzzz_0, tg_xyyyyy_xxzzzzzz_0, tg_xyyyyy_xyyyyyyy_0, tg_xyyyyy_xyyyyyyz_0, \
                                         tg_xyyyyy_xyyyyyzz_0, tg_xyyyyy_xyyyyzzz_0, tg_xyyyyy_xyyyzzzz_0, tg_xyyyyy_xyyzzzzz_0, \
                                         tg_xyyyyy_xyzzzzzz_0, tg_xyyyyy_xzzzzzzz_0, tg_xyyyyy_yyyyyyyy_0, tg_xyyyyy_yyyyyyyz_0, \
                                         tg_xyyyyy_yyyyyyzz_0, tg_xyyyyy_yyyyyzzz_0, tg_xyyyyy_yyyyzzzz_0, tg_xyyyyy_yyyzzzzz_0, \
                                         tg_xyyyyy_yyzzzzzz_0, tg_xyyyyy_yzzzzzzz_0, tg_xyyyyy_zzzzzzzz_0, tg_xyyyyz_xxxxxxxx_0, \
                                         tg_xyyyyz_xxxxxxxy_0, tg_xyyyyz_xxxxxxxz_0, tg_xyyyyz_xxxxxxyy_0, tg_xyyyyz_xxxxxxyz_0, \
                                         tg_xyyyyz_xxxxxxzz_0, tg_xyyyyz_xxxxxyyy_0, tg_xyyyyz_xxxxxyyz_0, tg_xyyyyz_xxxxxyzz_0, \
                                         tg_xyyyyz_xxxxxzzz_0, tg_xyyyyz_xxxxyyyy_0, tg_xyyyyz_xxxxyyyz_0, tg_xyyyyz_xxxxyyzz_0, \
                                         tg_xyyyyz_xxxxyzzz_0, tg_xyyyyz_xxxxzzzz_0, tg_xyyyyz_xxxyyyyy_0, tg_xyyyyz_xxxyyyyz_0, \
                                         tg_xyyyyz_xxxyyyzz_0, tg_xyyyyz_xxxyyzzz_0, tg_xyyyyz_xxxyzzzz_0, tg_xyyyyz_xxxzzzzz_0, \
                                         tg_xyyyyz_xxyyyyyy_0, tg_xyyyyz_xxyyyyyz_0, tg_xyyyyz_xxyyyyzz_0, tg_xyyyyz_xxyyyzzz_0, \
                                         tg_xyyyyz_xxyyzzzz_0, tg_xyyyyz_xxyzzzzz_0, tg_xyyyyz_xxzzzzzz_0, tg_xyyyyz_xyyyyyyy_0, \
                                         tg_xyyyyz_xyyyyyyz_0, tg_xyyyyz_xyyyyyzz_0, tg_xyyyyz_xyyyyzzz_0, tg_xyyyyz_xyyyzzzz_0, \
                                         tg_xyyyyz_xyyzzzzz_0, tg_xyyyyz_xyzzzzzz_0, tg_xyyyyz_xzzzzzzz_0, tg_xyyyyz_yyyyyyyy_0, \
                                         tg_xyyyyz_yyyyyyyz_0, tg_xyyyyz_yyyyyyzz_0, tg_xyyyyz_yyyyyzzz_0, tg_xyyyyz_yyyyzzzz_0, \
                                         tg_xyyyyz_yyyzzzzz_0, tg_xyyyyz_yyzzzzzz_0, tg_xyyyyz_yzzzzzzz_0, tg_xyyyyz_zzzzzzzz_0, \
                                         tg_xyyyzz_xxxxxxxx_0, tg_xyyyzz_xxxxxxxy_0, tg_xyyyzz_xxxxxxxz_0, tg_xyyyzz_xxxxxxyy_0, \
                                         tg_xyyyzz_xxxxxxyz_0, tg_xyyyzz_xxxxxxzz_0, tg_xyyyzz_xxxxxyyy_0, tg_xyyyzz_xxxxxyyz_0, \
                                         tg_xyyyzz_xxxxxyzz_0, tg_xyyyzz_xxxxxzzz_0, tg_xyyyzz_xxxxyyyy_0, tg_yyyyy_xxxxxxyz_0, \
                                         tg_yyyyy_xxxxxxyz_1, tg_yyyyy_xxxxxxzz_0, tg_yyyyy_xxxxxxzz_1, tg_yyyyy_xxxxxyyy_0, \
                                         tg_yyyyy_xxxxxyyy_1, tg_yyyyy_xxxxxyyz_0, tg_yyyyy_xxxxxyyz_1, tg_yyyyy_xxxxxyz_1, \
                                         tg_yyyyy_xxxxxyzz_0, tg_yyyyy_xxxxxyzz_1, tg_yyyyy_xxxxxzz_1, tg_yyyyy_xxxxxzzz_0, \
                                         tg_yyyyy_xxxxxzzz_1, tg_yyyyy_xxxxyyy_1, tg_yyyyy_xxxxyyyy_0, tg_yyyyy_xxxxyyyy_1, \
                                         tg_yyyyy_xxxxyyyz_0, tg_yyyyy_xxxxyyyz_1, tg_yyyyy_xxxxyyz_1, tg_yyyyy_xxxxyyzz_0, \
                                         tg_yyyyy_xxxxyyzz_1, tg_yyyyy_xxxxyzz_1, tg_yyyyy_xxxxyzzz_0, tg_yyyyy_xxxxyzzz_1, \
                                         tg_yyyyy_xxxxzzz_1, tg_yyyyy_xxxxzzzz_0, tg_yyyyy_xxxxzzzz_1, tg_yyyyy_xxxyyyy_1, \
                                         tg_yyyyy_xxxyyyyy_0, tg_yyyyy_xxxyyyyy_1, tg_yyyyy_xxxyyyyz_0, tg_yyyyy_xxxyyyyz_1, \
                                         tg_yyyyy_xxxyyyz_1, tg_yyyyy_xxxyyyzz_0, tg_yyyyy_xxxyyyzz_1, tg_yyyyy_xxxyyzz_1, \
                                         tg_yyyyy_xxxyyzzz_0, tg_yyyyy_xxxyyzzz_1, tg_yyyyy_xxxyzzz_1, tg_yyyyy_xxxyzzzz_0, \
                                         tg_yyyyy_xxxyzzzz_1, tg_yyyyy_xxxzzzz_1, tg_yyyyy_xxxzzzzz_0, tg_yyyyy_xxxzzzzz_1, \
                                         tg_yyyyy_xxyyyyy_1, tg_yyyyy_xxyyyyyy_0, tg_yyyyy_xxyyyyyy_1, tg_yyyyy_xxyyyyyz_0, \
                                         tg_yyyyy_xxyyyyyz_1, tg_yyyyy_xxyyyyz_1, tg_yyyyy_xxyyyyzz_0, tg_yyyyy_xxyyyyzz_1, \
                                         tg_yyyyy_xxyyyzz_1, tg_yyyyy_xxyyyzzz_0, tg_yyyyy_xxyyyzzz_1, tg_yyyyy_xxyyzzz_1, \
                                         tg_yyyyy_xxyyzzzz_0, tg_yyyyy_xxyyzzzz_1, tg_yyyyy_xxyzzzz_1, tg_yyyyy_xxyzzzzz_0, \
                                         tg_yyyyy_xxyzzzzz_1, tg_yyyyy_xxzzzzz_1, tg_yyyyy_xxzzzzzz_0, tg_yyyyy_xxzzzzzz_1, \
                                         tg_yyyyy_xyyyyyy_1, tg_yyyyy_xyyyyyyy_0, tg_yyyyy_xyyyyyyy_1, tg_yyyyy_xyyyyyyz_0, \
                                         tg_yyyyy_xyyyyyyz_1, tg_yyyyy_xyyyyyz_1, tg_yyyyy_xyyyyyzz_0, tg_yyyyy_xyyyyyzz_1, \
                                         tg_yyyyy_xyyyyzz_1, tg_yyyyy_xyyyyzzz_0, tg_yyyyy_xyyyyzzz_1, tg_yyyyy_xyyyzzz_1, \
                                         tg_yyyyy_xyyyzzzz_0, tg_yyyyy_xyyyzzzz_1, tg_yyyyy_xyyzzzz_1, tg_yyyyy_xyyzzzzz_0, \
                                         tg_yyyyy_xyyzzzzz_1, tg_yyyyy_xyzzzzz_1, tg_yyyyy_xyzzzzzz_0, tg_yyyyy_xyzzzzzz_1, \
                                         tg_yyyyy_xzzzzzz_1, tg_yyyyy_xzzzzzzz_0, tg_yyyyy_xzzzzzzz_1, tg_yyyyy_yyyyyyy_1, \
                                         tg_yyyyy_yyyyyyyy_0, tg_yyyyy_yyyyyyyy_1, tg_yyyyy_yyyyyyyz_0, tg_yyyyy_yyyyyyyz_1, \
                                         tg_yyyyy_yyyyyyz_1, tg_yyyyy_yyyyyyzz_0, tg_yyyyy_yyyyyyzz_1, tg_yyyyy_yyyyyzz_1, \
                                         tg_yyyyy_yyyyyzzz_0, tg_yyyyy_yyyyyzzz_1, tg_yyyyy_yyyyzzz_1, tg_yyyyy_yyyyzzzz_0, \
                                         tg_yyyyy_yyyyzzzz_1, tg_yyyyy_yyyzzzz_1, tg_yyyyy_yyyzzzzz_0, tg_yyyyy_yyyzzzzz_1, \
                                         tg_yyyyy_yyzzzzz_1, tg_yyyyy_yyzzzzzz_0, tg_yyyyy_yyzzzzzz_1, tg_yyyyy_yzzzzzz_1, \
                                         tg_yyyyy_yzzzzzzz_0, tg_yyyyy_yzzzzzzz_1, tg_yyyyy_zzzzzzz_1, tg_yyyyy_zzzzzzzz_0, \
                                         tg_yyyyy_zzzzzzzz_1, tg_yyyyz_xxxxxxx_1, tg_yyyyz_xxxxxxxx_0, tg_yyyyz_xxxxxxxx_1, \
                                         tg_yyyyz_xxxxxxxy_0, tg_yyyyz_xxxxxxxy_1, tg_yyyyz_xxxxxxxz_0, tg_yyyyz_xxxxxxxz_1, \
                                         tg_yyyyz_xxxxxxy_1, tg_yyyyz_xxxxxxyy_0, tg_yyyyz_xxxxxxyy_1, tg_yyyyz_xxxxxxyz_0, \
                                         tg_yyyyz_xxxxxxyz_1, tg_yyyyz_xxxxxxz_1, tg_yyyyz_xxxxxxzz_0, tg_yyyyz_xxxxxxzz_1, \
                                         tg_yyyyz_xxxxxyy_1, tg_yyyyz_xxxxxyyy_0, tg_yyyyz_xxxxxyyy_1, tg_yyyyz_xxxxxyyz_0, \
                                         tg_yyyyz_xxxxxyyz_1, tg_yyyyz_xxxxxyz_1, tg_yyyyz_xxxxxyzz_0, tg_yyyyz_xxxxxyzz_1, \
                                         tg_yyyyz_xxxxxzz_1, tg_yyyyz_xxxxxzzz_0, tg_yyyyz_xxxxxzzz_1, tg_yyyyz_xxxxyyy_1, \
                                         tg_yyyyz_xxxxyyyy_0, tg_yyyyz_xxxxyyyy_1, tg_yyyyz_xxxxyyyz_0, tg_yyyyz_xxxxyyyz_1, \
                                         tg_yyyyz_xxxxyyz_1, tg_yyyyz_xxxxyyzz_0, tg_yyyyz_xxxxyyzz_1, tg_yyyyz_xxxxyzz_1, \
                                         tg_yyyyz_xxxxyzzz_0, tg_yyyyz_xxxxyzzz_1, tg_yyyyz_xxxxzzz_1, tg_yyyyz_xxxxzzzz_0, \
                                         tg_yyyyz_xxxxzzzz_1, tg_yyyyz_xxxyyyy_1, tg_yyyyz_xxxyyyyy_0, tg_yyyyz_xxxyyyyy_1, \
                                         tg_yyyyz_xxxyyyyz_0, tg_yyyyz_xxxyyyyz_1, tg_yyyyz_xxxyyyz_1, tg_yyyyz_xxxyyyzz_0, \
                                         tg_yyyyz_xxxyyyzz_1, tg_yyyyz_xxxyyzz_1, tg_yyyyz_xxxyyzzz_0, tg_yyyyz_xxxyyzzz_1, \
                                         tg_yyyyz_xxxyzzz_1, tg_yyyyz_xxxyzzzz_0, tg_yyyyz_xxxyzzzz_1, tg_yyyyz_xxxzzzz_1, \
                                         tg_yyyyz_xxxzzzzz_0, tg_yyyyz_xxxzzzzz_1, tg_yyyyz_xxyyyyy_1, tg_yyyyz_xxyyyyyy_0, \
                                         tg_yyyyz_xxyyyyyy_1, tg_yyyyz_xxyyyyyz_0, tg_yyyyz_xxyyyyyz_1, tg_yyyyz_xxyyyyz_1, \
                                         tg_yyyyz_xxyyyyzz_0, tg_yyyyz_xxyyyyzz_1, tg_yyyyz_xxyyyzz_1, tg_yyyyz_xxyyyzzz_0, \
                                         tg_yyyyz_xxyyyzzz_1, tg_yyyyz_xxyyzzz_1, tg_yyyyz_xxyyzzzz_0, tg_yyyyz_xxyyzzzz_1, \
                                         tg_yyyyz_xxyzzzz_1, tg_yyyyz_xxyzzzzz_0, tg_yyyyz_xxyzzzzz_1, tg_yyyyz_xxzzzzz_1, \
                                         tg_yyyyz_xxzzzzzz_0, tg_yyyyz_xxzzzzzz_1, tg_yyyyz_xyyyyyy_1, tg_yyyyz_xyyyyyyy_0, \
                                         tg_yyyyz_xyyyyyyy_1, tg_yyyyz_xyyyyyyz_0, tg_yyyyz_xyyyyyyz_1, tg_yyyyz_xyyyyyz_1, \
                                         tg_yyyyz_xyyyyyzz_0, tg_yyyyz_xyyyyyzz_1, tg_yyyyz_xyyyyzz_1, tg_yyyyz_xyyyyzzz_0, \
                                         tg_yyyyz_xyyyyzzz_1, tg_yyyyz_xyyyzzz_1, tg_yyyyz_xyyyzzzz_0, tg_yyyyz_xyyyzzzz_1, \
                                         tg_yyyyz_xyyzzzz_1, tg_yyyyz_xyyzzzzz_0, tg_yyyyz_xyyzzzzz_1, tg_yyyyz_xyzzzzz_1, \
                                         tg_yyyyz_xyzzzzzz_0, tg_yyyyz_xyzzzzzz_1, tg_yyyyz_xzzzzzz_1, tg_yyyyz_xzzzzzzz_0, \
                                         tg_yyyyz_xzzzzzzz_1, tg_yyyyz_yyyyyyy_1, tg_yyyyz_yyyyyyyy_0, tg_yyyyz_yyyyyyyy_1, \
                                         tg_yyyyz_yyyyyyyz_0, tg_yyyyz_yyyyyyyz_1, tg_yyyyz_yyyyyyz_1, tg_yyyyz_yyyyyyzz_0, \
                                         tg_yyyyz_yyyyyyzz_1, tg_yyyyz_yyyyyzz_1, tg_yyyyz_yyyyyzzz_0, tg_yyyyz_yyyyyzzz_1, \
                                         tg_yyyyz_yyyyzzz_1, tg_yyyyz_yyyyzzzz_0, tg_yyyyz_yyyyzzzz_1, tg_yyyyz_yyyzzzz_1, \
                                         tg_yyyyz_yyyzzzzz_0, tg_yyyyz_yyyzzzzz_1, tg_yyyyz_yyzzzzz_1, tg_yyyyz_yyzzzzzz_0, \
                                         tg_yyyyz_yyzzzzzz_1, tg_yyyyz_yzzzzzz_1, tg_yyyyz_yzzzzzzz_0, tg_yyyyz_yzzzzzzz_1, \
                                         tg_yyyyz_zzzzzzz_1, tg_yyyyz_zzzzzzzz_0, tg_yyyyz_zzzzzzzz_1, tg_yyyzz_xxxxxxx_1, \
                                         tg_yyyzz_xxxxxxxx_0, tg_yyyzz_xxxxxxxx_1, tg_yyyzz_xxxxxxxy_0, tg_yyyzz_xxxxxxxy_1, \
                                         tg_yyyzz_xxxxxxxz_0, tg_yyyzz_xxxxxxxz_1, tg_yyyzz_xxxxxxy_1, tg_yyyzz_xxxxxxyy_0, \
                                         tg_yyyzz_xxxxxxyy_1, tg_yyyzz_xxxxxxyz_0, tg_yyyzz_xxxxxxyz_1, tg_yyyzz_xxxxxxz_1, \
                                         tg_yyyzz_xxxxxxzz_0, tg_yyyzz_xxxxxxzz_1, tg_yyyzz_xxxxxyy_1, tg_yyyzz_xxxxxyyy_0, \
                                         tg_yyyzz_xxxxxyyy_1, tg_yyyzz_xxxxxyyz_0, tg_yyyzz_xxxxxyyz_1, tg_yyyzz_xxxxxyz_1, \
                                         tg_yyyzz_xxxxxyzz_0, tg_yyyzz_xxxxxyzz_1, tg_yyyzz_xxxxxzz_1, tg_yyyzz_xxxxxzzz_0, \
                                         tg_yyyzz_xxxxxzzz_1, tg_yyyzz_xxxxyyy_1, tg_yyyzz_xxxxyyyy_0, tg_yyyzz_xxxxyyyy_1, \
                                         tg_yyyzz_xxxxyyz_1, tg_yyyzz_xxxxyzz_1, tg_yyyzz_xxxxzzz_1, tg_yyyzz_xxxyyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fxn = fxn[j];

                    double fr = wp_x[j]; 

                    tg_xyyyyy_xxxxxxyz_0[j] = pb_x * tg_yyyyy_xxxxxxyz_0[j] + fr * tg_yyyyy_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_yyyyy_xxxxxyz_1[j];

                    tg_xyyyyy_xxxxxxzz_0[j] = pb_x * tg_yyyyy_xxxxxxzz_0[j] + fr * tg_yyyyy_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_yyyyy_xxxxxzz_1[j];

                    tg_xyyyyy_xxxxxyyy_0[j] = pb_x * tg_yyyyy_xxxxxyyy_0[j] + fr * tg_yyyyy_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_yyyyy_xxxxyyy_1[j];

                    tg_xyyyyy_xxxxxyyz_0[j] = pb_x * tg_yyyyy_xxxxxyyz_0[j] + fr * tg_yyyyy_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_yyyyy_xxxxyyz_1[j];

                    tg_xyyyyy_xxxxxyzz_0[j] = pb_x * tg_yyyyy_xxxxxyzz_0[j] + fr * tg_yyyyy_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_yyyyy_xxxxyzz_1[j];

                    tg_xyyyyy_xxxxxzzz_0[j] = pb_x * tg_yyyyy_xxxxxzzz_0[j] + fr * tg_yyyyy_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_yyyyy_xxxxzzz_1[j];

                    tg_xyyyyy_xxxxyyyy_0[j] = pb_x * tg_yyyyy_xxxxyyyy_0[j] + fr * tg_yyyyy_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_yyyyy_xxxyyyy_1[j];

                    tg_xyyyyy_xxxxyyyz_0[j] = pb_x * tg_yyyyy_xxxxyyyz_0[j] + fr * tg_yyyyy_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_yyyyy_xxxyyyz_1[j];

                    tg_xyyyyy_xxxxyyzz_0[j] = pb_x * tg_yyyyy_xxxxyyzz_0[j] + fr * tg_yyyyy_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_yyyyy_xxxyyzz_1[j];

                    tg_xyyyyy_xxxxyzzz_0[j] = pb_x * tg_yyyyy_xxxxyzzz_0[j] + fr * tg_yyyyy_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyy_xxxyzzz_1[j];

                    tg_xyyyyy_xxxxzzzz_0[j] = pb_x * tg_yyyyy_xxxxzzzz_0[j] + fr * tg_yyyyy_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyy_xxxzzzz_1[j];

                    tg_xyyyyy_xxxyyyyy_0[j] = pb_x * tg_yyyyy_xxxyyyyy_0[j] + fr * tg_yyyyy_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxyyyyy_1[j];

                    tg_xyyyyy_xxxyyyyz_0[j] = pb_x * tg_yyyyy_xxxyyyyz_0[j] + fr * tg_yyyyy_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxyyyyz_1[j];

                    tg_xyyyyy_xxxyyyzz_0[j] = pb_x * tg_yyyyy_xxxyyyzz_0[j] + fr * tg_yyyyy_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxyyyzz_1[j];

                    tg_xyyyyy_xxxyyzzz_0[j] = pb_x * tg_yyyyy_xxxyyzzz_0[j] + fr * tg_yyyyy_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxyyzzz_1[j];

                    tg_xyyyyy_xxxyzzzz_0[j] = pb_x * tg_yyyyy_xxxyzzzz_0[j] + fr * tg_yyyyy_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxyzzzz_1[j];

                    tg_xyyyyy_xxxzzzzz_0[j] = pb_x * tg_yyyyy_xxxzzzzz_0[j] + fr * tg_yyyyy_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyy_xxzzzzz_1[j];

                    tg_xyyyyy_xxyyyyyy_0[j] = pb_x * tg_yyyyy_xxyyyyyy_0[j] + fr * tg_yyyyy_xxyyyyyy_1[j] + fl1_fxn * tg_yyyyy_xyyyyyy_1[j];

                    tg_xyyyyy_xxyyyyyz_0[j] = pb_x * tg_yyyyy_xxyyyyyz_0[j] + fr * tg_yyyyy_xxyyyyyz_1[j] + fl1_fxn * tg_yyyyy_xyyyyyz_1[j];

                    tg_xyyyyy_xxyyyyzz_0[j] = pb_x * tg_yyyyy_xxyyyyzz_0[j] + fr * tg_yyyyy_xxyyyyzz_1[j] + fl1_fxn * tg_yyyyy_xyyyyzz_1[j];

                    tg_xyyyyy_xxyyyzzz_0[j] = pb_x * tg_yyyyy_xxyyyzzz_0[j] + fr * tg_yyyyy_xxyyyzzz_1[j] + fl1_fxn * tg_yyyyy_xyyyzzz_1[j];

                    tg_xyyyyy_xxyyzzzz_0[j] = pb_x * tg_yyyyy_xxyyzzzz_0[j] + fr * tg_yyyyy_xxyyzzzz_1[j] + fl1_fxn * tg_yyyyy_xyyzzzz_1[j];

                    tg_xyyyyy_xxyzzzzz_0[j] = pb_x * tg_yyyyy_xxyzzzzz_0[j] + fr * tg_yyyyy_xxyzzzzz_1[j] + fl1_fxn * tg_yyyyy_xyzzzzz_1[j];

                    tg_xyyyyy_xxzzzzzz_0[j] = pb_x * tg_yyyyy_xxzzzzzz_0[j] + fr * tg_yyyyy_xxzzzzzz_1[j] + fl1_fxn * tg_yyyyy_xzzzzzz_1[j];

                    tg_xyyyyy_xyyyyyyy_0[j] = pb_x * tg_yyyyy_xyyyyyyy_0[j] + fr * tg_yyyyy_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyyyyyy_1[j];

                    tg_xyyyyy_xyyyyyyz_0[j] = pb_x * tg_yyyyy_xyyyyyyz_0[j] + fr * tg_yyyyy_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyyyyyz_1[j];

                    tg_xyyyyy_xyyyyyzz_0[j] = pb_x * tg_yyyyy_xyyyyyzz_0[j] + fr * tg_yyyyy_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyyyyzz_1[j];

                    tg_xyyyyy_xyyyyzzz_0[j] = pb_x * tg_yyyyy_xyyyyzzz_0[j] + fr * tg_yyyyy_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyyyzzz_1[j];

                    tg_xyyyyy_xyyyzzzz_0[j] = pb_x * tg_yyyyy_xyyyzzzz_0[j] + fr * tg_yyyyy_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyyzzzz_1[j];

                    tg_xyyyyy_xyyzzzzz_0[j] = pb_x * tg_yyyyy_xyyzzzzz_0[j] + fr * tg_yyyyy_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yyzzzzz_1[j];

                    tg_xyyyyy_xyzzzzzz_0[j] = pb_x * tg_yyyyy_xyzzzzzz_0[j] + fr * tg_yyyyy_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_yzzzzzz_1[j];

                    tg_xyyyyy_xzzzzzzz_0[j] = pb_x * tg_yyyyy_xzzzzzzz_0[j] + fr * tg_yyyyy_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyy_zzzzzzz_1[j];

                    tg_xyyyyy_yyyyyyyy_0[j] = pb_x * tg_yyyyy_yyyyyyyy_0[j] + fr * tg_yyyyy_yyyyyyyy_1[j];

                    tg_xyyyyy_yyyyyyyz_0[j] = pb_x * tg_yyyyy_yyyyyyyz_0[j] + fr * tg_yyyyy_yyyyyyyz_1[j];

                    tg_xyyyyy_yyyyyyzz_0[j] = pb_x * tg_yyyyy_yyyyyyzz_0[j] + fr * tg_yyyyy_yyyyyyzz_1[j];

                    tg_xyyyyy_yyyyyzzz_0[j] = pb_x * tg_yyyyy_yyyyyzzz_0[j] + fr * tg_yyyyy_yyyyyzzz_1[j];

                    tg_xyyyyy_yyyyzzzz_0[j] = pb_x * tg_yyyyy_yyyyzzzz_0[j] + fr * tg_yyyyy_yyyyzzzz_1[j];

                    tg_xyyyyy_yyyzzzzz_0[j] = pb_x * tg_yyyyy_yyyzzzzz_0[j] + fr * tg_yyyyy_yyyzzzzz_1[j];

                    tg_xyyyyy_yyzzzzzz_0[j] = pb_x * tg_yyyyy_yyzzzzzz_0[j] + fr * tg_yyyyy_yyzzzzzz_1[j];

                    tg_xyyyyy_yzzzzzzz_0[j] = pb_x * tg_yyyyy_yzzzzzzz_0[j] + fr * tg_yyyyy_yzzzzzzz_1[j];

                    tg_xyyyyy_zzzzzzzz_0[j] = pb_x * tg_yyyyy_zzzzzzzz_0[j] + fr * tg_yyyyy_zzzzzzzz_1[j];

                    tg_xyyyyz_xxxxxxxx_0[j] = pb_x * tg_yyyyz_xxxxxxxx_0[j] + fr * tg_yyyyz_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_yyyyz_xxxxxxx_1[j];

                    tg_xyyyyz_xxxxxxxy_0[j] = pb_x * tg_yyyyz_xxxxxxxy_0[j] + fr * tg_yyyyz_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_yyyyz_xxxxxxy_1[j];

                    tg_xyyyyz_xxxxxxxz_0[j] = pb_x * tg_yyyyz_xxxxxxxz_0[j] + fr * tg_yyyyz_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_yyyyz_xxxxxxz_1[j];

                    tg_xyyyyz_xxxxxxyy_0[j] = pb_x * tg_yyyyz_xxxxxxyy_0[j] + fr * tg_yyyyz_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_yyyyz_xxxxxyy_1[j];

                    tg_xyyyyz_xxxxxxyz_0[j] = pb_x * tg_yyyyz_xxxxxxyz_0[j] + fr * tg_yyyyz_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_yyyyz_xxxxxyz_1[j];

                    tg_xyyyyz_xxxxxxzz_0[j] = pb_x * tg_yyyyz_xxxxxxzz_0[j] + fr * tg_yyyyz_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_yyyyz_xxxxxzz_1[j];

                    tg_xyyyyz_xxxxxyyy_0[j] = pb_x * tg_yyyyz_xxxxxyyy_0[j] + fr * tg_yyyyz_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_yyyyz_xxxxyyy_1[j];

                    tg_xyyyyz_xxxxxyyz_0[j] = pb_x * tg_yyyyz_xxxxxyyz_0[j] + fr * tg_yyyyz_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_yyyyz_xxxxyyz_1[j];

                    tg_xyyyyz_xxxxxyzz_0[j] = pb_x * tg_yyyyz_xxxxxyzz_0[j] + fr * tg_yyyyz_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_yyyyz_xxxxyzz_1[j];

                    tg_xyyyyz_xxxxxzzz_0[j] = pb_x * tg_yyyyz_xxxxxzzz_0[j] + fr * tg_yyyyz_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_yyyyz_xxxxzzz_1[j];

                    tg_xyyyyz_xxxxyyyy_0[j] = pb_x * tg_yyyyz_xxxxyyyy_0[j] + fr * tg_yyyyz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_yyyyz_xxxyyyy_1[j];

                    tg_xyyyyz_xxxxyyyz_0[j] = pb_x * tg_yyyyz_xxxxyyyz_0[j] + fr * tg_yyyyz_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_yyyyz_xxxyyyz_1[j];

                    tg_xyyyyz_xxxxyyzz_0[j] = pb_x * tg_yyyyz_xxxxyyzz_0[j] + fr * tg_yyyyz_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_yyyyz_xxxyyzz_1[j];

                    tg_xyyyyz_xxxxyzzz_0[j] = pb_x * tg_yyyyz_xxxxyzzz_0[j] + fr * tg_yyyyz_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyz_xxxyzzz_1[j];

                    tg_xyyyyz_xxxxzzzz_0[j] = pb_x * tg_yyyyz_xxxxzzzz_0[j] + fr * tg_yyyyz_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyz_xxxzzzz_1[j];

                    tg_xyyyyz_xxxyyyyy_0[j] = pb_x * tg_yyyyz_xxxyyyyy_0[j] + fr * tg_yyyyz_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxyyyyy_1[j];

                    tg_xyyyyz_xxxyyyyz_0[j] = pb_x * tg_yyyyz_xxxyyyyz_0[j] + fr * tg_yyyyz_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxyyyyz_1[j];

                    tg_xyyyyz_xxxyyyzz_0[j] = pb_x * tg_yyyyz_xxxyyyzz_0[j] + fr * tg_yyyyz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxyyyzz_1[j];

                    tg_xyyyyz_xxxyyzzz_0[j] = pb_x * tg_yyyyz_xxxyyzzz_0[j] + fr * tg_yyyyz_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxyyzzz_1[j];

                    tg_xyyyyz_xxxyzzzz_0[j] = pb_x * tg_yyyyz_xxxyzzzz_0[j] + fr * tg_yyyyz_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxyzzzz_1[j];

                    tg_xyyyyz_xxxzzzzz_0[j] = pb_x * tg_yyyyz_xxxzzzzz_0[j] + fr * tg_yyyyz_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyz_xxzzzzz_1[j];

                    tg_xyyyyz_xxyyyyyy_0[j] = pb_x * tg_yyyyz_xxyyyyyy_0[j] + fr * tg_yyyyz_xxyyyyyy_1[j] + fl1_fxn * tg_yyyyz_xyyyyyy_1[j];

                    tg_xyyyyz_xxyyyyyz_0[j] = pb_x * tg_yyyyz_xxyyyyyz_0[j] + fr * tg_yyyyz_xxyyyyyz_1[j] + fl1_fxn * tg_yyyyz_xyyyyyz_1[j];

                    tg_xyyyyz_xxyyyyzz_0[j] = pb_x * tg_yyyyz_xxyyyyzz_0[j] + fr * tg_yyyyz_xxyyyyzz_1[j] + fl1_fxn * tg_yyyyz_xyyyyzz_1[j];

                    tg_xyyyyz_xxyyyzzz_0[j] = pb_x * tg_yyyyz_xxyyyzzz_0[j] + fr * tg_yyyyz_xxyyyzzz_1[j] + fl1_fxn * tg_yyyyz_xyyyzzz_1[j];

                    tg_xyyyyz_xxyyzzzz_0[j] = pb_x * tg_yyyyz_xxyyzzzz_0[j] + fr * tg_yyyyz_xxyyzzzz_1[j] + fl1_fxn * tg_yyyyz_xyyzzzz_1[j];

                    tg_xyyyyz_xxyzzzzz_0[j] = pb_x * tg_yyyyz_xxyzzzzz_0[j] + fr * tg_yyyyz_xxyzzzzz_1[j] + fl1_fxn * tg_yyyyz_xyzzzzz_1[j];

                    tg_xyyyyz_xxzzzzzz_0[j] = pb_x * tg_yyyyz_xxzzzzzz_0[j] + fr * tg_yyyyz_xxzzzzzz_1[j] + fl1_fxn * tg_yyyyz_xzzzzzz_1[j];

                    tg_xyyyyz_xyyyyyyy_0[j] = pb_x * tg_yyyyz_xyyyyyyy_0[j] + fr * tg_yyyyz_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyyyyyy_1[j];

                    tg_xyyyyz_xyyyyyyz_0[j] = pb_x * tg_yyyyz_xyyyyyyz_0[j] + fr * tg_yyyyz_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyyyyyz_1[j];

                    tg_xyyyyz_xyyyyyzz_0[j] = pb_x * tg_yyyyz_xyyyyyzz_0[j] + fr * tg_yyyyz_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyyyyzz_1[j];

                    tg_xyyyyz_xyyyyzzz_0[j] = pb_x * tg_yyyyz_xyyyyzzz_0[j] + fr * tg_yyyyz_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyyyzzz_1[j];

                    tg_xyyyyz_xyyyzzzz_0[j] = pb_x * tg_yyyyz_xyyyzzzz_0[j] + fr * tg_yyyyz_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyyzzzz_1[j];

                    tg_xyyyyz_xyyzzzzz_0[j] = pb_x * tg_yyyyz_xyyzzzzz_0[j] + fr * tg_yyyyz_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yyzzzzz_1[j];

                    tg_xyyyyz_xyzzzzzz_0[j] = pb_x * tg_yyyyz_xyzzzzzz_0[j] + fr * tg_yyyyz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_yzzzzzz_1[j];

                    tg_xyyyyz_xzzzzzzz_0[j] = pb_x * tg_yyyyz_xzzzzzzz_0[j] + fr * tg_yyyyz_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyz_zzzzzzz_1[j];

                    tg_xyyyyz_yyyyyyyy_0[j] = pb_x * tg_yyyyz_yyyyyyyy_0[j] + fr * tg_yyyyz_yyyyyyyy_1[j];

                    tg_xyyyyz_yyyyyyyz_0[j] = pb_x * tg_yyyyz_yyyyyyyz_0[j] + fr * tg_yyyyz_yyyyyyyz_1[j];

                    tg_xyyyyz_yyyyyyzz_0[j] = pb_x * tg_yyyyz_yyyyyyzz_0[j] + fr * tg_yyyyz_yyyyyyzz_1[j];

                    tg_xyyyyz_yyyyyzzz_0[j] = pb_x * tg_yyyyz_yyyyyzzz_0[j] + fr * tg_yyyyz_yyyyyzzz_1[j];

                    tg_xyyyyz_yyyyzzzz_0[j] = pb_x * tg_yyyyz_yyyyzzzz_0[j] + fr * tg_yyyyz_yyyyzzzz_1[j];

                    tg_xyyyyz_yyyzzzzz_0[j] = pb_x * tg_yyyyz_yyyzzzzz_0[j] + fr * tg_yyyyz_yyyzzzzz_1[j];

                    tg_xyyyyz_yyzzzzzz_0[j] = pb_x * tg_yyyyz_yyzzzzzz_0[j] + fr * tg_yyyyz_yyzzzzzz_1[j];

                    tg_xyyyyz_yzzzzzzz_0[j] = pb_x * tg_yyyyz_yzzzzzzz_0[j] + fr * tg_yyyyz_yzzzzzzz_1[j];

                    tg_xyyyyz_zzzzzzzz_0[j] = pb_x * tg_yyyyz_zzzzzzzz_0[j] + fr * tg_yyyyz_zzzzzzzz_1[j];

                    tg_xyyyzz_xxxxxxxx_0[j] = pb_x * tg_yyyzz_xxxxxxxx_0[j] + fr * tg_yyyzz_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_yyyzz_xxxxxxx_1[j];

                    tg_xyyyzz_xxxxxxxy_0[j] = pb_x * tg_yyyzz_xxxxxxxy_0[j] + fr * tg_yyyzz_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_yyyzz_xxxxxxy_1[j];

                    tg_xyyyzz_xxxxxxxz_0[j] = pb_x * tg_yyyzz_xxxxxxxz_0[j] + fr * tg_yyyzz_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_yyyzz_xxxxxxz_1[j];

                    tg_xyyyzz_xxxxxxyy_0[j] = pb_x * tg_yyyzz_xxxxxxyy_0[j] + fr * tg_yyyzz_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_yyyzz_xxxxxyy_1[j];

                    tg_xyyyzz_xxxxxxyz_0[j] = pb_x * tg_yyyzz_xxxxxxyz_0[j] + fr * tg_yyyzz_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_yyyzz_xxxxxyz_1[j];

                    tg_xyyyzz_xxxxxxzz_0[j] = pb_x * tg_yyyzz_xxxxxxzz_0[j] + fr * tg_yyyzz_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_yyyzz_xxxxxzz_1[j];

                    tg_xyyyzz_xxxxxyyy_0[j] = pb_x * tg_yyyzz_xxxxxyyy_0[j] + fr * tg_yyyzz_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_yyyzz_xxxxyyy_1[j];

                    tg_xyyyzz_xxxxxyyz_0[j] = pb_x * tg_yyyzz_xxxxxyyz_0[j] + fr * tg_yyyzz_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_yyyzz_xxxxyyz_1[j];

                    tg_xyyyzz_xxxxxyzz_0[j] = pb_x * tg_yyyzz_xxxxxyzz_0[j] + fr * tg_yyyzz_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_yyyzz_xxxxyzz_1[j];

                    tg_xyyyzz_xxxxxzzz_0[j] = pb_x * tg_yyyzz_xxxxxzzz_0[j] + fr * tg_yyyzz_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_yyyzz_xxxxzzz_1[j];

                    tg_xyyyzz_xxxxyyyy_0[j] = pb_x * tg_yyyzz_xxxxyyyy_0[j] + fr * tg_yyyzz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_yyyzz_xxxyyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_776_873(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (776,873)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_yyyzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 776); 

                auto tg_yyyzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 777); 

                auto tg_yyyzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 778); 

                auto tg_yyyzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 779); 

                auto tg_yyyzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 780); 

                auto tg_yyyzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 781); 

                auto tg_yyyzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 782); 

                auto tg_yyyzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 783); 

                auto tg_yyyzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 784); 

                auto tg_yyyzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 785); 

                auto tg_yyyzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 786); 

                auto tg_yyyzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 787); 

                auto tg_yyyzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 788); 

                auto tg_yyyzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 789); 

                auto tg_yyyzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 790); 

                auto tg_yyyzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 791); 

                auto tg_yyyzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 792); 

                auto tg_yyyzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 793); 

                auto tg_yyyzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 794); 

                auto tg_yyyzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 795); 

                auto tg_yyyzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 796); 

                auto tg_yyyzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 797); 

                auto tg_yyyzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 798); 

                auto tg_yyyzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 799); 

                auto tg_yyyzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 800); 

                auto tg_yyyzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 801); 

                auto tg_yyyzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 802); 

                auto tg_yyyzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 803); 

                auto tg_yyyzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 804); 

                auto tg_yyyzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 805); 

                auto tg_yyyzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 806); 

                auto tg_yyyzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 807); 

                auto tg_yyyzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 808); 

                auto tg_yyyzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 809); 

                auto tg_yyzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 810); 

                auto tg_yyzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 811); 

                auto tg_yyzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 812); 

                auto tg_yyzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 813); 

                auto tg_yyzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 814); 

                auto tg_yyzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 815); 

                auto tg_yyzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 816); 

                auto tg_yyzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 817); 

                auto tg_yyzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 818); 

                auto tg_yyzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 819); 

                auto tg_yyzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 820); 

                auto tg_yyzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 821); 

                auto tg_yyzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 822); 

                auto tg_yyzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 823); 

                auto tg_yyzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 824); 

                auto tg_yyzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 825); 

                auto tg_yyzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 826); 

                auto tg_yyzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 827); 

                auto tg_yyzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 828); 

                auto tg_yyzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 829); 

                auto tg_yyzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 830); 

                auto tg_yyzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 831); 

                auto tg_yyzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 832); 

                auto tg_yyzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 833); 

                auto tg_yyzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 834); 

                auto tg_yyzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 835); 

                auto tg_yyzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 836); 

                auto tg_yyzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 837); 

                auto tg_yyzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 838); 

                auto tg_yyzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 839); 

                auto tg_yyzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 840); 

                auto tg_yyzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 841); 

                auto tg_yyzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 842); 

                auto tg_yyzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 843); 

                auto tg_yyzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 844); 

                auto tg_yyzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 845); 

                auto tg_yyzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 846); 

                auto tg_yyzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 847); 

                auto tg_yyzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 848); 

                auto tg_yyzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 849); 

                auto tg_yyzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 850); 

                auto tg_yyzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 851); 

                auto tg_yyzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 852); 

                auto tg_yyzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 853); 

                auto tg_yyzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 854); 

                auto tg_yzzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 855); 

                auto tg_yzzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 856); 

                auto tg_yzzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 857); 

                auto tg_yzzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 858); 

                auto tg_yzzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 859); 

                auto tg_yzzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 860); 

                auto tg_yzzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 861); 

                auto tg_yzzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 862); 

                auto tg_yzzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 863); 

                auto tg_yzzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 864); 

                auto tg_yzzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 865); 

                auto tg_yzzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 866); 

                auto tg_yzzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 867); 

                auto tg_yzzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 868); 

                auto tg_yzzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 869); 

                auto tg_yzzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 870); 

                auto tg_yzzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 871); 

                auto tg_yzzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 872); 

                auto tg_yyyzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 776); 

                auto tg_yyyzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 777); 

                auto tg_yyyzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 778); 

                auto tg_yyyzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 779); 

                auto tg_yyyzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 780); 

                auto tg_yyyzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 781); 

                auto tg_yyyzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 782); 

                auto tg_yyyzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 783); 

                auto tg_yyyzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 784); 

                auto tg_yyyzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 785); 

                auto tg_yyyzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 786); 

                auto tg_yyyzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 787); 

                auto tg_yyyzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 788); 

                auto tg_yyyzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 789); 

                auto tg_yyyzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 790); 

                auto tg_yyyzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 791); 

                auto tg_yyyzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 792); 

                auto tg_yyyzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 793); 

                auto tg_yyyzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 794); 

                auto tg_yyyzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 795); 

                auto tg_yyyzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 796); 

                auto tg_yyyzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 797); 

                auto tg_yyyzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 798); 

                auto tg_yyyzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 799); 

                auto tg_yyyzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 800); 

                auto tg_yyyzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 801); 

                auto tg_yyyzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 802); 

                auto tg_yyyzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 803); 

                auto tg_yyyzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 804); 

                auto tg_yyyzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 805); 

                auto tg_yyyzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 806); 

                auto tg_yyyzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 807); 

                auto tg_yyyzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 808); 

                auto tg_yyyzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 809); 

                auto tg_yyzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 810); 

                auto tg_yyzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 811); 

                auto tg_yyzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 812); 

                auto tg_yyzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 813); 

                auto tg_yyzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 814); 

                auto tg_yyzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 815); 

                auto tg_yyzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 816); 

                auto tg_yyzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 817); 

                auto tg_yyzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 818); 

                auto tg_yyzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 819); 

                auto tg_yyzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 820); 

                auto tg_yyzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 821); 

                auto tg_yyzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 822); 

                auto tg_yyzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 823); 

                auto tg_yyzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 824); 

                auto tg_yyzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 825); 

                auto tg_yyzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 826); 

                auto tg_yyzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 827); 

                auto tg_yyzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 828); 

                auto tg_yyzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 829); 

                auto tg_yyzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 830); 

                auto tg_yyzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 831); 

                auto tg_yyzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 832); 

                auto tg_yyzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 833); 

                auto tg_yyzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 834); 

                auto tg_yyzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 835); 

                auto tg_yyzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 836); 

                auto tg_yyzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 837); 

                auto tg_yyzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 838); 

                auto tg_yyzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 839); 

                auto tg_yyzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 840); 

                auto tg_yyzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 841); 

                auto tg_yyzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 842); 

                auto tg_yyzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 843); 

                auto tg_yyzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 844); 

                auto tg_yyzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 845); 

                auto tg_yyzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 846); 

                auto tg_yyzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 847); 

                auto tg_yyzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 848); 

                auto tg_yyzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 849); 

                auto tg_yyzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 850); 

                auto tg_yyzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 851); 

                auto tg_yyzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 852); 

                auto tg_yyzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 853); 

                auto tg_yyzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 854); 

                auto tg_yzzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 855); 

                auto tg_yzzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 856); 

                auto tg_yzzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 857); 

                auto tg_yzzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 858); 

                auto tg_yzzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 859); 

                auto tg_yzzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 860); 

                auto tg_yzzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 861); 

                auto tg_yzzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 862); 

                auto tg_yzzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 863); 

                auto tg_yzzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 864); 

                auto tg_yzzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 865); 

                auto tg_yzzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 866); 

                auto tg_yzzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 867); 

                auto tg_yzzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 868); 

                auto tg_yzzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 869); 

                auto tg_yzzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 870); 

                auto tg_yzzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 871); 

                auto tg_yzzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 872); 

                auto tg_yyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 629); 

                auto tg_yyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 636); 

                auto tg_yyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 699); 

                auto tg_yzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 701); 

                // set up pointers to integrals

                auto tg_xyyyzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 776); 

                auto tg_xyyyzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 777); 

                auto tg_xyyyzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 778); 

                auto tg_xyyyzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 779); 

                auto tg_xyyyzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 780); 

                auto tg_xyyyzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 781); 

                auto tg_xyyyzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 782); 

                auto tg_xyyyzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 783); 

                auto tg_xyyyzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 784); 

                auto tg_xyyyzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 785); 

                auto tg_xyyyzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 786); 

                auto tg_xyyyzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 787); 

                auto tg_xyyyzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 788); 

                auto tg_xyyyzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 789); 

                auto tg_xyyyzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 790); 

                auto tg_xyyyzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 791); 

                auto tg_xyyyzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 792); 

                auto tg_xyyyzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 793); 

                auto tg_xyyyzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 794); 

                auto tg_xyyyzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 795); 

                auto tg_xyyyzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 796); 

                auto tg_xyyyzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 797); 

                auto tg_xyyyzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 798); 

                auto tg_xyyyzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 799); 

                auto tg_xyyyzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 800); 

                auto tg_xyyyzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 801); 

                auto tg_xyyyzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 802); 

                auto tg_xyyyzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 803); 

                auto tg_xyyyzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 804); 

                auto tg_xyyyzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 805); 

                auto tg_xyyyzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 806); 

                auto tg_xyyyzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 807); 

                auto tg_xyyyzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 808); 

                auto tg_xyyyzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 809); 

                auto tg_xyyzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 810); 

                auto tg_xyyzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 811); 

                auto tg_xyyzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 812); 

                auto tg_xyyzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 813); 

                auto tg_xyyzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 814); 

                auto tg_xyyzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 815); 

                auto tg_xyyzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 816); 

                auto tg_xyyzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 817); 

                auto tg_xyyzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 818); 

                auto tg_xyyzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 819); 

                auto tg_xyyzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 820); 

                auto tg_xyyzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 821); 

                auto tg_xyyzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 822); 

                auto tg_xyyzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 823); 

                auto tg_xyyzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 824); 

                auto tg_xyyzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 825); 

                auto tg_xyyzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 826); 

                auto tg_xyyzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 827); 

                auto tg_xyyzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 828); 

                auto tg_xyyzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 829); 

                auto tg_xyyzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 830); 

                auto tg_xyyzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 831); 

                auto tg_xyyzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 832); 

                auto tg_xyyzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 833); 

                auto tg_xyyzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 834); 

                auto tg_xyyzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 835); 

                auto tg_xyyzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 836); 

                auto tg_xyyzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 837); 

                auto tg_xyyzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 838); 

                auto tg_xyyzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 839); 

                auto tg_xyyzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 840); 

                auto tg_xyyzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 841); 

                auto tg_xyyzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 842); 

                auto tg_xyyzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 843); 

                auto tg_xyyzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 844); 

                auto tg_xyyzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 845); 

                auto tg_xyyzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 846); 

                auto tg_xyyzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 847); 

                auto tg_xyyzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 848); 

                auto tg_xyyzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 849); 

                auto tg_xyyzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 850); 

                auto tg_xyyzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 851); 

                auto tg_xyyzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 852); 

                auto tg_xyyzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 853); 

                auto tg_xyyzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 854); 

                auto tg_xyzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 855); 

                auto tg_xyzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 856); 

                auto tg_xyzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 857); 

                auto tg_xyzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 858); 

                auto tg_xyzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 859); 

                auto tg_xyzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 860); 

                auto tg_xyzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 861); 

                auto tg_xyzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 862); 

                auto tg_xyzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 863); 

                auto tg_xyzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 864); 

                auto tg_xyzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 865); 

                auto tg_xyzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 866); 

                auto tg_xyzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 867); 

                auto tg_xyzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 868); 

                auto tg_xyzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 869); 

                auto tg_xyzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 870); 

                auto tg_xyzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 871); 

                auto tg_xyzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 872); 

                // Batch of Integrals (776,873)

                #pragma omp simd aligned(fxn, tg_xyyyzz_xxxxyyyz_0, tg_xyyyzz_xxxxyyzz_0, \
                                         tg_xyyyzz_xxxxyzzz_0, tg_xyyyzz_xxxxzzzz_0, tg_xyyyzz_xxxyyyyy_0, tg_xyyyzz_xxxyyyyz_0, \
                                         tg_xyyyzz_xxxyyyzz_0, tg_xyyyzz_xxxyyzzz_0, tg_xyyyzz_xxxyzzzz_0, tg_xyyyzz_xxxzzzzz_0, \
                                         tg_xyyyzz_xxyyyyyy_0, tg_xyyyzz_xxyyyyyz_0, tg_xyyyzz_xxyyyyzz_0, tg_xyyyzz_xxyyyzzz_0, \
                                         tg_xyyyzz_xxyyzzzz_0, tg_xyyyzz_xxyzzzzz_0, tg_xyyyzz_xxzzzzzz_0, tg_xyyyzz_xyyyyyyy_0, \
                                         tg_xyyyzz_xyyyyyyz_0, tg_xyyyzz_xyyyyyzz_0, tg_xyyyzz_xyyyyzzz_0, tg_xyyyzz_xyyyzzzz_0, \
                                         tg_xyyyzz_xyyzzzzz_0, tg_xyyyzz_xyzzzzzz_0, tg_xyyyzz_xzzzzzzz_0, tg_xyyyzz_yyyyyyyy_0, \
                                         tg_xyyyzz_yyyyyyyz_0, tg_xyyyzz_yyyyyyzz_0, tg_xyyyzz_yyyyyzzz_0, tg_xyyyzz_yyyyzzzz_0, \
                                         tg_xyyyzz_yyyzzzzz_0, tg_xyyyzz_yyzzzzzz_0, tg_xyyyzz_yzzzzzzz_0, tg_xyyyzz_zzzzzzzz_0, \
                                         tg_xyyzzz_xxxxxxxx_0, tg_xyyzzz_xxxxxxxy_0, tg_xyyzzz_xxxxxxxz_0, tg_xyyzzz_xxxxxxyy_0, \
                                         tg_xyyzzz_xxxxxxyz_0, tg_xyyzzz_xxxxxxzz_0, tg_xyyzzz_xxxxxyyy_0, tg_xyyzzz_xxxxxyyz_0, \
                                         tg_xyyzzz_xxxxxyzz_0, tg_xyyzzz_xxxxxzzz_0, tg_xyyzzz_xxxxyyyy_0, tg_xyyzzz_xxxxyyyz_0, \
                                         tg_xyyzzz_xxxxyyzz_0, tg_xyyzzz_xxxxyzzz_0, tg_xyyzzz_xxxxzzzz_0, tg_xyyzzz_xxxyyyyy_0, \
                                         tg_xyyzzz_xxxyyyyz_0, tg_xyyzzz_xxxyyyzz_0, tg_xyyzzz_xxxyyzzz_0, tg_xyyzzz_xxxyzzzz_0, \
                                         tg_xyyzzz_xxxzzzzz_0, tg_xyyzzz_xxyyyyyy_0, tg_xyyzzz_xxyyyyyz_0, tg_xyyzzz_xxyyyyzz_0, \
                                         tg_xyyzzz_xxyyyzzz_0, tg_xyyzzz_xxyyzzzz_0, tg_xyyzzz_xxyzzzzz_0, tg_xyyzzz_xxzzzzzz_0, \
                                         tg_xyyzzz_xyyyyyyy_0, tg_xyyzzz_xyyyyyyz_0, tg_xyyzzz_xyyyyyzz_0, tg_xyyzzz_xyyyyzzz_0, \
                                         tg_xyyzzz_xyyyzzzz_0, tg_xyyzzz_xyyzzzzz_0, tg_xyyzzz_xyzzzzzz_0, tg_xyyzzz_xzzzzzzz_0, \
                                         tg_xyyzzz_yyyyyyyy_0, tg_xyyzzz_yyyyyyyz_0, tg_xyyzzz_yyyyyyzz_0, tg_xyyzzz_yyyyyzzz_0, \
                                         tg_xyyzzz_yyyyzzzz_0, tg_xyyzzz_yyyzzzzz_0, tg_xyyzzz_yyzzzzzz_0, tg_xyyzzz_yzzzzzzz_0, \
                                         tg_xyyzzz_zzzzzzzz_0, tg_xyzzzz_xxxxxxxx_0, tg_xyzzzz_xxxxxxxy_0, tg_xyzzzz_xxxxxxxz_0, \
                                         tg_xyzzzz_xxxxxxyy_0, tg_xyzzzz_xxxxxxyz_0, tg_xyzzzz_xxxxxxzz_0, tg_xyzzzz_xxxxxyyy_0, \
                                         tg_xyzzzz_xxxxxyyz_0, tg_xyzzzz_xxxxxyzz_0, tg_xyzzzz_xxxxxzzz_0, tg_xyzzzz_xxxxyyyy_0, \
                                         tg_xyzzzz_xxxxyyyz_0, tg_xyzzzz_xxxxyyzz_0, tg_xyzzzz_xxxxyzzz_0, tg_xyzzzz_xxxxzzzz_0, \
                                         tg_xyzzzz_xxxyyyyy_0, tg_xyzzzz_xxxyyyyz_0, tg_xyzzzz_xxxyyyzz_0, tg_yyyzz_xxxxyyyz_0, \
                                         tg_yyyzz_xxxxyyyz_1, tg_yyyzz_xxxxyyzz_0, tg_yyyzz_xxxxyyzz_1, tg_yyyzz_xxxxyzzz_0, \
                                         tg_yyyzz_xxxxyzzz_1, tg_yyyzz_xxxxzzzz_0, tg_yyyzz_xxxxzzzz_1, tg_yyyzz_xxxyyyyy_0, \
                                         tg_yyyzz_xxxyyyyy_1, tg_yyyzz_xxxyyyyz_0, tg_yyyzz_xxxyyyyz_1, tg_yyyzz_xxxyyyz_1, \
                                         tg_yyyzz_xxxyyyzz_0, tg_yyyzz_xxxyyyzz_1, tg_yyyzz_xxxyyzz_1, tg_yyyzz_xxxyyzzz_0, \
                                         tg_yyyzz_xxxyyzzz_1, tg_yyyzz_xxxyzzz_1, tg_yyyzz_xxxyzzzz_0, tg_yyyzz_xxxyzzzz_1, \
                                         tg_yyyzz_xxxzzzz_1, tg_yyyzz_xxxzzzzz_0, tg_yyyzz_xxxzzzzz_1, tg_yyyzz_xxyyyyy_1, \
                                         tg_yyyzz_xxyyyyyy_0, tg_yyyzz_xxyyyyyy_1, tg_yyyzz_xxyyyyyz_0, tg_yyyzz_xxyyyyyz_1, \
                                         tg_yyyzz_xxyyyyz_1, tg_yyyzz_xxyyyyzz_0, tg_yyyzz_xxyyyyzz_1, tg_yyyzz_xxyyyzz_1, \
                                         tg_yyyzz_xxyyyzzz_0, tg_yyyzz_xxyyyzzz_1, tg_yyyzz_xxyyzzz_1, tg_yyyzz_xxyyzzzz_0, \
                                         tg_yyyzz_xxyyzzzz_1, tg_yyyzz_xxyzzzz_1, tg_yyyzz_xxyzzzzz_0, tg_yyyzz_xxyzzzzz_1, \
                                         tg_yyyzz_xxzzzzz_1, tg_yyyzz_xxzzzzzz_0, tg_yyyzz_xxzzzzzz_1, tg_yyyzz_xyyyyyy_1, \
                                         tg_yyyzz_xyyyyyyy_0, tg_yyyzz_xyyyyyyy_1, tg_yyyzz_xyyyyyyz_0, tg_yyyzz_xyyyyyyz_1, \
                                         tg_yyyzz_xyyyyyz_1, tg_yyyzz_xyyyyyzz_0, tg_yyyzz_xyyyyyzz_1, tg_yyyzz_xyyyyzz_1, \
                                         tg_yyyzz_xyyyyzzz_0, tg_yyyzz_xyyyyzzz_1, tg_yyyzz_xyyyzzz_1, tg_yyyzz_xyyyzzzz_0, \
                                         tg_yyyzz_xyyyzzzz_1, tg_yyyzz_xyyzzzz_1, tg_yyyzz_xyyzzzzz_0, tg_yyyzz_xyyzzzzz_1, \
                                         tg_yyyzz_xyzzzzz_1, tg_yyyzz_xyzzzzzz_0, tg_yyyzz_xyzzzzzz_1, tg_yyyzz_xzzzzzz_1, \
                                         tg_yyyzz_xzzzzzzz_0, tg_yyyzz_xzzzzzzz_1, tg_yyyzz_yyyyyyy_1, tg_yyyzz_yyyyyyyy_0, \
                                         tg_yyyzz_yyyyyyyy_1, tg_yyyzz_yyyyyyyz_0, tg_yyyzz_yyyyyyyz_1, tg_yyyzz_yyyyyyz_1, \
                                         tg_yyyzz_yyyyyyzz_0, tg_yyyzz_yyyyyyzz_1, tg_yyyzz_yyyyyzz_1, tg_yyyzz_yyyyyzzz_0, \
                                         tg_yyyzz_yyyyyzzz_1, tg_yyyzz_yyyyzzz_1, tg_yyyzz_yyyyzzzz_0, tg_yyyzz_yyyyzzzz_1, \
                                         tg_yyyzz_yyyzzzz_1, tg_yyyzz_yyyzzzzz_0, tg_yyyzz_yyyzzzzz_1, tg_yyyzz_yyzzzzz_1, \
                                         tg_yyyzz_yyzzzzzz_0, tg_yyyzz_yyzzzzzz_1, tg_yyyzz_yzzzzzz_1, tg_yyyzz_yzzzzzzz_0, \
                                         tg_yyyzz_yzzzzzzz_1, tg_yyyzz_zzzzzzz_1, tg_yyyzz_zzzzzzzz_0, tg_yyyzz_zzzzzzzz_1, \
                                         tg_yyzzz_xxxxxxx_1, tg_yyzzz_xxxxxxxx_0, tg_yyzzz_xxxxxxxx_1, tg_yyzzz_xxxxxxxy_0, \
                                         tg_yyzzz_xxxxxxxy_1, tg_yyzzz_xxxxxxxz_0, tg_yyzzz_xxxxxxxz_1, tg_yyzzz_xxxxxxy_1, \
                                         tg_yyzzz_xxxxxxyy_0, tg_yyzzz_xxxxxxyy_1, tg_yyzzz_xxxxxxyz_0, tg_yyzzz_xxxxxxyz_1, \
                                         tg_yyzzz_xxxxxxz_1, tg_yyzzz_xxxxxxzz_0, tg_yyzzz_xxxxxxzz_1, tg_yyzzz_xxxxxyy_1, \
                                         tg_yyzzz_xxxxxyyy_0, tg_yyzzz_xxxxxyyy_1, tg_yyzzz_xxxxxyyz_0, tg_yyzzz_xxxxxyyz_1, \
                                         tg_yyzzz_xxxxxyz_1, tg_yyzzz_xxxxxyzz_0, tg_yyzzz_xxxxxyzz_1, tg_yyzzz_xxxxxzz_1, \
                                         tg_yyzzz_xxxxxzzz_0, tg_yyzzz_xxxxxzzz_1, tg_yyzzz_xxxxyyy_1, tg_yyzzz_xxxxyyyy_0, \
                                         tg_yyzzz_xxxxyyyy_1, tg_yyzzz_xxxxyyyz_0, tg_yyzzz_xxxxyyyz_1, tg_yyzzz_xxxxyyz_1, \
                                         tg_yyzzz_xxxxyyzz_0, tg_yyzzz_xxxxyyzz_1, tg_yyzzz_xxxxyzz_1, tg_yyzzz_xxxxyzzz_0, \
                                         tg_yyzzz_xxxxyzzz_1, tg_yyzzz_xxxxzzz_1, tg_yyzzz_xxxxzzzz_0, tg_yyzzz_xxxxzzzz_1, \
                                         tg_yyzzz_xxxyyyy_1, tg_yyzzz_xxxyyyyy_0, tg_yyzzz_xxxyyyyy_1, tg_yyzzz_xxxyyyyz_0, \
                                         tg_yyzzz_xxxyyyyz_1, tg_yyzzz_xxxyyyz_1, tg_yyzzz_xxxyyyzz_0, tg_yyzzz_xxxyyyzz_1, \
                                         tg_yyzzz_xxxyyzz_1, tg_yyzzz_xxxyyzzz_0, tg_yyzzz_xxxyyzzz_1, tg_yyzzz_xxxyzzz_1, \
                                         tg_yyzzz_xxxyzzzz_0, tg_yyzzz_xxxyzzzz_1, tg_yyzzz_xxxzzzz_1, tg_yyzzz_xxxzzzzz_0, \
                                         tg_yyzzz_xxxzzzzz_1, tg_yyzzz_xxyyyyy_1, tg_yyzzz_xxyyyyyy_0, tg_yyzzz_xxyyyyyy_1, \
                                         tg_yyzzz_xxyyyyyz_0, tg_yyzzz_xxyyyyyz_1, tg_yyzzz_xxyyyyz_1, tg_yyzzz_xxyyyyzz_0, \
                                         tg_yyzzz_xxyyyyzz_1, tg_yyzzz_xxyyyzz_1, tg_yyzzz_xxyyyzzz_0, tg_yyzzz_xxyyyzzz_1, \
                                         tg_yyzzz_xxyyzzz_1, tg_yyzzz_xxyyzzzz_0, tg_yyzzz_xxyyzzzz_1, tg_yyzzz_xxyzzzz_1, \
                                         tg_yyzzz_xxyzzzzz_0, tg_yyzzz_xxyzzzzz_1, tg_yyzzz_xxzzzzz_1, tg_yyzzz_xxzzzzzz_0, \
                                         tg_yyzzz_xxzzzzzz_1, tg_yyzzz_xyyyyyy_1, tg_yyzzz_xyyyyyyy_0, tg_yyzzz_xyyyyyyy_1, \
                                         tg_yyzzz_xyyyyyyz_0, tg_yyzzz_xyyyyyyz_1, tg_yyzzz_xyyyyyz_1, tg_yyzzz_xyyyyyzz_0, \
                                         tg_yyzzz_xyyyyyzz_1, tg_yyzzz_xyyyyzz_1, tg_yyzzz_xyyyyzzz_0, tg_yyzzz_xyyyyzzz_1, \
                                         tg_yyzzz_xyyyzzz_1, tg_yyzzz_xyyyzzzz_0, tg_yyzzz_xyyyzzzz_1, tg_yyzzz_xyyzzzz_1, \
                                         tg_yyzzz_xyyzzzzz_0, tg_yyzzz_xyyzzzzz_1, tg_yyzzz_xyzzzzz_1, tg_yyzzz_xyzzzzzz_0, \
                                         tg_yyzzz_xyzzzzzz_1, tg_yyzzz_xzzzzzz_1, tg_yyzzz_xzzzzzzz_0, tg_yyzzz_xzzzzzzz_1, \
                                         tg_yyzzz_yyyyyyy_1, tg_yyzzz_yyyyyyyy_0, tg_yyzzz_yyyyyyyy_1, tg_yyzzz_yyyyyyyz_0, \
                                         tg_yyzzz_yyyyyyyz_1, tg_yyzzz_yyyyyyz_1, tg_yyzzz_yyyyyyzz_0, tg_yyzzz_yyyyyyzz_1, \
                                         tg_yyzzz_yyyyyzz_1, tg_yyzzz_yyyyyzzz_0, tg_yyzzz_yyyyyzzz_1, tg_yyzzz_yyyyzzz_1, \
                                         tg_yyzzz_yyyyzzzz_0, tg_yyzzz_yyyyzzzz_1, tg_yyzzz_yyyzzzz_1, tg_yyzzz_yyyzzzzz_0, \
                                         tg_yyzzz_yyyzzzzz_1, tg_yyzzz_yyzzzzz_1, tg_yyzzz_yyzzzzzz_0, tg_yyzzz_yyzzzzzz_1, \
                                         tg_yyzzz_yzzzzzz_1, tg_yyzzz_yzzzzzzz_0, tg_yyzzz_yzzzzzzz_1, tg_yyzzz_zzzzzzz_1, \
                                         tg_yyzzz_zzzzzzzz_0, tg_yyzzz_zzzzzzzz_1, tg_yzzzz_xxxxxxx_1, tg_yzzzz_xxxxxxxx_0, \
                                         tg_yzzzz_xxxxxxxx_1, tg_yzzzz_xxxxxxxy_0, tg_yzzzz_xxxxxxxy_1, tg_yzzzz_xxxxxxxz_0, \
                                         tg_yzzzz_xxxxxxxz_1, tg_yzzzz_xxxxxxy_1, tg_yzzzz_xxxxxxyy_0, tg_yzzzz_xxxxxxyy_1, \
                                         tg_yzzzz_xxxxxxyz_0, tg_yzzzz_xxxxxxyz_1, tg_yzzzz_xxxxxxz_1, tg_yzzzz_xxxxxxzz_0, \
                                         tg_yzzzz_xxxxxxzz_1, tg_yzzzz_xxxxxyy_1, tg_yzzzz_xxxxxyyy_0, tg_yzzzz_xxxxxyyy_1, \
                                         tg_yzzzz_xxxxxyyz_0, tg_yzzzz_xxxxxyyz_1, tg_yzzzz_xxxxxyz_1, tg_yzzzz_xxxxxyzz_0, \
                                         tg_yzzzz_xxxxxyzz_1, tg_yzzzz_xxxxxzz_1, tg_yzzzz_xxxxxzzz_0, tg_yzzzz_xxxxxzzz_1, \
                                         tg_yzzzz_xxxxyyy_1, tg_yzzzz_xxxxyyyy_0, tg_yzzzz_xxxxyyyy_1, tg_yzzzz_xxxxyyyz_0, \
                                         tg_yzzzz_xxxxyyyz_1, tg_yzzzz_xxxxyyz_1, tg_yzzzz_xxxxyyzz_0, tg_yzzzz_xxxxyyzz_1, \
                                         tg_yzzzz_xxxxyzz_1, tg_yzzzz_xxxxyzzz_0, tg_yzzzz_xxxxyzzz_1, tg_yzzzz_xxxxzzz_1, \
                                         tg_yzzzz_xxxxzzzz_0, tg_yzzzz_xxxxzzzz_1, tg_yzzzz_xxxyyyy_1, tg_yzzzz_xxxyyyyy_0, \
                                         tg_yzzzz_xxxyyyyy_1, tg_yzzzz_xxxyyyyz_0, tg_yzzzz_xxxyyyyz_1, tg_yzzzz_xxxyyyz_1, \
                                         tg_yzzzz_xxxyyyzz_0, tg_yzzzz_xxxyyyzz_1, tg_yzzzz_xxxyyzz_1, tg_yzzzz_xxxyzzz_1, \
                                         tg_yzzzz_xxxzzzz_1, tg_yzzzz_xxyyyyy_1, tg_yzzzz_xxyyyyz_1, tg_yzzzz_xxyyyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fxn = fxn[j];

                    double fr = wp_x[j]; 

                    tg_xyyyzz_xxxxyyyz_0[j] = pb_x * tg_yyyzz_xxxxyyyz_0[j] + fr * tg_yyyzz_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_yyyzz_xxxyyyz_1[j];

                    tg_xyyyzz_xxxxyyzz_0[j] = pb_x * tg_yyyzz_xxxxyyzz_0[j] + fr * tg_yyyzz_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_yyyzz_xxxyyzz_1[j];

                    tg_xyyyzz_xxxxyzzz_0[j] = pb_x * tg_yyyzz_xxxxyzzz_0[j] + fr * tg_yyyzz_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_yyyzz_xxxyzzz_1[j];

                    tg_xyyyzz_xxxxzzzz_0[j] = pb_x * tg_yyyzz_xxxxzzzz_0[j] + fr * tg_yyyzz_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_yyyzz_xxxzzzz_1[j];

                    tg_xyyyzz_xxxyyyyy_0[j] = pb_x * tg_yyyzz_xxxyyyyy_0[j] + fr * tg_yyyzz_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxyyyyy_1[j];

                    tg_xyyyzz_xxxyyyyz_0[j] = pb_x * tg_yyyzz_xxxyyyyz_0[j] + fr * tg_yyyzz_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxyyyyz_1[j];

                    tg_xyyyzz_xxxyyyzz_0[j] = pb_x * tg_yyyzz_xxxyyyzz_0[j] + fr * tg_yyyzz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxyyyzz_1[j];

                    tg_xyyyzz_xxxyyzzz_0[j] = pb_x * tg_yyyzz_xxxyyzzz_0[j] + fr * tg_yyyzz_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxyyzzz_1[j];

                    tg_xyyyzz_xxxyzzzz_0[j] = pb_x * tg_yyyzz_xxxyzzzz_0[j] + fr * tg_yyyzz_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxyzzzz_1[j];

                    tg_xyyyzz_xxxzzzzz_0[j] = pb_x * tg_yyyzz_xxxzzzzz_0[j] + fr * tg_yyyzz_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzz_xxzzzzz_1[j];

                    tg_xyyyzz_xxyyyyyy_0[j] = pb_x * tg_yyyzz_xxyyyyyy_0[j] + fr * tg_yyyzz_xxyyyyyy_1[j] + fl1_fxn * tg_yyyzz_xyyyyyy_1[j];

                    tg_xyyyzz_xxyyyyyz_0[j] = pb_x * tg_yyyzz_xxyyyyyz_0[j] + fr * tg_yyyzz_xxyyyyyz_1[j] + fl1_fxn * tg_yyyzz_xyyyyyz_1[j];

                    tg_xyyyzz_xxyyyyzz_0[j] = pb_x * tg_yyyzz_xxyyyyzz_0[j] + fr * tg_yyyzz_xxyyyyzz_1[j] + fl1_fxn * tg_yyyzz_xyyyyzz_1[j];

                    tg_xyyyzz_xxyyyzzz_0[j] = pb_x * tg_yyyzz_xxyyyzzz_0[j] + fr * tg_yyyzz_xxyyyzzz_1[j] + fl1_fxn * tg_yyyzz_xyyyzzz_1[j];

                    tg_xyyyzz_xxyyzzzz_0[j] = pb_x * tg_yyyzz_xxyyzzzz_0[j] + fr * tg_yyyzz_xxyyzzzz_1[j] + fl1_fxn * tg_yyyzz_xyyzzzz_1[j];

                    tg_xyyyzz_xxyzzzzz_0[j] = pb_x * tg_yyyzz_xxyzzzzz_0[j] + fr * tg_yyyzz_xxyzzzzz_1[j] + fl1_fxn * tg_yyyzz_xyzzzzz_1[j];

                    tg_xyyyzz_xxzzzzzz_0[j] = pb_x * tg_yyyzz_xxzzzzzz_0[j] + fr * tg_yyyzz_xxzzzzzz_1[j] + fl1_fxn * tg_yyyzz_xzzzzzz_1[j];

                    tg_xyyyzz_xyyyyyyy_0[j] = pb_x * tg_yyyzz_xyyyyyyy_0[j] + fr * tg_yyyzz_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyyyyyy_1[j];

                    tg_xyyyzz_xyyyyyyz_0[j] = pb_x * tg_yyyzz_xyyyyyyz_0[j] + fr * tg_yyyzz_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyyyyyz_1[j];

                    tg_xyyyzz_xyyyyyzz_0[j] = pb_x * tg_yyyzz_xyyyyyzz_0[j] + fr * tg_yyyzz_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyyyyzz_1[j];

                    tg_xyyyzz_xyyyyzzz_0[j] = pb_x * tg_yyyzz_xyyyyzzz_0[j] + fr * tg_yyyzz_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyyyzzz_1[j];

                    tg_xyyyzz_xyyyzzzz_0[j] = pb_x * tg_yyyzz_xyyyzzzz_0[j] + fr * tg_yyyzz_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyyzzzz_1[j];

                    tg_xyyyzz_xyyzzzzz_0[j] = pb_x * tg_yyyzz_xyyzzzzz_0[j] + fr * tg_yyyzz_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yyzzzzz_1[j];

                    tg_xyyyzz_xyzzzzzz_0[j] = pb_x * tg_yyyzz_xyzzzzzz_0[j] + fr * tg_yyyzz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_yzzzzzz_1[j];

                    tg_xyyyzz_xzzzzzzz_0[j] = pb_x * tg_yyyzz_xzzzzzzz_0[j] + fr * tg_yyyzz_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzz_zzzzzzz_1[j];

                    tg_xyyyzz_yyyyyyyy_0[j] = pb_x * tg_yyyzz_yyyyyyyy_0[j] + fr * tg_yyyzz_yyyyyyyy_1[j];

                    tg_xyyyzz_yyyyyyyz_0[j] = pb_x * tg_yyyzz_yyyyyyyz_0[j] + fr * tg_yyyzz_yyyyyyyz_1[j];

                    tg_xyyyzz_yyyyyyzz_0[j] = pb_x * tg_yyyzz_yyyyyyzz_0[j] + fr * tg_yyyzz_yyyyyyzz_1[j];

                    tg_xyyyzz_yyyyyzzz_0[j] = pb_x * tg_yyyzz_yyyyyzzz_0[j] + fr * tg_yyyzz_yyyyyzzz_1[j];

                    tg_xyyyzz_yyyyzzzz_0[j] = pb_x * tg_yyyzz_yyyyzzzz_0[j] + fr * tg_yyyzz_yyyyzzzz_1[j];

                    tg_xyyyzz_yyyzzzzz_0[j] = pb_x * tg_yyyzz_yyyzzzzz_0[j] + fr * tg_yyyzz_yyyzzzzz_1[j];

                    tg_xyyyzz_yyzzzzzz_0[j] = pb_x * tg_yyyzz_yyzzzzzz_0[j] + fr * tg_yyyzz_yyzzzzzz_1[j];

                    tg_xyyyzz_yzzzzzzz_0[j] = pb_x * tg_yyyzz_yzzzzzzz_0[j] + fr * tg_yyyzz_yzzzzzzz_1[j];

                    tg_xyyyzz_zzzzzzzz_0[j] = pb_x * tg_yyyzz_zzzzzzzz_0[j] + fr * tg_yyyzz_zzzzzzzz_1[j];

                    tg_xyyzzz_xxxxxxxx_0[j] = pb_x * tg_yyzzz_xxxxxxxx_0[j] + fr * tg_yyzzz_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_yyzzz_xxxxxxx_1[j];

                    tg_xyyzzz_xxxxxxxy_0[j] = pb_x * tg_yyzzz_xxxxxxxy_0[j] + fr * tg_yyzzz_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_yyzzz_xxxxxxy_1[j];

                    tg_xyyzzz_xxxxxxxz_0[j] = pb_x * tg_yyzzz_xxxxxxxz_0[j] + fr * tg_yyzzz_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_yyzzz_xxxxxxz_1[j];

                    tg_xyyzzz_xxxxxxyy_0[j] = pb_x * tg_yyzzz_xxxxxxyy_0[j] + fr * tg_yyzzz_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_yyzzz_xxxxxyy_1[j];

                    tg_xyyzzz_xxxxxxyz_0[j] = pb_x * tg_yyzzz_xxxxxxyz_0[j] + fr * tg_yyzzz_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_yyzzz_xxxxxyz_1[j];

                    tg_xyyzzz_xxxxxxzz_0[j] = pb_x * tg_yyzzz_xxxxxxzz_0[j] + fr * tg_yyzzz_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_yyzzz_xxxxxzz_1[j];

                    tg_xyyzzz_xxxxxyyy_0[j] = pb_x * tg_yyzzz_xxxxxyyy_0[j] + fr * tg_yyzzz_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_yyzzz_xxxxyyy_1[j];

                    tg_xyyzzz_xxxxxyyz_0[j] = pb_x * tg_yyzzz_xxxxxyyz_0[j] + fr * tg_yyzzz_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_yyzzz_xxxxyyz_1[j];

                    tg_xyyzzz_xxxxxyzz_0[j] = pb_x * tg_yyzzz_xxxxxyzz_0[j] + fr * tg_yyzzz_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_yyzzz_xxxxyzz_1[j];

                    tg_xyyzzz_xxxxxzzz_0[j] = pb_x * tg_yyzzz_xxxxxzzz_0[j] + fr * tg_yyzzz_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_yyzzz_xxxxzzz_1[j];

                    tg_xyyzzz_xxxxyyyy_0[j] = pb_x * tg_yyzzz_xxxxyyyy_0[j] + fr * tg_yyzzz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_yyzzz_xxxyyyy_1[j];

                    tg_xyyzzz_xxxxyyyz_0[j] = pb_x * tg_yyzzz_xxxxyyyz_0[j] + fr * tg_yyzzz_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_yyzzz_xxxyyyz_1[j];

                    tg_xyyzzz_xxxxyyzz_0[j] = pb_x * tg_yyzzz_xxxxyyzz_0[j] + fr * tg_yyzzz_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_yyzzz_xxxyyzz_1[j];

                    tg_xyyzzz_xxxxyzzz_0[j] = pb_x * tg_yyzzz_xxxxyzzz_0[j] + fr * tg_yyzzz_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_yyzzz_xxxyzzz_1[j];

                    tg_xyyzzz_xxxxzzzz_0[j] = pb_x * tg_yyzzz_xxxxzzzz_0[j] + fr * tg_yyzzz_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_yyzzz_xxxzzzz_1[j];

                    tg_xyyzzz_xxxyyyyy_0[j] = pb_x * tg_yyzzz_xxxyyyyy_0[j] + fr * tg_yyzzz_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxyyyyy_1[j];

                    tg_xyyzzz_xxxyyyyz_0[j] = pb_x * tg_yyzzz_xxxyyyyz_0[j] + fr * tg_yyzzz_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxyyyyz_1[j];

                    tg_xyyzzz_xxxyyyzz_0[j] = pb_x * tg_yyzzz_xxxyyyzz_0[j] + fr * tg_yyzzz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxyyyzz_1[j];

                    tg_xyyzzz_xxxyyzzz_0[j] = pb_x * tg_yyzzz_xxxyyzzz_0[j] + fr * tg_yyzzz_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxyyzzz_1[j];

                    tg_xyyzzz_xxxyzzzz_0[j] = pb_x * tg_yyzzz_xxxyzzzz_0[j] + fr * tg_yyzzz_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxyzzzz_1[j];

                    tg_xyyzzz_xxxzzzzz_0[j] = pb_x * tg_yyzzz_xxxzzzzz_0[j] + fr * tg_yyzzz_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzz_xxzzzzz_1[j];

                    tg_xyyzzz_xxyyyyyy_0[j] = pb_x * tg_yyzzz_xxyyyyyy_0[j] + fr * tg_yyzzz_xxyyyyyy_1[j] + fl1_fxn * tg_yyzzz_xyyyyyy_1[j];

                    tg_xyyzzz_xxyyyyyz_0[j] = pb_x * tg_yyzzz_xxyyyyyz_0[j] + fr * tg_yyzzz_xxyyyyyz_1[j] + fl1_fxn * tg_yyzzz_xyyyyyz_1[j];

                    tg_xyyzzz_xxyyyyzz_0[j] = pb_x * tg_yyzzz_xxyyyyzz_0[j] + fr * tg_yyzzz_xxyyyyzz_1[j] + fl1_fxn * tg_yyzzz_xyyyyzz_1[j];

                    tg_xyyzzz_xxyyyzzz_0[j] = pb_x * tg_yyzzz_xxyyyzzz_0[j] + fr * tg_yyzzz_xxyyyzzz_1[j] + fl1_fxn * tg_yyzzz_xyyyzzz_1[j];

                    tg_xyyzzz_xxyyzzzz_0[j] = pb_x * tg_yyzzz_xxyyzzzz_0[j] + fr * tg_yyzzz_xxyyzzzz_1[j] + fl1_fxn * tg_yyzzz_xyyzzzz_1[j];

                    tg_xyyzzz_xxyzzzzz_0[j] = pb_x * tg_yyzzz_xxyzzzzz_0[j] + fr * tg_yyzzz_xxyzzzzz_1[j] + fl1_fxn * tg_yyzzz_xyzzzzz_1[j];

                    tg_xyyzzz_xxzzzzzz_0[j] = pb_x * tg_yyzzz_xxzzzzzz_0[j] + fr * tg_yyzzz_xxzzzzzz_1[j] + fl1_fxn * tg_yyzzz_xzzzzzz_1[j];

                    tg_xyyzzz_xyyyyyyy_0[j] = pb_x * tg_yyzzz_xyyyyyyy_0[j] + fr * tg_yyzzz_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyyyyyy_1[j];

                    tg_xyyzzz_xyyyyyyz_0[j] = pb_x * tg_yyzzz_xyyyyyyz_0[j] + fr * tg_yyzzz_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyyyyyz_1[j];

                    tg_xyyzzz_xyyyyyzz_0[j] = pb_x * tg_yyzzz_xyyyyyzz_0[j] + fr * tg_yyzzz_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyyyyzz_1[j];

                    tg_xyyzzz_xyyyyzzz_0[j] = pb_x * tg_yyzzz_xyyyyzzz_0[j] + fr * tg_yyzzz_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyyyzzz_1[j];

                    tg_xyyzzz_xyyyzzzz_0[j] = pb_x * tg_yyzzz_xyyyzzzz_0[j] + fr * tg_yyzzz_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyyzzzz_1[j];

                    tg_xyyzzz_xyyzzzzz_0[j] = pb_x * tg_yyzzz_xyyzzzzz_0[j] + fr * tg_yyzzz_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yyzzzzz_1[j];

                    tg_xyyzzz_xyzzzzzz_0[j] = pb_x * tg_yyzzz_xyzzzzzz_0[j] + fr * tg_yyzzz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_yzzzzzz_1[j];

                    tg_xyyzzz_xzzzzzzz_0[j] = pb_x * tg_yyzzz_xzzzzzzz_0[j] + fr * tg_yyzzz_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzz_zzzzzzz_1[j];

                    tg_xyyzzz_yyyyyyyy_0[j] = pb_x * tg_yyzzz_yyyyyyyy_0[j] + fr * tg_yyzzz_yyyyyyyy_1[j];

                    tg_xyyzzz_yyyyyyyz_0[j] = pb_x * tg_yyzzz_yyyyyyyz_0[j] + fr * tg_yyzzz_yyyyyyyz_1[j];

                    tg_xyyzzz_yyyyyyzz_0[j] = pb_x * tg_yyzzz_yyyyyyzz_0[j] + fr * tg_yyzzz_yyyyyyzz_1[j];

                    tg_xyyzzz_yyyyyzzz_0[j] = pb_x * tg_yyzzz_yyyyyzzz_0[j] + fr * tg_yyzzz_yyyyyzzz_1[j];

                    tg_xyyzzz_yyyyzzzz_0[j] = pb_x * tg_yyzzz_yyyyzzzz_0[j] + fr * tg_yyzzz_yyyyzzzz_1[j];

                    tg_xyyzzz_yyyzzzzz_0[j] = pb_x * tg_yyzzz_yyyzzzzz_0[j] + fr * tg_yyzzz_yyyzzzzz_1[j];

                    tg_xyyzzz_yyzzzzzz_0[j] = pb_x * tg_yyzzz_yyzzzzzz_0[j] + fr * tg_yyzzz_yyzzzzzz_1[j];

                    tg_xyyzzz_yzzzzzzz_0[j] = pb_x * tg_yyzzz_yzzzzzzz_0[j] + fr * tg_yyzzz_yzzzzzzz_1[j];

                    tg_xyyzzz_zzzzzzzz_0[j] = pb_x * tg_yyzzz_zzzzzzzz_0[j] + fr * tg_yyzzz_zzzzzzzz_1[j];

                    tg_xyzzzz_xxxxxxxx_0[j] = pb_x * tg_yzzzz_xxxxxxxx_0[j] + fr * tg_yzzzz_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_yzzzz_xxxxxxx_1[j];

                    tg_xyzzzz_xxxxxxxy_0[j] = pb_x * tg_yzzzz_xxxxxxxy_0[j] + fr * tg_yzzzz_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_yzzzz_xxxxxxy_1[j];

                    tg_xyzzzz_xxxxxxxz_0[j] = pb_x * tg_yzzzz_xxxxxxxz_0[j] + fr * tg_yzzzz_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_yzzzz_xxxxxxz_1[j];

                    tg_xyzzzz_xxxxxxyy_0[j] = pb_x * tg_yzzzz_xxxxxxyy_0[j] + fr * tg_yzzzz_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_yzzzz_xxxxxyy_1[j];

                    tg_xyzzzz_xxxxxxyz_0[j] = pb_x * tg_yzzzz_xxxxxxyz_0[j] + fr * tg_yzzzz_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_yzzzz_xxxxxyz_1[j];

                    tg_xyzzzz_xxxxxxzz_0[j] = pb_x * tg_yzzzz_xxxxxxzz_0[j] + fr * tg_yzzzz_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_yzzzz_xxxxxzz_1[j];

                    tg_xyzzzz_xxxxxyyy_0[j] = pb_x * tg_yzzzz_xxxxxyyy_0[j] + fr * tg_yzzzz_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_yzzzz_xxxxyyy_1[j];

                    tg_xyzzzz_xxxxxyyz_0[j] = pb_x * tg_yzzzz_xxxxxyyz_0[j] + fr * tg_yzzzz_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_yzzzz_xxxxyyz_1[j];

                    tg_xyzzzz_xxxxxyzz_0[j] = pb_x * tg_yzzzz_xxxxxyzz_0[j] + fr * tg_yzzzz_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_yzzzz_xxxxyzz_1[j];

                    tg_xyzzzz_xxxxxzzz_0[j] = pb_x * tg_yzzzz_xxxxxzzz_0[j] + fr * tg_yzzzz_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_yzzzz_xxxxzzz_1[j];

                    tg_xyzzzz_xxxxyyyy_0[j] = pb_x * tg_yzzzz_xxxxyyyy_0[j] + fr * tg_yzzzz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_yzzzz_xxxyyyy_1[j];

                    tg_xyzzzz_xxxxyyyz_0[j] = pb_x * tg_yzzzz_xxxxyyyz_0[j] + fr * tg_yzzzz_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_yzzzz_xxxyyyz_1[j];

                    tg_xyzzzz_xxxxyyzz_0[j] = pb_x * tg_yzzzz_xxxxyyzz_0[j] + fr * tg_yzzzz_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_yzzzz_xxxyyzz_1[j];

                    tg_xyzzzz_xxxxyzzz_0[j] = pb_x * tg_yzzzz_xxxxyzzz_0[j] + fr * tg_yzzzz_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_yzzzz_xxxyzzz_1[j];

                    tg_xyzzzz_xxxxzzzz_0[j] = pb_x * tg_yzzzz_xxxxzzzz_0[j] + fr * tg_yzzzz_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_yzzzz_xxxzzzz_1[j];

                    tg_xyzzzz_xxxyyyyy_0[j] = pb_x * tg_yzzzz_xxxyyyyy_0[j] + fr * tg_yzzzz_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxyyyyy_1[j];

                    tg_xyzzzz_xxxyyyyz_0[j] = pb_x * tg_yzzzz_xxxyyyyz_0[j] + fr * tg_yzzzz_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxyyyyz_1[j];

                    tg_xyzzzz_xxxyyyzz_0[j] = pb_x * tg_yzzzz_xxxyyyzz_0[j] + fr * tg_yzzzz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxyyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_873_970(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (873,970)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyy_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 675); 

                auto tg_yyyyy_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 676); 

                auto tg_yyyyy_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 677); 

                auto tg_yyyyy_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 678); 

                auto tg_yyyyy_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 679); 

                auto tg_yyyyy_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 680); 

                auto tg_yyyyy_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 681); 

                auto tg_yyyyy_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 682); 

                auto tg_yyyyy_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 683); 

                auto tg_yyyyy_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 684); 

                auto tg_yyyyy_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 685); 

                auto tg_yyyyy_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 686); 

                auto tg_yyyyy_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 687); 

                auto tg_yyyyy_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 688); 

                auto tg_yyyyy_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 689); 

                auto tg_yyyyy_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 690); 

                auto tg_yyyyy_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 691); 

                auto tg_yyyyy_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 692); 

                auto tg_yyyyy_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 693); 

                auto tg_yyyyy_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 694); 

                auto tg_yyyyy_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 695); 

                auto tg_yyyyy_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 696); 

                auto tg_yyyyy_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 697); 

                auto tg_yyyyy_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 698); 

                auto tg_yyyyy_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 699); 

                auto tg_yzzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 873); 

                auto tg_yzzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 874); 

                auto tg_yzzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 875); 

                auto tg_yzzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 876); 

                auto tg_yzzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 877); 

                auto tg_yzzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 878); 

                auto tg_yzzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 879); 

                auto tg_yzzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 880); 

                auto tg_yzzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 881); 

                auto tg_yzzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 882); 

                auto tg_yzzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 883); 

                auto tg_yzzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 884); 

                auto tg_yzzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 885); 

                auto tg_yzzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 886); 

                auto tg_yzzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 887); 

                auto tg_yzzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 888); 

                auto tg_yzzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 889); 

                auto tg_yzzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 890); 

                auto tg_yzzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 891); 

                auto tg_yzzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 892); 

                auto tg_yzzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 893); 

                auto tg_yzzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 894); 

                auto tg_yzzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 895); 

                auto tg_yzzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 896); 

                auto tg_yzzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 897); 

                auto tg_yzzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 898); 

                auto tg_yzzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 899); 

                auto tg_zzzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 900); 

                auto tg_zzzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 901); 

                auto tg_zzzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 902); 

                auto tg_zzzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 903); 

                auto tg_zzzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 904); 

                auto tg_zzzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 905); 

                auto tg_zzzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 906); 

                auto tg_zzzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 907); 

                auto tg_zzzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 908); 

                auto tg_zzzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 909); 

                auto tg_zzzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 910); 

                auto tg_zzzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 911); 

                auto tg_zzzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 912); 

                auto tg_zzzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 913); 

                auto tg_zzzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 914); 

                auto tg_zzzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 915); 

                auto tg_zzzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 916); 

                auto tg_zzzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 917); 

                auto tg_zzzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 918); 

                auto tg_zzzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 919); 

                auto tg_zzzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 920); 

                auto tg_zzzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 921); 

                auto tg_zzzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 922); 

                auto tg_zzzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 923); 

                auto tg_zzzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 924); 

                auto tg_zzzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 925); 

                auto tg_zzzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 926); 

                auto tg_zzzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 927); 

                auto tg_zzzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 928); 

                auto tg_zzzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 929); 

                auto tg_zzzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 930); 

                auto tg_zzzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 931); 

                auto tg_zzzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 932); 

                auto tg_zzzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 933); 

                auto tg_zzzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 934); 

                auto tg_zzzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 935); 

                auto tg_zzzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 936); 

                auto tg_zzzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 937); 

                auto tg_zzzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 938); 

                auto tg_zzzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 939); 

                auto tg_zzzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 940); 

                auto tg_zzzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 941); 

                auto tg_zzzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 942); 

                auto tg_zzzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 943); 

                auto tg_zzzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 944); 

                auto tg_yyyyy_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 675); 

                auto tg_yyyyy_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 676); 

                auto tg_yyyyy_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 677); 

                auto tg_yyyyy_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 678); 

                auto tg_yyyyy_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 679); 

                auto tg_yyyyy_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 680); 

                auto tg_yyyyy_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 681); 

                auto tg_yyyyy_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 682); 

                auto tg_yyyyy_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 683); 

                auto tg_yyyyy_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 684); 

                auto tg_yyyyy_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 685); 

                auto tg_yyyyy_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 686); 

                auto tg_yyyyy_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 687); 

                auto tg_yyyyy_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 688); 

                auto tg_yyyyy_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 689); 

                auto tg_yyyyy_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 690); 

                auto tg_yyyyy_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 691); 

                auto tg_yyyyy_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 692); 

                auto tg_yyyyy_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 693); 

                auto tg_yyyyy_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 694); 

                auto tg_yyyyy_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 695); 

                auto tg_yyyyy_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 696); 

                auto tg_yyyyy_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 697); 

                auto tg_yyyyy_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 698); 

                auto tg_yyyyy_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 699); 

                auto tg_yzzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 873); 

                auto tg_yzzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 874); 

                auto tg_yzzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 875); 

                auto tg_yzzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 876); 

                auto tg_yzzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 877); 

                auto tg_yzzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 878); 

                auto tg_yzzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 879); 

                auto tg_yzzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 880); 

                auto tg_yzzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 881); 

                auto tg_yzzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 882); 

                auto tg_yzzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 883); 

                auto tg_yzzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 884); 

                auto tg_yzzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 885); 

                auto tg_yzzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 886); 

                auto tg_yzzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 887); 

                auto tg_yzzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 888); 

                auto tg_yzzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 889); 

                auto tg_yzzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 890); 

                auto tg_yzzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 891); 

                auto tg_yzzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 892); 

                auto tg_yzzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 893); 

                auto tg_yzzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 894); 

                auto tg_yzzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 895); 

                auto tg_yzzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 896); 

                auto tg_yzzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 897); 

                auto tg_yzzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 898); 

                auto tg_yzzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 899); 

                auto tg_zzzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 900); 

                auto tg_zzzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 901); 

                auto tg_zzzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 902); 

                auto tg_zzzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 903); 

                auto tg_zzzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 904); 

                auto tg_zzzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 905); 

                auto tg_zzzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 906); 

                auto tg_zzzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 907); 

                auto tg_zzzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 908); 

                auto tg_zzzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 909); 

                auto tg_zzzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 910); 

                auto tg_zzzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 911); 

                auto tg_zzzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 912); 

                auto tg_zzzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 913); 

                auto tg_zzzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 914); 

                auto tg_zzzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 915); 

                auto tg_zzzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 916); 

                auto tg_zzzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 917); 

                auto tg_zzzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 918); 

                auto tg_zzzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 919); 

                auto tg_zzzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 920); 

                auto tg_zzzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 921); 

                auto tg_zzzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 922); 

                auto tg_zzzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 923); 

                auto tg_zzzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 924); 

                auto tg_zzzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 925); 

                auto tg_zzzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 926); 

                auto tg_zzzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 927); 

                auto tg_zzzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 928); 

                auto tg_zzzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 929); 

                auto tg_zzzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 930); 

                auto tg_zzzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 931); 

                auto tg_zzzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 932); 

                auto tg_zzzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 933); 

                auto tg_zzzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 934); 

                auto tg_zzzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 935); 

                auto tg_zzzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 936); 

                auto tg_zzzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 937); 

                auto tg_zzzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 938); 

                auto tg_zzzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 939); 

                auto tg_zzzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 940); 

                auto tg_zzzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 941); 

                auto tg_zzzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 942); 

                auto tg_zzzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 943); 

                auto tg_zzzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 944); 

                auto tg_yyyy_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 450); 

                auto tg_yyyy_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 451); 

                auto tg_yyyy_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 452); 

                auto tg_yyyy_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 453); 

                auto tg_yyyy_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 454); 

                auto tg_yyyy_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 455); 

                auto tg_yyyy_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 456); 

                auto tg_yyyy_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 457); 

                auto tg_yyyy_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 458); 

                auto tg_yyyy_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 459); 

                auto tg_yyyy_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 460); 

                auto tg_yyyy_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 461); 

                auto tg_yyyy_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 462); 

                auto tg_yyyy_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 463); 

                auto tg_yyyy_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 464); 

                auto tg_yyyy_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 465); 

                auto tg_yyyy_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 466); 

                auto tg_yyyy_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 467); 

                auto tg_yyyy_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 468); 

                auto tg_yyyy_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 469); 

                auto tg_yyyy_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 470); 

                auto tg_yyyy_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 471); 

                auto tg_yyyy_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 472); 

                auto tg_yyyy_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 473); 

                auto tg_yyyy_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 474); 

                auto tg_yyyy_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 450); 

                auto tg_yyyy_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 451); 

                auto tg_yyyy_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 452); 

                auto tg_yyyy_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 453); 

                auto tg_yyyy_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 454); 

                auto tg_yyyy_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 455); 

                auto tg_yyyy_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 456); 

                auto tg_yyyy_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 457); 

                auto tg_yyyy_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 458); 

                auto tg_yyyy_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 459); 

                auto tg_yyyy_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 460); 

                auto tg_yyyy_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 461); 

                auto tg_yyyy_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 462); 

                auto tg_yyyy_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 463); 

                auto tg_yyyy_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 464); 

                auto tg_yyyy_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 465); 

                auto tg_yyyy_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 466); 

                auto tg_yyyy_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 467); 

                auto tg_yyyy_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 468); 

                auto tg_yyyy_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 469); 

                auto tg_yyyy_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 470); 

                auto tg_yyyy_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 471); 

                auto tg_yyyy_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 472); 

                auto tg_yyyy_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 473); 

                auto tg_yyyy_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 474); 

                auto tg_yyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 543); 

                auto tg_yyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 558); 

                auto tg_yzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 714); 

                auto tg_yzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 755); 

                // set up pointers to integrals

                auto tg_xyzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 873); 

                auto tg_xyzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 874); 

                auto tg_xyzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 875); 

                auto tg_xyzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 876); 

                auto tg_xyzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 877); 

                auto tg_xyzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 878); 

                auto tg_xyzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 879); 

                auto tg_xyzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 880); 

                auto tg_xyzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 881); 

                auto tg_xyzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 882); 

                auto tg_xyzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 883); 

                auto tg_xyzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 884); 

                auto tg_xyzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 885); 

                auto tg_xyzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 886); 

                auto tg_xyzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 887); 

                auto tg_xyzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 888); 

                auto tg_xyzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 889); 

                auto tg_xyzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 890); 

                auto tg_xyzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 891); 

                auto tg_xyzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 892); 

                auto tg_xyzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 893); 

                auto tg_xyzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 894); 

                auto tg_xyzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 895); 

                auto tg_xyzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 896); 

                auto tg_xyzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 897); 

                auto tg_xyzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 898); 

                auto tg_xyzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 899); 

                auto tg_xzzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 900); 

                auto tg_xzzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 901); 

                auto tg_xzzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 902); 

                auto tg_xzzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 903); 

                auto tg_xzzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 904); 

                auto tg_xzzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 905); 

                auto tg_xzzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 906); 

                auto tg_xzzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 907); 

                auto tg_xzzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 908); 

                auto tg_xzzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 909); 

                auto tg_xzzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 910); 

                auto tg_xzzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 911); 

                auto tg_xzzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 912); 

                auto tg_xzzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 913); 

                auto tg_xzzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 914); 

                auto tg_xzzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 915); 

                auto tg_xzzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 916); 

                auto tg_xzzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 917); 

                auto tg_xzzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 918); 

                auto tg_xzzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 919); 

                auto tg_xzzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 920); 

                auto tg_xzzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 921); 

                auto tg_xzzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 922); 

                auto tg_xzzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 923); 

                auto tg_xzzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 924); 

                auto tg_xzzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 925); 

                auto tg_xzzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 926); 

                auto tg_xzzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 927); 

                auto tg_xzzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 928); 

                auto tg_xzzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 929); 

                auto tg_xzzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 930); 

                auto tg_xzzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 931); 

                auto tg_xzzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 932); 

                auto tg_xzzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 933); 

                auto tg_xzzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 934); 

                auto tg_xzzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 935); 

                auto tg_xzzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 936); 

                auto tg_xzzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 937); 

                auto tg_xzzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 938); 

                auto tg_xzzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 939); 

                auto tg_xzzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 940); 

                auto tg_xzzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 941); 

                auto tg_xzzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 942); 

                auto tg_xzzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 943); 

                auto tg_xzzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 944); 

                auto tg_yyyyyy_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 945); 

                auto tg_yyyyyy_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 946); 

                auto tg_yyyyyy_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 947); 

                auto tg_yyyyyy_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 948); 

                auto tg_yyyyyy_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 949); 

                auto tg_yyyyyy_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 950); 

                auto tg_yyyyyy_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 951); 

                auto tg_yyyyyy_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 952); 

                auto tg_yyyyyy_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 953); 

                auto tg_yyyyyy_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 954); 

                auto tg_yyyyyy_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 955); 

                auto tg_yyyyyy_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 956); 

                auto tg_yyyyyy_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 957); 

                auto tg_yyyyyy_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 958); 

                auto tg_yyyyyy_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 959); 

                auto tg_yyyyyy_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 960); 

                auto tg_yyyyyy_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 961); 

                auto tg_yyyyyy_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 962); 

                auto tg_yyyyyy_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 963); 

                auto tg_yyyyyy_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 964); 

                auto tg_yyyyyy_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 965); 

                auto tg_yyyyyy_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 966); 

                auto tg_yyyyyy_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 967); 

                auto tg_yyyyyy_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 968); 

                auto tg_yyyyyy_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 969); 

                // Batch of Integrals (873,970)

                #pragma omp simd aligned(fxn, fza, tg_xyzzzz_xxxyyzzz_0, tg_xyzzzz_xxxyzzzz_0, \
                                         tg_xyzzzz_xxxzzzzz_0, tg_xyzzzz_xxyyyyyy_0, tg_xyzzzz_xxyyyyyz_0, tg_xyzzzz_xxyyyyzz_0, \
                                         tg_xyzzzz_xxyyyzzz_0, tg_xyzzzz_xxyyzzzz_0, tg_xyzzzz_xxyzzzzz_0, tg_xyzzzz_xxzzzzzz_0, \
                                         tg_xyzzzz_xyyyyyyy_0, tg_xyzzzz_xyyyyyyz_0, tg_xyzzzz_xyyyyyzz_0, tg_xyzzzz_xyyyyzzz_0, \
                                         tg_xyzzzz_xyyyzzzz_0, tg_xyzzzz_xyyzzzzz_0, tg_xyzzzz_xyzzzzzz_0, tg_xyzzzz_xzzzzzzz_0, \
                                         tg_xyzzzz_yyyyyyyy_0, tg_xyzzzz_yyyyyyyz_0, tg_xyzzzz_yyyyyyzz_0, tg_xyzzzz_yyyyyzzz_0, \
                                         tg_xyzzzz_yyyyzzzz_0, tg_xyzzzz_yyyzzzzz_0, tg_xyzzzz_yyzzzzzz_0, tg_xyzzzz_yzzzzzzz_0, \
                                         tg_xyzzzz_zzzzzzzz_0, tg_xzzzzz_xxxxxxxx_0, tg_xzzzzz_xxxxxxxy_0, tg_xzzzzz_xxxxxxxz_0, \
                                         tg_xzzzzz_xxxxxxyy_0, tg_xzzzzz_xxxxxxyz_0, tg_xzzzzz_xxxxxxzz_0, tg_xzzzzz_xxxxxyyy_0, \
                                         tg_xzzzzz_xxxxxyyz_0, tg_xzzzzz_xxxxxyzz_0, tg_xzzzzz_xxxxxzzz_0, tg_xzzzzz_xxxxyyyy_0, \
                                         tg_xzzzzz_xxxxyyyz_0, tg_xzzzzz_xxxxyyzz_0, tg_xzzzzz_xxxxyzzz_0, tg_xzzzzz_xxxxzzzz_0, \
                                         tg_xzzzzz_xxxyyyyy_0, tg_xzzzzz_xxxyyyyz_0, tg_xzzzzz_xxxyyyzz_0, tg_xzzzzz_xxxyyzzz_0, \
                                         tg_xzzzzz_xxxyzzzz_0, tg_xzzzzz_xxxzzzzz_0, tg_xzzzzz_xxyyyyyy_0, tg_xzzzzz_xxyyyyyz_0, \
                                         tg_xzzzzz_xxyyyyzz_0, tg_xzzzzz_xxyyyzzz_0, tg_xzzzzz_xxyyzzzz_0, tg_xzzzzz_xxyzzzzz_0, \
                                         tg_xzzzzz_xxzzzzzz_0, tg_xzzzzz_xyyyyyyy_0, tg_xzzzzz_xyyyyyyz_0, tg_xzzzzz_xyyyyyzz_0, \
                                         tg_xzzzzz_xyyyyzzz_0, tg_xzzzzz_xyyyzzzz_0, tg_xzzzzz_xyyzzzzz_0, tg_xzzzzz_xyzzzzzz_0, \
                                         tg_xzzzzz_xzzzzzzz_0, tg_xzzzzz_yyyyyyyy_0, tg_xzzzzz_yyyyyyyz_0, tg_xzzzzz_yyyyyyzz_0, \
                                         tg_xzzzzz_yyyyyzzz_0, tg_xzzzzz_yyyyzzzz_0, tg_xzzzzz_yyyzzzzz_0, tg_xzzzzz_yyzzzzzz_0, \
                                         tg_xzzzzz_yzzzzzzz_0, tg_xzzzzz_zzzzzzzz_0, tg_yyyy_xxxxxxxx_0, tg_yyyy_xxxxxxxx_1, \
                                         tg_yyyy_xxxxxxxy_0, tg_yyyy_xxxxxxxy_1, tg_yyyy_xxxxxxxz_0, tg_yyyy_xxxxxxxz_1, \
                                         tg_yyyy_xxxxxxyy_0, tg_yyyy_xxxxxxyy_1, tg_yyyy_xxxxxxyz_0, tg_yyyy_xxxxxxyz_1, \
                                         tg_yyyy_xxxxxxzz_0, tg_yyyy_xxxxxxzz_1, tg_yyyy_xxxxxyyy_0, tg_yyyy_xxxxxyyy_1, \
                                         tg_yyyy_xxxxxyyz_0, tg_yyyy_xxxxxyyz_1, tg_yyyy_xxxxxyzz_0, tg_yyyy_xxxxxyzz_1, \
                                         tg_yyyy_xxxxxzzz_0, tg_yyyy_xxxxxzzz_1, tg_yyyy_xxxxyyyy_0, tg_yyyy_xxxxyyyy_1, \
                                         tg_yyyy_xxxxyyyz_0, tg_yyyy_xxxxyyyz_1, tg_yyyy_xxxxyyzz_0, tg_yyyy_xxxxyyzz_1, \
                                         tg_yyyy_xxxxyzzz_0, tg_yyyy_xxxxyzzz_1, tg_yyyy_xxxxzzzz_0, tg_yyyy_xxxxzzzz_1, \
                                         tg_yyyy_xxxyyyyy_0, tg_yyyy_xxxyyyyy_1, tg_yyyy_xxxyyyyz_0, tg_yyyy_xxxyyyyz_1, \
                                         tg_yyyy_xxxyyyzz_0, tg_yyyy_xxxyyyzz_1, tg_yyyy_xxxyyzzz_0, tg_yyyy_xxxyyzzz_1, \
                                         tg_yyyy_xxxyzzzz_0, tg_yyyy_xxxyzzzz_1, tg_yyyy_xxxzzzzz_0, tg_yyyy_xxxzzzzz_1, \
                                         tg_yyyy_xxyyyyyy_0, tg_yyyy_xxyyyyyy_1, tg_yyyy_xxyyyyyz_0, tg_yyyy_xxyyyyyz_1, \
                                         tg_yyyy_xxyyyyzz_0, tg_yyyy_xxyyyyzz_1, tg_yyyy_xxyyyzzz_0, tg_yyyy_xxyyyzzz_1, \
                                         tg_yyyyy_xxxxxxx_1, tg_yyyyy_xxxxxxxx_0, tg_yyyyy_xxxxxxxx_1, tg_yyyyy_xxxxxxxy_0, \
                                         tg_yyyyy_xxxxxxxy_1, tg_yyyyy_xxxxxxxz_0, tg_yyyyy_xxxxxxxz_1, tg_yyyyy_xxxxxxy_1, \
                                         tg_yyyyy_xxxxxxyy_0, tg_yyyyy_xxxxxxyy_1, tg_yyyyy_xxxxxxyz_0, tg_yyyyy_xxxxxxyz_1, \
                                         tg_yyyyy_xxxxxxz_1, tg_yyyyy_xxxxxxzz_0, tg_yyyyy_xxxxxxzz_1, tg_yyyyy_xxxxxyy_1, \
                                         tg_yyyyy_xxxxxyyy_0, tg_yyyyy_xxxxxyyy_1, tg_yyyyy_xxxxxyyz_0, tg_yyyyy_xxxxxyyz_1, \
                                         tg_yyyyy_xxxxxyz_1, tg_yyyyy_xxxxxyzz_0, tg_yyyyy_xxxxxyzz_1, tg_yyyyy_xxxxxzz_1, \
                                         tg_yyyyy_xxxxxzzz_0, tg_yyyyy_xxxxxzzz_1, tg_yyyyy_xxxxyyy_1, tg_yyyyy_xxxxyyyy_0, \
                                         tg_yyyyy_xxxxyyyy_1, tg_yyyyy_xxxxyyyz_0, tg_yyyyy_xxxxyyyz_1, tg_yyyyy_xxxxyyz_1, \
                                         tg_yyyyy_xxxxyyzz_0, tg_yyyyy_xxxxyyzz_1, tg_yyyyy_xxxxyzz_1, tg_yyyyy_xxxxyzzz_0, \
                                         tg_yyyyy_xxxxyzzz_1, tg_yyyyy_xxxxzzz_1, tg_yyyyy_xxxxzzzz_0, tg_yyyyy_xxxxzzzz_1, \
                                         tg_yyyyy_xxxyyyy_1, tg_yyyyy_xxxyyyyy_0, tg_yyyyy_xxxyyyyy_1, tg_yyyyy_xxxyyyyz_0, \
                                         tg_yyyyy_xxxyyyyz_1, tg_yyyyy_xxxyyyz_1, tg_yyyyy_xxxyyyzz_0, tg_yyyyy_xxxyyyzz_1, \
                                         tg_yyyyy_xxxyyzz_1, tg_yyyyy_xxxyyzzz_0, tg_yyyyy_xxxyyzzz_1, tg_yyyyy_xxxyzzz_1, \
                                         tg_yyyyy_xxxyzzzz_0, tg_yyyyy_xxxyzzzz_1, tg_yyyyy_xxxzzzz_1, tg_yyyyy_xxxzzzzz_0, \
                                         tg_yyyyy_xxxzzzzz_1, tg_yyyyy_xxyyyyy_1, tg_yyyyy_xxyyyyyy_0, tg_yyyyy_xxyyyyyy_1, \
                                         tg_yyyyy_xxyyyyyz_0, tg_yyyyy_xxyyyyyz_1, tg_yyyyy_xxyyyyz_1, tg_yyyyy_xxyyyyzz_0, \
                                         tg_yyyyy_xxyyyyzz_1, tg_yyyyy_xxyyyzz_1, tg_yyyyy_xxyyyzzz_0, tg_yyyyy_xxyyyzzz_1, \
                                         tg_yyyyy_xxyyzzz_1, tg_yyyyyy_xxxxxxxx_0, tg_yyyyyy_xxxxxxxy_0, tg_yyyyyy_xxxxxxxz_0, \
                                         tg_yyyyyy_xxxxxxyy_0, tg_yyyyyy_xxxxxxyz_0, tg_yyyyyy_xxxxxxzz_0, tg_yyyyyy_xxxxxyyy_0, \
                                         tg_yyyyyy_xxxxxyyz_0, tg_yyyyyy_xxxxxyzz_0, tg_yyyyyy_xxxxxzzz_0, tg_yyyyyy_xxxxyyyy_0, \
                                         tg_yyyyyy_xxxxyyyz_0, tg_yyyyyy_xxxxyyzz_0, tg_yyyyyy_xxxxyzzz_0, tg_yyyyyy_xxxxzzzz_0, \
                                         tg_yyyyyy_xxxyyyyy_0, tg_yyyyyy_xxxyyyyz_0, tg_yyyyyy_xxxyyyzz_0, tg_yyyyyy_xxxyyzzz_0, \
                                         tg_yyyyyy_xxxyzzzz_0, tg_yyyyyy_xxxzzzzz_0, tg_yyyyyy_xxyyyyyy_0, tg_yyyyyy_xxyyyyyz_0, \
                                         tg_yyyyyy_xxyyyyzz_0, tg_yyyyyy_xxyyyzzz_0, tg_yzzzz_xxxyyzzz_0, tg_yzzzz_xxxyyzzz_1, \
                                         tg_yzzzz_xxxyzzzz_0, tg_yzzzz_xxxyzzzz_1, tg_yzzzz_xxxzzzzz_0, tg_yzzzz_xxxzzzzz_1, \
                                         tg_yzzzz_xxyyyyyy_0, tg_yzzzz_xxyyyyyy_1, tg_yzzzz_xxyyyyyz_0, tg_yzzzz_xxyyyyyz_1, \
                                         tg_yzzzz_xxyyyyzz_0, tg_yzzzz_xxyyyyzz_1, tg_yzzzz_xxyyyzzz_0, tg_yzzzz_xxyyyzzz_1, \
                                         tg_yzzzz_xxyyzzz_1, tg_yzzzz_xxyyzzzz_0, tg_yzzzz_xxyyzzzz_1, tg_yzzzz_xxyzzzz_1, \
                                         tg_yzzzz_xxyzzzzz_0, tg_yzzzz_xxyzzzzz_1, tg_yzzzz_xxzzzzz_1, tg_yzzzz_xxzzzzzz_0, \
                                         tg_yzzzz_xxzzzzzz_1, tg_yzzzz_xyyyyyy_1, tg_yzzzz_xyyyyyyy_0, tg_yzzzz_xyyyyyyy_1, \
                                         tg_yzzzz_xyyyyyyz_0, tg_yzzzz_xyyyyyyz_1, tg_yzzzz_xyyyyyz_1, tg_yzzzz_xyyyyyzz_0, \
                                         tg_yzzzz_xyyyyyzz_1, tg_yzzzz_xyyyyzz_1, tg_yzzzz_xyyyyzzz_0, tg_yzzzz_xyyyyzzz_1, \
                                         tg_yzzzz_xyyyzzz_1, tg_yzzzz_xyyyzzzz_0, tg_yzzzz_xyyyzzzz_1, tg_yzzzz_xyyzzzz_1, \
                                         tg_yzzzz_xyyzzzzz_0, tg_yzzzz_xyyzzzzz_1, tg_yzzzz_xyzzzzz_1, tg_yzzzz_xyzzzzzz_0, \
                                         tg_yzzzz_xyzzzzzz_1, tg_yzzzz_xzzzzzz_1, tg_yzzzz_xzzzzzzz_0, tg_yzzzz_xzzzzzzz_1, \
                                         tg_yzzzz_yyyyyyy_1, tg_yzzzz_yyyyyyyy_0, tg_yzzzz_yyyyyyyy_1, tg_yzzzz_yyyyyyyz_0, \
                                         tg_yzzzz_yyyyyyyz_1, tg_yzzzz_yyyyyyz_1, tg_yzzzz_yyyyyyzz_0, tg_yzzzz_yyyyyyzz_1, \
                                         tg_yzzzz_yyyyyzz_1, tg_yzzzz_yyyyyzzz_0, tg_yzzzz_yyyyyzzz_1, tg_yzzzz_yyyyzzz_1, \
                                         tg_yzzzz_yyyyzzzz_0, tg_yzzzz_yyyyzzzz_1, tg_yzzzz_yyyzzzz_1, tg_yzzzz_yyyzzzzz_0, \
                                         tg_yzzzz_yyyzzzzz_1, tg_yzzzz_yyzzzzz_1, tg_yzzzz_yyzzzzzz_0, tg_yzzzz_yyzzzzzz_1, \
                                         tg_yzzzz_yzzzzzz_1, tg_yzzzz_yzzzzzzz_0, tg_yzzzz_yzzzzzzz_1, tg_yzzzz_zzzzzzz_1, \
                                         tg_yzzzz_zzzzzzzz_0, tg_yzzzz_zzzzzzzz_1, tg_zzzzz_xxxxxxx_1, tg_zzzzz_xxxxxxxx_0, \
                                         tg_zzzzz_xxxxxxxx_1, tg_zzzzz_xxxxxxxy_0, tg_zzzzz_xxxxxxxy_1, tg_zzzzz_xxxxxxxz_0, \
                                         tg_zzzzz_xxxxxxxz_1, tg_zzzzz_xxxxxxy_1, tg_zzzzz_xxxxxxyy_0, tg_zzzzz_xxxxxxyy_1, \
                                         tg_zzzzz_xxxxxxyz_0, tg_zzzzz_xxxxxxyz_1, tg_zzzzz_xxxxxxz_1, tg_zzzzz_xxxxxxzz_0, \
                                         tg_zzzzz_xxxxxxzz_1, tg_zzzzz_xxxxxyy_1, tg_zzzzz_xxxxxyyy_0, tg_zzzzz_xxxxxyyy_1, \
                                         tg_zzzzz_xxxxxyyz_0, tg_zzzzz_xxxxxyyz_1, tg_zzzzz_xxxxxyz_1, tg_zzzzz_xxxxxyzz_0, \
                                         tg_zzzzz_xxxxxyzz_1, tg_zzzzz_xxxxxzz_1, tg_zzzzz_xxxxxzzz_0, tg_zzzzz_xxxxxzzz_1, \
                                         tg_zzzzz_xxxxyyy_1, tg_zzzzz_xxxxyyyy_0, tg_zzzzz_xxxxyyyy_1, tg_zzzzz_xxxxyyyz_0, \
                                         tg_zzzzz_xxxxyyyz_1, tg_zzzzz_xxxxyyz_1, tg_zzzzz_xxxxyyzz_0, tg_zzzzz_xxxxyyzz_1, \
                                         tg_zzzzz_xxxxyzz_1, tg_zzzzz_xxxxyzzz_0, tg_zzzzz_xxxxyzzz_1, tg_zzzzz_xxxxzzz_1, \
                                         tg_zzzzz_xxxxzzzz_0, tg_zzzzz_xxxxzzzz_1, tg_zzzzz_xxxyyyy_1, tg_zzzzz_xxxyyyyy_0, \
                                         tg_zzzzz_xxxyyyyy_1, tg_zzzzz_xxxyyyyz_0, tg_zzzzz_xxxyyyyz_1, tg_zzzzz_xxxyyyz_1, \
                                         tg_zzzzz_xxxyyyzz_0, tg_zzzzz_xxxyyyzz_1, tg_zzzzz_xxxyyzz_1, tg_zzzzz_xxxyyzzz_0, \
                                         tg_zzzzz_xxxyyzzz_1, tg_zzzzz_xxxyzzz_1, tg_zzzzz_xxxyzzzz_0, tg_zzzzz_xxxyzzzz_1, \
                                         tg_zzzzz_xxxzzzz_1, tg_zzzzz_xxxzzzzz_0, tg_zzzzz_xxxzzzzz_1, tg_zzzzz_xxyyyyy_1, \
                                         tg_zzzzz_xxyyyyyy_0, tg_zzzzz_xxyyyyyy_1, tg_zzzzz_xxyyyyyz_0, tg_zzzzz_xxyyyyyz_1, \
                                         tg_zzzzz_xxyyyyz_1, tg_zzzzz_xxyyyyzz_0, tg_zzzzz_xxyyyyzz_1, tg_zzzzz_xxyyyzz_1, \
                                         tg_zzzzz_xxyyyzzz_0, tg_zzzzz_xxyyyzzz_1, tg_zzzzz_xxyyzzz_1, tg_zzzzz_xxyyzzzz_0, \
                                         tg_zzzzz_xxyyzzzz_1, tg_zzzzz_xxyzzzz_1, tg_zzzzz_xxyzzzzz_0, tg_zzzzz_xxyzzzzz_1, \
                                         tg_zzzzz_xxzzzzz_1, tg_zzzzz_xxzzzzzz_0, tg_zzzzz_xxzzzzzz_1, tg_zzzzz_xyyyyyy_1, \
                                         tg_zzzzz_xyyyyyyy_0, tg_zzzzz_xyyyyyyy_1, tg_zzzzz_xyyyyyyz_0, tg_zzzzz_xyyyyyyz_1, \
                                         tg_zzzzz_xyyyyyz_1, tg_zzzzz_xyyyyyzz_0, tg_zzzzz_xyyyyyzz_1, tg_zzzzz_xyyyyzz_1, \
                                         tg_zzzzz_xyyyyzzz_0, tg_zzzzz_xyyyyzzz_1, tg_zzzzz_xyyyzzz_1, tg_zzzzz_xyyyzzzz_0, \
                                         tg_zzzzz_xyyyzzzz_1, tg_zzzzz_xyyzzzz_1, tg_zzzzz_xyyzzzzz_0, tg_zzzzz_xyyzzzzz_1, \
                                         tg_zzzzz_xyzzzzz_1, tg_zzzzz_xyzzzzzz_0, tg_zzzzz_xyzzzzzz_1, tg_zzzzz_xzzzzzz_1, \
                                         tg_zzzzz_xzzzzzzz_0, tg_zzzzz_xzzzzzzz_1, tg_zzzzz_yyyyyyy_1, tg_zzzzz_yyyyyyyy_0, \
                                         tg_zzzzz_yyyyyyyy_1, tg_zzzzz_yyyyyyyz_0, tg_zzzzz_yyyyyyyz_1, tg_zzzzz_yyyyyyz_1, \
                                         tg_zzzzz_yyyyyyzz_0, tg_zzzzz_yyyyyyzz_1, tg_zzzzz_yyyyyzz_1, tg_zzzzz_yyyyyzzz_0, \
                                         tg_zzzzz_yyyyyzzz_1, tg_zzzzz_yyyyzzz_1, tg_zzzzz_yyyyzzzz_0, tg_zzzzz_yyyyzzzz_1, \
                                         tg_zzzzz_yyyzzzz_1, tg_zzzzz_yyyzzzzz_0, tg_zzzzz_yyyzzzzz_1, tg_zzzzz_yyzzzzz_1, \
                                         tg_zzzzz_yyzzzzzz_0, tg_zzzzz_yyzzzzzz_1, tg_zzzzz_yzzzzzz_1, tg_zzzzz_yzzzzzzz_0, \
                                         tg_zzzzz_yzzzzzzz_1, tg_zzzzz_zzzzzzz_1, tg_zzzzz_zzzzzzzz_0, tg_zzzzz_zzzzzzzz_1, wp_x, \
                                         wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xyzzzz_xxxyyzzz_0[j] = pb_x * tg_yzzzz_xxxyyzzz_0[j] + fr * tg_yzzzz_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxyyzzz_1[j];

                    tg_xyzzzz_xxxyzzzz_0[j] = pb_x * tg_yzzzz_xxxyzzzz_0[j] + fr * tg_yzzzz_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxyzzzz_1[j];

                    tg_xyzzzz_xxxzzzzz_0[j] = pb_x * tg_yzzzz_xxxzzzzz_0[j] + fr * tg_yzzzz_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzz_xxzzzzz_1[j];

                    tg_xyzzzz_xxyyyyyy_0[j] = pb_x * tg_yzzzz_xxyyyyyy_0[j] + fr * tg_yzzzz_xxyyyyyy_1[j] + fl1_fxn * tg_yzzzz_xyyyyyy_1[j];

                    tg_xyzzzz_xxyyyyyz_0[j] = pb_x * tg_yzzzz_xxyyyyyz_0[j] + fr * tg_yzzzz_xxyyyyyz_1[j] + fl1_fxn * tg_yzzzz_xyyyyyz_1[j];

                    tg_xyzzzz_xxyyyyzz_0[j] = pb_x * tg_yzzzz_xxyyyyzz_0[j] + fr * tg_yzzzz_xxyyyyzz_1[j] + fl1_fxn * tg_yzzzz_xyyyyzz_1[j];

                    tg_xyzzzz_xxyyyzzz_0[j] = pb_x * tg_yzzzz_xxyyyzzz_0[j] + fr * tg_yzzzz_xxyyyzzz_1[j] + fl1_fxn * tg_yzzzz_xyyyzzz_1[j];

                    tg_xyzzzz_xxyyzzzz_0[j] = pb_x * tg_yzzzz_xxyyzzzz_0[j] + fr * tg_yzzzz_xxyyzzzz_1[j] + fl1_fxn * tg_yzzzz_xyyzzzz_1[j];

                    tg_xyzzzz_xxyzzzzz_0[j] = pb_x * tg_yzzzz_xxyzzzzz_0[j] + fr * tg_yzzzz_xxyzzzzz_1[j] + fl1_fxn * tg_yzzzz_xyzzzzz_1[j];

                    tg_xyzzzz_xxzzzzzz_0[j] = pb_x * tg_yzzzz_xxzzzzzz_0[j] + fr * tg_yzzzz_xxzzzzzz_1[j] + fl1_fxn * tg_yzzzz_xzzzzzz_1[j];

                    tg_xyzzzz_xyyyyyyy_0[j] = pb_x * tg_yzzzz_xyyyyyyy_0[j] + fr * tg_yzzzz_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyyyyyy_1[j];

                    tg_xyzzzz_xyyyyyyz_0[j] = pb_x * tg_yzzzz_xyyyyyyz_0[j] + fr * tg_yzzzz_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyyyyyz_1[j];

                    tg_xyzzzz_xyyyyyzz_0[j] = pb_x * tg_yzzzz_xyyyyyzz_0[j] + fr * tg_yzzzz_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyyyyzz_1[j];

                    tg_xyzzzz_xyyyyzzz_0[j] = pb_x * tg_yzzzz_xyyyyzzz_0[j] + fr * tg_yzzzz_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyyyzzz_1[j];

                    tg_xyzzzz_xyyyzzzz_0[j] = pb_x * tg_yzzzz_xyyyzzzz_0[j] + fr * tg_yzzzz_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyyzzzz_1[j];

                    tg_xyzzzz_xyyzzzzz_0[j] = pb_x * tg_yzzzz_xyyzzzzz_0[j] + fr * tg_yzzzz_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yyzzzzz_1[j];

                    tg_xyzzzz_xyzzzzzz_0[j] = pb_x * tg_yzzzz_xyzzzzzz_0[j] + fr * tg_yzzzz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_yzzzzzz_1[j];

                    tg_xyzzzz_xzzzzzzz_0[j] = pb_x * tg_yzzzz_xzzzzzzz_0[j] + fr * tg_yzzzz_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzz_zzzzzzz_1[j];

                    tg_xyzzzz_yyyyyyyy_0[j] = pb_x * tg_yzzzz_yyyyyyyy_0[j] + fr * tg_yzzzz_yyyyyyyy_1[j];

                    tg_xyzzzz_yyyyyyyz_0[j] = pb_x * tg_yzzzz_yyyyyyyz_0[j] + fr * tg_yzzzz_yyyyyyyz_1[j];

                    tg_xyzzzz_yyyyyyzz_0[j] = pb_x * tg_yzzzz_yyyyyyzz_0[j] + fr * tg_yzzzz_yyyyyyzz_1[j];

                    tg_xyzzzz_yyyyyzzz_0[j] = pb_x * tg_yzzzz_yyyyyzzz_0[j] + fr * tg_yzzzz_yyyyyzzz_1[j];

                    tg_xyzzzz_yyyyzzzz_0[j] = pb_x * tg_yzzzz_yyyyzzzz_0[j] + fr * tg_yzzzz_yyyyzzzz_1[j];

                    tg_xyzzzz_yyyzzzzz_0[j] = pb_x * tg_yzzzz_yyyzzzzz_0[j] + fr * tg_yzzzz_yyyzzzzz_1[j];

                    tg_xyzzzz_yyzzzzzz_0[j] = pb_x * tg_yzzzz_yyzzzzzz_0[j] + fr * tg_yzzzz_yyzzzzzz_1[j];

                    tg_xyzzzz_yzzzzzzz_0[j] = pb_x * tg_yzzzz_yzzzzzzz_0[j] + fr * tg_yzzzz_yzzzzzzz_1[j];

                    tg_xyzzzz_zzzzzzzz_0[j] = pb_x * tg_yzzzz_zzzzzzzz_0[j] + fr * tg_yzzzz_zzzzzzzz_1[j];

                    tg_xzzzzz_xxxxxxxx_0[j] = pb_x * tg_zzzzz_xxxxxxxx_0[j] + fr * tg_zzzzz_xxxxxxxx_1[j] + 4.0 * fl1_fxn * tg_zzzzz_xxxxxxx_1[j];

                    tg_xzzzzz_xxxxxxxy_0[j] = pb_x * tg_zzzzz_xxxxxxxy_0[j] + fr * tg_zzzzz_xxxxxxxy_1[j] + 3.5 * fl1_fxn * tg_zzzzz_xxxxxxy_1[j];

                    tg_xzzzzz_xxxxxxxz_0[j] = pb_x * tg_zzzzz_xxxxxxxz_0[j] + fr * tg_zzzzz_xxxxxxxz_1[j] + 3.5 * fl1_fxn * tg_zzzzz_xxxxxxz_1[j];

                    tg_xzzzzz_xxxxxxyy_0[j] = pb_x * tg_zzzzz_xxxxxxyy_0[j] + fr * tg_zzzzz_xxxxxxyy_1[j] + 3.0 * fl1_fxn * tg_zzzzz_xxxxxyy_1[j];

                    tg_xzzzzz_xxxxxxyz_0[j] = pb_x * tg_zzzzz_xxxxxxyz_0[j] + fr * tg_zzzzz_xxxxxxyz_1[j] + 3.0 * fl1_fxn * tg_zzzzz_xxxxxyz_1[j];

                    tg_xzzzzz_xxxxxxzz_0[j] = pb_x * tg_zzzzz_xxxxxxzz_0[j] + fr * tg_zzzzz_xxxxxxzz_1[j] + 3.0 * fl1_fxn * tg_zzzzz_xxxxxzz_1[j];

                    tg_xzzzzz_xxxxxyyy_0[j] = pb_x * tg_zzzzz_xxxxxyyy_0[j] + fr * tg_zzzzz_xxxxxyyy_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxxxyyy_1[j];

                    tg_xzzzzz_xxxxxyyz_0[j] = pb_x * tg_zzzzz_xxxxxyyz_0[j] + fr * tg_zzzzz_xxxxxyyz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxxxyyz_1[j];

                    tg_xzzzzz_xxxxxyzz_0[j] = pb_x * tg_zzzzz_xxxxxyzz_0[j] + fr * tg_zzzzz_xxxxxyzz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxxxyzz_1[j];

                    tg_xzzzzz_xxxxxzzz_0[j] = pb_x * tg_zzzzz_xxxxxzzz_0[j] + fr * tg_zzzzz_xxxxxzzz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxxxzzz_1[j];

                    tg_xzzzzz_xxxxyyyy_0[j] = pb_x * tg_zzzzz_xxxxyyyy_0[j] + fr * tg_zzzzz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxyyyy_1[j];

                    tg_xzzzzz_xxxxyyyz_0[j] = pb_x * tg_zzzzz_xxxxyyyz_0[j] + fr * tg_zzzzz_xxxxyyyz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxyyyz_1[j];

                    tg_xzzzzz_xxxxyyzz_0[j] = pb_x * tg_zzzzz_xxxxyyzz_0[j] + fr * tg_zzzzz_xxxxyyzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxyyzz_1[j];

                    tg_xzzzzz_xxxxyzzz_0[j] = pb_x * tg_zzzzz_xxxxyzzz_0[j] + fr * tg_zzzzz_xxxxyzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxyzzz_1[j];

                    tg_xzzzzz_xxxxzzzz_0[j] = pb_x * tg_zzzzz_xxxxzzzz_0[j] + fr * tg_zzzzz_xxxxzzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxzzzz_1[j];

                    tg_xzzzzz_xxxyyyyy_0[j] = pb_x * tg_zzzzz_xxxyyyyy_0[j] + fr * tg_zzzzz_xxxyyyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyyyyy_1[j];

                    tg_xzzzzz_xxxyyyyz_0[j] = pb_x * tg_zzzzz_xxxyyyyz_0[j] + fr * tg_zzzzz_xxxyyyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyyyyz_1[j];

                    tg_xzzzzz_xxxyyyzz_0[j] = pb_x * tg_zzzzz_xxxyyyzz_0[j] + fr * tg_zzzzz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyyyzz_1[j];

                    tg_xzzzzz_xxxyyzzz_0[j] = pb_x * tg_zzzzz_xxxyyzzz_0[j] + fr * tg_zzzzz_xxxyyzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyyzzz_1[j];

                    tg_xzzzzz_xxxyzzzz_0[j] = pb_x * tg_zzzzz_xxxyzzzz_0[j] + fr * tg_zzzzz_xxxyzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyzzzz_1[j];

                    tg_xzzzzz_xxxzzzzz_0[j] = pb_x * tg_zzzzz_xxxzzzzz_0[j] + fr * tg_zzzzz_xxxzzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxzzzzz_1[j];

                    tg_xzzzzz_xxyyyyyy_0[j] = pb_x * tg_zzzzz_xxyyyyyy_0[j] + fr * tg_zzzzz_xxyyyyyy_1[j] + fl1_fxn * tg_zzzzz_xyyyyyy_1[j];

                    tg_xzzzzz_xxyyyyyz_0[j] = pb_x * tg_zzzzz_xxyyyyyz_0[j] + fr * tg_zzzzz_xxyyyyyz_1[j] + fl1_fxn * tg_zzzzz_xyyyyyz_1[j];

                    tg_xzzzzz_xxyyyyzz_0[j] = pb_x * tg_zzzzz_xxyyyyzz_0[j] + fr * tg_zzzzz_xxyyyyzz_1[j] + fl1_fxn * tg_zzzzz_xyyyyzz_1[j];

                    tg_xzzzzz_xxyyyzzz_0[j] = pb_x * tg_zzzzz_xxyyyzzz_0[j] + fr * tg_zzzzz_xxyyyzzz_1[j] + fl1_fxn * tg_zzzzz_xyyyzzz_1[j];

                    tg_xzzzzz_xxyyzzzz_0[j] = pb_x * tg_zzzzz_xxyyzzzz_0[j] + fr * tg_zzzzz_xxyyzzzz_1[j] + fl1_fxn * tg_zzzzz_xyyzzzz_1[j];

                    tg_xzzzzz_xxyzzzzz_0[j] = pb_x * tg_zzzzz_xxyzzzzz_0[j] + fr * tg_zzzzz_xxyzzzzz_1[j] + fl1_fxn * tg_zzzzz_xyzzzzz_1[j];

                    tg_xzzzzz_xxzzzzzz_0[j] = pb_x * tg_zzzzz_xxzzzzzz_0[j] + fr * tg_zzzzz_xxzzzzzz_1[j] + fl1_fxn * tg_zzzzz_xzzzzzz_1[j];

                    tg_xzzzzz_xyyyyyyy_0[j] = pb_x * tg_zzzzz_xyyyyyyy_0[j] + fr * tg_zzzzz_xyyyyyyy_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyyyyyy_1[j];

                    tg_xzzzzz_xyyyyyyz_0[j] = pb_x * tg_zzzzz_xyyyyyyz_0[j] + fr * tg_zzzzz_xyyyyyyz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyyyyyz_1[j];

                    tg_xzzzzz_xyyyyyzz_0[j] = pb_x * tg_zzzzz_xyyyyyzz_0[j] + fr * tg_zzzzz_xyyyyyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyyyyzz_1[j];

                    tg_xzzzzz_xyyyyzzz_0[j] = pb_x * tg_zzzzz_xyyyyzzz_0[j] + fr * tg_zzzzz_xyyyyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyyyzzz_1[j];

                    tg_xzzzzz_xyyyzzzz_0[j] = pb_x * tg_zzzzz_xyyyzzzz_0[j] + fr * tg_zzzzz_xyyyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyyzzzz_1[j];

                    tg_xzzzzz_xyyzzzzz_0[j] = pb_x * tg_zzzzz_xyyzzzzz_0[j] + fr * tg_zzzzz_xyyzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yyzzzzz_1[j];

                    tg_xzzzzz_xyzzzzzz_0[j] = pb_x * tg_zzzzz_xyzzzzzz_0[j] + fr * tg_zzzzz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_yzzzzzz_1[j];

                    tg_xzzzzz_xzzzzzzz_0[j] = pb_x * tg_zzzzz_xzzzzzzz_0[j] + fr * tg_zzzzz_xzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_zzzzzzz_1[j];

                    tg_xzzzzz_yyyyyyyy_0[j] = pb_x * tg_zzzzz_yyyyyyyy_0[j] + fr * tg_zzzzz_yyyyyyyy_1[j];

                    tg_xzzzzz_yyyyyyyz_0[j] = pb_x * tg_zzzzz_yyyyyyyz_0[j] + fr * tg_zzzzz_yyyyyyyz_1[j];

                    tg_xzzzzz_yyyyyyzz_0[j] = pb_x * tg_zzzzz_yyyyyyzz_0[j] + fr * tg_zzzzz_yyyyyyzz_1[j];

                    tg_xzzzzz_yyyyyzzz_0[j] = pb_x * tg_zzzzz_yyyyyzzz_0[j] + fr * tg_zzzzz_yyyyyzzz_1[j];

                    tg_xzzzzz_yyyyzzzz_0[j] = pb_x * tg_zzzzz_yyyyzzzz_0[j] + fr * tg_zzzzz_yyyyzzzz_1[j];

                    tg_xzzzzz_yyyzzzzz_0[j] = pb_x * tg_zzzzz_yyyzzzzz_0[j] + fr * tg_zzzzz_yyyzzzzz_1[j];

                    tg_xzzzzz_yyzzzzzz_0[j] = pb_x * tg_zzzzz_yyzzzzzz_0[j] + fr * tg_zzzzz_yyzzzzzz_1[j];

                    tg_xzzzzz_yzzzzzzz_0[j] = pb_x * tg_zzzzz_yzzzzzzz_0[j] + fr * tg_zzzzz_yzzzzzzz_1[j];

                    tg_xzzzzz_zzzzzzzz_0[j] = pb_x * tg_zzzzz_zzzzzzzz_0[j] + fr * tg_zzzzz_zzzzzzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyy_xxxxxxxx_0[j] = pb_y * tg_yyyyy_xxxxxxxx_0[j] + fr * tg_yyyyy_xxxxxxxx_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxxx_0[j] - tg_yyyy_xxxxxxxx_1[j] * fl1_fza);

                    tg_yyyyyy_xxxxxxxy_0[j] = pb_y * tg_yyyyy_xxxxxxxy_0[j] + fr * tg_yyyyy_xxxxxxxy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxxy_0[j] - tg_yyyy_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxxxxxx_1[j];

                    tg_yyyyyy_xxxxxxxz_0[j] = pb_y * tg_yyyyy_xxxxxxxz_0[j] + fr * tg_yyyyy_xxxxxxxz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxxz_0[j] - tg_yyyy_xxxxxxxz_1[j] * fl1_fza);

                    tg_yyyyyy_xxxxxxyy_0[j] = pb_y * tg_yyyyy_xxxxxxyy_0[j] + fr * tg_yyyyy_xxxxxxyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxyy_0[j] - tg_yyyy_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xxxxxxy_1[j];

                    tg_yyyyyy_xxxxxxyz_0[j] = pb_y * tg_yyyyy_xxxxxxyz_0[j] + fr * tg_yyyyy_xxxxxxyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxyz_0[j] - tg_yyyy_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxxxxxz_1[j];

                    tg_yyyyyy_xxxxxxzz_0[j] = pb_y * tg_yyyyy_xxxxxxzz_0[j] + fr * tg_yyyyy_xxxxxxzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxxzz_0[j] - tg_yyyy_xxxxxxzz_1[j] * fl1_fza);

                    tg_yyyyyy_xxxxxyyy_0[j] = pb_y * tg_yyyyy_xxxxxyyy_0[j] + fr * tg_yyyyy_xxxxxyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxyyy_0[j] - tg_yyyy_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_xxxxxyy_1[j];

                    tg_yyyyyy_xxxxxyyz_0[j] = pb_y * tg_yyyyy_xxxxxyyz_0[j] + fr * tg_yyyyy_xxxxxyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxyyz_0[j] - tg_yyyy_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xxxxxyz_1[j];

                    tg_yyyyyy_xxxxxyzz_0[j] = pb_y * tg_yyyyy_xxxxxyzz_0[j] + fr * tg_yyyyy_xxxxxyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxyzz_0[j] - tg_yyyy_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxxxxzz_1[j];

                    tg_yyyyyy_xxxxxzzz_0[j] = pb_y * tg_yyyyy_xxxxxzzz_0[j] + fr * tg_yyyyy_xxxxxzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxxzzz_0[j] - tg_yyyy_xxxxxzzz_1[j] * fl1_fza);

                    tg_yyyyyy_xxxxyyyy_0[j] = pb_y * tg_yyyyy_xxxxyyyy_0[j] + fr * tg_yyyyy_xxxxyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxyyyy_0[j] - tg_yyyy_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyy_xxxxyyy_1[j];

                    tg_yyyyyy_xxxxyyyz_0[j] = pb_y * tg_yyyyy_xxxxyyyz_0[j] + fr * tg_yyyyy_xxxxyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxyyyz_0[j] - tg_yyyy_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_xxxxyyz_1[j];

                    tg_yyyyyy_xxxxyyzz_0[j] = pb_y * tg_yyyyy_xxxxyyzz_0[j] + fr * tg_yyyyy_xxxxyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxyyzz_0[j] - tg_yyyy_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xxxxyzz_1[j];

                    tg_yyyyyy_xxxxyzzz_0[j] = pb_y * tg_yyyyy_xxxxyzzz_0[j] + fr * tg_yyyyy_xxxxyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxyzzz_0[j] - tg_yyyy_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxxxzzz_1[j];

                    tg_yyyyyy_xxxxzzzz_0[j] = pb_y * tg_yyyyy_xxxxzzzz_0[j] + fr * tg_yyyyy_xxxxzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxxzzzz_0[j] - tg_yyyy_xxxxzzzz_1[j] * fl1_fza);

                    tg_yyyyyy_xxxyyyyy_0[j] = pb_y * tg_yyyyy_xxxyyyyy_0[j] + fr * tg_yyyyy_xxxyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxyyyyy_0[j] - tg_yyyy_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyy_xxxyyyy_1[j];

                    tg_yyyyyy_xxxyyyyz_0[j] = pb_y * tg_yyyyy_xxxyyyyz_0[j] + fr * tg_yyyyy_xxxyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxyyyyz_0[j] - tg_yyyy_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyy_xxxyyyz_1[j];

                    tg_yyyyyy_xxxyyyzz_0[j] = pb_y * tg_yyyyy_xxxyyyzz_0[j] + fr * tg_yyyyy_xxxyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxyyyzz_0[j] - tg_yyyy_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_xxxyyzz_1[j];

                    tg_yyyyyy_xxxyyzzz_0[j] = pb_y * tg_yyyyy_xxxyyzzz_0[j] + fr * tg_yyyyy_xxxyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxyyzzz_0[j] - tg_yyyy_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xxxyzzz_1[j];

                    tg_yyyyyy_xxxyzzzz_0[j] = pb_y * tg_yyyyy_xxxyzzzz_0[j] + fr * tg_yyyyy_xxxyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxyzzzz_0[j] - tg_yyyy_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxxzzzz_1[j];

                    tg_yyyyyy_xxxzzzzz_0[j] = pb_y * tg_yyyyy_xxxzzzzz_0[j] + fr * tg_yyyyy_xxxzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxxzzzzz_0[j] - tg_yyyy_xxxzzzzz_1[j] * fl1_fza);

                    tg_yyyyyy_xxyyyyyy_0[j] = pb_y * tg_yyyyy_xxyyyyyy_0[j] + fr * tg_yyyyy_xxyyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyyyyyy_0[j] - tg_yyyy_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyy_xxyyyyy_1[j];

                    tg_yyyyyy_xxyyyyyz_0[j] = pb_y * tg_yyyyy_xxyyyyyz_0[j] + fr * tg_yyyyy_xxyyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyyyyyz_0[j] - tg_yyyy_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyy_xxyyyyz_1[j];

                    tg_yyyyyy_xxyyyyzz_0[j] = pb_y * tg_yyyyy_xxyyyyzz_0[j] + fr * tg_yyyyy_xxyyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyyyyzz_0[j] - tg_yyyy_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyy_xxyyyzz_1[j];

                    tg_yyyyyy_xxyyyzzz_0[j] = pb_y * tg_yyyyy_xxyyyzzz_0[j] + fr * tg_yyyyy_xxyyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyyyzzz_0[j] - tg_yyyy_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_xxyyzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_970_1067(      CMemBlock2D<double>* primBuffer,
                                          const CRecursionMap&       recursionMap,
                                          const CMemBlock2D<double>& osFactors,
                                          const CMemBlock2D<double>& wpDistances,
                                          const CGtoPairsBlock&      braGtoPairsBlock,
                                          const CGtoPairsBlock&      ketGtoPairsBlock,
                                          const int32_t              nKetPrimPairs,
                                          const int32_t              iContrPair)
    {
        // Batch of Integrals (970,1067)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyy_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 700); 

                auto tg_yyyyy_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 701); 

                auto tg_yyyyy_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 702); 

                auto tg_yyyyy_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 703); 

                auto tg_yyyyy_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 704); 

                auto tg_yyyyy_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 705); 

                auto tg_yyyyy_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 706); 

                auto tg_yyyyy_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 707); 

                auto tg_yyyyy_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 708); 

                auto tg_yyyyy_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 709); 

                auto tg_yyyyy_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 710); 

                auto tg_yyyyy_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 711); 

                auto tg_yyyyy_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 712); 

                auto tg_yyyyy_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 713); 

                auto tg_yyyyy_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 714); 

                auto tg_yyyyy_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 715); 

                auto tg_yyyyy_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 716); 

                auto tg_yyyyy_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 717); 

                auto tg_yyyyy_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 718); 

                auto tg_yyyyy_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 719); 

                auto tg_yyyyz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 720); 

                auto tg_yyyyz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 721); 

                auto tg_yyyyz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 722); 

                auto tg_yyyyz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 723); 

                auto tg_yyyyz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 724); 

                auto tg_yyyyz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 725); 

                auto tg_yyyyz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 726); 

                auto tg_yyyyz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 727); 

                auto tg_yyyyz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 728); 

                auto tg_yyyyz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 729); 

                auto tg_yyyyz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 730); 

                auto tg_yyyyz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 731); 

                auto tg_yyyyz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 732); 

                auto tg_yyyyz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 733); 

                auto tg_yyyyz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 734); 

                auto tg_yyyyz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 735); 

                auto tg_yyyyz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 736); 

                auto tg_yyyyz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 737); 

                auto tg_yyyyz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 738); 

                auto tg_yyyyz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 739); 

                auto tg_yyyyz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 740); 

                auto tg_yyyyz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 741); 

                auto tg_yyyyz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 742); 

                auto tg_yyyyz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 743); 

                auto tg_yyyyz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 744); 

                auto tg_yyyyz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 745); 

                auto tg_yyyyz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 746); 

                auto tg_yyyyz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 747); 

                auto tg_yyyyz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 748); 

                auto tg_yyyyz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 749); 

                auto tg_yyyyz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 750); 

                auto tg_yyyyz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 751); 

                auto tg_yyyyz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 752); 

                auto tg_yyyyz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 753); 

                auto tg_yyyyz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 754); 

                auto tg_yyyyz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 755); 

                auto tg_yyyyz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 756); 

                auto tg_yyyyz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 757); 

                auto tg_yyyyz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 758); 

                auto tg_yyyyz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 759); 

                auto tg_yyyyz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 760); 

                auto tg_yyyyz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 761); 

                auto tg_yyyyz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 762); 

                auto tg_yyyyz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 763); 

                auto tg_yyyyz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 764); 

                auto tg_yyyzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 765); 

                auto tg_yyyzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 766); 

                auto tg_yyyzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 767); 

                auto tg_yyyzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 768); 

                auto tg_yyyzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 769); 

                auto tg_yyyzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 770); 

                auto tg_yyyzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 771); 

                auto tg_yyyzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 772); 

                auto tg_yyyzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 773); 

                auto tg_yyyzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 774); 

                auto tg_yyyzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 775); 

                auto tg_yyyzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 776); 

                auto tg_yyyzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 777); 

                auto tg_yyyzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 778); 

                auto tg_yyyzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 779); 

                auto tg_yyyzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 780); 

                auto tg_yyyzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 781); 

                auto tg_yyyzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 782); 

                auto tg_yyyzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 783); 

                auto tg_yyyzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 784); 

                auto tg_yyyzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 785); 

                auto tg_yyyzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 786); 

                auto tg_yyyzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 787); 

                auto tg_yyyzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 788); 

                auto tg_yyyzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 789); 

                auto tg_yyyzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 790); 

                auto tg_yyyzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 791); 

                auto tg_yyyzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 792); 

                auto tg_yyyzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 793); 

                auto tg_yyyzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 794); 

                auto tg_yyyzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 795); 

                auto tg_yyyzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 796); 

                auto tg_yyyyy_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 700); 

                auto tg_yyyyy_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 701); 

                auto tg_yyyyy_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 702); 

                auto tg_yyyyy_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 703); 

                auto tg_yyyyy_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 704); 

                auto tg_yyyyy_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 705); 

                auto tg_yyyyy_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 706); 

                auto tg_yyyyy_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 707); 

                auto tg_yyyyy_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 708); 

                auto tg_yyyyy_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 709); 

                auto tg_yyyyy_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 710); 

                auto tg_yyyyy_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 711); 

                auto tg_yyyyy_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 712); 

                auto tg_yyyyy_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 713); 

                auto tg_yyyyy_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 714); 

                auto tg_yyyyy_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 715); 

                auto tg_yyyyy_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 716); 

                auto tg_yyyyy_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 717); 

                auto tg_yyyyy_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 718); 

                auto tg_yyyyy_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 719); 

                auto tg_yyyyz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 720); 

                auto tg_yyyyz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 721); 

                auto tg_yyyyz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 722); 

                auto tg_yyyyz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 723); 

                auto tg_yyyyz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 724); 

                auto tg_yyyyz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 725); 

                auto tg_yyyyz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 726); 

                auto tg_yyyyz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 727); 

                auto tg_yyyyz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 728); 

                auto tg_yyyyz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 729); 

                auto tg_yyyyz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 730); 

                auto tg_yyyyz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 731); 

                auto tg_yyyyz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 732); 

                auto tg_yyyyz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 733); 

                auto tg_yyyyz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 734); 

                auto tg_yyyyz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 735); 

                auto tg_yyyyz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 736); 

                auto tg_yyyyz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 737); 

                auto tg_yyyyz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 738); 

                auto tg_yyyyz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 739); 

                auto tg_yyyyz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 740); 

                auto tg_yyyyz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 741); 

                auto tg_yyyyz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 742); 

                auto tg_yyyyz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 743); 

                auto tg_yyyyz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 744); 

                auto tg_yyyyz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 745); 

                auto tg_yyyyz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 746); 

                auto tg_yyyyz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 747); 

                auto tg_yyyyz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 748); 

                auto tg_yyyyz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 749); 

                auto tg_yyyyz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 750); 

                auto tg_yyyyz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 751); 

                auto tg_yyyyz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 752); 

                auto tg_yyyyz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 753); 

                auto tg_yyyyz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 754); 

                auto tg_yyyyz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 755); 

                auto tg_yyyyz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 756); 

                auto tg_yyyyz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 757); 

                auto tg_yyyyz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 758); 

                auto tg_yyyyz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 759); 

                auto tg_yyyyz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 760); 

                auto tg_yyyyz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 761); 

                auto tg_yyyyz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 762); 

                auto tg_yyyyz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 763); 

                auto tg_yyyyz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 764); 

                auto tg_yyyzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 765); 

                auto tg_yyyzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 766); 

                auto tg_yyyzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 767); 

                auto tg_yyyzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 768); 

                auto tg_yyyzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 769); 

                auto tg_yyyzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 770); 

                auto tg_yyyzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 771); 

                auto tg_yyyzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 772); 

                auto tg_yyyzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 773); 

                auto tg_yyyzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 774); 

                auto tg_yyyzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 775); 

                auto tg_yyyzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 776); 

                auto tg_yyyzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 777); 

                auto tg_yyyzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 778); 

                auto tg_yyyzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 779); 

                auto tg_yyyzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 780); 

                auto tg_yyyzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 781); 

                auto tg_yyyzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 782); 

                auto tg_yyyzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 783); 

                auto tg_yyyzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 784); 

                auto tg_yyyzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 785); 

                auto tg_yyyzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 786); 

                auto tg_yyyzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 787); 

                auto tg_yyyzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 788); 

                auto tg_yyyzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 789); 

                auto tg_yyyzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 790); 

                auto tg_yyyzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 791); 

                auto tg_yyyzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 792); 

                auto tg_yyyzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 793); 

                auto tg_yyyzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 794); 

                auto tg_yyyzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 795); 

                auto tg_yyyzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 796); 

                auto tg_yyyy_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 475); 

                auto tg_yyyy_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 476); 

                auto tg_yyyy_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 477); 

                auto tg_yyyy_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 478); 

                auto tg_yyyy_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 479); 

                auto tg_yyyy_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 480); 

                auto tg_yyyy_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 481); 

                auto tg_yyyy_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 482); 

                auto tg_yyyy_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 483); 

                auto tg_yyyy_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 484); 

                auto tg_yyyy_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 485); 

                auto tg_yyyy_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 486); 

                auto tg_yyyy_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 487); 

                auto tg_yyyy_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 488); 

                auto tg_yyyy_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 489); 

                auto tg_yyyy_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 490); 

                auto tg_yyyy_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 491); 

                auto tg_yyyy_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 492); 

                auto tg_yyyy_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 493); 

                auto tg_yyyy_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 494); 

                auto tg_yyyz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 495); 

                auto tg_yyyz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 496); 

                auto tg_yyyz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 497); 

                auto tg_yyyz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 498); 

                auto tg_yyyz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 499); 

                auto tg_yyyz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 500); 

                auto tg_yyyz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 501); 

                auto tg_yyyz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 502); 

                auto tg_yyyz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 503); 

                auto tg_yyyz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 504); 

                auto tg_yyyz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 505); 

                auto tg_yyyz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 506); 

                auto tg_yyyz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 507); 

                auto tg_yyyz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 508); 

                auto tg_yyyz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 509); 

                auto tg_yyyz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 510); 

                auto tg_yyyz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 511); 

                auto tg_yyyz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 512); 

                auto tg_yyyz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 513); 

                auto tg_yyyz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 514); 

                auto tg_yyyz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 515); 

                auto tg_yyyz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 516); 

                auto tg_yyyz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 517); 

                auto tg_yyyz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 518); 

                auto tg_yyyz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 519); 

                auto tg_yyyz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 520); 

                auto tg_yyyz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 521); 

                auto tg_yyyz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 522); 

                auto tg_yyyz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 523); 

                auto tg_yyyz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 524); 

                auto tg_yyyz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 525); 

                auto tg_yyyz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 526); 

                auto tg_yyyz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 527); 

                auto tg_yyyz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 528); 

                auto tg_yyyz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 529); 

                auto tg_yyyz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 530); 

                auto tg_yyyz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 531); 

                auto tg_yyyz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 532); 

                auto tg_yyyz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 533); 

                auto tg_yyyz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 534); 

                auto tg_yyyz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 535); 

                auto tg_yyyz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 536); 

                auto tg_yyyz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 537); 

                auto tg_yyyz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 538); 

                auto tg_yyyz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 539); 

                auto tg_yyzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 540); 

                auto tg_yyzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 541); 

                auto tg_yyzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 542); 

                auto tg_yyzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 543); 

                auto tg_yyzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 544); 

                auto tg_yyzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 545); 

                auto tg_yyzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 546); 

                auto tg_yyzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 547); 

                auto tg_yyzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 548); 

                auto tg_yyzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 549); 

                auto tg_yyzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 550); 

                auto tg_yyzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 551); 

                auto tg_yyzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 552); 

                auto tg_yyzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 553); 

                auto tg_yyzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 554); 

                auto tg_yyzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 555); 

                auto tg_yyzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 556); 

                auto tg_yyzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 557); 

                auto tg_yyzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 558); 

                auto tg_yyzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 559); 

                auto tg_yyzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 560); 

                auto tg_yyzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 561); 

                auto tg_yyzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 562); 

                auto tg_yyzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 563); 

                auto tg_yyzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 564); 

                auto tg_yyzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 565); 

                auto tg_yyzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 566); 

                auto tg_yyzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 567); 

                auto tg_yyzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 568); 

                auto tg_yyzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 569); 

                auto tg_yyzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 570); 

                auto tg_yyzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 571); 

                auto tg_yyyy_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 475); 

                auto tg_yyyy_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 476); 

                auto tg_yyyy_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 477); 

                auto tg_yyyy_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 478); 

                auto tg_yyyy_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 479); 

                auto tg_yyyy_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 480); 

                auto tg_yyyy_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 481); 

                auto tg_yyyy_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 482); 

                auto tg_yyyy_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 483); 

                auto tg_yyyy_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 484); 

                auto tg_yyyy_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 485); 

                auto tg_yyyy_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 486); 

                auto tg_yyyy_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 487); 

                auto tg_yyyy_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 488); 

                auto tg_yyyy_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 489); 

                auto tg_yyyy_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 490); 

                auto tg_yyyy_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 491); 

                auto tg_yyyy_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 492); 

                auto tg_yyyy_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 493); 

                auto tg_yyyy_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 494); 

                auto tg_yyyz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 495); 

                auto tg_yyyz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 496); 

                auto tg_yyyz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 497); 

                auto tg_yyyz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 498); 

                auto tg_yyyz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 499); 

                auto tg_yyyz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 500); 

                auto tg_yyyz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 501); 

                auto tg_yyyz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 502); 

                auto tg_yyyz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 503); 

                auto tg_yyyz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 504); 

                auto tg_yyyz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 505); 

                auto tg_yyyz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 506); 

                auto tg_yyyz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 507); 

                auto tg_yyyz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 508); 

                auto tg_yyyz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 509); 

                auto tg_yyyz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 510); 

                auto tg_yyyz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 511); 

                auto tg_yyyz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 512); 

                auto tg_yyyz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 513); 

                auto tg_yyyz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 514); 

                auto tg_yyyz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 515); 

                auto tg_yyyz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 516); 

                auto tg_yyyz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 517); 

                auto tg_yyyz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 518); 

                auto tg_yyyz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 519); 

                auto tg_yyyz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 520); 

                auto tg_yyyz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 521); 

                auto tg_yyyz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 522); 

                auto tg_yyyz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 523); 

                auto tg_yyyz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 524); 

                auto tg_yyyz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 525); 

                auto tg_yyyz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 526); 

                auto tg_yyyz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 527); 

                auto tg_yyyz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 528); 

                auto tg_yyyz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 529); 

                auto tg_yyyz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 530); 

                auto tg_yyyz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 531); 

                auto tg_yyyz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 532); 

                auto tg_yyyz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 533); 

                auto tg_yyyz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 534); 

                auto tg_yyyz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 535); 

                auto tg_yyyz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 536); 

                auto tg_yyyz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 537); 

                auto tg_yyyz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 538); 

                auto tg_yyyz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 539); 

                auto tg_yyzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 540); 

                auto tg_yyzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 541); 

                auto tg_yyzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 542); 

                auto tg_yyzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 543); 

                auto tg_yyzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 544); 

                auto tg_yyzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 545); 

                auto tg_yyzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 546); 

                auto tg_yyzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 547); 

                auto tg_yyzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 548); 

                auto tg_yyzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 549); 

                auto tg_yyzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 550); 

                auto tg_yyzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 551); 

                auto tg_yyzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 552); 

                auto tg_yyzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 553); 

                auto tg_yyzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 554); 

                auto tg_yyzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 555); 

                auto tg_yyzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 556); 

                auto tg_yyzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 557); 

                auto tg_yyzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 558); 

                auto tg_yyzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 559); 

                auto tg_yyzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 560); 

                auto tg_yyzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 561); 

                auto tg_yyzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 562); 

                auto tg_yyzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 563); 

                auto tg_yyzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 564); 

                auto tg_yyzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 565); 

                auto tg_yyzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 566); 

                auto tg_yyzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 567); 

                auto tg_yyzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 568); 

                auto tg_yyzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 569); 

                auto tg_yyzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 570); 

                auto tg_yyzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 571); 

                auto tg_yyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 599); 

                auto tg_yyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 622); 

                auto tg_yyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 629); 

                auto tg_yyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 636); 

                // set up pointers to integrals

                auto tg_yyyyyy_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 970); 

                auto tg_yyyyyy_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 971); 

                auto tg_yyyyyy_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 972); 

                auto tg_yyyyyy_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 973); 

                auto tg_yyyyyy_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 974); 

                auto tg_yyyyyy_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 975); 

                auto tg_yyyyyy_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 976); 

                auto tg_yyyyyy_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 977); 

                auto tg_yyyyyy_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 978); 

                auto tg_yyyyyy_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 979); 

                auto tg_yyyyyy_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 980); 

                auto tg_yyyyyy_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 981); 

                auto tg_yyyyyy_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 982); 

                auto tg_yyyyyy_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 983); 

                auto tg_yyyyyy_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 984); 

                auto tg_yyyyyy_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 985); 

                auto tg_yyyyyy_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 986); 

                auto tg_yyyyyy_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 987); 

                auto tg_yyyyyy_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 988); 

                auto tg_yyyyyy_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 989); 

                auto tg_yyyyyz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 990); 

                auto tg_yyyyyz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 991); 

                auto tg_yyyyyz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 992); 

                auto tg_yyyyyz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 993); 

                auto tg_yyyyyz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 994); 

                auto tg_yyyyyz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 995); 

                auto tg_yyyyyz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 996); 

                auto tg_yyyyyz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 997); 

                auto tg_yyyyyz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 998); 

                auto tg_yyyyyz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 999); 

                auto tg_yyyyyz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1000); 

                auto tg_yyyyyz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1001); 

                auto tg_yyyyyz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1002); 

                auto tg_yyyyyz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1003); 

                auto tg_yyyyyz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1004); 

                auto tg_yyyyyz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1005); 

                auto tg_yyyyyz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1006); 

                auto tg_yyyyyz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1007); 

                auto tg_yyyyyz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1008); 

                auto tg_yyyyyz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1009); 

                auto tg_yyyyyz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1010); 

                auto tg_yyyyyz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1011); 

                auto tg_yyyyyz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1012); 

                auto tg_yyyyyz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1013); 

                auto tg_yyyyyz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1014); 

                auto tg_yyyyyz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1015); 

                auto tg_yyyyyz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1016); 

                auto tg_yyyyyz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1017); 

                auto tg_yyyyyz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1018); 

                auto tg_yyyyyz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1019); 

                auto tg_yyyyyz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1020); 

                auto tg_yyyyyz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1021); 

                auto tg_yyyyyz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1022); 

                auto tg_yyyyyz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1023); 

                auto tg_yyyyyz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1024); 

                auto tg_yyyyyz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1025); 

                auto tg_yyyyyz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1026); 

                auto tg_yyyyyz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1027); 

                auto tg_yyyyyz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1028); 

                auto tg_yyyyyz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1029); 

                auto tg_yyyyyz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1030); 

                auto tg_yyyyyz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1031); 

                auto tg_yyyyyz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1032); 

                auto tg_yyyyyz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1033); 

                auto tg_yyyyyz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1034); 

                auto tg_yyyyzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1035); 

                auto tg_yyyyzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1036); 

                auto tg_yyyyzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1037); 

                auto tg_yyyyzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1038); 

                auto tg_yyyyzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1039); 

                auto tg_yyyyzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1040); 

                auto tg_yyyyzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1041); 

                auto tg_yyyyzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1042); 

                auto tg_yyyyzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1043); 

                auto tg_yyyyzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1044); 

                auto tg_yyyyzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1045); 

                auto tg_yyyyzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1046); 

                auto tg_yyyyzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1047); 

                auto tg_yyyyzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1048); 

                auto tg_yyyyzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1049); 

                auto tg_yyyyzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1050); 

                auto tg_yyyyzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1051); 

                auto tg_yyyyzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1052); 

                auto tg_yyyyzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1053); 

                auto tg_yyyyzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1054); 

                auto tg_yyyyzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1055); 

                auto tg_yyyyzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1056); 

                auto tg_yyyyzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1057); 

                auto tg_yyyyzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1058); 

                auto tg_yyyyzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1059); 

                auto tg_yyyyzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1060); 

                auto tg_yyyyzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1061); 

                auto tg_yyyyzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1062); 

                auto tg_yyyyzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1063); 

                auto tg_yyyyzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1064); 

                auto tg_yyyyzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1065); 

                auto tg_yyyyzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1066); 

                // Batch of Integrals (970,1067)

                #pragma omp simd aligned(fxn, fza, tg_yyyy_xxyyzzzz_0, tg_yyyy_xxyyzzzz_1, tg_yyyy_xxyzzzzz_0, \
                                         tg_yyyy_xxyzzzzz_1, tg_yyyy_xxzzzzzz_0, tg_yyyy_xxzzzzzz_1, tg_yyyy_xyyyyyyy_0, \
                                         tg_yyyy_xyyyyyyy_1, tg_yyyy_xyyyyyyz_0, tg_yyyy_xyyyyyyz_1, tg_yyyy_xyyyyyzz_0, \
                                         tg_yyyy_xyyyyyzz_1, tg_yyyy_xyyyyzzz_0, tg_yyyy_xyyyyzzz_1, tg_yyyy_xyyyzzzz_0, \
                                         tg_yyyy_xyyyzzzz_1, tg_yyyy_xyyzzzzz_0, tg_yyyy_xyyzzzzz_1, tg_yyyy_xyzzzzzz_0, \
                                         tg_yyyy_xyzzzzzz_1, tg_yyyy_xzzzzzzz_0, tg_yyyy_xzzzzzzz_1, tg_yyyy_yyyyyyyy_0, \
                                         tg_yyyy_yyyyyyyy_1, tg_yyyy_yyyyyyyz_0, tg_yyyy_yyyyyyyz_1, tg_yyyy_yyyyyyzz_0, \
                                         tg_yyyy_yyyyyyzz_1, tg_yyyy_yyyyyzzz_0, tg_yyyy_yyyyyzzz_1, tg_yyyy_yyyyzzzz_0, \
                                         tg_yyyy_yyyyzzzz_1, tg_yyyy_yyyzzzzz_0, tg_yyyy_yyyzzzzz_1, tg_yyyy_yyzzzzzz_0, \
                                         tg_yyyy_yyzzzzzz_1, tg_yyyy_yzzzzzzz_0, tg_yyyy_yzzzzzzz_1, tg_yyyy_zzzzzzzz_0, \
                                         tg_yyyy_zzzzzzzz_1, tg_yyyyy_xxyyzzzz_0, tg_yyyyy_xxyyzzzz_1, tg_yyyyy_xxyzzzz_1, \
                                         tg_yyyyy_xxyzzzzz_0, tg_yyyyy_xxyzzzzz_1, tg_yyyyy_xxzzzzz_1, tg_yyyyy_xxzzzzzz_0, \
                                         tg_yyyyy_xxzzzzzz_1, tg_yyyyy_xyyyyyy_1, tg_yyyyy_xyyyyyyy_0, tg_yyyyy_xyyyyyyy_1, \
                                         tg_yyyyy_xyyyyyyz_0, tg_yyyyy_xyyyyyyz_1, tg_yyyyy_xyyyyyz_1, tg_yyyyy_xyyyyyzz_0, \
                                         tg_yyyyy_xyyyyyzz_1, tg_yyyyy_xyyyyzz_1, tg_yyyyy_xyyyyzzz_0, tg_yyyyy_xyyyyzzz_1, \
                                         tg_yyyyy_xyyyzzz_1, tg_yyyyy_xyyyzzzz_0, tg_yyyyy_xyyyzzzz_1, tg_yyyyy_xyyzzzz_1, \
                                         tg_yyyyy_xyyzzzzz_0, tg_yyyyy_xyyzzzzz_1, tg_yyyyy_xyzzzzz_1, tg_yyyyy_xyzzzzzz_0, \
                                         tg_yyyyy_xyzzzzzz_1, tg_yyyyy_xzzzzzz_1, tg_yyyyy_xzzzzzzz_0, tg_yyyyy_xzzzzzzz_1, \
                                         tg_yyyyy_yyyyyyy_1, tg_yyyyy_yyyyyyyy_0, tg_yyyyy_yyyyyyyy_1, tg_yyyyy_yyyyyyyz_0, \
                                         tg_yyyyy_yyyyyyyz_1, tg_yyyyy_yyyyyyz_1, tg_yyyyy_yyyyyyzz_0, tg_yyyyy_yyyyyyzz_1, \
                                         tg_yyyyy_yyyyyzz_1, tg_yyyyy_yyyyyzzz_0, tg_yyyyy_yyyyyzzz_1, tg_yyyyy_yyyyzzz_1, \
                                         tg_yyyyy_yyyyzzzz_0, tg_yyyyy_yyyyzzzz_1, tg_yyyyy_yyyzzzz_1, tg_yyyyy_yyyzzzzz_0, \
                                         tg_yyyyy_yyyzzzzz_1, tg_yyyyy_yyzzzzz_1, tg_yyyyy_yyzzzzzz_0, tg_yyyyy_yyzzzzzz_1, \
                                         tg_yyyyy_yzzzzzz_1, tg_yyyyy_yzzzzzzz_0, tg_yyyyy_yzzzzzzz_1, tg_yyyyy_zzzzzzz_1, \
                                         tg_yyyyy_zzzzzzzz_0, tg_yyyyy_zzzzzzzz_1, tg_yyyyyy_xxyyzzzz_0, tg_yyyyyy_xxyzzzzz_0, \
                                         tg_yyyyyy_xxzzzzzz_0, tg_yyyyyy_xyyyyyyy_0, tg_yyyyyy_xyyyyyyz_0, tg_yyyyyy_xyyyyyzz_0, \
                                         tg_yyyyyy_xyyyyzzz_0, tg_yyyyyy_xyyyzzzz_0, tg_yyyyyy_xyyzzzzz_0, tg_yyyyyy_xyzzzzzz_0, \
                                         tg_yyyyyy_xzzzzzzz_0, tg_yyyyyy_yyyyyyyy_0, tg_yyyyyy_yyyyyyyz_0, tg_yyyyyy_yyyyyyzz_0, \
                                         tg_yyyyyy_yyyyyzzz_0, tg_yyyyyy_yyyyzzzz_0, tg_yyyyyy_yyyzzzzz_0, tg_yyyyyy_yyzzzzzz_0, \
                                         tg_yyyyyy_yzzzzzzz_0, tg_yyyyyy_zzzzzzzz_0, tg_yyyyyz_xxxxxxxx_0, tg_yyyyyz_xxxxxxxy_0, \
                                         tg_yyyyyz_xxxxxxxz_0, tg_yyyyyz_xxxxxxyy_0, tg_yyyyyz_xxxxxxyz_0, tg_yyyyyz_xxxxxxzz_0, \
                                         tg_yyyyyz_xxxxxyyy_0, tg_yyyyyz_xxxxxyyz_0, tg_yyyyyz_xxxxxyzz_0, tg_yyyyyz_xxxxxzzz_0, \
                                         tg_yyyyyz_xxxxyyyy_0, tg_yyyyyz_xxxxyyyz_0, tg_yyyyyz_xxxxyyzz_0, tg_yyyyyz_xxxxyzzz_0, \
                                         tg_yyyyyz_xxxxzzzz_0, tg_yyyyyz_xxxyyyyy_0, tg_yyyyyz_xxxyyyyz_0, tg_yyyyyz_xxxyyyzz_0, \
                                         tg_yyyyyz_xxxyyzzz_0, tg_yyyyyz_xxxyzzzz_0, tg_yyyyyz_xxxzzzzz_0, tg_yyyyyz_xxyyyyyy_0, \
                                         tg_yyyyyz_xxyyyyyz_0, tg_yyyyyz_xxyyyyzz_0, tg_yyyyyz_xxyyyzzz_0, tg_yyyyyz_xxyyzzzz_0, \
                                         tg_yyyyyz_xxyzzzzz_0, tg_yyyyyz_xxzzzzzz_0, tg_yyyyyz_xyyyyyyy_0, tg_yyyyyz_xyyyyyyz_0, \
                                         tg_yyyyyz_xyyyyyzz_0, tg_yyyyyz_xyyyyzzz_0, tg_yyyyyz_xyyyzzzz_0, tg_yyyyyz_xyyzzzzz_0, \
                                         tg_yyyyyz_xyzzzzzz_0, tg_yyyyyz_xzzzzzzz_0, tg_yyyyyz_yyyyyyyy_0, tg_yyyyyz_yyyyyyyz_0, \
                                         tg_yyyyyz_yyyyyyzz_0, tg_yyyyyz_yyyyyzzz_0, tg_yyyyyz_yyyyzzzz_0, tg_yyyyyz_yyyzzzzz_0, \
                                         tg_yyyyyz_yyzzzzzz_0, tg_yyyyyz_yzzzzzzz_0, tg_yyyyyz_zzzzzzzz_0, tg_yyyyz_xxxxxxx_1, \
                                         tg_yyyyz_xxxxxxxx_0, tg_yyyyz_xxxxxxxx_1, tg_yyyyz_xxxxxxxy_0, tg_yyyyz_xxxxxxxy_1, \
                                         tg_yyyyz_xxxxxxxz_0, tg_yyyyz_xxxxxxxz_1, tg_yyyyz_xxxxxxy_1, tg_yyyyz_xxxxxxyy_0, \
                                         tg_yyyyz_xxxxxxyy_1, tg_yyyyz_xxxxxxyz_0, tg_yyyyz_xxxxxxyz_1, tg_yyyyz_xxxxxxz_1, \
                                         tg_yyyyz_xxxxxxzz_0, tg_yyyyz_xxxxxxzz_1, tg_yyyyz_xxxxxyy_1, tg_yyyyz_xxxxxyyy_0, \
                                         tg_yyyyz_xxxxxyyy_1, tg_yyyyz_xxxxxyyz_0, tg_yyyyz_xxxxxyyz_1, tg_yyyyz_xxxxxyz_1, \
                                         tg_yyyyz_xxxxxyzz_0, tg_yyyyz_xxxxxyzz_1, tg_yyyyz_xxxxxzz_1, tg_yyyyz_xxxxxzzz_0, \
                                         tg_yyyyz_xxxxxzzz_1, tg_yyyyz_xxxxyyy_1, tg_yyyyz_xxxxyyyy_0, tg_yyyyz_xxxxyyyy_1, \
                                         tg_yyyyz_xxxxyyyz_0, tg_yyyyz_xxxxyyyz_1, tg_yyyyz_xxxxyyz_1, tg_yyyyz_xxxxyyzz_0, \
                                         tg_yyyyz_xxxxyyzz_1, tg_yyyyz_xxxxyzz_1, tg_yyyyz_xxxxyzzz_0, tg_yyyyz_xxxxyzzz_1, \
                                         tg_yyyyz_xxxxzzz_1, tg_yyyyz_xxxxzzzz_0, tg_yyyyz_xxxxzzzz_1, tg_yyyyz_xxxyyyy_1, \
                                         tg_yyyyz_xxxyyyyy_0, tg_yyyyz_xxxyyyyy_1, tg_yyyyz_xxxyyyyz_0, tg_yyyyz_xxxyyyyz_1, \
                                         tg_yyyyz_xxxyyyz_1, tg_yyyyz_xxxyyyzz_0, tg_yyyyz_xxxyyyzz_1, tg_yyyyz_xxxyyzz_1, \
                                         tg_yyyyz_xxxyyzzz_0, tg_yyyyz_xxxyyzzz_1, tg_yyyyz_xxxyzzz_1, tg_yyyyz_xxxyzzzz_0, \
                                         tg_yyyyz_xxxyzzzz_1, tg_yyyyz_xxxzzzz_1, tg_yyyyz_xxxzzzzz_0, tg_yyyyz_xxxzzzzz_1, \
                                         tg_yyyyz_xxyyyyy_1, tg_yyyyz_xxyyyyyy_0, tg_yyyyz_xxyyyyyy_1, tg_yyyyz_xxyyyyyz_0, \
                                         tg_yyyyz_xxyyyyyz_1, tg_yyyyz_xxyyyyz_1, tg_yyyyz_xxyyyyzz_0, tg_yyyyz_xxyyyyzz_1, \
                                         tg_yyyyz_xxyyyzz_1, tg_yyyyz_xxyyyzzz_0, tg_yyyyz_xxyyyzzz_1, tg_yyyyz_xxyyzzz_1, \
                                         tg_yyyyz_xxyyzzzz_0, tg_yyyyz_xxyyzzzz_1, tg_yyyyz_xxyzzzz_1, tg_yyyyz_xxyzzzzz_0, \
                                         tg_yyyyz_xxyzzzzz_1, tg_yyyyz_xxzzzzz_1, tg_yyyyz_xxzzzzzz_0, tg_yyyyz_xxzzzzzz_1, \
                                         tg_yyyyz_xyyyyyy_1, tg_yyyyz_xyyyyyyy_0, tg_yyyyz_xyyyyyyy_1, tg_yyyyz_xyyyyyyz_0, \
                                         tg_yyyyz_xyyyyyyz_1, tg_yyyyz_xyyyyyz_1, tg_yyyyz_xyyyyyzz_0, tg_yyyyz_xyyyyyzz_1, \
                                         tg_yyyyz_xyyyyzz_1, tg_yyyyz_xyyyyzzz_0, tg_yyyyz_xyyyyzzz_1, tg_yyyyz_xyyyzzz_1, \
                                         tg_yyyyz_xyyyzzzz_0, tg_yyyyz_xyyyzzzz_1, tg_yyyyz_xyyzzzz_1, tg_yyyyz_xyyzzzzz_0, \
                                         tg_yyyyz_xyyzzzzz_1, tg_yyyyz_xyzzzzz_1, tg_yyyyz_xyzzzzzz_0, tg_yyyyz_xyzzzzzz_1, \
                                         tg_yyyyz_xzzzzzz_1, tg_yyyyz_xzzzzzzz_0, tg_yyyyz_xzzzzzzz_1, tg_yyyyz_yyyyyyy_1, \
                                         tg_yyyyz_yyyyyyyy_0, tg_yyyyz_yyyyyyyy_1, tg_yyyyz_yyyyyyyz_0, tg_yyyyz_yyyyyyyz_1, \
                                         tg_yyyyz_yyyyyyz_1, tg_yyyyz_yyyyyyzz_0, tg_yyyyz_yyyyyyzz_1, tg_yyyyz_yyyyyzz_1, \
                                         tg_yyyyz_yyyyyzzz_0, tg_yyyyz_yyyyyzzz_1, tg_yyyyz_yyyyzzz_1, tg_yyyyz_yyyyzzzz_0, \
                                         tg_yyyyz_yyyyzzzz_1, tg_yyyyz_yyyzzzz_1, tg_yyyyz_yyyzzzzz_0, tg_yyyyz_yyyzzzzz_1, \
                                         tg_yyyyz_yyzzzzz_1, tg_yyyyz_yyzzzzzz_0, tg_yyyyz_yyzzzzzz_1, tg_yyyyz_yzzzzzz_1, \
                                         tg_yyyyz_yzzzzzzz_0, tg_yyyyz_yzzzzzzz_1, tg_yyyyz_zzzzzzz_1, tg_yyyyz_zzzzzzzz_0, \
                                         tg_yyyyz_zzzzzzzz_1, tg_yyyyzz_xxxxxxxx_0, tg_yyyyzz_xxxxxxxy_0, tg_yyyyzz_xxxxxxxz_0, \
                                         tg_yyyyzz_xxxxxxyy_0, tg_yyyyzz_xxxxxxyz_0, tg_yyyyzz_xxxxxxzz_0, tg_yyyyzz_xxxxxyyy_0, \
                                         tg_yyyyzz_xxxxxyyz_0, tg_yyyyzz_xxxxxyzz_0, tg_yyyyzz_xxxxxzzz_0, tg_yyyyzz_xxxxyyyy_0, \
                                         tg_yyyyzz_xxxxyyyz_0, tg_yyyyzz_xxxxyyzz_0, tg_yyyyzz_xxxxyzzz_0, tg_yyyyzz_xxxxzzzz_0, \
                                         tg_yyyyzz_xxxyyyyy_0, tg_yyyyzz_xxxyyyyz_0, tg_yyyyzz_xxxyyyzz_0, tg_yyyyzz_xxxyyzzz_0, \
                                         tg_yyyyzz_xxxyzzzz_0, tg_yyyyzz_xxxzzzzz_0, tg_yyyyzz_xxyyyyyy_0, tg_yyyyzz_xxyyyyyz_0, \
                                         tg_yyyyzz_xxyyyyzz_0, tg_yyyyzz_xxyyyzzz_0, tg_yyyyzz_xxyyzzzz_0, tg_yyyyzz_xxyzzzzz_0, \
                                         tg_yyyyzz_xxzzzzzz_0, tg_yyyyzz_xyyyyyyy_0, tg_yyyyzz_xyyyyyyz_0, tg_yyyyzz_xyyyyyzz_0, \
                                         tg_yyyyzz_xyyyyzzz_0, tg_yyyz_xxxxxxxx_0, tg_yyyz_xxxxxxxx_1, tg_yyyz_xxxxxxxy_0, \
                                         tg_yyyz_xxxxxxxy_1, tg_yyyz_xxxxxxxz_0, tg_yyyz_xxxxxxxz_1, tg_yyyz_xxxxxxyy_0, \
                                         tg_yyyz_xxxxxxyy_1, tg_yyyz_xxxxxxyz_0, tg_yyyz_xxxxxxyz_1, tg_yyyz_xxxxxxzz_0, \
                                         tg_yyyz_xxxxxxzz_1, tg_yyyz_xxxxxyyy_0, tg_yyyz_xxxxxyyy_1, tg_yyyz_xxxxxyyz_0, \
                                         tg_yyyz_xxxxxyyz_1, tg_yyyz_xxxxxyzz_0, tg_yyyz_xxxxxyzz_1, tg_yyyz_xxxxxzzz_0, \
                                         tg_yyyz_xxxxxzzz_1, tg_yyyz_xxxxyyyy_0, tg_yyyz_xxxxyyyy_1, tg_yyyz_xxxxyyyz_0, \
                                         tg_yyyz_xxxxyyyz_1, tg_yyyz_xxxxyyzz_0, tg_yyyz_xxxxyyzz_1, tg_yyyz_xxxxyzzz_0, \
                                         tg_yyyz_xxxxyzzz_1, tg_yyyz_xxxxzzzz_0, tg_yyyz_xxxxzzzz_1, tg_yyyz_xxxyyyyy_0, \
                                         tg_yyyz_xxxyyyyy_1, tg_yyyz_xxxyyyyz_0, tg_yyyz_xxxyyyyz_1, tg_yyyz_xxxyyyzz_0, \
                                         tg_yyyz_xxxyyyzz_1, tg_yyyz_xxxyyzzz_0, tg_yyyz_xxxyyzzz_1, tg_yyyz_xxxyzzzz_0, \
                                         tg_yyyz_xxxyzzzz_1, tg_yyyz_xxxzzzzz_0, tg_yyyz_xxxzzzzz_1, tg_yyyz_xxyyyyyy_0, \
                                         tg_yyyz_xxyyyyyy_1, tg_yyyz_xxyyyyyz_0, tg_yyyz_xxyyyyyz_1, tg_yyyz_xxyyyyzz_0, \
                                         tg_yyyz_xxyyyyzz_1, tg_yyyz_xxyyyzzz_0, tg_yyyz_xxyyyzzz_1, tg_yyyz_xxyyzzzz_0, \
                                         tg_yyyz_xxyyzzzz_1, tg_yyyz_xxyzzzzz_0, tg_yyyz_xxyzzzzz_1, tg_yyyz_xxzzzzzz_0, \
                                         tg_yyyz_xxzzzzzz_1, tg_yyyz_xyyyyyyy_0, tg_yyyz_xyyyyyyy_1, tg_yyyz_xyyyyyyz_0, \
                                         tg_yyyz_xyyyyyyz_1, tg_yyyz_xyyyyyzz_0, tg_yyyz_xyyyyyzz_1, tg_yyyz_xyyyyzzz_0, \
                                         tg_yyyz_xyyyyzzz_1, tg_yyyz_xyyyzzzz_0, tg_yyyz_xyyyzzzz_1, tg_yyyz_xyyzzzzz_0, \
                                         tg_yyyz_xyyzzzzz_1, tg_yyyz_xyzzzzzz_0, tg_yyyz_xyzzzzzz_1, tg_yyyz_xzzzzzzz_0, \
                                         tg_yyyz_xzzzzzzz_1, tg_yyyz_yyyyyyyy_0, tg_yyyz_yyyyyyyy_1, tg_yyyz_yyyyyyyz_0, \
                                         tg_yyyz_yyyyyyyz_1, tg_yyyz_yyyyyyzz_0, tg_yyyz_yyyyyyzz_1, tg_yyyz_yyyyyzzz_0, \
                                         tg_yyyz_yyyyyzzz_1, tg_yyyz_yyyyzzzz_0, tg_yyyz_yyyyzzzz_1, tg_yyyz_yyyzzzzz_0, \
                                         tg_yyyz_yyyzzzzz_1, tg_yyyz_yyzzzzzz_0, tg_yyyz_yyzzzzzz_1, tg_yyyz_yzzzzzzz_0, \
                                         tg_yyyz_yzzzzzzz_1, tg_yyyz_zzzzzzzz_0, tg_yyyz_zzzzzzzz_1, tg_yyyzz_xxxxxxx_1, \
                                         tg_yyyzz_xxxxxxxx_0, tg_yyyzz_xxxxxxxx_1, tg_yyyzz_xxxxxxxy_0, tg_yyyzz_xxxxxxxy_1, \
                                         tg_yyyzz_xxxxxxxz_0, tg_yyyzz_xxxxxxxz_1, tg_yyyzz_xxxxxxy_1, tg_yyyzz_xxxxxxyy_0, \
                                         tg_yyyzz_xxxxxxyy_1, tg_yyyzz_xxxxxxyz_0, tg_yyyzz_xxxxxxyz_1, tg_yyyzz_xxxxxxz_1, \
                                         tg_yyyzz_xxxxxxzz_0, tg_yyyzz_xxxxxxzz_1, tg_yyyzz_xxxxxyy_1, tg_yyyzz_xxxxxyyy_0, \
                                         tg_yyyzz_xxxxxyyy_1, tg_yyyzz_xxxxxyyz_0, tg_yyyzz_xxxxxyyz_1, tg_yyyzz_xxxxxyz_1, \
                                         tg_yyyzz_xxxxxyzz_0, tg_yyyzz_xxxxxyzz_1, tg_yyyzz_xxxxxzz_1, tg_yyyzz_xxxxxzzz_0, \
                                         tg_yyyzz_xxxxxzzz_1, tg_yyyzz_xxxxyyy_1, tg_yyyzz_xxxxyyyy_0, tg_yyyzz_xxxxyyyy_1, \
                                         tg_yyyzz_xxxxyyyz_0, tg_yyyzz_xxxxyyyz_1, tg_yyyzz_xxxxyyz_1, tg_yyyzz_xxxxyyzz_0, \
                                         tg_yyyzz_xxxxyyzz_1, tg_yyyzz_xxxxyzz_1, tg_yyyzz_xxxxyzzz_0, tg_yyyzz_xxxxyzzz_1, \
                                         tg_yyyzz_xxxxzzz_1, tg_yyyzz_xxxxzzzz_0, tg_yyyzz_xxxxzzzz_1, tg_yyyzz_xxxyyyy_1, \
                                         tg_yyyzz_xxxyyyyy_0, tg_yyyzz_xxxyyyyy_1, tg_yyyzz_xxxyyyyz_0, tg_yyyzz_xxxyyyyz_1, \
                                         tg_yyyzz_xxxyyyz_1, tg_yyyzz_xxxyyyzz_0, tg_yyyzz_xxxyyyzz_1, tg_yyyzz_xxxyyzz_1, \
                                         tg_yyyzz_xxxyyzzz_0, tg_yyyzz_xxxyyzzz_1, tg_yyyzz_xxxyzzz_1, tg_yyyzz_xxxyzzzz_0, \
                                         tg_yyyzz_xxxyzzzz_1, tg_yyyzz_xxxzzzz_1, tg_yyyzz_xxxzzzzz_0, tg_yyyzz_xxxzzzzz_1, \
                                         tg_yyyzz_xxyyyyy_1, tg_yyyzz_xxyyyyyy_0, tg_yyyzz_xxyyyyyy_1, tg_yyyzz_xxyyyyyz_0, \
                                         tg_yyyzz_xxyyyyyz_1, tg_yyyzz_xxyyyyz_1, tg_yyyzz_xxyyyyzz_0, tg_yyyzz_xxyyyyzz_1, \
                                         tg_yyyzz_xxyyyzz_1, tg_yyyzz_xxyyyzzz_0, tg_yyyzz_xxyyyzzz_1, tg_yyyzz_xxyyzzz_1, \
                                         tg_yyyzz_xxyyzzzz_0, tg_yyyzz_xxyyzzzz_1, tg_yyyzz_xxyzzzz_1, tg_yyyzz_xxyzzzzz_0, \
                                         tg_yyyzz_xxyzzzzz_1, tg_yyyzz_xxzzzzz_1, tg_yyyzz_xxzzzzzz_0, tg_yyyzz_xxzzzzzz_1, \
                                         tg_yyyzz_xyyyyyy_1, tg_yyyzz_xyyyyyyy_0, tg_yyyzz_xyyyyyyy_1, tg_yyyzz_xyyyyyyz_0, \
                                         tg_yyyzz_xyyyyyyz_1, tg_yyyzz_xyyyyyz_1, tg_yyyzz_xyyyyyzz_0, tg_yyyzz_xyyyyyzz_1, \
                                         tg_yyyzz_xyyyyzz_1, tg_yyyzz_xyyyyzzz_0, tg_yyyzz_xyyyyzzz_1, tg_yyyzz_xyyyzzz_1, \
                                         tg_yyzz_xxxxxxxx_0, tg_yyzz_xxxxxxxx_1, tg_yyzz_xxxxxxxy_0, tg_yyzz_xxxxxxxy_1, \
                                         tg_yyzz_xxxxxxxz_0, tg_yyzz_xxxxxxxz_1, tg_yyzz_xxxxxxyy_0, tg_yyzz_xxxxxxyy_1, \
                                         tg_yyzz_xxxxxxyz_0, tg_yyzz_xxxxxxyz_1, tg_yyzz_xxxxxxzz_0, tg_yyzz_xxxxxxzz_1, \
                                         tg_yyzz_xxxxxyyy_0, tg_yyzz_xxxxxyyy_1, tg_yyzz_xxxxxyyz_0, tg_yyzz_xxxxxyyz_1, \
                                         tg_yyzz_xxxxxyzz_0, tg_yyzz_xxxxxyzz_1, tg_yyzz_xxxxxzzz_0, tg_yyzz_xxxxxzzz_1, \
                                         tg_yyzz_xxxxyyyy_0, tg_yyzz_xxxxyyyy_1, tg_yyzz_xxxxyyyz_0, tg_yyzz_xxxxyyyz_1, \
                                         tg_yyzz_xxxxyyzz_0, tg_yyzz_xxxxyyzz_1, tg_yyzz_xxxxyzzz_0, tg_yyzz_xxxxyzzz_1, \
                                         tg_yyzz_xxxxzzzz_0, tg_yyzz_xxxxzzzz_1, tg_yyzz_xxxyyyyy_0, tg_yyzz_xxxyyyyy_1, \
                                         tg_yyzz_xxxyyyyz_0, tg_yyzz_xxxyyyyz_1, tg_yyzz_xxxyyyzz_0, tg_yyzz_xxxyyyzz_1, \
                                         tg_yyzz_xxxyyzzz_0, tg_yyzz_xxxyyzzz_1, tg_yyzz_xxxyzzzz_0, tg_yyzz_xxxyzzzz_1, \
                                         tg_yyzz_xxxzzzzz_0, tg_yyzz_xxxzzzzz_1, tg_yyzz_xxyyyyyy_0, tg_yyzz_xxyyyyyy_1, \
                                         tg_yyzz_xxyyyyyz_0, tg_yyzz_xxyyyyyz_1, tg_yyzz_xxyyyyzz_0, tg_yyzz_xxyyyyzz_1, \
                                         tg_yyzz_xxyyyzzz_0, tg_yyzz_xxyyyzzz_1, tg_yyzz_xxyyzzzz_0, tg_yyzz_xxyyzzzz_1, \
                                         tg_yyzz_xxyzzzzz_0, tg_yyzz_xxyzzzzz_1, tg_yyzz_xxzzzzzz_0, tg_yyzz_xxzzzzzz_1, \
                                         tg_yyzz_xyyyyyyy_0, tg_yyzz_xyyyyyyy_1, tg_yyzz_xyyyyyyz_0, tg_yyzz_xyyyyyyz_1, \
                                         tg_yyzz_xyyyyyzz_0, tg_yyzz_xyyyyyzz_1, tg_yyzz_xyyyyzzz_0, tg_yyzz_xyyyyzzz_1, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyyyyy_xxyyzzzz_0[j] = pb_y * tg_yyyyy_xxyyzzzz_0[j] + fr * tg_yyyyy_xxyyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyyzzzz_0[j] - tg_yyyy_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xxyzzzz_1[j];

                    tg_yyyyyy_xxyzzzzz_0[j] = pb_y * tg_yyyyy_xxyzzzzz_0[j] + fr * tg_yyyyy_xxyzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxyzzzzz_0[j] - tg_yyyy_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xxzzzzz_1[j];

                    tg_yyyyyy_xxzzzzzz_0[j] = pb_y * tg_yyyyy_xxzzzzzz_0[j] + fr * tg_yyyyy_xxzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xxzzzzzz_0[j] - tg_yyyy_xxzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyy_xyyyyyyy_0[j] = pb_y * tg_yyyyy_xyyyyyyy_0[j] + fr * tg_yyyyy_xyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyyyyyy_0[j] - tg_yyyy_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyy_xyyyyyy_1[j];

                    tg_yyyyyy_xyyyyyyz_0[j] = pb_y * tg_yyyyy_xyyyyyyz_0[j] + fr * tg_yyyyy_xyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyyyyyz_0[j] - tg_yyyy_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyy_xyyyyyz_1[j];

                    tg_yyyyyy_xyyyyyzz_0[j] = pb_y * tg_yyyyy_xyyyyyzz_0[j] + fr * tg_yyyyy_xyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyyyyzz_0[j] - tg_yyyy_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyy_xyyyyzz_1[j];

                    tg_yyyyyy_xyyyyzzz_0[j] = pb_y * tg_yyyyy_xyyyyzzz_0[j] + fr * tg_yyyyy_xyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyyyzzz_0[j] - tg_yyyy_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyy_xyyyzzz_1[j];

                    tg_yyyyyy_xyyyzzzz_0[j] = pb_y * tg_yyyyy_xyyyzzzz_0[j] + fr * tg_yyyyy_xyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyyzzzz_0[j] - tg_yyyy_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_xyyzzzz_1[j];

                    tg_yyyyyy_xyyzzzzz_0[j] = pb_y * tg_yyyyy_xyyzzzzz_0[j] + fr * tg_yyyyy_xyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyyzzzzz_0[j] - tg_yyyy_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_xyzzzzz_1[j];

                    tg_yyyyyy_xyzzzzzz_0[j] = pb_y * tg_yyyyy_xyzzzzzz_0[j] + fr * tg_yyyyy_xyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xyzzzzzz_0[j] - tg_yyyy_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_xzzzzzz_1[j];

                    tg_yyyyyy_xzzzzzzz_0[j] = pb_y * tg_yyyyy_xzzzzzzz_0[j] + fr * tg_yyyyy_xzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_xzzzzzzz_0[j] - tg_yyyy_xzzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyy_yyyyyyyy_0[j] = pb_y * tg_yyyyy_yyyyyyyy_0[j] + fr * tg_yyyyy_yyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyyyyyy_0[j] - tg_yyyy_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_yyyyy_yyyyyyy_1[j];

                    tg_yyyyyy_yyyyyyyz_0[j] = pb_y * tg_yyyyy_yyyyyyyz_0[j] + fr * tg_yyyyy_yyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyyyyyz_0[j] - tg_yyyy_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyy_yyyyyyz_1[j];

                    tg_yyyyyy_yyyyyyzz_0[j] = pb_y * tg_yyyyy_yyyyyyzz_0[j] + fr * tg_yyyyy_yyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyyyyzz_0[j] - tg_yyyy_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyy_yyyyyzz_1[j];

                    tg_yyyyyy_yyyyyzzz_0[j] = pb_y * tg_yyyyy_yyyyyzzz_0[j] + fr * tg_yyyyy_yyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyyyzzz_0[j] - tg_yyyy_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyy_yyyyzzz_1[j];

                    tg_yyyyyy_yyyyzzzz_0[j] = pb_y * tg_yyyyy_yyyyzzzz_0[j] + fr * tg_yyyyy_yyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyyzzzz_0[j] - tg_yyyy_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyy_yyyzzzz_1[j];

                    tg_yyyyyy_yyyzzzzz_0[j] = pb_y * tg_yyyyy_yyyzzzzz_0[j] + fr * tg_yyyyy_yyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyyzzzzz_0[j] - tg_yyyy_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyy_yyzzzzz_1[j];

                    tg_yyyyyy_yyzzzzzz_0[j] = pb_y * tg_yyyyy_yyzzzzzz_0[j] + fr * tg_yyyyy_yyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yyzzzzzz_0[j] - tg_yyyy_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyy_yzzzzzz_1[j];

                    tg_yyyyyy_yzzzzzzz_0[j] = pb_y * tg_yyyyy_yzzzzzzz_0[j] + fr * tg_yyyyy_yzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_yzzzzzzz_0[j] - tg_yyyy_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyy_zzzzzzz_1[j];

                    tg_yyyyyy_zzzzzzzz_0[j] = pb_y * tg_yyyyy_zzzzzzzz_0[j] + fr * tg_yyyyy_zzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyy_zzzzzzzz_0[j] - tg_yyyy_zzzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyz_xxxxxxxx_0[j] = pb_y * tg_yyyyz_xxxxxxxx_0[j] + fr * tg_yyyyz_xxxxxxxx_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxxx_0[j] - tg_yyyz_xxxxxxxx_1[j] * fl1_fza);

                    tg_yyyyyz_xxxxxxxy_0[j] = pb_y * tg_yyyyz_xxxxxxxy_0[j] + fr * tg_yyyyz_xxxxxxxy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxxy_0[j] - tg_yyyz_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxxxxxx_1[j];

                    tg_yyyyyz_xxxxxxxz_0[j] = pb_y * tg_yyyyz_xxxxxxxz_0[j] + fr * tg_yyyyz_xxxxxxxz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxxz_0[j] - tg_yyyz_xxxxxxxz_1[j] * fl1_fza);

                    tg_yyyyyz_xxxxxxyy_0[j] = pb_y * tg_yyyyz_xxxxxxyy_0[j] + fr * tg_yyyyz_xxxxxxyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxyy_0[j] - tg_yyyz_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xxxxxxy_1[j];

                    tg_yyyyyz_xxxxxxyz_0[j] = pb_y * tg_yyyyz_xxxxxxyz_0[j] + fr * tg_yyyyz_xxxxxxyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxyz_0[j] - tg_yyyz_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxxxxxz_1[j];

                    tg_yyyyyz_xxxxxxzz_0[j] = pb_y * tg_yyyyz_xxxxxxzz_0[j] + fr * tg_yyyyz_xxxxxxzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxxzz_0[j] - tg_yyyz_xxxxxxzz_1[j] * fl1_fza);

                    tg_yyyyyz_xxxxxyyy_0[j] = pb_y * tg_yyyyz_xxxxxyyy_0[j] + fr * tg_yyyyz_xxxxxyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxyyy_0[j] - tg_yyyz_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_xxxxxyy_1[j];

                    tg_yyyyyz_xxxxxyyz_0[j] = pb_y * tg_yyyyz_xxxxxyyz_0[j] + fr * tg_yyyyz_xxxxxyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxyyz_0[j] - tg_yyyz_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xxxxxyz_1[j];

                    tg_yyyyyz_xxxxxyzz_0[j] = pb_y * tg_yyyyz_xxxxxyzz_0[j] + fr * tg_yyyyz_xxxxxyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxyzz_0[j] - tg_yyyz_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxxxxzz_1[j];

                    tg_yyyyyz_xxxxxzzz_0[j] = pb_y * tg_yyyyz_xxxxxzzz_0[j] + fr * tg_yyyyz_xxxxxzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxxzzz_0[j] - tg_yyyz_xxxxxzzz_1[j] * fl1_fza);

                    tg_yyyyyz_xxxxyyyy_0[j] = pb_y * tg_yyyyz_xxxxyyyy_0[j] + fr * tg_yyyyz_xxxxyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxyyyy_0[j] - tg_yyyz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyz_xxxxyyy_1[j];

                    tg_yyyyyz_xxxxyyyz_0[j] = pb_y * tg_yyyyz_xxxxyyyz_0[j] + fr * tg_yyyyz_xxxxyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxyyyz_0[j] - tg_yyyz_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_xxxxyyz_1[j];

                    tg_yyyyyz_xxxxyyzz_0[j] = pb_y * tg_yyyyz_xxxxyyzz_0[j] + fr * tg_yyyyz_xxxxyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxyyzz_0[j] - tg_yyyz_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xxxxyzz_1[j];

                    tg_yyyyyz_xxxxyzzz_0[j] = pb_y * tg_yyyyz_xxxxyzzz_0[j] + fr * tg_yyyyz_xxxxyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxyzzz_0[j] - tg_yyyz_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxxxzzz_1[j];

                    tg_yyyyyz_xxxxzzzz_0[j] = pb_y * tg_yyyyz_xxxxzzzz_0[j] + fr * tg_yyyyz_xxxxzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxxzzzz_0[j] - tg_yyyz_xxxxzzzz_1[j] * fl1_fza);

                    tg_yyyyyz_xxxyyyyy_0[j] = pb_y * tg_yyyyz_xxxyyyyy_0[j] + fr * tg_yyyyz_xxxyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxyyyyy_0[j] - tg_yyyz_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyz_xxxyyyy_1[j];

                    tg_yyyyyz_xxxyyyyz_0[j] = pb_y * tg_yyyyz_xxxyyyyz_0[j] + fr * tg_yyyyz_xxxyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxyyyyz_0[j] - tg_yyyz_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyz_xxxyyyz_1[j];

                    tg_yyyyyz_xxxyyyzz_0[j] = pb_y * tg_yyyyz_xxxyyyzz_0[j] + fr * tg_yyyyz_xxxyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxyyyzz_0[j] - tg_yyyz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_xxxyyzz_1[j];

                    tg_yyyyyz_xxxyyzzz_0[j] = pb_y * tg_yyyyz_xxxyyzzz_0[j] + fr * tg_yyyyz_xxxyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxyyzzz_0[j] - tg_yyyz_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xxxyzzz_1[j];

                    tg_yyyyyz_xxxyzzzz_0[j] = pb_y * tg_yyyyz_xxxyzzzz_0[j] + fr * tg_yyyyz_xxxyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxyzzzz_0[j] - tg_yyyz_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxxzzzz_1[j];

                    tg_yyyyyz_xxxzzzzz_0[j] = pb_y * tg_yyyyz_xxxzzzzz_0[j] + fr * tg_yyyyz_xxxzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxxzzzzz_0[j] - tg_yyyz_xxxzzzzz_1[j] * fl1_fza);

                    tg_yyyyyz_xxyyyyyy_0[j] = pb_y * tg_yyyyz_xxyyyyyy_0[j] + fr * tg_yyyyz_xxyyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyyyyyy_0[j] - tg_yyyz_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyz_xxyyyyy_1[j];

                    tg_yyyyyz_xxyyyyyz_0[j] = pb_y * tg_yyyyz_xxyyyyyz_0[j] + fr * tg_yyyyz_xxyyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyyyyyz_0[j] - tg_yyyz_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyz_xxyyyyz_1[j];

                    tg_yyyyyz_xxyyyyzz_0[j] = pb_y * tg_yyyyz_xxyyyyzz_0[j] + fr * tg_yyyyz_xxyyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyyyyzz_0[j] - tg_yyyz_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyz_xxyyyzz_1[j];

                    tg_yyyyyz_xxyyyzzz_0[j] = pb_y * tg_yyyyz_xxyyyzzz_0[j] + fr * tg_yyyyz_xxyyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyyyzzz_0[j] - tg_yyyz_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_xxyyzzz_1[j];

                    tg_yyyyyz_xxyyzzzz_0[j] = pb_y * tg_yyyyz_xxyyzzzz_0[j] + fr * tg_yyyyz_xxyyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyyzzzz_0[j] - tg_yyyz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xxyzzzz_1[j];

                    tg_yyyyyz_xxyzzzzz_0[j] = pb_y * tg_yyyyz_xxyzzzzz_0[j] + fr * tg_yyyyz_xxyzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxyzzzzz_0[j] - tg_yyyz_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xxzzzzz_1[j];

                    tg_yyyyyz_xxzzzzzz_0[j] = pb_y * tg_yyyyz_xxzzzzzz_0[j] + fr * tg_yyyyz_xxzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xxzzzzzz_0[j] - tg_yyyz_xxzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyz_xyyyyyyy_0[j] = pb_y * tg_yyyyz_xyyyyyyy_0[j] + fr * tg_yyyyz_xyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyyyyyy_0[j] - tg_yyyz_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyz_xyyyyyy_1[j];

                    tg_yyyyyz_xyyyyyyz_0[j] = pb_y * tg_yyyyz_xyyyyyyz_0[j] + fr * tg_yyyyz_xyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyyyyyz_0[j] - tg_yyyz_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyz_xyyyyyz_1[j];

                    tg_yyyyyz_xyyyyyzz_0[j] = pb_y * tg_yyyyz_xyyyyyzz_0[j] + fr * tg_yyyyz_xyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyyyyzz_0[j] - tg_yyyz_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyz_xyyyyzz_1[j];

                    tg_yyyyyz_xyyyyzzz_0[j] = pb_y * tg_yyyyz_xyyyyzzz_0[j] + fr * tg_yyyyz_xyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyyyzzz_0[j] - tg_yyyz_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyz_xyyyzzz_1[j];

                    tg_yyyyyz_xyyyzzzz_0[j] = pb_y * tg_yyyyz_xyyyzzzz_0[j] + fr * tg_yyyyz_xyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyyzzzz_0[j] - tg_yyyz_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_xyyzzzz_1[j];

                    tg_yyyyyz_xyyzzzzz_0[j] = pb_y * tg_yyyyz_xyyzzzzz_0[j] + fr * tg_yyyyz_xyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyyzzzzz_0[j] - tg_yyyz_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_xyzzzzz_1[j];

                    tg_yyyyyz_xyzzzzzz_0[j] = pb_y * tg_yyyyz_xyzzzzzz_0[j] + fr * tg_yyyyz_xyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xyzzzzzz_0[j] - tg_yyyz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_xzzzzzz_1[j];

                    tg_yyyyyz_xzzzzzzz_0[j] = pb_y * tg_yyyyz_xzzzzzzz_0[j] + fr * tg_yyyyz_xzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_xzzzzzzz_0[j] - tg_yyyz_xzzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyz_yyyyyyyy_0[j] = pb_y * tg_yyyyz_yyyyyyyy_0[j] + fr * tg_yyyyz_yyyyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyyyyyy_0[j] - tg_yyyz_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_yyyyz_yyyyyyy_1[j];

                    tg_yyyyyz_yyyyyyyz_0[j] = pb_y * tg_yyyyz_yyyyyyyz_0[j] + fr * tg_yyyyz_yyyyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyyyyyz_0[j] - tg_yyyz_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyz_yyyyyyz_1[j];

                    tg_yyyyyz_yyyyyyzz_0[j] = pb_y * tg_yyyyz_yyyyyyzz_0[j] + fr * tg_yyyyz_yyyyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyyyyzz_0[j] - tg_yyyz_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyz_yyyyyzz_1[j];

                    tg_yyyyyz_yyyyyzzz_0[j] = pb_y * tg_yyyyz_yyyyyzzz_0[j] + fr * tg_yyyyz_yyyyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyyyzzz_0[j] - tg_yyyz_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyz_yyyyzzz_1[j];

                    tg_yyyyyz_yyyyzzzz_0[j] = pb_y * tg_yyyyz_yyyyzzzz_0[j] + fr * tg_yyyyz_yyyyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyyzzzz_0[j] - tg_yyyz_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyz_yyyzzzz_1[j];

                    tg_yyyyyz_yyyzzzzz_0[j] = pb_y * tg_yyyyz_yyyzzzzz_0[j] + fr * tg_yyyyz_yyyzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyyzzzzz_0[j] - tg_yyyz_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyz_yyzzzzz_1[j];

                    tg_yyyyyz_yyzzzzzz_0[j] = pb_y * tg_yyyyz_yyzzzzzz_0[j] + fr * tg_yyyyz_yyzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yyzzzzzz_0[j] - tg_yyyz_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyz_yzzzzzz_1[j];

                    tg_yyyyyz_yzzzzzzz_0[j] = pb_y * tg_yyyyz_yzzzzzzz_0[j] + fr * tg_yyyyz_yzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_yzzzzzzz_0[j] - tg_yyyz_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyz_zzzzzzz_1[j];

                    tg_yyyyyz_zzzzzzzz_0[j] = pb_y * tg_yyyyz_zzzzzzzz_0[j] + fr * tg_yyyyz_zzzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyz_zzzzzzzz_0[j] - tg_yyyz_zzzzzzzz_1[j] * fl1_fza);

                    tg_yyyyzz_xxxxxxxx_0[j] = pb_y * tg_yyyzz_xxxxxxxx_0[j] + fr * tg_yyyzz_xxxxxxxx_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxxx_0[j] - tg_yyzz_xxxxxxxx_1[j] * fl1_fza);

                    tg_yyyyzz_xxxxxxxy_0[j] = pb_y * tg_yyyzz_xxxxxxxy_0[j] + fr * tg_yyyzz_xxxxxxxy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxxy_0[j] - tg_yyzz_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxxxxxx_1[j];

                    tg_yyyyzz_xxxxxxxz_0[j] = pb_y * tg_yyyzz_xxxxxxxz_0[j] + fr * tg_yyyzz_xxxxxxxz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxxz_0[j] - tg_yyzz_xxxxxxxz_1[j] * fl1_fza);

                    tg_yyyyzz_xxxxxxyy_0[j] = pb_y * tg_yyyzz_xxxxxxyy_0[j] + fr * tg_yyyzz_xxxxxxyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxyy_0[j] - tg_yyzz_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xxxxxxy_1[j];

                    tg_yyyyzz_xxxxxxyz_0[j] = pb_y * tg_yyyzz_xxxxxxyz_0[j] + fr * tg_yyyzz_xxxxxxyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxyz_0[j] - tg_yyzz_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxxxxxz_1[j];

                    tg_yyyyzz_xxxxxxzz_0[j] = pb_y * tg_yyyzz_xxxxxxzz_0[j] + fr * tg_yyyzz_xxxxxxzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxxzz_0[j] - tg_yyzz_xxxxxxzz_1[j] * fl1_fza);

                    tg_yyyyzz_xxxxxyyy_0[j] = pb_y * tg_yyyzz_xxxxxyyy_0[j] + fr * tg_yyyzz_xxxxxyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxyyy_0[j] - tg_yyzz_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_xxxxxyy_1[j];

                    tg_yyyyzz_xxxxxyyz_0[j] = pb_y * tg_yyyzz_xxxxxyyz_0[j] + fr * tg_yyyzz_xxxxxyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxyyz_0[j] - tg_yyzz_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xxxxxyz_1[j];

                    tg_yyyyzz_xxxxxyzz_0[j] = pb_y * tg_yyyzz_xxxxxyzz_0[j] + fr * tg_yyyzz_xxxxxyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxyzz_0[j] - tg_yyzz_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxxxxzz_1[j];

                    tg_yyyyzz_xxxxxzzz_0[j] = pb_y * tg_yyyzz_xxxxxzzz_0[j] + fr * tg_yyyzz_xxxxxzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxxzzz_0[j] - tg_yyzz_xxxxxzzz_1[j] * fl1_fza);

                    tg_yyyyzz_xxxxyyyy_0[j] = pb_y * tg_yyyzz_xxxxyyyy_0[j] + fr * tg_yyyzz_xxxxyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxyyyy_0[j] - tg_yyzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzz_xxxxyyy_1[j];

                    tg_yyyyzz_xxxxyyyz_0[j] = pb_y * tg_yyyzz_xxxxyyyz_0[j] + fr * tg_yyyzz_xxxxyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxyyyz_0[j] - tg_yyzz_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_xxxxyyz_1[j];

                    tg_yyyyzz_xxxxyyzz_0[j] = pb_y * tg_yyyzz_xxxxyyzz_0[j] + fr * tg_yyyzz_xxxxyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxyyzz_0[j] - tg_yyzz_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xxxxyzz_1[j];

                    tg_yyyyzz_xxxxyzzz_0[j] = pb_y * tg_yyyzz_xxxxyzzz_0[j] + fr * tg_yyyzz_xxxxyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxyzzz_0[j] - tg_yyzz_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxxxzzz_1[j];

                    tg_yyyyzz_xxxxzzzz_0[j] = pb_y * tg_yyyzz_xxxxzzzz_0[j] + fr * tg_yyyzz_xxxxzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxxzzzz_0[j] - tg_yyzz_xxxxzzzz_1[j] * fl1_fza);

                    tg_yyyyzz_xxxyyyyy_0[j] = pb_y * tg_yyyzz_xxxyyyyy_0[j] + fr * tg_yyyzz_xxxyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxyyyyy_0[j] - tg_yyzz_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzz_xxxyyyy_1[j];

                    tg_yyyyzz_xxxyyyyz_0[j] = pb_y * tg_yyyzz_xxxyyyyz_0[j] + fr * tg_yyyzz_xxxyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxyyyyz_0[j] - tg_yyzz_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzz_xxxyyyz_1[j];

                    tg_yyyyzz_xxxyyyzz_0[j] = pb_y * tg_yyyzz_xxxyyyzz_0[j] + fr * tg_yyyzz_xxxyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxyyyzz_0[j] - tg_yyzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_xxxyyzz_1[j];

                    tg_yyyyzz_xxxyyzzz_0[j] = pb_y * tg_yyyzz_xxxyyzzz_0[j] + fr * tg_yyyzz_xxxyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxyyzzz_0[j] - tg_yyzz_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xxxyzzz_1[j];

                    tg_yyyyzz_xxxyzzzz_0[j] = pb_y * tg_yyyzz_xxxyzzzz_0[j] + fr * tg_yyyzz_xxxyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxyzzzz_0[j] - tg_yyzz_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxxzzzz_1[j];

                    tg_yyyyzz_xxxzzzzz_0[j] = pb_y * tg_yyyzz_xxxzzzzz_0[j] + fr * tg_yyyzz_xxxzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxxzzzzz_0[j] - tg_yyzz_xxxzzzzz_1[j] * fl1_fza);

                    tg_yyyyzz_xxyyyyyy_0[j] = pb_y * tg_yyyzz_xxyyyyyy_0[j] + fr * tg_yyyzz_xxyyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyyyyyy_0[j] - tg_yyzz_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzz_xxyyyyy_1[j];

                    tg_yyyyzz_xxyyyyyz_0[j] = pb_y * tg_yyyzz_xxyyyyyz_0[j] + fr * tg_yyyzz_xxyyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyyyyyz_0[j] - tg_yyzz_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzz_xxyyyyz_1[j];

                    tg_yyyyzz_xxyyyyzz_0[j] = pb_y * tg_yyyzz_xxyyyyzz_0[j] + fr * tg_yyyzz_xxyyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyyyyzz_0[j] - tg_yyzz_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzz_xxyyyzz_1[j];

                    tg_yyyyzz_xxyyyzzz_0[j] = pb_y * tg_yyyzz_xxyyyzzz_0[j] + fr * tg_yyyzz_xxyyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyyyzzz_0[j] - tg_yyzz_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_xxyyzzz_1[j];

                    tg_yyyyzz_xxyyzzzz_0[j] = pb_y * tg_yyyzz_xxyyzzzz_0[j] + fr * tg_yyyzz_xxyyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyyzzzz_0[j] - tg_yyzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xxyzzzz_1[j];

                    tg_yyyyzz_xxyzzzzz_0[j] = pb_y * tg_yyyzz_xxyzzzzz_0[j] + fr * tg_yyyzz_xxyzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxyzzzzz_0[j] - tg_yyzz_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xxzzzzz_1[j];

                    tg_yyyyzz_xxzzzzzz_0[j] = pb_y * tg_yyyzz_xxzzzzzz_0[j] + fr * tg_yyyzz_xxzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xxzzzzzz_0[j] - tg_yyzz_xxzzzzzz_1[j] * fl1_fza);

                    tg_yyyyzz_xyyyyyyy_0[j] = pb_y * tg_yyyzz_xyyyyyyy_0[j] + fr * tg_yyyzz_xyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyyyyyy_0[j] - tg_yyzz_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyzz_xyyyyyy_1[j];

                    tg_yyyyzz_xyyyyyyz_0[j] = pb_y * tg_yyyzz_xyyyyyyz_0[j] + fr * tg_yyyzz_xyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyyyyyz_0[j] - tg_yyzz_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzz_xyyyyyz_1[j];

                    tg_yyyyzz_xyyyyyzz_0[j] = pb_y * tg_yyyzz_xyyyyyzz_0[j] + fr * tg_yyyzz_xyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyyyyzz_0[j] - tg_yyzz_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzz_xyyyyzz_1[j];

                    tg_yyyyzz_xyyyyzzz_0[j] = pb_y * tg_yyyzz_xyyyyzzz_0[j] + fr * tg_yyyzz_xyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyyyzzz_0[j] - tg_yyzz_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzz_xyyyzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_1067_1164(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1067,1164)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 797); 

                auto tg_yyyzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 798); 

                auto tg_yyyzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 799); 

                auto tg_yyyzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 800); 

                auto tg_yyyzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 801); 

                auto tg_yyyzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 802); 

                auto tg_yyyzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 803); 

                auto tg_yyyzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 804); 

                auto tg_yyyzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 805); 

                auto tg_yyyzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 806); 

                auto tg_yyyzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 807); 

                auto tg_yyyzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 808); 

                auto tg_yyyzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 809); 

                auto tg_yyzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 810); 

                auto tg_yyzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 811); 

                auto tg_yyzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 812); 

                auto tg_yyzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 813); 

                auto tg_yyzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 814); 

                auto tg_yyzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 815); 

                auto tg_yyzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 816); 

                auto tg_yyzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 817); 

                auto tg_yyzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 818); 

                auto tg_yyzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 819); 

                auto tg_yyzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 820); 

                auto tg_yyzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 821); 

                auto tg_yyzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 822); 

                auto tg_yyzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 823); 

                auto tg_yyzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 824); 

                auto tg_yyzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 825); 

                auto tg_yyzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 826); 

                auto tg_yyzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 827); 

                auto tg_yyzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 828); 

                auto tg_yyzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 829); 

                auto tg_yyzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 830); 

                auto tg_yyzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 831); 

                auto tg_yyzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 832); 

                auto tg_yyzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 833); 

                auto tg_yyzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 834); 

                auto tg_yyzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 835); 

                auto tg_yyzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 836); 

                auto tg_yyzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 837); 

                auto tg_yyzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 838); 

                auto tg_yyzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 839); 

                auto tg_yyzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 840); 

                auto tg_yyzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 841); 

                auto tg_yyzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 842); 

                auto tg_yyzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 843); 

                auto tg_yyzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 844); 

                auto tg_yyzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 845); 

                auto tg_yyzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 846); 

                auto tg_yyzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 847); 

                auto tg_yyzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 848); 

                auto tg_yyzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 849); 

                auto tg_yyzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 850); 

                auto tg_yyzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 851); 

                auto tg_yyzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 852); 

                auto tg_yyzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 853); 

                auto tg_yyzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 854); 

                auto tg_yzzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 855); 

                auto tg_yzzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 856); 

                auto tg_yzzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 857); 

                auto tg_yzzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 858); 

                auto tg_yzzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 859); 

                auto tg_yzzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 860); 

                auto tg_yzzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 861); 

                auto tg_yzzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 862); 

                auto tg_yzzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 863); 

                auto tg_yzzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 864); 

                auto tg_yzzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 865); 

                auto tg_yzzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 866); 

                auto tg_yzzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 867); 

                auto tg_yzzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 868); 

                auto tg_yzzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 869); 

                auto tg_yzzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 870); 

                auto tg_yzzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 871); 

                auto tg_yzzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 872); 

                auto tg_yzzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 873); 

                auto tg_yzzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 874); 

                auto tg_yzzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 875); 

                auto tg_yzzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 876); 

                auto tg_yzzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 877); 

                auto tg_yzzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 878); 

                auto tg_yzzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 879); 

                auto tg_yzzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 880); 

                auto tg_yzzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 881); 

                auto tg_yzzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 882); 

                auto tg_yzzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 883); 

                auto tg_yzzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 884); 

                auto tg_yzzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 885); 

                auto tg_yzzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 886); 

                auto tg_yzzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 887); 

                auto tg_yzzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 888); 

                auto tg_yzzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 889); 

                auto tg_yzzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 890); 

                auto tg_yzzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 891); 

                auto tg_yzzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 892); 

                auto tg_yzzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 893); 

                auto tg_yyyzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 797); 

                auto tg_yyyzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 798); 

                auto tg_yyyzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 799); 

                auto tg_yyyzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 800); 

                auto tg_yyyzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 801); 

                auto tg_yyyzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 802); 

                auto tg_yyyzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 803); 

                auto tg_yyyzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 804); 

                auto tg_yyyzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 805); 

                auto tg_yyyzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 806); 

                auto tg_yyyzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 807); 

                auto tg_yyyzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 808); 

                auto tg_yyyzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 809); 

                auto tg_yyzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 810); 

                auto tg_yyzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 811); 

                auto tg_yyzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 812); 

                auto tg_yyzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 813); 

                auto tg_yyzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 814); 

                auto tg_yyzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 815); 

                auto tg_yyzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 816); 

                auto tg_yyzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 817); 

                auto tg_yyzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 818); 

                auto tg_yyzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 819); 

                auto tg_yyzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 820); 

                auto tg_yyzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 821); 

                auto tg_yyzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 822); 

                auto tg_yyzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 823); 

                auto tg_yyzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 824); 

                auto tg_yyzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 825); 

                auto tg_yyzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 826); 

                auto tg_yyzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 827); 

                auto tg_yyzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 828); 

                auto tg_yyzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 829); 

                auto tg_yyzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 830); 

                auto tg_yyzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 831); 

                auto tg_yyzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 832); 

                auto tg_yyzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 833); 

                auto tg_yyzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 834); 

                auto tg_yyzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 835); 

                auto tg_yyzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 836); 

                auto tg_yyzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 837); 

                auto tg_yyzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 838); 

                auto tg_yyzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 839); 

                auto tg_yyzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 840); 

                auto tg_yyzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 841); 

                auto tg_yyzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 842); 

                auto tg_yyzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 843); 

                auto tg_yyzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 844); 

                auto tg_yyzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 845); 

                auto tg_yyzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 846); 

                auto tg_yyzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 847); 

                auto tg_yyzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 848); 

                auto tg_yyzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 849); 

                auto tg_yyzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 850); 

                auto tg_yyzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 851); 

                auto tg_yyzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 852); 

                auto tg_yyzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 853); 

                auto tg_yyzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 854); 

                auto tg_yzzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 855); 

                auto tg_yzzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 856); 

                auto tg_yzzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 857); 

                auto tg_yzzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 858); 

                auto tg_yzzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 859); 

                auto tg_yzzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 860); 

                auto tg_yzzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 861); 

                auto tg_yzzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 862); 

                auto tg_yzzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 863); 

                auto tg_yzzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 864); 

                auto tg_yzzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 865); 

                auto tg_yzzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 866); 

                auto tg_yzzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 867); 

                auto tg_yzzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 868); 

                auto tg_yzzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 869); 

                auto tg_yzzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 870); 

                auto tg_yzzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 871); 

                auto tg_yzzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 872); 

                auto tg_yzzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 873); 

                auto tg_yzzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 874); 

                auto tg_yzzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 875); 

                auto tg_yzzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 876); 

                auto tg_yzzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 877); 

                auto tg_yzzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 878); 

                auto tg_yzzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 879); 

                auto tg_yzzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 880); 

                auto tg_yzzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 881); 

                auto tg_yzzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 882); 

                auto tg_yzzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 883); 

                auto tg_yzzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 884); 

                auto tg_yzzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 885); 

                auto tg_yzzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 886); 

                auto tg_yzzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 887); 

                auto tg_yzzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 888); 

                auto tg_yzzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 889); 

                auto tg_yzzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 890); 

                auto tg_yzzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 891); 

                auto tg_yzzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 892); 

                auto tg_yzzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 893); 

                auto tg_yyzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 572); 

                auto tg_yyzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 573); 

                auto tg_yyzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 574); 

                auto tg_yyzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 575); 

                auto tg_yyzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 576); 

                auto tg_yyzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 577); 

                auto tg_yyzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 578); 

                auto tg_yyzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 579); 

                auto tg_yyzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 580); 

                auto tg_yyzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 581); 

                auto tg_yyzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 582); 

                auto tg_yyzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 583); 

                auto tg_yyzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 584); 

                auto tg_yzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 585); 

                auto tg_yzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 586); 

                auto tg_yzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 587); 

                auto tg_yzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 588); 

                auto tg_yzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 589); 

                auto tg_yzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 590); 

                auto tg_yzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 591); 

                auto tg_yzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 592); 

                auto tg_yzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 593); 

                auto tg_yzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 594); 

                auto tg_yzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 595); 

                auto tg_yzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 596); 

                auto tg_yzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 597); 

                auto tg_yzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 598); 

                auto tg_yzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 599); 

                auto tg_yzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 600); 

                auto tg_yzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 601); 

                auto tg_yzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 602); 

                auto tg_yzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 603); 

                auto tg_yzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 604); 

                auto tg_yzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 605); 

                auto tg_yzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 606); 

                auto tg_yzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 607); 

                auto tg_yzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 608); 

                auto tg_yzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 609); 

                auto tg_yzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 610); 

                auto tg_yzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 611); 

                auto tg_yzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 612); 

                auto tg_yzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 613); 

                auto tg_yzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 614); 

                auto tg_yzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 615); 

                auto tg_yzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 616); 

                auto tg_yzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 617); 

                auto tg_yzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 618); 

                auto tg_yzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 619); 

                auto tg_yzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 620); 

                auto tg_yzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 621); 

                auto tg_yzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 622); 

                auto tg_yzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 623); 

                auto tg_yzzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 624); 

                auto tg_yzzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 625); 

                auto tg_yzzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 626); 

                auto tg_yzzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 627); 

                auto tg_yzzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 628); 

                auto tg_yzzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 629); 

                auto tg_zzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 668); 

                auto tg_yyzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 572); 

                auto tg_yyzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 573); 

                auto tg_yyzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 574); 

                auto tg_yyzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 575); 

                auto tg_yyzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 576); 

                auto tg_yyzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 577); 

                auto tg_yyzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 578); 

                auto tg_yyzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 579); 

                auto tg_yyzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 580); 

                auto tg_yyzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 581); 

                auto tg_yyzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 582); 

                auto tg_yyzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 583); 

                auto tg_yyzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 584); 

                auto tg_yzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 585); 

                auto tg_yzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 586); 

                auto tg_yzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 587); 

                auto tg_yzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 588); 

                auto tg_yzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 589); 

                auto tg_yzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 590); 

                auto tg_yzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 591); 

                auto tg_yzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 592); 

                auto tg_yzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 593); 

                auto tg_yzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 594); 

                auto tg_yzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 595); 

                auto tg_yzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 596); 

                auto tg_yzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 597); 

                auto tg_yzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 598); 

                auto tg_yzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 599); 

                auto tg_yzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 600); 

                auto tg_yzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 601); 

                auto tg_yzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 602); 

                auto tg_yzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 603); 

                auto tg_yzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 604); 

                auto tg_yzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 605); 

                auto tg_yzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 606); 

                auto tg_yzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 607); 

                auto tg_yzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 608); 

                auto tg_yzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 609); 

                auto tg_yzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 610); 

                auto tg_yzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 611); 

                auto tg_yzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 612); 

                auto tg_yzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 613); 

                auto tg_yzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 614); 

                auto tg_yzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 615); 

                auto tg_yzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 616); 

                auto tg_yzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 617); 

                auto tg_yzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 618); 

                auto tg_yzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 619); 

                auto tg_yzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 620); 

                auto tg_yzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 621); 

                auto tg_yzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 622); 

                auto tg_yzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 623); 

                auto tg_yzzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 624); 

                auto tg_yzzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 625); 

                auto tg_yzzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 626); 

                auto tg_yzzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 627); 

                auto tg_yzzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 628); 

                auto tg_yzzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 629); 

                auto tg_zzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 668); 

                auto tg_yyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 699); 

                auto tg_yzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 701); 

                auto tg_yzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 714); 

                // set up pointers to integrals

                auto tg_yyyyzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1067); 

                auto tg_yyyyzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1068); 

                auto tg_yyyyzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1069); 

                auto tg_yyyyzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1070); 

                auto tg_yyyyzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1071); 

                auto tg_yyyyzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1072); 

                auto tg_yyyyzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1073); 

                auto tg_yyyyzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1074); 

                auto tg_yyyyzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1075); 

                auto tg_yyyyzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1076); 

                auto tg_yyyyzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1077); 

                auto tg_yyyyzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1078); 

                auto tg_yyyyzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1079); 

                auto tg_yyyzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1080); 

                auto tg_yyyzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1081); 

                auto tg_yyyzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1082); 

                auto tg_yyyzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1083); 

                auto tg_yyyzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1084); 

                auto tg_yyyzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1085); 

                auto tg_yyyzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1086); 

                auto tg_yyyzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1087); 

                auto tg_yyyzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1088); 

                auto tg_yyyzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1089); 

                auto tg_yyyzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1090); 

                auto tg_yyyzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1091); 

                auto tg_yyyzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1092); 

                auto tg_yyyzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1093); 

                auto tg_yyyzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1094); 

                auto tg_yyyzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1095); 

                auto tg_yyyzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1096); 

                auto tg_yyyzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1097); 

                auto tg_yyyzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1098); 

                auto tg_yyyzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1099); 

                auto tg_yyyzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1100); 

                auto tg_yyyzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1101); 

                auto tg_yyyzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1102); 

                auto tg_yyyzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1103); 

                auto tg_yyyzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1104); 

                auto tg_yyyzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1105); 

                auto tg_yyyzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1106); 

                auto tg_yyyzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1107); 

                auto tg_yyyzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1108); 

                auto tg_yyyzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1109); 

                auto tg_yyyzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1110); 

                auto tg_yyyzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1111); 

                auto tg_yyyzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1112); 

                auto tg_yyyzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1113); 

                auto tg_yyyzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1114); 

                auto tg_yyyzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1115); 

                auto tg_yyyzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1116); 

                auto tg_yyyzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1117); 

                auto tg_yyyzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1118); 

                auto tg_yyyzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1119); 

                auto tg_yyyzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1120); 

                auto tg_yyyzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1121); 

                auto tg_yyyzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1122); 

                auto tg_yyyzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1123); 

                auto tg_yyyzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1124); 

                auto tg_yyzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1125); 

                auto tg_yyzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1126); 

                auto tg_yyzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1127); 

                auto tg_yyzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1128); 

                auto tg_yyzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1129); 

                auto tg_yyzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1130); 

                auto tg_yyzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1131); 

                auto tg_yyzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1132); 

                auto tg_yyzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1133); 

                auto tg_yyzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1134); 

                auto tg_yyzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1135); 

                auto tg_yyzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1136); 

                auto tg_yyzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1137); 

                auto tg_yyzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1138); 

                auto tg_yyzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1139); 

                auto tg_yyzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1140); 

                auto tg_yyzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1141); 

                auto tg_yyzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1142); 

                auto tg_yyzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1143); 

                auto tg_yyzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1144); 

                auto tg_yyzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1145); 

                auto tg_yyzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1146); 

                auto tg_yyzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1147); 

                auto tg_yyzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1148); 

                auto tg_yyzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1149); 

                auto tg_yyzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1150); 

                auto tg_yyzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1151); 

                auto tg_yyzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1152); 

                auto tg_yyzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1153); 

                auto tg_yyzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1154); 

                auto tg_yyzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1155); 

                auto tg_yyzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1156); 

                auto tg_yyzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1157); 

                auto tg_yyzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1158); 

                auto tg_yyzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1159); 

                auto tg_yyzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1160); 

                auto tg_yyzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1161); 

                auto tg_yyzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1162); 

                auto tg_yyzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1163); 

                // Batch of Integrals (1067,1164)

                #pragma omp simd aligned(fxn, fza, tg_yyyyzz_xyyyzzzz_0, tg_yyyyzz_xyyzzzzz_0, \
                                         tg_yyyyzz_xyzzzzzz_0, tg_yyyyzz_xzzzzzzz_0, tg_yyyyzz_yyyyyyyy_0, tg_yyyyzz_yyyyyyyz_0, \
                                         tg_yyyyzz_yyyyyyzz_0, tg_yyyyzz_yyyyyzzz_0, tg_yyyyzz_yyyyzzzz_0, tg_yyyyzz_yyyzzzzz_0, \
                                         tg_yyyyzz_yyzzzzzz_0, tg_yyyyzz_yzzzzzzz_0, tg_yyyyzz_zzzzzzzz_0, tg_yyyzz_xyyyzzzz_0, \
                                         tg_yyyzz_xyyyzzzz_1, tg_yyyzz_xyyzzzz_1, tg_yyyzz_xyyzzzzz_0, tg_yyyzz_xyyzzzzz_1, \
                                         tg_yyyzz_xyzzzzz_1, tg_yyyzz_xyzzzzzz_0, tg_yyyzz_xyzzzzzz_1, tg_yyyzz_xzzzzzz_1, \
                                         tg_yyyzz_xzzzzzzz_0, tg_yyyzz_xzzzzzzz_1, tg_yyyzz_yyyyyyy_1, tg_yyyzz_yyyyyyyy_0, \
                                         tg_yyyzz_yyyyyyyy_1, tg_yyyzz_yyyyyyyz_0, tg_yyyzz_yyyyyyyz_1, tg_yyyzz_yyyyyyz_1, \
                                         tg_yyyzz_yyyyyyzz_0, tg_yyyzz_yyyyyyzz_1, tg_yyyzz_yyyyyzz_1, tg_yyyzz_yyyyyzzz_0, \
                                         tg_yyyzz_yyyyyzzz_1, tg_yyyzz_yyyyzzz_1, tg_yyyzz_yyyyzzzz_0, tg_yyyzz_yyyyzzzz_1, \
                                         tg_yyyzz_yyyzzzz_1, tg_yyyzz_yyyzzzzz_0, tg_yyyzz_yyyzzzzz_1, tg_yyyzz_yyzzzzz_1, \
                                         tg_yyyzz_yyzzzzzz_0, tg_yyyzz_yyzzzzzz_1, tg_yyyzz_yzzzzzz_1, tg_yyyzz_yzzzzzzz_0, \
                                         tg_yyyzz_yzzzzzzz_1, tg_yyyzz_zzzzzzz_1, tg_yyyzz_zzzzzzzz_0, tg_yyyzz_zzzzzzzz_1, \
                                         tg_yyyzzz_xxxxxxxx_0, tg_yyyzzz_xxxxxxxy_0, tg_yyyzzz_xxxxxxxz_0, tg_yyyzzz_xxxxxxyy_0, \
                                         tg_yyyzzz_xxxxxxyz_0, tg_yyyzzz_xxxxxxzz_0, tg_yyyzzz_xxxxxyyy_0, tg_yyyzzz_xxxxxyyz_0, \
                                         tg_yyyzzz_xxxxxyzz_0, tg_yyyzzz_xxxxxzzz_0, tg_yyyzzz_xxxxyyyy_0, tg_yyyzzz_xxxxyyyz_0, \
                                         tg_yyyzzz_xxxxyyzz_0, tg_yyyzzz_xxxxyzzz_0, tg_yyyzzz_xxxxzzzz_0, tg_yyyzzz_xxxyyyyy_0, \
                                         tg_yyyzzz_xxxyyyyz_0, tg_yyyzzz_xxxyyyzz_0, tg_yyyzzz_xxxyyzzz_0, tg_yyyzzz_xxxyzzzz_0, \
                                         tg_yyyzzz_xxxzzzzz_0, tg_yyyzzz_xxyyyyyy_0, tg_yyyzzz_xxyyyyyz_0, tg_yyyzzz_xxyyyyzz_0, \
                                         tg_yyyzzz_xxyyyzzz_0, tg_yyyzzz_xxyyzzzz_0, tg_yyyzzz_xxyzzzzz_0, tg_yyyzzz_xxzzzzzz_0, \
                                         tg_yyyzzz_xyyyyyyy_0, tg_yyyzzz_xyyyyyyz_0, tg_yyyzzz_xyyyyyzz_0, tg_yyyzzz_xyyyyzzz_0, \
                                         tg_yyyzzz_xyyyzzzz_0, tg_yyyzzz_xyyzzzzz_0, tg_yyyzzz_xyzzzzzz_0, tg_yyyzzz_xzzzzzzz_0, \
                                         tg_yyyzzz_yyyyyyyy_0, tg_yyyzzz_yyyyyyyz_0, tg_yyyzzz_yyyyyyzz_0, tg_yyyzzz_yyyyyzzz_0, \
                                         tg_yyyzzz_yyyyzzzz_0, tg_yyyzzz_yyyzzzzz_0, tg_yyyzzz_yyzzzzzz_0, tg_yyyzzz_yzzzzzzz_0, \
                                         tg_yyyzzz_zzzzzzzz_0, tg_yyzz_xyyyzzzz_0, tg_yyzz_xyyyzzzz_1, tg_yyzz_xyyzzzzz_0, \
                                         tg_yyzz_xyyzzzzz_1, tg_yyzz_xyzzzzzz_0, tg_yyzz_xyzzzzzz_1, tg_yyzz_xzzzzzzz_0, \
                                         tg_yyzz_xzzzzzzz_1, tg_yyzz_yyyyyyyy_0, tg_yyzz_yyyyyyyy_1, tg_yyzz_yyyyyyyz_0, \
                                         tg_yyzz_yyyyyyyz_1, tg_yyzz_yyyyyyzz_0, tg_yyzz_yyyyyyzz_1, tg_yyzz_yyyyyzzz_0, \
                                         tg_yyzz_yyyyyzzz_1, tg_yyzz_yyyyzzzz_0, tg_yyzz_yyyyzzzz_1, tg_yyzz_yyyzzzzz_0, \
                                         tg_yyzz_yyyzzzzz_1, tg_yyzz_yyzzzzzz_0, tg_yyzz_yyzzzzzz_1, tg_yyzz_yzzzzzzz_0, \
                                         tg_yyzz_yzzzzzzz_1, tg_yyzz_zzzzzzzz_0, tg_yyzz_zzzzzzzz_1, tg_yyzzz_xxxxxxx_1, \
                                         tg_yyzzz_xxxxxxxx_0, tg_yyzzz_xxxxxxxx_1, tg_yyzzz_xxxxxxxy_0, tg_yyzzz_xxxxxxxy_1, \
                                         tg_yyzzz_xxxxxxxz_0, tg_yyzzz_xxxxxxxz_1, tg_yyzzz_xxxxxxy_1, tg_yyzzz_xxxxxxyy_0, \
                                         tg_yyzzz_xxxxxxyy_1, tg_yyzzz_xxxxxxyz_0, tg_yyzzz_xxxxxxyz_1, tg_yyzzz_xxxxxxz_1, \
                                         tg_yyzzz_xxxxxxzz_0, tg_yyzzz_xxxxxxzz_1, tg_yyzzz_xxxxxyy_1, tg_yyzzz_xxxxxyyy_0, \
                                         tg_yyzzz_xxxxxyyy_1, tg_yyzzz_xxxxxyyz_0, tg_yyzzz_xxxxxyyz_1, tg_yyzzz_xxxxxyz_1, \
                                         tg_yyzzz_xxxxxyzz_0, tg_yyzzz_xxxxxyzz_1, tg_yyzzz_xxxxxzz_1, tg_yyzzz_xxxxxzzz_0, \
                                         tg_yyzzz_xxxxxzzz_1, tg_yyzzz_xxxxyyy_1, tg_yyzzz_xxxxyyyy_0, tg_yyzzz_xxxxyyyy_1, \
                                         tg_yyzzz_xxxxyyyz_0, tg_yyzzz_xxxxyyyz_1, tg_yyzzz_xxxxyyz_1, tg_yyzzz_xxxxyyzz_0, \
                                         tg_yyzzz_xxxxyyzz_1, tg_yyzzz_xxxxyzz_1, tg_yyzzz_xxxxyzzz_0, tg_yyzzz_xxxxyzzz_1, \
                                         tg_yyzzz_xxxxzzz_1, tg_yyzzz_xxxxzzzz_0, tg_yyzzz_xxxxzzzz_1, tg_yyzzz_xxxyyyy_1, \
                                         tg_yyzzz_xxxyyyyy_0, tg_yyzzz_xxxyyyyy_1, tg_yyzzz_xxxyyyyz_0, tg_yyzzz_xxxyyyyz_1, \
                                         tg_yyzzz_xxxyyyz_1, tg_yyzzz_xxxyyyzz_0, tg_yyzzz_xxxyyyzz_1, tg_yyzzz_xxxyyzz_1, \
                                         tg_yyzzz_xxxyyzzz_0, tg_yyzzz_xxxyyzzz_1, tg_yyzzz_xxxyzzz_1, tg_yyzzz_xxxyzzzz_0, \
                                         tg_yyzzz_xxxyzzzz_1, tg_yyzzz_xxxzzzz_1, tg_yyzzz_xxxzzzzz_0, tg_yyzzz_xxxzzzzz_1, \
                                         tg_yyzzz_xxyyyyy_1, tg_yyzzz_xxyyyyyy_0, tg_yyzzz_xxyyyyyy_1, tg_yyzzz_xxyyyyyz_0, \
                                         tg_yyzzz_xxyyyyyz_1, tg_yyzzz_xxyyyyz_1, tg_yyzzz_xxyyyyzz_0, tg_yyzzz_xxyyyyzz_1, \
                                         tg_yyzzz_xxyyyzz_1, tg_yyzzz_xxyyyzzz_0, tg_yyzzz_xxyyyzzz_1, tg_yyzzz_xxyyzzz_1, \
                                         tg_yyzzz_xxyyzzzz_0, tg_yyzzz_xxyyzzzz_1, tg_yyzzz_xxyzzzz_1, tg_yyzzz_xxyzzzzz_0, \
                                         tg_yyzzz_xxyzzzzz_1, tg_yyzzz_xxzzzzz_1, tg_yyzzz_xxzzzzzz_0, tg_yyzzz_xxzzzzzz_1, \
                                         tg_yyzzz_xyyyyyy_1, tg_yyzzz_xyyyyyyy_0, tg_yyzzz_xyyyyyyy_1, tg_yyzzz_xyyyyyyz_0, \
                                         tg_yyzzz_xyyyyyyz_1, tg_yyzzz_xyyyyyz_1, tg_yyzzz_xyyyyyzz_0, tg_yyzzz_xyyyyyzz_1, \
                                         tg_yyzzz_xyyyyzz_1, tg_yyzzz_xyyyyzzz_0, tg_yyzzz_xyyyyzzz_1, tg_yyzzz_xyyyzzz_1, \
                                         tg_yyzzz_xyyyzzzz_0, tg_yyzzz_xyyyzzzz_1, tg_yyzzz_xyyzzzz_1, tg_yyzzz_xyyzzzzz_0, \
                                         tg_yyzzz_xyyzzzzz_1, tg_yyzzz_xyzzzzz_1, tg_yyzzz_xyzzzzzz_0, tg_yyzzz_xyzzzzzz_1, \
                                         tg_yyzzz_xzzzzzz_1, tg_yyzzz_xzzzzzzz_0, tg_yyzzz_xzzzzzzz_1, tg_yyzzz_yyyyyyy_1, \
                                         tg_yyzzz_yyyyyyyy_0, tg_yyzzz_yyyyyyyy_1, tg_yyzzz_yyyyyyyz_0, tg_yyzzz_yyyyyyyz_1, \
                                         tg_yyzzz_yyyyyyz_1, tg_yyzzz_yyyyyyzz_0, tg_yyzzz_yyyyyyzz_1, tg_yyzzz_yyyyyzz_1, \
                                         tg_yyzzz_yyyyyzzz_0, tg_yyzzz_yyyyyzzz_1, tg_yyzzz_yyyyzzz_1, tg_yyzzz_yyyyzzzz_0, \
                                         tg_yyzzz_yyyyzzzz_1, tg_yyzzz_yyyzzzz_1, tg_yyzzz_yyyzzzzz_0, tg_yyzzz_yyyzzzzz_1, \
                                         tg_yyzzz_yyzzzzz_1, tg_yyzzz_yyzzzzzz_0, tg_yyzzz_yyzzzzzz_1, tg_yyzzz_yzzzzzz_1, \
                                         tg_yyzzz_yzzzzzzz_0, tg_yyzzz_yzzzzzzz_1, tg_yyzzz_zzzzzzz_1, tg_yyzzz_zzzzzzzz_0, \
                                         tg_yyzzz_zzzzzzzz_1, tg_yyzzzz_xxxxxxxx_0, tg_yyzzzz_xxxxxxxy_0, tg_yyzzzz_xxxxxxxz_0, \
                                         tg_yyzzzz_xxxxxxyy_0, tg_yyzzzz_xxxxxxyz_0, tg_yyzzzz_xxxxxxzz_0, tg_yyzzzz_xxxxxyyy_0, \
                                         tg_yyzzzz_xxxxxyyz_0, tg_yyzzzz_xxxxxyzz_0, tg_yyzzzz_xxxxxzzz_0, tg_yyzzzz_xxxxyyyy_0, \
                                         tg_yyzzzz_xxxxyyyz_0, tg_yyzzzz_xxxxyyzz_0, tg_yyzzzz_xxxxyzzz_0, tg_yyzzzz_xxxxzzzz_0, \
                                         tg_yyzzzz_xxxyyyyy_0, tg_yyzzzz_xxxyyyyz_0, tg_yyzzzz_xxxyyyzz_0, tg_yyzzzz_xxxyyzzz_0, \
                                         tg_yyzzzz_xxxyzzzz_0, tg_yyzzzz_xxxzzzzz_0, tg_yyzzzz_xxyyyyyy_0, tg_yyzzzz_xxyyyyyz_0, \
                                         tg_yyzzzz_xxyyyyzz_0, tg_yyzzzz_xxyyyzzz_0, tg_yyzzzz_xxyyzzzz_0, tg_yyzzzz_xxyzzzzz_0, \
                                         tg_yyzzzz_xxzzzzzz_0, tg_yyzzzz_xyyyyyyy_0, tg_yyzzzz_xyyyyyyz_0, tg_yyzzzz_xyyyyyzz_0, \
                                         tg_yyzzzz_xyyyyzzz_0, tg_yyzzzz_xyyyzzzz_0, tg_yyzzzz_xyyzzzzz_0, tg_yyzzzz_xyzzzzzz_0, \
                                         tg_yyzzzz_xzzzzzzz_0, tg_yyzzzz_yyyyyyyy_0, tg_yyzzzz_yyyyyyyz_0, tg_yyzzzz_yyyyyyzz_0, \
                                         tg_yzzz_xxxxxxxx_0, tg_yzzz_xxxxxxxx_1, tg_yzzz_xxxxxxxy_0, tg_yzzz_xxxxxxxy_1, \
                                         tg_yzzz_xxxxxxxz_0, tg_yzzz_xxxxxxxz_1, tg_yzzz_xxxxxxyy_0, tg_yzzz_xxxxxxyy_1, \
                                         tg_yzzz_xxxxxxyz_0, tg_yzzz_xxxxxxyz_1, tg_yzzz_xxxxxxzz_0, tg_yzzz_xxxxxxzz_1, \
                                         tg_yzzz_xxxxxyyy_0, tg_yzzz_xxxxxyyy_1, tg_yzzz_xxxxxyyz_0, tg_yzzz_xxxxxyyz_1, \
                                         tg_yzzz_xxxxxyzz_0, tg_yzzz_xxxxxyzz_1, tg_yzzz_xxxxxzzz_0, tg_yzzz_xxxxxzzz_1, \
                                         tg_yzzz_xxxxyyyy_0, tg_yzzz_xxxxyyyy_1, tg_yzzz_xxxxyyyz_0, tg_yzzz_xxxxyyyz_1, \
                                         tg_yzzz_xxxxyyzz_0, tg_yzzz_xxxxyyzz_1, tg_yzzz_xxxxyzzz_0, tg_yzzz_xxxxyzzz_1, \
                                         tg_yzzz_xxxxzzzz_0, tg_yzzz_xxxxzzzz_1, tg_yzzz_xxxyyyyy_0, tg_yzzz_xxxyyyyy_1, \
                                         tg_yzzz_xxxyyyyz_0, tg_yzzz_xxxyyyyz_1, tg_yzzz_xxxyyyzz_0, tg_yzzz_xxxyyyzz_1, \
                                         tg_yzzz_xxxyyzzz_0, tg_yzzz_xxxyyzzz_1, tg_yzzz_xxxyzzzz_0, tg_yzzz_xxxyzzzz_1, \
                                         tg_yzzz_xxxzzzzz_0, tg_yzzz_xxxzzzzz_1, tg_yzzz_xxyyyyyy_0, tg_yzzz_xxyyyyyy_1, \
                                         tg_yzzz_xxyyyyyz_0, tg_yzzz_xxyyyyyz_1, tg_yzzz_xxyyyyzz_0, tg_yzzz_xxyyyyzz_1, \
                                         tg_yzzz_xxyyyzzz_0, tg_yzzz_xxyyyzzz_1, tg_yzzz_xxyyzzzz_0, tg_yzzz_xxyyzzzz_1, \
                                         tg_yzzz_xxyzzzzz_0, tg_yzzz_xxyzzzzz_1, tg_yzzz_xxzzzzzz_0, tg_yzzz_xxzzzzzz_1, \
                                         tg_yzzz_xyyyyyyy_0, tg_yzzz_xyyyyyyy_1, tg_yzzz_xyyyyyyz_0, tg_yzzz_xyyyyyyz_1, \
                                         tg_yzzz_xyyyyyzz_0, tg_yzzz_xyyyyyzz_1, tg_yzzz_xyyyyzzz_0, tg_yzzz_xyyyyzzz_1, \
                                         tg_yzzz_xyyyzzzz_0, tg_yzzz_xyyyzzzz_1, tg_yzzz_xyyzzzzz_0, tg_yzzz_xyyzzzzz_1, \
                                         tg_yzzz_xyzzzzzz_0, tg_yzzz_xyzzzzzz_1, tg_yzzz_xzzzzzzz_0, tg_yzzz_xzzzzzzz_1, \
                                         tg_yzzz_yyyyyyyy_0, tg_yzzz_yyyyyyyy_1, tg_yzzz_yyyyyyyz_0, tg_yzzz_yyyyyyyz_1, \
                                         tg_yzzz_yyyyyyzz_0, tg_yzzz_yyyyyyzz_1, tg_yzzz_yyyyyzzz_0, tg_yzzz_yyyyyzzz_1, \
                                         tg_yzzz_yyyyzzzz_0, tg_yzzz_yyyyzzzz_1, tg_yzzz_yyyzzzzz_0, tg_yzzz_yyyzzzzz_1, \
                                         tg_yzzz_yyzzzzzz_0, tg_yzzz_yyzzzzzz_1, tg_yzzz_yzzzzzzz_0, tg_yzzz_yzzzzzzz_1, \
                                         tg_yzzz_zzzzzzzz_0, tg_yzzz_zzzzzzzz_1, tg_yzzzz_xxxxxxx_1, tg_yzzzz_xxxxxxxx_0, \
                                         tg_yzzzz_xxxxxxxx_1, tg_yzzzz_xxxxxxxy_0, tg_yzzzz_xxxxxxxy_1, tg_yzzzz_xxxxxxxz_0, \
                                         tg_yzzzz_xxxxxxxz_1, tg_yzzzz_xxxxxxy_1, tg_yzzzz_xxxxxxyy_0, tg_yzzzz_xxxxxxyy_1, \
                                         tg_yzzzz_xxxxxxyz_0, tg_yzzzz_xxxxxxyz_1, tg_yzzzz_xxxxxxz_1, tg_yzzzz_xxxxxxzz_0, \
                                         tg_yzzzz_xxxxxxzz_1, tg_yzzzz_xxxxxyy_1, tg_yzzzz_xxxxxyyy_0, tg_yzzzz_xxxxxyyy_1, \
                                         tg_yzzzz_xxxxxyyz_0, tg_yzzzz_xxxxxyyz_1, tg_yzzzz_xxxxxyz_1, tg_yzzzz_xxxxxyzz_0, \
                                         tg_yzzzz_xxxxxyzz_1, tg_yzzzz_xxxxxzz_1, tg_yzzzz_xxxxxzzz_0, tg_yzzzz_xxxxxzzz_1, \
                                         tg_yzzzz_xxxxyyy_1, tg_yzzzz_xxxxyyyy_0, tg_yzzzz_xxxxyyyy_1, tg_yzzzz_xxxxyyyz_0, \
                                         tg_yzzzz_xxxxyyyz_1, tg_yzzzz_xxxxyyz_1, tg_yzzzz_xxxxyyzz_0, tg_yzzzz_xxxxyyzz_1, \
                                         tg_yzzzz_xxxxyzz_1, tg_yzzzz_xxxxyzzz_0, tg_yzzzz_xxxxyzzz_1, tg_yzzzz_xxxxzzz_1, \
                                         tg_yzzzz_xxxxzzzz_0, tg_yzzzz_xxxxzzzz_1, tg_yzzzz_xxxyyyy_1, tg_yzzzz_xxxyyyyy_0, \
                                         tg_yzzzz_xxxyyyyy_1, tg_yzzzz_xxxyyyyz_0, tg_yzzzz_xxxyyyyz_1, tg_yzzzz_xxxyyyz_1, \
                                         tg_yzzzz_xxxyyyzz_0, tg_yzzzz_xxxyyyzz_1, tg_yzzzz_xxxyyzz_1, tg_yzzzz_xxxyyzzz_0, \
                                         tg_yzzzz_xxxyyzzz_1, tg_yzzzz_xxxyzzz_1, tg_yzzzz_xxxyzzzz_0, tg_yzzzz_xxxyzzzz_1, \
                                         tg_yzzzz_xxxzzzz_1, tg_yzzzz_xxxzzzzz_0, tg_yzzzz_xxxzzzzz_1, tg_yzzzz_xxyyyyy_1, \
                                         tg_yzzzz_xxyyyyyy_0, tg_yzzzz_xxyyyyyy_1, tg_yzzzz_xxyyyyyz_0, tg_yzzzz_xxyyyyyz_1, \
                                         tg_yzzzz_xxyyyyz_1, tg_yzzzz_xxyyyyzz_0, tg_yzzzz_xxyyyyzz_1, tg_yzzzz_xxyyyzz_1, \
                                         tg_yzzzz_xxyyyzzz_0, tg_yzzzz_xxyyyzzz_1, tg_yzzzz_xxyyzzz_1, tg_yzzzz_xxyyzzzz_0, \
                                         tg_yzzzz_xxyyzzzz_1, tg_yzzzz_xxyzzzz_1, tg_yzzzz_xxyzzzzz_0, tg_yzzzz_xxyzzzzz_1, \
                                         tg_yzzzz_xxzzzzz_1, tg_yzzzz_xxzzzzzz_0, tg_yzzzz_xxzzzzzz_1, tg_yzzzz_xyyyyyy_1, \
                                         tg_yzzzz_xyyyyyyy_0, tg_yzzzz_xyyyyyyy_1, tg_yzzzz_xyyyyyyz_0, tg_yzzzz_xyyyyyyz_1, \
                                         tg_yzzzz_xyyyyyz_1, tg_yzzzz_xyyyyyzz_0, tg_yzzzz_xyyyyyzz_1, tg_yzzzz_xyyyyzz_1, \
                                         tg_yzzzz_xyyyyzzz_0, tg_yzzzz_xyyyyzzz_1, tg_yzzzz_xyyyzzz_1, tg_yzzzz_xyyyzzzz_0, \
                                         tg_yzzzz_xyyyzzzz_1, tg_yzzzz_xyyzzzz_1, tg_yzzzz_xyyzzzzz_0, tg_yzzzz_xyyzzzzz_1, \
                                         tg_yzzzz_xyzzzzz_1, tg_yzzzz_xyzzzzzz_0, tg_yzzzz_xyzzzzzz_1, tg_yzzzz_xzzzzzz_1, \
                                         tg_yzzzz_xzzzzzzz_0, tg_yzzzz_xzzzzzzz_1, tg_yzzzz_yyyyyyy_1, tg_yzzzz_yyyyyyyy_0, \
                                         tg_yzzzz_yyyyyyyy_1, tg_yzzzz_yyyyyyyz_0, tg_yzzzz_yyyyyyyz_1, tg_yzzzz_yyyyyyz_1, \
                                         tg_yzzzz_yyyyyyzz_0, tg_yzzzz_yyyyyyzz_1, tg_yzzzz_yyyyyzz_1, tg_zzzz_xxxxxxxx_0, \
                                         tg_zzzz_xxxxxxxx_1, tg_zzzz_xxxxxxxy_0, tg_zzzz_xxxxxxxy_1, tg_zzzz_xxxxxxxz_0, \
                                         tg_zzzz_xxxxxxxz_1, tg_zzzz_xxxxxxyy_0, tg_zzzz_xxxxxxyy_1, tg_zzzz_xxxxxxyz_0, \
                                         tg_zzzz_xxxxxxyz_1, tg_zzzz_xxxxxxzz_0, tg_zzzz_xxxxxxzz_1, tg_zzzz_xxxxxyyy_0, \
                                         tg_zzzz_xxxxxyyy_1, tg_zzzz_xxxxxyyz_0, tg_zzzz_xxxxxyyz_1, tg_zzzz_xxxxxyzz_0, \
                                         tg_zzzz_xxxxxyzz_1, tg_zzzz_xxxxxzzz_0, tg_zzzz_xxxxxzzz_1, tg_zzzz_xxxxyyyy_0, \
                                         tg_zzzz_xxxxyyyy_1, tg_zzzz_xxxxyyyz_0, tg_zzzz_xxxxyyyz_1, tg_zzzz_xxxxyyzz_0, \
                                         tg_zzzz_xxxxyyzz_1, tg_zzzz_xxxxyzzz_0, tg_zzzz_xxxxyzzz_1, tg_zzzz_xxxxzzzz_0, \
                                         tg_zzzz_xxxxzzzz_1, tg_zzzz_xxxyyyyy_0, tg_zzzz_xxxyyyyy_1, tg_zzzz_xxxyyyyz_0, \
                                         tg_zzzz_xxxyyyyz_1, tg_zzzz_xxxyyyzz_0, tg_zzzz_xxxyyyzz_1, tg_zzzz_xxxyyzzz_0, \
                                         tg_zzzz_xxxyyzzz_1, tg_zzzz_xxxyzzzz_0, tg_zzzz_xxxyzzzz_1, tg_zzzz_xxxzzzzz_0, \
                                         tg_zzzz_xxxzzzzz_1, tg_zzzz_xxyyyyyy_0, tg_zzzz_xxyyyyyy_1, tg_zzzz_xxyyyyyz_0, \
                                         tg_zzzz_xxyyyyyz_1, tg_zzzz_xxyyyyzz_0, tg_zzzz_xxyyyyzz_1, tg_zzzz_xxyyyzzz_0, \
                                         tg_zzzz_xxyyyzzz_1, tg_zzzz_xxyyzzzz_0, tg_zzzz_xxyyzzzz_1, tg_zzzz_xxyzzzzz_0, \
                                         tg_zzzz_xxyzzzzz_1, tg_zzzz_xxzzzzzz_0, tg_zzzz_xxzzzzzz_1, tg_zzzz_xyyyyyyy_0, \
                                         tg_zzzz_xyyyyyyy_1, tg_zzzz_xyyyyyyz_0, tg_zzzz_xyyyyyyz_1, tg_zzzz_xyyyyyzz_0, \
                                         tg_zzzz_xyyyyyzz_1, tg_zzzz_xyyyyzzz_0, tg_zzzz_xyyyyzzz_1, tg_zzzz_xyyyzzzz_0, \
                                         tg_zzzz_xyyyzzzz_1, tg_zzzz_xyyzzzzz_0, tg_zzzz_xyyzzzzz_1, tg_zzzz_xyzzzzzz_0, \
                                         tg_zzzz_xyzzzzzz_1, tg_zzzz_xzzzzzzz_0, tg_zzzz_xzzzzzzz_1, tg_zzzz_yyyyyyyy_0, \
                                         tg_zzzz_yyyyyyyy_1, tg_zzzz_yyyyyyyz_0, tg_zzzz_yyyyyyyz_1, tg_zzzz_yyyyyyzz_0, \
                                         tg_zzzz_yyyyyyzz_1, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyyyzz_xyyyzzzz_0[j] = pb_y * tg_yyyzz_xyyyzzzz_0[j] + fr * tg_yyyzz_xyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyyzzzz_0[j] - tg_yyzz_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_xyyzzzz_1[j];

                    tg_yyyyzz_xyyzzzzz_0[j] = pb_y * tg_yyyzz_xyyzzzzz_0[j] + fr * tg_yyyzz_xyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyyzzzzz_0[j] - tg_yyzz_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_xyzzzzz_1[j];

                    tg_yyyyzz_xyzzzzzz_0[j] = pb_y * tg_yyyzz_xyzzzzzz_0[j] + fr * tg_yyyzz_xyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xyzzzzzz_0[j] - tg_yyzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_xzzzzzz_1[j];

                    tg_yyyyzz_xzzzzzzz_0[j] = pb_y * tg_yyyzz_xzzzzzzz_0[j] + fr * tg_yyyzz_xzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_xzzzzzzz_0[j] - tg_yyzz_xzzzzzzz_1[j] * fl1_fza);

                    tg_yyyyzz_yyyyyyyy_0[j] = pb_y * tg_yyyzz_yyyyyyyy_0[j] + fr * tg_yyyzz_yyyyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyyyyyy_0[j] - tg_yyzz_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_yyyzz_yyyyyyy_1[j];

                    tg_yyyyzz_yyyyyyyz_0[j] = pb_y * tg_yyyzz_yyyyyyyz_0[j] + fr * tg_yyyzz_yyyyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyyyyyz_0[j] - tg_yyzz_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyzz_yyyyyyz_1[j];

                    tg_yyyyzz_yyyyyyzz_0[j] = pb_y * tg_yyyzz_yyyyyyzz_0[j] + fr * tg_yyyzz_yyyyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyyyyzz_0[j] - tg_yyzz_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzz_yyyyyzz_1[j];

                    tg_yyyyzz_yyyyyzzz_0[j] = pb_y * tg_yyyzz_yyyyyzzz_0[j] + fr * tg_yyyzz_yyyyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyyyzzz_0[j] - tg_yyzz_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzz_yyyyzzz_1[j];

                    tg_yyyyzz_yyyyzzzz_0[j] = pb_y * tg_yyyzz_yyyyzzzz_0[j] + fr * tg_yyyzz_yyyyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyyzzzz_0[j] - tg_yyzz_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzz_yyyzzzz_1[j];

                    tg_yyyyzz_yyyzzzzz_0[j] = pb_y * tg_yyyzz_yyyzzzzz_0[j] + fr * tg_yyyzz_yyyzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyyzzzzz_0[j] - tg_yyzz_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzz_yyzzzzz_1[j];

                    tg_yyyyzz_yyzzzzzz_0[j] = pb_y * tg_yyyzz_yyzzzzzz_0[j] + fr * tg_yyyzz_yyzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yyzzzzzz_0[j] - tg_yyzz_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzz_yzzzzzz_1[j];

                    tg_yyyyzz_yzzzzzzz_0[j] = pb_y * tg_yyyzz_yzzzzzzz_0[j] + fr * tg_yyyzz_yzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_yzzzzzzz_0[j] - tg_yyzz_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzz_zzzzzzz_1[j];

                    tg_yyyyzz_zzzzzzzz_0[j] = pb_y * tg_yyyzz_zzzzzzzz_0[j] + fr * tg_yyyzz_zzzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzz_zzzzzzzz_0[j] - tg_yyzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_yyyzzz_xxxxxxxx_0[j] = pb_y * tg_yyzzz_xxxxxxxx_0[j] + fr * tg_yyzzz_xxxxxxxx_1[j] + fl1_fx * (tg_yzzz_xxxxxxxx_0[j] - tg_yzzz_xxxxxxxx_1[j] * fl1_fza);

                    tg_yyyzzz_xxxxxxxy_0[j] = pb_y * tg_yyzzz_xxxxxxxy_0[j] + fr * tg_yyzzz_xxxxxxxy_1[j] + fl1_fx * (tg_yzzz_xxxxxxxy_0[j] - tg_yzzz_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxxxxxx_1[j];

                    tg_yyyzzz_xxxxxxxz_0[j] = pb_y * tg_yyzzz_xxxxxxxz_0[j] + fr * tg_yyzzz_xxxxxxxz_1[j] + fl1_fx * (tg_yzzz_xxxxxxxz_0[j] - tg_yzzz_xxxxxxxz_1[j] * fl1_fza);

                    tg_yyyzzz_xxxxxxyy_0[j] = pb_y * tg_yyzzz_xxxxxxyy_0[j] + fr * tg_yyzzz_xxxxxxyy_1[j] + fl1_fx * (tg_yzzz_xxxxxxyy_0[j] - tg_yzzz_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xxxxxxy_1[j];

                    tg_yyyzzz_xxxxxxyz_0[j] = pb_y * tg_yyzzz_xxxxxxyz_0[j] + fr * tg_yyzzz_xxxxxxyz_1[j] + fl1_fx * (tg_yzzz_xxxxxxyz_0[j] - tg_yzzz_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxxxxxz_1[j];

                    tg_yyyzzz_xxxxxxzz_0[j] = pb_y * tg_yyzzz_xxxxxxzz_0[j] + fr * tg_yyzzz_xxxxxxzz_1[j] + fl1_fx * (tg_yzzz_xxxxxxzz_0[j] - tg_yzzz_xxxxxxzz_1[j] * fl1_fza);

                    tg_yyyzzz_xxxxxyyy_0[j] = pb_y * tg_yyzzz_xxxxxyyy_0[j] + fr * tg_yyzzz_xxxxxyyy_1[j] + fl1_fx * (tg_yzzz_xxxxxyyy_0[j] - tg_yzzz_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_xxxxxyy_1[j];

                    tg_yyyzzz_xxxxxyyz_0[j] = pb_y * tg_yyzzz_xxxxxyyz_0[j] + fr * tg_yyzzz_xxxxxyyz_1[j] + fl1_fx * (tg_yzzz_xxxxxyyz_0[j] - tg_yzzz_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xxxxxyz_1[j];

                    tg_yyyzzz_xxxxxyzz_0[j] = pb_y * tg_yyzzz_xxxxxyzz_0[j] + fr * tg_yyzzz_xxxxxyzz_1[j] + fl1_fx * (tg_yzzz_xxxxxyzz_0[j] - tg_yzzz_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxxxxzz_1[j];

                    tg_yyyzzz_xxxxxzzz_0[j] = pb_y * tg_yyzzz_xxxxxzzz_0[j] + fr * tg_yyzzz_xxxxxzzz_1[j] + fl1_fx * (tg_yzzz_xxxxxzzz_0[j] - tg_yzzz_xxxxxzzz_1[j] * fl1_fza);

                    tg_yyyzzz_xxxxyyyy_0[j] = pb_y * tg_yyzzz_xxxxyyyy_0[j] + fr * tg_yyzzz_xxxxyyyy_1[j] + fl1_fx * (tg_yzzz_xxxxyyyy_0[j] - tg_yzzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzz_xxxxyyy_1[j];

                    tg_yyyzzz_xxxxyyyz_0[j] = pb_y * tg_yyzzz_xxxxyyyz_0[j] + fr * tg_yyzzz_xxxxyyyz_1[j] + fl1_fx * (tg_yzzz_xxxxyyyz_0[j] - tg_yzzz_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_xxxxyyz_1[j];

                    tg_yyyzzz_xxxxyyzz_0[j] = pb_y * tg_yyzzz_xxxxyyzz_0[j] + fr * tg_yyzzz_xxxxyyzz_1[j] + fl1_fx * (tg_yzzz_xxxxyyzz_0[j] - tg_yzzz_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xxxxyzz_1[j];

                    tg_yyyzzz_xxxxyzzz_0[j] = pb_y * tg_yyzzz_xxxxyzzz_0[j] + fr * tg_yyzzz_xxxxyzzz_1[j] + fl1_fx * (tg_yzzz_xxxxyzzz_0[j] - tg_yzzz_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxxxzzz_1[j];

                    tg_yyyzzz_xxxxzzzz_0[j] = pb_y * tg_yyzzz_xxxxzzzz_0[j] + fr * tg_yyzzz_xxxxzzzz_1[j] + fl1_fx * (tg_yzzz_xxxxzzzz_0[j] - tg_yzzz_xxxxzzzz_1[j] * fl1_fza);

                    tg_yyyzzz_xxxyyyyy_0[j] = pb_y * tg_yyzzz_xxxyyyyy_0[j] + fr * tg_yyzzz_xxxyyyyy_1[j] + fl1_fx * (tg_yzzz_xxxyyyyy_0[j] - tg_yzzz_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzz_xxxyyyy_1[j];

                    tg_yyyzzz_xxxyyyyz_0[j] = pb_y * tg_yyzzz_xxxyyyyz_0[j] + fr * tg_yyzzz_xxxyyyyz_1[j] + fl1_fx * (tg_yzzz_xxxyyyyz_0[j] - tg_yzzz_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzz_xxxyyyz_1[j];

                    tg_yyyzzz_xxxyyyzz_0[j] = pb_y * tg_yyzzz_xxxyyyzz_0[j] + fr * tg_yyzzz_xxxyyyzz_1[j] + fl1_fx * (tg_yzzz_xxxyyyzz_0[j] - tg_yzzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_xxxyyzz_1[j];

                    tg_yyyzzz_xxxyyzzz_0[j] = pb_y * tg_yyzzz_xxxyyzzz_0[j] + fr * tg_yyzzz_xxxyyzzz_1[j] + fl1_fx * (tg_yzzz_xxxyyzzz_0[j] - tg_yzzz_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xxxyzzz_1[j];

                    tg_yyyzzz_xxxyzzzz_0[j] = pb_y * tg_yyzzz_xxxyzzzz_0[j] + fr * tg_yyzzz_xxxyzzzz_1[j] + fl1_fx * (tg_yzzz_xxxyzzzz_0[j] - tg_yzzz_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxxzzzz_1[j];

                    tg_yyyzzz_xxxzzzzz_0[j] = pb_y * tg_yyzzz_xxxzzzzz_0[j] + fr * tg_yyzzz_xxxzzzzz_1[j] + fl1_fx * (tg_yzzz_xxxzzzzz_0[j] - tg_yzzz_xxxzzzzz_1[j] * fl1_fza);

                    tg_yyyzzz_xxyyyyyy_0[j] = pb_y * tg_yyzzz_xxyyyyyy_0[j] + fr * tg_yyzzz_xxyyyyyy_1[j] + fl1_fx * (tg_yzzz_xxyyyyyy_0[j] - tg_yzzz_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzz_xxyyyyy_1[j];

                    tg_yyyzzz_xxyyyyyz_0[j] = pb_y * tg_yyzzz_xxyyyyyz_0[j] + fr * tg_yyzzz_xxyyyyyz_1[j] + fl1_fx * (tg_yzzz_xxyyyyyz_0[j] - tg_yzzz_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzz_xxyyyyz_1[j];

                    tg_yyyzzz_xxyyyyzz_0[j] = pb_y * tg_yyzzz_xxyyyyzz_0[j] + fr * tg_yyzzz_xxyyyyzz_1[j] + fl1_fx * (tg_yzzz_xxyyyyzz_0[j] - tg_yzzz_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzz_xxyyyzz_1[j];

                    tg_yyyzzz_xxyyyzzz_0[j] = pb_y * tg_yyzzz_xxyyyzzz_0[j] + fr * tg_yyzzz_xxyyyzzz_1[j] + fl1_fx * (tg_yzzz_xxyyyzzz_0[j] - tg_yzzz_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_xxyyzzz_1[j];

                    tg_yyyzzz_xxyyzzzz_0[j] = pb_y * tg_yyzzz_xxyyzzzz_0[j] + fr * tg_yyzzz_xxyyzzzz_1[j] + fl1_fx * (tg_yzzz_xxyyzzzz_0[j] - tg_yzzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xxyzzzz_1[j];

                    tg_yyyzzz_xxyzzzzz_0[j] = pb_y * tg_yyzzz_xxyzzzzz_0[j] + fr * tg_yyzzz_xxyzzzzz_1[j] + fl1_fx * (tg_yzzz_xxyzzzzz_0[j] - tg_yzzz_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xxzzzzz_1[j];

                    tg_yyyzzz_xxzzzzzz_0[j] = pb_y * tg_yyzzz_xxzzzzzz_0[j] + fr * tg_yyzzz_xxzzzzzz_1[j] + fl1_fx * (tg_yzzz_xxzzzzzz_0[j] - tg_yzzz_xxzzzzzz_1[j] * fl1_fza);

                    tg_yyyzzz_xyyyyyyy_0[j] = pb_y * tg_yyzzz_xyyyyyyy_0[j] + fr * tg_yyzzz_xyyyyyyy_1[j] + fl1_fx * (tg_yzzz_xyyyyyyy_0[j] - tg_yzzz_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyzzz_xyyyyyy_1[j];

                    tg_yyyzzz_xyyyyyyz_0[j] = pb_y * tg_yyzzz_xyyyyyyz_0[j] + fr * tg_yyzzz_xyyyyyyz_1[j] + fl1_fx * (tg_yzzz_xyyyyyyz_0[j] - tg_yzzz_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzz_xyyyyyz_1[j];

                    tg_yyyzzz_xyyyyyzz_0[j] = pb_y * tg_yyzzz_xyyyyyzz_0[j] + fr * tg_yyzzz_xyyyyyzz_1[j] + fl1_fx * (tg_yzzz_xyyyyyzz_0[j] - tg_yzzz_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzz_xyyyyzz_1[j];

                    tg_yyyzzz_xyyyyzzz_0[j] = pb_y * tg_yyzzz_xyyyyzzz_0[j] + fr * tg_yyzzz_xyyyyzzz_1[j] + fl1_fx * (tg_yzzz_xyyyyzzz_0[j] - tg_yzzz_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzz_xyyyzzz_1[j];

                    tg_yyyzzz_xyyyzzzz_0[j] = pb_y * tg_yyzzz_xyyyzzzz_0[j] + fr * tg_yyzzz_xyyyzzzz_1[j] + fl1_fx * (tg_yzzz_xyyyzzzz_0[j] - tg_yzzz_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_xyyzzzz_1[j];

                    tg_yyyzzz_xyyzzzzz_0[j] = pb_y * tg_yyzzz_xyyzzzzz_0[j] + fr * tg_yyzzz_xyyzzzzz_1[j] + fl1_fx * (tg_yzzz_xyyzzzzz_0[j] - tg_yzzz_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_xyzzzzz_1[j];

                    tg_yyyzzz_xyzzzzzz_0[j] = pb_y * tg_yyzzz_xyzzzzzz_0[j] + fr * tg_yyzzz_xyzzzzzz_1[j] + fl1_fx * (tg_yzzz_xyzzzzzz_0[j] - tg_yzzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_xzzzzzz_1[j];

                    tg_yyyzzz_xzzzzzzz_0[j] = pb_y * tg_yyzzz_xzzzzzzz_0[j] + fr * tg_yyzzz_xzzzzzzz_1[j] + fl1_fx * (tg_yzzz_xzzzzzzz_0[j] - tg_yzzz_xzzzzzzz_1[j] * fl1_fza);

                    tg_yyyzzz_yyyyyyyy_0[j] = pb_y * tg_yyzzz_yyyyyyyy_0[j] + fr * tg_yyzzz_yyyyyyyy_1[j] + fl1_fx * (tg_yzzz_yyyyyyyy_0[j] - tg_yzzz_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_yyzzz_yyyyyyy_1[j];

                    tg_yyyzzz_yyyyyyyz_0[j] = pb_y * tg_yyzzz_yyyyyyyz_0[j] + fr * tg_yyzzz_yyyyyyyz_1[j] + fl1_fx * (tg_yzzz_yyyyyyyz_0[j] - tg_yzzz_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyzzz_yyyyyyz_1[j];

                    tg_yyyzzz_yyyyyyzz_0[j] = pb_y * tg_yyzzz_yyyyyyzz_0[j] + fr * tg_yyzzz_yyyyyyzz_1[j] + fl1_fx * (tg_yzzz_yyyyyyzz_0[j] - tg_yzzz_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzz_yyyyyzz_1[j];

                    tg_yyyzzz_yyyyyzzz_0[j] = pb_y * tg_yyzzz_yyyyyzzz_0[j] + fr * tg_yyzzz_yyyyyzzz_1[j] + fl1_fx * (tg_yzzz_yyyyyzzz_0[j] - tg_yzzz_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzz_yyyyzzz_1[j];

                    tg_yyyzzz_yyyyzzzz_0[j] = pb_y * tg_yyzzz_yyyyzzzz_0[j] + fr * tg_yyzzz_yyyyzzzz_1[j] + fl1_fx * (tg_yzzz_yyyyzzzz_0[j] - tg_yzzz_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzz_yyyzzzz_1[j];

                    tg_yyyzzz_yyyzzzzz_0[j] = pb_y * tg_yyzzz_yyyzzzzz_0[j] + fr * tg_yyzzz_yyyzzzzz_1[j] + fl1_fx * (tg_yzzz_yyyzzzzz_0[j] - tg_yzzz_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzz_yyzzzzz_1[j];

                    tg_yyyzzz_yyzzzzzz_0[j] = pb_y * tg_yyzzz_yyzzzzzz_0[j] + fr * tg_yyzzz_yyzzzzzz_1[j] + fl1_fx * (tg_yzzz_yyzzzzzz_0[j] - tg_yzzz_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzz_yzzzzzz_1[j];

                    tg_yyyzzz_yzzzzzzz_0[j] = pb_y * tg_yyzzz_yzzzzzzz_0[j] + fr * tg_yyzzz_yzzzzzzz_1[j] + fl1_fx * (tg_yzzz_yzzzzzzz_0[j] - tg_yzzz_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzz_zzzzzzz_1[j];

                    tg_yyyzzz_zzzzzzzz_0[j] = pb_y * tg_yyzzz_zzzzzzzz_0[j] + fr * tg_yyzzz_zzzzzzzz_1[j] + fl1_fx * (tg_yzzz_zzzzzzzz_0[j] - tg_yzzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_yyzzzz_xxxxxxxx_0[j] = pb_y * tg_yzzzz_xxxxxxxx_0[j] + fr * tg_yzzzz_xxxxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxx_0[j] - tg_zzzz_xxxxxxxx_1[j] * fl1_fza);

                    tg_yyzzzz_xxxxxxxy_0[j] = pb_y * tg_yzzzz_xxxxxxxy_0[j] + fr * tg_yzzzz_xxxxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxy_0[j] - tg_zzzz_xxxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxxxxxx_1[j];

                    tg_yyzzzz_xxxxxxxz_0[j] = pb_y * tg_yzzzz_xxxxxxxz_0[j] + fr * tg_yzzzz_xxxxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxxz_0[j] - tg_zzzz_xxxxxxxz_1[j] * fl1_fza);

                    tg_yyzzzz_xxxxxxyy_0[j] = pb_y * tg_yzzzz_xxxxxxyy_0[j] + fr * tg_yzzzz_xxxxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxyy_0[j] - tg_zzzz_xxxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xxxxxxy_1[j];

                    tg_yyzzzz_xxxxxxyz_0[j] = pb_y * tg_yzzzz_xxxxxxyz_0[j] + fr * tg_yzzzz_xxxxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxyz_0[j] - tg_zzzz_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxxxxxz_1[j];

                    tg_yyzzzz_xxxxxxzz_0[j] = pb_y * tg_yzzzz_xxxxxxzz_0[j] + fr * tg_yzzzz_xxxxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxxzz_0[j] - tg_zzzz_xxxxxxzz_1[j] * fl1_fza);

                    tg_yyzzzz_xxxxxyyy_0[j] = pb_y * tg_yzzzz_xxxxxyyy_0[j] + fr * tg_yzzzz_xxxxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyyy_0[j] - tg_zzzz_xxxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_xxxxxyy_1[j];

                    tg_yyzzzz_xxxxxyyz_0[j] = pb_y * tg_yzzzz_xxxxxyyz_0[j] + fr * tg_yzzzz_xxxxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyyz_0[j] - tg_zzzz_xxxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xxxxxyz_1[j];

                    tg_yyzzzz_xxxxxyzz_0[j] = pb_y * tg_yzzzz_xxxxxyzz_0[j] + fr * tg_yzzzz_xxxxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxyzz_0[j] - tg_zzzz_xxxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxxxxzz_1[j];

                    tg_yyzzzz_xxxxxzzz_0[j] = pb_y * tg_yzzzz_xxxxxzzz_0[j] + fr * tg_yzzzz_xxxxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxxzzz_0[j] - tg_zzzz_xxxxxzzz_1[j] * fl1_fza);

                    tg_yyzzzz_xxxxyyyy_0[j] = pb_y * tg_yzzzz_xxxxyyyy_0[j] + fr * tg_yzzzz_xxxxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyyy_0[j] - tg_zzzz_xxxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzz_xxxxyyy_1[j];

                    tg_yyzzzz_xxxxyyyz_0[j] = pb_y * tg_yzzzz_xxxxyyyz_0[j] + fr * tg_yzzzz_xxxxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyyz_0[j] - tg_zzzz_xxxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_xxxxyyz_1[j];

                    tg_yyzzzz_xxxxyyzz_0[j] = pb_y * tg_yzzzz_xxxxyyzz_0[j] + fr * tg_yzzzz_xxxxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyyzz_0[j] - tg_zzzz_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xxxxyzz_1[j];

                    tg_yyzzzz_xxxxyzzz_0[j] = pb_y * tg_yzzzz_xxxxyzzz_0[j] + fr * tg_yzzzz_xxxxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxyzzz_0[j] - tg_zzzz_xxxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxxxzzz_1[j];

                    tg_yyzzzz_xxxxzzzz_0[j] = pb_y * tg_yzzzz_xxxxzzzz_0[j] + fr * tg_yzzzz_xxxxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxxzzzz_0[j] - tg_zzzz_xxxxzzzz_1[j] * fl1_fza);

                    tg_yyzzzz_xxxyyyyy_0[j] = pb_y * tg_yzzzz_xxxyyyyy_0[j] + fr * tg_yzzzz_xxxyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyyy_0[j] - tg_zzzz_xxxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzz_xxxyyyy_1[j];

                    tg_yyzzzz_xxxyyyyz_0[j] = pb_y * tg_yzzzz_xxxyyyyz_0[j] + fr * tg_yzzzz_xxxyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyyz_0[j] - tg_zzzz_xxxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzz_xxxyyyz_1[j];

                    tg_yyzzzz_xxxyyyzz_0[j] = pb_y * tg_yzzzz_xxxyyyzz_0[j] + fr * tg_yzzzz_xxxyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyyzz_0[j] - tg_zzzz_xxxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_xxxyyzz_1[j];

                    tg_yyzzzz_xxxyyzzz_0[j] = pb_y * tg_yzzzz_xxxyyzzz_0[j] + fr * tg_yzzzz_xxxyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyyzzz_0[j] - tg_zzzz_xxxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xxxyzzz_1[j];

                    tg_yyzzzz_xxxyzzzz_0[j] = pb_y * tg_yzzzz_xxxyzzzz_0[j] + fr * tg_yzzzz_xxxyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxyzzzz_0[j] - tg_zzzz_xxxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxxzzzz_1[j];

                    tg_yyzzzz_xxxzzzzz_0[j] = pb_y * tg_yzzzz_xxxzzzzz_0[j] + fr * tg_yzzzz_xxxzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxxzzzzz_0[j] - tg_zzzz_xxxzzzzz_1[j] * fl1_fza);

                    tg_yyzzzz_xxyyyyyy_0[j] = pb_y * tg_yzzzz_xxyyyyyy_0[j] + fr * tg_yzzzz_xxyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyyy_0[j] - tg_zzzz_xxyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzz_xxyyyyy_1[j];

                    tg_yyzzzz_xxyyyyyz_0[j] = pb_y * tg_yzzzz_xxyyyyyz_0[j] + fr * tg_yzzzz_xxyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyyz_0[j] - tg_zzzz_xxyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzz_xxyyyyz_1[j];

                    tg_yyzzzz_xxyyyyzz_0[j] = pb_y * tg_yzzzz_xxyyyyzz_0[j] + fr * tg_yzzzz_xxyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyyzz_0[j] - tg_zzzz_xxyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzz_xxyyyzz_1[j];

                    tg_yyzzzz_xxyyyzzz_0[j] = pb_y * tg_yzzzz_xxyyyzzz_0[j] + fr * tg_yzzzz_xxyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyyzzz_0[j] - tg_zzzz_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_xxyyzzz_1[j];

                    tg_yyzzzz_xxyyzzzz_0[j] = pb_y * tg_yzzzz_xxyyzzzz_0[j] + fr * tg_yzzzz_xxyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyyzzzz_0[j] - tg_zzzz_xxyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xxyzzzz_1[j];

                    tg_yyzzzz_xxyzzzzz_0[j] = pb_y * tg_yzzzz_xxyzzzzz_0[j] + fr * tg_yzzzz_xxyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxyzzzzz_0[j] - tg_zzzz_xxyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xxzzzzz_1[j];

                    tg_yyzzzz_xxzzzzzz_0[j] = pb_y * tg_yzzzz_xxzzzzzz_0[j] + fr * tg_yzzzz_xxzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xxzzzzzz_0[j] - tg_zzzz_xxzzzzzz_1[j] * fl1_fza);

                    tg_yyzzzz_xyyyyyyy_0[j] = pb_y * tg_yzzzz_xyyyyyyy_0[j] + fr * tg_yzzzz_xyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyyy_0[j] - tg_zzzz_xyyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yzzzz_xyyyyyy_1[j];

                    tg_yyzzzz_xyyyyyyz_0[j] = pb_y * tg_yzzzz_xyyyyyyz_0[j] + fr * tg_yzzzz_xyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyyz_0[j] - tg_zzzz_xyyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzz_xyyyyyz_1[j];

                    tg_yyzzzz_xyyyyyzz_0[j] = pb_y * tg_yzzzz_xyyyyyzz_0[j] + fr * tg_yzzzz_xyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyyzz_0[j] - tg_zzzz_xyyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzz_xyyyyzz_1[j];

                    tg_yyzzzz_xyyyyzzz_0[j] = pb_y * tg_yzzzz_xyyyyzzz_0[j] + fr * tg_yzzzz_xyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyyzzz_0[j] - tg_zzzz_xyyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzz_xyyyzzz_1[j];

                    tg_yyzzzz_xyyyzzzz_0[j] = pb_y * tg_yzzzz_xyyyzzzz_0[j] + fr * tg_yzzzz_xyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyyzzzz_0[j] - tg_zzzz_xyyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_xyyzzzz_1[j];

                    tg_yyzzzz_xyyzzzzz_0[j] = pb_y * tg_yzzzz_xyyzzzzz_0[j] + fr * tg_yzzzz_xyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyyzzzzz_0[j] - tg_zzzz_xyyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_xyzzzzz_1[j];

                    tg_yyzzzz_xyzzzzzz_0[j] = pb_y * tg_yzzzz_xyzzzzzz_0[j] + fr * tg_yzzzz_xyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xyzzzzzz_0[j] - tg_zzzz_xyzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_xzzzzzz_1[j];

                    tg_yyzzzz_xzzzzzzz_0[j] = pb_y * tg_yzzzz_xzzzzzzz_0[j] + fr * tg_yzzzz_xzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_xzzzzzzz_0[j] - tg_zzzz_xzzzzzzz_1[j] * fl1_fza);

                    tg_yyzzzz_yyyyyyyy_0[j] = pb_y * tg_yzzzz_yyyyyyyy_0[j] + fr * tg_yzzzz_yyyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyyy_0[j] - tg_zzzz_yyyyyyyy_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_yzzzz_yyyyyyy_1[j];

                    tg_yyzzzz_yyyyyyyz_0[j] = pb_y * tg_yzzzz_yyyyyyyz_0[j] + fr * tg_yzzzz_yyyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyyz_0[j] - tg_zzzz_yyyyyyyz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yzzzz_yyyyyyz_1[j];

                    tg_yyzzzz_yyyyyyzz_0[j] = pb_y * tg_yzzzz_yyyyyyzz_0[j] + fr * tg_yzzzz_yyyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyyzz_0[j] - tg_zzzz_yyyyyyzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzz_yyyyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSISL_1164_1260(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1164,1260)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {6, -1, -1, -1},
                                             {8, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_6_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_6_8_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_5_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_4_8_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_4_8_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {4, -1, -1, -1}, {8, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yzzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 894); 

                auto tg_yzzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 895); 

                auto tg_yzzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 896); 

                auto tg_yzzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 897); 

                auto tg_yzzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 898); 

                auto tg_yzzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 899); 

                auto tg_zzzzz_xxxxxxxx_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 900); 

                auto tg_zzzzz_xxxxxxxy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 901); 

                auto tg_zzzzz_xxxxxxxz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 902); 

                auto tg_zzzzz_xxxxxxyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 903); 

                auto tg_zzzzz_xxxxxxyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 904); 

                auto tg_zzzzz_xxxxxxzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 905); 

                auto tg_zzzzz_xxxxxyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 906); 

                auto tg_zzzzz_xxxxxyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 907); 

                auto tg_zzzzz_xxxxxyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 908); 

                auto tg_zzzzz_xxxxxzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 909); 

                auto tg_zzzzz_xxxxyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 910); 

                auto tg_zzzzz_xxxxyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 911); 

                auto tg_zzzzz_xxxxyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 912); 

                auto tg_zzzzz_xxxxyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 913); 

                auto tg_zzzzz_xxxxzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 914); 

                auto tg_zzzzz_xxxyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 915); 

                auto tg_zzzzz_xxxyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 916); 

                auto tg_zzzzz_xxxyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 917); 

                auto tg_zzzzz_xxxyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 918); 

                auto tg_zzzzz_xxxyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 919); 

                auto tg_zzzzz_xxxzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 920); 

                auto tg_zzzzz_xxyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 921); 

                auto tg_zzzzz_xxyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 922); 

                auto tg_zzzzz_xxyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 923); 

                auto tg_zzzzz_xxyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 924); 

                auto tg_zzzzz_xxyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 925); 

                auto tg_zzzzz_xxyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 926); 

                auto tg_zzzzz_xxzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 927); 

                auto tg_zzzzz_xyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 928); 

                auto tg_zzzzz_xyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 929); 

                auto tg_zzzzz_xyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 930); 

                auto tg_zzzzz_xyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 931); 

                auto tg_zzzzz_xyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 932); 

                auto tg_zzzzz_xyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 933); 

                auto tg_zzzzz_xyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 934); 

                auto tg_zzzzz_xzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 935); 

                auto tg_zzzzz_yyyyyyyy_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 936); 

                auto tg_zzzzz_yyyyyyyz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 937); 

                auto tg_zzzzz_yyyyyyzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 938); 

                auto tg_zzzzz_yyyyyzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 939); 

                auto tg_zzzzz_yyyyzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 940); 

                auto tg_zzzzz_yyyzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 941); 

                auto tg_zzzzz_yyzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 942); 

                auto tg_zzzzz_yzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 943); 

                auto tg_zzzzz_zzzzzzzz_0 = primBuffer[pidx_g_5_8_m0].data(945 * idx + 944); 

                auto tg_yzzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 894); 

                auto tg_yzzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 895); 

                auto tg_yzzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 896); 

                auto tg_yzzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 897); 

                auto tg_yzzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 898); 

                auto tg_yzzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 899); 

                auto tg_zzzzz_xxxxxxxx_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 900); 

                auto tg_zzzzz_xxxxxxxy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 901); 

                auto tg_zzzzz_xxxxxxxz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 902); 

                auto tg_zzzzz_xxxxxxyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 903); 

                auto tg_zzzzz_xxxxxxyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 904); 

                auto tg_zzzzz_xxxxxxzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 905); 

                auto tg_zzzzz_xxxxxyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 906); 

                auto tg_zzzzz_xxxxxyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 907); 

                auto tg_zzzzz_xxxxxyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 908); 

                auto tg_zzzzz_xxxxxzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 909); 

                auto tg_zzzzz_xxxxyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 910); 

                auto tg_zzzzz_xxxxyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 911); 

                auto tg_zzzzz_xxxxyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 912); 

                auto tg_zzzzz_xxxxyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 913); 

                auto tg_zzzzz_xxxxzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 914); 

                auto tg_zzzzz_xxxyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 915); 

                auto tg_zzzzz_xxxyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 916); 

                auto tg_zzzzz_xxxyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 917); 

                auto tg_zzzzz_xxxyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 918); 

                auto tg_zzzzz_xxxyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 919); 

                auto tg_zzzzz_xxxzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 920); 

                auto tg_zzzzz_xxyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 921); 

                auto tg_zzzzz_xxyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 922); 

                auto tg_zzzzz_xxyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 923); 

                auto tg_zzzzz_xxyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 924); 

                auto tg_zzzzz_xxyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 925); 

                auto tg_zzzzz_xxyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 926); 

                auto tg_zzzzz_xxzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 927); 

                auto tg_zzzzz_xyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 928); 

                auto tg_zzzzz_xyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 929); 

                auto tg_zzzzz_xyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 930); 

                auto tg_zzzzz_xyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 931); 

                auto tg_zzzzz_xyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 932); 

                auto tg_zzzzz_xyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 933); 

                auto tg_zzzzz_xyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 934); 

                auto tg_zzzzz_xzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 935); 

                auto tg_zzzzz_yyyyyyyy_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 936); 

                auto tg_zzzzz_yyyyyyyz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 937); 

                auto tg_zzzzz_yyyyyyzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 938); 

                auto tg_zzzzz_yyyyyzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 939); 

                auto tg_zzzzz_yyyyzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 940); 

                auto tg_zzzzz_yyyzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 941); 

                auto tg_zzzzz_yyzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 942); 

                auto tg_zzzzz_yzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 943); 

                auto tg_zzzzz_zzzzzzzz_1 = primBuffer[pidx_g_5_8_m1].data(945 * idx + 944); 

                auto tg_zzzz_xxxxxxxx_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 668); 

                auto tg_zzzz_yyyyyzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 669); 

                auto tg_zzzz_yyyyzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 670); 

                auto tg_zzzz_yyyzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 671); 

                auto tg_zzzz_yyzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 672); 

                auto tg_zzzz_yzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 673); 

                auto tg_zzzz_zzzzzzzz_0 = primBuffer[pidx_g_4_8_m0].data(675 * idx + 674); 

                auto tg_zzzz_xxxxxxxx_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 630); 

                auto tg_zzzz_xxxxxxxy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 631); 

                auto tg_zzzz_xxxxxxxz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 632); 

                auto tg_zzzz_xxxxxxyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 633); 

                auto tg_zzzz_xxxxxxyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 634); 

                auto tg_zzzz_xxxxxxzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 635); 

                auto tg_zzzz_xxxxxyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 636); 

                auto tg_zzzz_xxxxxyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 637); 

                auto tg_zzzz_xxxxxyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 638); 

                auto tg_zzzz_xxxxxzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 639); 

                auto tg_zzzz_xxxxyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 640); 

                auto tg_zzzz_xxxxyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 641); 

                auto tg_zzzz_xxxxyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 642); 

                auto tg_zzzz_xxxxyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 643); 

                auto tg_zzzz_xxxxzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 644); 

                auto tg_zzzz_xxxyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 645); 

                auto tg_zzzz_xxxyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 646); 

                auto tg_zzzz_xxxyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 647); 

                auto tg_zzzz_xxxyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 648); 

                auto tg_zzzz_xxxyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 649); 

                auto tg_zzzz_xxxzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 650); 

                auto tg_zzzz_xxyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 651); 

                auto tg_zzzz_xxyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 652); 

                auto tg_zzzz_xxyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 653); 

                auto tg_zzzz_xxyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 654); 

                auto tg_zzzz_xxyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 655); 

                auto tg_zzzz_xxyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 656); 

                auto tg_zzzz_xxzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 657); 

                auto tg_zzzz_xyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 658); 

                auto tg_zzzz_xyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 659); 

                auto tg_zzzz_xyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 660); 

                auto tg_zzzz_xyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 661); 

                auto tg_zzzz_xyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 662); 

                auto tg_zzzz_xyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 663); 

                auto tg_zzzz_xyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 664); 

                auto tg_zzzz_xzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 665); 

                auto tg_zzzz_yyyyyyyy_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 666); 

                auto tg_zzzz_yyyyyyyz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 667); 

                auto tg_zzzz_yyyyyyzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 668); 

                auto tg_zzzz_yyyyyzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 669); 

                auto tg_zzzz_yyyyzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 670); 

                auto tg_zzzz_yyyzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 671); 

                auto tg_zzzz_yyzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 672); 

                auto tg_zzzz_yzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 673); 

                auto tg_zzzz_zzzzzzzz_1 = primBuffer[pidx_g_4_8_m1].data(675 * idx + 674); 

                auto tg_yzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 755); 

                // set up pointers to integrals

                auto tg_yyzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1164); 

                auto tg_yyzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1165); 

                auto tg_yyzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1166); 

                auto tg_yyzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1167); 

                auto tg_yyzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1168); 

                auto tg_yyzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1169); 

                auto tg_yzzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1170); 

                auto tg_yzzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1171); 

                auto tg_yzzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1172); 

                auto tg_yzzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1173); 

                auto tg_yzzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1174); 

                auto tg_yzzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1175); 

                auto tg_yzzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1176); 

                auto tg_yzzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1177); 

                auto tg_yzzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1178); 

                auto tg_yzzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1179); 

                auto tg_yzzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1180); 

                auto tg_yzzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1181); 

                auto tg_yzzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1182); 

                auto tg_yzzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1183); 

                auto tg_yzzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1184); 

                auto tg_yzzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1185); 

                auto tg_yzzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1186); 

                auto tg_yzzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1187); 

                auto tg_yzzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1188); 

                auto tg_yzzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1189); 

                auto tg_yzzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1190); 

                auto tg_yzzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1191); 

                auto tg_yzzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1192); 

                auto tg_yzzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1193); 

                auto tg_yzzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1194); 

                auto tg_yzzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1195); 

                auto tg_yzzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1196); 

                auto tg_yzzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1197); 

                auto tg_yzzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1198); 

                auto tg_yzzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1199); 

                auto tg_yzzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1200); 

                auto tg_yzzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1201); 

                auto tg_yzzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1202); 

                auto tg_yzzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1203); 

                auto tg_yzzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1204); 

                auto tg_yzzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1205); 

                auto tg_yzzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1206); 

                auto tg_yzzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1207); 

                auto tg_yzzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1208); 

                auto tg_yzzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1209); 

                auto tg_yzzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1210); 

                auto tg_yzzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1211); 

                auto tg_yzzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1212); 

                auto tg_yzzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1213); 

                auto tg_yzzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1214); 

                auto tg_zzzzzz_xxxxxxxx_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1215); 

                auto tg_zzzzzz_xxxxxxxy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1216); 

                auto tg_zzzzzz_xxxxxxxz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1217); 

                auto tg_zzzzzz_xxxxxxyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1218); 

                auto tg_zzzzzz_xxxxxxyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1219); 

                auto tg_zzzzzz_xxxxxxzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1220); 

                auto tg_zzzzzz_xxxxxyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1221); 

                auto tg_zzzzzz_xxxxxyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1222); 

                auto tg_zzzzzz_xxxxxyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1223); 

                auto tg_zzzzzz_xxxxxzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1224); 

                auto tg_zzzzzz_xxxxyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1225); 

                auto tg_zzzzzz_xxxxyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1226); 

                auto tg_zzzzzz_xxxxyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1227); 

                auto tg_zzzzzz_xxxxyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1228); 

                auto tg_zzzzzz_xxxxzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1229); 

                auto tg_zzzzzz_xxxyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1230); 

                auto tg_zzzzzz_xxxyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1231); 

                auto tg_zzzzzz_xxxyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1232); 

                auto tg_zzzzzz_xxxyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1233); 

                auto tg_zzzzzz_xxxyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1234); 

                auto tg_zzzzzz_xxxzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1235); 

                auto tg_zzzzzz_xxyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1236); 

                auto tg_zzzzzz_xxyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1237); 

                auto tg_zzzzzz_xxyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1238); 

                auto tg_zzzzzz_xxyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1239); 

                auto tg_zzzzzz_xxyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1240); 

                auto tg_zzzzzz_xxyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1241); 

                auto tg_zzzzzz_xxzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1242); 

                auto tg_zzzzzz_xyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1243); 

                auto tg_zzzzzz_xyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1244); 

                auto tg_zzzzzz_xyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1245); 

                auto tg_zzzzzz_xyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1246); 

                auto tg_zzzzzz_xyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1247); 

                auto tg_zzzzzz_xyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1248); 

                auto tg_zzzzzz_xyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1249); 

                auto tg_zzzzzz_xzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1250); 

                auto tg_zzzzzz_yyyyyyyy_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1251); 

                auto tg_zzzzzz_yyyyyyyz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1252); 

                auto tg_zzzzzz_yyyyyyzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1253); 

                auto tg_zzzzzz_yyyyyzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1254); 

                auto tg_zzzzzz_yyyyzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1255); 

                auto tg_zzzzzz_yyyzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1256); 

                auto tg_zzzzzz_yyzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1257); 

                auto tg_zzzzzz_yzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1258); 

                auto tg_zzzzzz_zzzzzzzz_0 = primBuffer[pidx_g_6_8_m0].data(1260 * idx + 1259); 

                // Batch of Integrals (1164,1260)

                #pragma omp simd aligned(fxn, fza, tg_yyzzzz_yyyyyzzz_0, tg_yyzzzz_yyyyzzzz_0, \
                                         tg_yyzzzz_yyyzzzzz_0, tg_yyzzzz_yyzzzzzz_0, tg_yyzzzz_yzzzzzzz_0, tg_yyzzzz_zzzzzzzz_0, \
                                         tg_yzzzz_yyyyyzzz_0, tg_yzzzz_yyyyyzzz_1, tg_yzzzz_yyyyzzz_1, tg_yzzzz_yyyyzzzz_0, \
                                         tg_yzzzz_yyyyzzzz_1, tg_yzzzz_yyyzzzz_1, tg_yzzzz_yyyzzzzz_0, tg_yzzzz_yyyzzzzz_1, \
                                         tg_yzzzz_yyzzzzz_1, tg_yzzzz_yyzzzzzz_0, tg_yzzzz_yyzzzzzz_1, tg_yzzzz_yzzzzzz_1, \
                                         tg_yzzzz_yzzzzzzz_0, tg_yzzzz_yzzzzzzz_1, tg_yzzzz_zzzzzzz_1, tg_yzzzz_zzzzzzzz_0, \
                                         tg_yzzzz_zzzzzzzz_1, tg_yzzzzz_xxxxxxxx_0, tg_yzzzzz_xxxxxxxy_0, tg_yzzzzz_xxxxxxxz_0, \
                                         tg_yzzzzz_xxxxxxyy_0, tg_yzzzzz_xxxxxxyz_0, tg_yzzzzz_xxxxxxzz_0, tg_yzzzzz_xxxxxyyy_0, \
                                         tg_yzzzzz_xxxxxyyz_0, tg_yzzzzz_xxxxxyzz_0, tg_yzzzzz_xxxxxzzz_0, tg_yzzzzz_xxxxyyyy_0, \
                                         tg_yzzzzz_xxxxyyyz_0, tg_yzzzzz_xxxxyyzz_0, tg_yzzzzz_xxxxyzzz_0, tg_yzzzzz_xxxxzzzz_0, \
                                         tg_yzzzzz_xxxyyyyy_0, tg_yzzzzz_xxxyyyyz_0, tg_yzzzzz_xxxyyyzz_0, tg_yzzzzz_xxxyyzzz_0, \
                                         tg_yzzzzz_xxxyzzzz_0, tg_yzzzzz_xxxzzzzz_0, tg_yzzzzz_xxyyyyyy_0, tg_yzzzzz_xxyyyyyz_0, \
                                         tg_yzzzzz_xxyyyyzz_0, tg_yzzzzz_xxyyyzzz_0, tg_yzzzzz_xxyyzzzz_0, tg_yzzzzz_xxyzzzzz_0, \
                                         tg_yzzzzz_xxzzzzzz_0, tg_yzzzzz_xyyyyyyy_0, tg_yzzzzz_xyyyyyyz_0, tg_yzzzzz_xyyyyyzz_0, \
                                         tg_yzzzzz_xyyyyzzz_0, tg_yzzzzz_xyyyzzzz_0, tg_yzzzzz_xyyzzzzz_0, tg_yzzzzz_xyzzzzzz_0, \
                                         tg_yzzzzz_xzzzzzzz_0, tg_yzzzzz_yyyyyyyy_0, tg_yzzzzz_yyyyyyyz_0, tg_yzzzzz_yyyyyyzz_0, \
                                         tg_yzzzzz_yyyyyzzz_0, tg_yzzzzz_yyyyzzzz_0, tg_yzzzzz_yyyzzzzz_0, tg_yzzzzz_yyzzzzzz_0, \
                                         tg_yzzzzz_yzzzzzzz_0, tg_yzzzzz_zzzzzzzz_0, tg_zzzz_xxxxxxxx_0, tg_zzzz_xxxxxxxx_1, \
                                         tg_zzzz_xxxxxxxy_0, tg_zzzz_xxxxxxxy_1, tg_zzzz_xxxxxxxz_0, tg_zzzz_xxxxxxxz_1, \
                                         tg_zzzz_xxxxxxyy_0, tg_zzzz_xxxxxxyy_1, tg_zzzz_xxxxxxyz_0, tg_zzzz_xxxxxxyz_1, \
                                         tg_zzzz_xxxxxxzz_0, tg_zzzz_xxxxxxzz_1, tg_zzzz_xxxxxyyy_0, tg_zzzz_xxxxxyyy_1, \
                                         tg_zzzz_xxxxxyyz_0, tg_zzzz_xxxxxyyz_1, tg_zzzz_xxxxxyzz_0, tg_zzzz_xxxxxyzz_1, \
                                         tg_zzzz_xxxxxzzz_0, tg_zzzz_xxxxxzzz_1, tg_zzzz_xxxxyyyy_0, tg_zzzz_xxxxyyyy_1, \
                                         tg_zzzz_xxxxyyyz_0, tg_zzzz_xxxxyyyz_1, tg_zzzz_xxxxyyzz_0, tg_zzzz_xxxxyyzz_1, \
                                         tg_zzzz_xxxxyzzz_0, tg_zzzz_xxxxyzzz_1, tg_zzzz_xxxxzzzz_0, tg_zzzz_xxxxzzzz_1, \
                                         tg_zzzz_xxxyyyyy_0, tg_zzzz_xxxyyyyy_1, tg_zzzz_xxxyyyyz_0, tg_zzzz_xxxyyyyz_1, \
                                         tg_zzzz_xxxyyyzz_0, tg_zzzz_xxxyyyzz_1, tg_zzzz_xxxyyzzz_0, tg_zzzz_xxxyyzzz_1, \
                                         tg_zzzz_xxxyzzzz_0, tg_zzzz_xxxyzzzz_1, tg_zzzz_xxxzzzzz_0, tg_zzzz_xxxzzzzz_1, \
                                         tg_zzzz_xxyyyyyy_0, tg_zzzz_xxyyyyyy_1, tg_zzzz_xxyyyyyz_0, tg_zzzz_xxyyyyyz_1, \
                                         tg_zzzz_xxyyyyzz_0, tg_zzzz_xxyyyyzz_1, tg_zzzz_xxyyyzzz_0, tg_zzzz_xxyyyzzz_1, \
                                         tg_zzzz_xxyyzzzz_0, tg_zzzz_xxyyzzzz_1, tg_zzzz_xxyzzzzz_0, tg_zzzz_xxyzzzzz_1, \
                                         tg_zzzz_xxzzzzzz_0, tg_zzzz_xxzzzzzz_1, tg_zzzz_xyyyyyyy_0, tg_zzzz_xyyyyyyy_1, \
                                         tg_zzzz_xyyyyyyz_0, tg_zzzz_xyyyyyyz_1, tg_zzzz_xyyyyyzz_0, tg_zzzz_xyyyyyzz_1, \
                                         tg_zzzz_xyyyyzzz_0, tg_zzzz_xyyyyzzz_1, tg_zzzz_xyyyzzzz_0, tg_zzzz_xyyyzzzz_1, \
                                         tg_zzzz_xyyzzzzz_0, tg_zzzz_xyyzzzzz_1, tg_zzzz_xyzzzzzz_0, tg_zzzz_xyzzzzzz_1, \
                                         tg_zzzz_xzzzzzzz_0, tg_zzzz_xzzzzzzz_1, tg_zzzz_yyyyyyyy_0, tg_zzzz_yyyyyyyy_1, \
                                         tg_zzzz_yyyyyyyz_0, tg_zzzz_yyyyyyyz_1, tg_zzzz_yyyyyyzz_0, tg_zzzz_yyyyyyzz_1, \
                                         tg_zzzz_yyyyyzzz_0, tg_zzzz_yyyyyzzz_1, tg_zzzz_yyyyzzzz_0, tg_zzzz_yyyyzzzz_1, \
                                         tg_zzzz_yyyzzzzz_0, tg_zzzz_yyyzzzzz_1, tg_zzzz_yyzzzzzz_0, tg_zzzz_yyzzzzzz_1, \
                                         tg_zzzz_yzzzzzzz_0, tg_zzzz_yzzzzzzz_1, tg_zzzz_zzzzzzzz_0, tg_zzzz_zzzzzzzz_1, \
                                         tg_zzzzz_xxxxxxx_1, tg_zzzzz_xxxxxxxx_0, tg_zzzzz_xxxxxxxx_1, tg_zzzzz_xxxxxxxy_0, \
                                         tg_zzzzz_xxxxxxxy_1, tg_zzzzz_xxxxxxxz_0, tg_zzzzz_xxxxxxxz_1, tg_zzzzz_xxxxxxy_1, \
                                         tg_zzzzz_xxxxxxyy_0, tg_zzzzz_xxxxxxyy_1, tg_zzzzz_xxxxxxyz_0, tg_zzzzz_xxxxxxyz_1, \
                                         tg_zzzzz_xxxxxxz_1, tg_zzzzz_xxxxxxzz_0, tg_zzzzz_xxxxxxzz_1, tg_zzzzz_xxxxxyy_1, \
                                         tg_zzzzz_xxxxxyyy_0, tg_zzzzz_xxxxxyyy_1, tg_zzzzz_xxxxxyyz_0, tg_zzzzz_xxxxxyyz_1, \
                                         tg_zzzzz_xxxxxyz_1, tg_zzzzz_xxxxxyzz_0, tg_zzzzz_xxxxxyzz_1, tg_zzzzz_xxxxxzz_1, \
                                         tg_zzzzz_xxxxxzzz_0, tg_zzzzz_xxxxxzzz_1, tg_zzzzz_xxxxyyy_1, tg_zzzzz_xxxxyyyy_0, \
                                         tg_zzzzz_xxxxyyyy_1, tg_zzzzz_xxxxyyyz_0, tg_zzzzz_xxxxyyyz_1, tg_zzzzz_xxxxyyz_1, \
                                         tg_zzzzz_xxxxyyzz_0, tg_zzzzz_xxxxyyzz_1, tg_zzzzz_xxxxyzz_1, tg_zzzzz_xxxxyzzz_0, \
                                         tg_zzzzz_xxxxyzzz_1, tg_zzzzz_xxxxzzz_1, tg_zzzzz_xxxxzzzz_0, tg_zzzzz_xxxxzzzz_1, \
                                         tg_zzzzz_xxxyyyy_1, tg_zzzzz_xxxyyyyy_0, tg_zzzzz_xxxyyyyy_1, tg_zzzzz_xxxyyyyz_0, \
                                         tg_zzzzz_xxxyyyyz_1, tg_zzzzz_xxxyyyz_1, tg_zzzzz_xxxyyyzz_0, tg_zzzzz_xxxyyyzz_1, \
                                         tg_zzzzz_xxxyyzz_1, tg_zzzzz_xxxyyzzz_0, tg_zzzzz_xxxyyzzz_1, tg_zzzzz_xxxyzzz_1, \
                                         tg_zzzzz_xxxyzzzz_0, tg_zzzzz_xxxyzzzz_1, tg_zzzzz_xxxzzzz_1, tg_zzzzz_xxxzzzzz_0, \
                                         tg_zzzzz_xxxzzzzz_1, tg_zzzzz_xxyyyyy_1, tg_zzzzz_xxyyyyyy_0, tg_zzzzz_xxyyyyyy_1, \
                                         tg_zzzzz_xxyyyyyz_0, tg_zzzzz_xxyyyyyz_1, tg_zzzzz_xxyyyyz_1, tg_zzzzz_xxyyyyzz_0, \
                                         tg_zzzzz_xxyyyyzz_1, tg_zzzzz_xxyyyzz_1, tg_zzzzz_xxyyyzzz_0, tg_zzzzz_xxyyyzzz_1, \
                                         tg_zzzzz_xxyyzzz_1, tg_zzzzz_xxyyzzzz_0, tg_zzzzz_xxyyzzzz_1, tg_zzzzz_xxyzzzz_1, \
                                         tg_zzzzz_xxyzzzzz_0, tg_zzzzz_xxyzzzzz_1, tg_zzzzz_xxzzzzz_1, tg_zzzzz_xxzzzzzz_0, \
                                         tg_zzzzz_xxzzzzzz_1, tg_zzzzz_xyyyyyy_1, tg_zzzzz_xyyyyyyy_0, tg_zzzzz_xyyyyyyy_1, \
                                         tg_zzzzz_xyyyyyyz_0, tg_zzzzz_xyyyyyyz_1, tg_zzzzz_xyyyyyz_1, tg_zzzzz_xyyyyyzz_0, \
                                         tg_zzzzz_xyyyyyzz_1, tg_zzzzz_xyyyyzz_1, tg_zzzzz_xyyyyzzz_0, tg_zzzzz_xyyyyzzz_1, \
                                         tg_zzzzz_xyyyzzz_1, tg_zzzzz_xyyyzzzz_0, tg_zzzzz_xyyyzzzz_1, tg_zzzzz_xyyzzzz_1, \
                                         tg_zzzzz_xyyzzzzz_0, tg_zzzzz_xyyzzzzz_1, tg_zzzzz_xyzzzzz_1, tg_zzzzz_xyzzzzzz_0, \
                                         tg_zzzzz_xyzzzzzz_1, tg_zzzzz_xzzzzzz_1, tg_zzzzz_xzzzzzzz_0, tg_zzzzz_xzzzzzzz_1, \
                                         tg_zzzzz_yyyyyyy_1, tg_zzzzz_yyyyyyyy_0, tg_zzzzz_yyyyyyyy_1, tg_zzzzz_yyyyyyyz_0, \
                                         tg_zzzzz_yyyyyyyz_1, tg_zzzzz_yyyyyyz_1, tg_zzzzz_yyyyyyzz_0, tg_zzzzz_yyyyyyzz_1, \
                                         tg_zzzzz_yyyyyzz_1, tg_zzzzz_yyyyyzzz_0, tg_zzzzz_yyyyyzzz_1, tg_zzzzz_yyyyzzz_1, \
                                         tg_zzzzz_yyyyzzzz_0, tg_zzzzz_yyyyzzzz_1, tg_zzzzz_yyyzzzz_1, tg_zzzzz_yyyzzzzz_0, \
                                         tg_zzzzz_yyyzzzzz_1, tg_zzzzz_yyzzzzz_1, tg_zzzzz_yyzzzzzz_0, tg_zzzzz_yyzzzzzz_1, \
                                         tg_zzzzz_yzzzzzz_1, tg_zzzzz_yzzzzzzz_0, tg_zzzzz_yzzzzzzz_1, tg_zzzzz_zzzzzzz_1, \
                                         tg_zzzzz_zzzzzzzz_0, tg_zzzzz_zzzzzzzz_1, tg_zzzzzz_xxxxxxxx_0, tg_zzzzzz_xxxxxxxy_0, \
                                         tg_zzzzzz_xxxxxxxz_0, tg_zzzzzz_xxxxxxyy_0, tg_zzzzzz_xxxxxxyz_0, tg_zzzzzz_xxxxxxzz_0, \
                                         tg_zzzzzz_xxxxxyyy_0, tg_zzzzzz_xxxxxyyz_0, tg_zzzzzz_xxxxxyzz_0, tg_zzzzzz_xxxxxzzz_0, \
                                         tg_zzzzzz_xxxxyyyy_0, tg_zzzzzz_xxxxyyyz_0, tg_zzzzzz_xxxxyyzz_0, tg_zzzzzz_xxxxyzzz_0, \
                                         tg_zzzzzz_xxxxzzzz_0, tg_zzzzzz_xxxyyyyy_0, tg_zzzzzz_xxxyyyyz_0, tg_zzzzzz_xxxyyyzz_0, \
                                         tg_zzzzzz_xxxyyzzz_0, tg_zzzzzz_xxxyzzzz_0, tg_zzzzzz_xxxzzzzz_0, tg_zzzzzz_xxyyyyyy_0, \
                                         tg_zzzzzz_xxyyyyyz_0, tg_zzzzzz_xxyyyyzz_0, tg_zzzzzz_xxyyyzzz_0, tg_zzzzzz_xxyyzzzz_0, \
                                         tg_zzzzzz_xxyzzzzz_0, tg_zzzzzz_xxzzzzzz_0, tg_zzzzzz_xyyyyyyy_0, tg_zzzzzz_xyyyyyyz_0, \
                                         tg_zzzzzz_xyyyyyzz_0, tg_zzzzzz_xyyyyzzz_0, tg_zzzzzz_xyyyzzzz_0, tg_zzzzzz_xyyzzzzz_0, \
                                         tg_zzzzzz_xyzzzzzz_0, tg_zzzzzz_xzzzzzzz_0, tg_zzzzzz_yyyyyyyy_0, tg_zzzzzz_yyyyyyyz_0, \
                                         tg_zzzzzz_yyyyyyzz_0, tg_zzzzzz_yyyyyzzz_0, tg_zzzzzz_yyyyzzzz_0, tg_zzzzzz_yyyzzzzz_0, \
                                         tg_zzzzzz_yyzzzzzz_0, tg_zzzzzz_yzzzzzzz_0, tg_zzzzzz_zzzzzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyzzzz_yyyyyzzz_0[j] = pb_y * tg_yzzzz_yyyyyzzz_0[j] + fr * tg_yzzzz_yyyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyyzzz_0[j] - tg_zzzz_yyyyyzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzz_yyyyzzz_1[j];

                    tg_yyzzzz_yyyyzzzz_0[j] = pb_y * tg_yzzzz_yyyyzzzz_0[j] + fr * tg_yzzzz_yyyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyyzzzz_0[j] - tg_zzzz_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzz_yyyzzzz_1[j];

                    tg_yyzzzz_yyyzzzzz_0[j] = pb_y * tg_yzzzz_yyyzzzzz_0[j] + fr * tg_yzzzz_yyyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyyzzzzz_0[j] - tg_zzzz_yyyzzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzz_yyzzzzz_1[j];

                    tg_yyzzzz_yyzzzzzz_0[j] = pb_y * tg_yzzzz_yyzzzzzz_0[j] + fr * tg_yzzzz_yyzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yyzzzzzz_0[j] - tg_zzzz_yyzzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzz_yzzzzzz_1[j];

                    tg_yyzzzz_yzzzzzzz_0[j] = pb_y * tg_yzzzz_yzzzzzzz_0[j] + fr * tg_yzzzz_yzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_yzzzzzzz_0[j] - tg_zzzz_yzzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzz_zzzzzzz_1[j];

                    tg_yyzzzz_zzzzzzzz_0[j] = pb_y * tg_yzzzz_zzzzzzzz_0[j] + fr * tg_yzzzz_zzzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzz_zzzzzzzz_0[j] - tg_zzzz_zzzzzzzz_1[j] * fl1_fza);

                    tg_yzzzzz_xxxxxxxx_0[j] = pb_y * tg_zzzzz_xxxxxxxx_0[j] + fr * tg_zzzzz_xxxxxxxx_1[j];

                    tg_yzzzzz_xxxxxxxy_0[j] = pb_y * tg_zzzzz_xxxxxxxy_0[j] + fr * tg_zzzzz_xxxxxxxy_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxxxxxx_1[j];

                    tg_yzzzzz_xxxxxxxz_0[j] = pb_y * tg_zzzzz_xxxxxxxz_0[j] + fr * tg_zzzzz_xxxxxxxz_1[j];

                    tg_yzzzzz_xxxxxxyy_0[j] = pb_y * tg_zzzzz_xxxxxxyy_0[j] + fr * tg_zzzzz_xxxxxxyy_1[j] + fl1_fxn * tg_zzzzz_xxxxxxy_1[j];

                    tg_yzzzzz_xxxxxxyz_0[j] = pb_y * tg_zzzzz_xxxxxxyz_0[j] + fr * tg_zzzzz_xxxxxxyz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxxxxxz_1[j];

                    tg_yzzzzz_xxxxxxzz_0[j] = pb_y * tg_zzzzz_xxxxxxzz_0[j] + fr * tg_zzzzz_xxxxxxzz_1[j];

                    tg_yzzzzz_xxxxxyyy_0[j] = pb_y * tg_zzzzz_xxxxxyyy_0[j] + fr * tg_zzzzz_xxxxxyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxxxxyy_1[j];

                    tg_yzzzzz_xxxxxyyz_0[j] = pb_y * tg_zzzzz_xxxxxyyz_0[j] + fr * tg_zzzzz_xxxxxyyz_1[j] + fl1_fxn * tg_zzzzz_xxxxxyz_1[j];

                    tg_yzzzzz_xxxxxyzz_0[j] = pb_y * tg_zzzzz_xxxxxyzz_0[j] + fr * tg_zzzzz_xxxxxyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxxxxzz_1[j];

                    tg_yzzzzz_xxxxxzzz_0[j] = pb_y * tg_zzzzz_xxxxxzzz_0[j] + fr * tg_zzzzz_xxxxxzzz_1[j];

                    tg_yzzzzz_xxxxyyyy_0[j] = pb_y * tg_zzzzz_xxxxyyyy_0[j] + fr * tg_zzzzz_xxxxyyyy_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxxyyy_1[j];

                    tg_yzzzzz_xxxxyyyz_0[j] = pb_y * tg_zzzzz_xxxxyyyz_0[j] + fr * tg_zzzzz_xxxxyyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxxxyyz_1[j];

                    tg_yzzzzz_xxxxyyzz_0[j] = pb_y * tg_zzzzz_xxxxyyzz_0[j] + fr * tg_zzzzz_xxxxyyzz_1[j] + fl1_fxn * tg_zzzzz_xxxxyzz_1[j];

                    tg_yzzzzz_xxxxyzzz_0[j] = pb_y * tg_zzzzz_xxxxyzzz_0[j] + fr * tg_zzzzz_xxxxyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxxxzzz_1[j];

                    tg_yzzzzz_xxxxzzzz_0[j] = pb_y * tg_zzzzz_xxxxzzzz_0[j] + fr * tg_zzzzz_xxxxzzzz_1[j];

                    tg_yzzzzz_xxxyyyyy_0[j] = pb_y * tg_zzzzz_xxxyyyyy_0[j] + fr * tg_zzzzz_xxxyyyyy_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxxyyyy_1[j];

                    tg_yzzzzz_xxxyyyyz_0[j] = pb_y * tg_zzzzz_xxxyyyyz_0[j] + fr * tg_zzzzz_xxxyyyyz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxxyyyz_1[j];

                    tg_yzzzzz_xxxyyyzz_0[j] = pb_y * tg_zzzzz_xxxyyyzz_0[j] + fr * tg_zzzzz_xxxyyyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxxyyzz_1[j];

                    tg_yzzzzz_xxxyyzzz_0[j] = pb_y * tg_zzzzz_xxxyyzzz_0[j] + fr * tg_zzzzz_xxxyyzzz_1[j] + fl1_fxn * tg_zzzzz_xxxyzzz_1[j];

                    tg_yzzzzz_xxxyzzzz_0[j] = pb_y * tg_zzzzz_xxxyzzzz_0[j] + fr * tg_zzzzz_xxxyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxxzzzz_1[j];

                    tg_yzzzzz_xxxzzzzz_0[j] = pb_y * tg_zzzzz_xxxzzzzz_0[j] + fr * tg_zzzzz_xxxzzzzz_1[j];

                    tg_yzzzzz_xxyyyyyy_0[j] = pb_y * tg_zzzzz_xxyyyyyy_0[j] + fr * tg_zzzzz_xxyyyyyy_1[j] + 3.0 * fl1_fxn * tg_zzzzz_xxyyyyy_1[j];

                    tg_yzzzzz_xxyyyyyz_0[j] = pb_y * tg_zzzzz_xxyyyyyz_0[j] + fr * tg_zzzzz_xxyyyyyz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xxyyyyz_1[j];

                    tg_yzzzzz_xxyyyyzz_0[j] = pb_y * tg_zzzzz_xxyyyyzz_0[j] + fr * tg_zzzzz_xxyyyyzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xxyyyzz_1[j];

                    tg_yzzzzz_xxyyyzzz_0[j] = pb_y * tg_zzzzz_xxyyyzzz_0[j] + fr * tg_zzzzz_xxyyyzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xxyyzzz_1[j];

                    tg_yzzzzz_xxyyzzzz_0[j] = pb_y * tg_zzzzz_xxyyzzzz_0[j] + fr * tg_zzzzz_xxyyzzzz_1[j] + fl1_fxn * tg_zzzzz_xxyzzzz_1[j];

                    tg_yzzzzz_xxyzzzzz_0[j] = pb_y * tg_zzzzz_xxyzzzzz_0[j] + fr * tg_zzzzz_xxyzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xxzzzzz_1[j];

                    tg_yzzzzz_xxzzzzzz_0[j] = pb_y * tg_zzzzz_xxzzzzzz_0[j] + fr * tg_zzzzz_xxzzzzzz_1[j];

                    tg_yzzzzz_xyyyyyyy_0[j] = pb_y * tg_zzzzz_xyyyyyyy_0[j] + fr * tg_zzzzz_xyyyyyyy_1[j] + 3.5 * fl1_fxn * tg_zzzzz_xyyyyyy_1[j];

                    tg_yzzzzz_xyyyyyyz_0[j] = pb_y * tg_zzzzz_xyyyyyyz_0[j] + fr * tg_zzzzz_xyyyyyyz_1[j] + 3.0 * fl1_fxn * tg_zzzzz_xyyyyyz_1[j];

                    tg_yzzzzz_xyyyyyzz_0[j] = pb_y * tg_zzzzz_xyyyyyzz_0[j] + fr * tg_zzzzz_xyyyyyzz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_xyyyyzz_1[j];

                    tg_yzzzzz_xyyyyzzz_0[j] = pb_y * tg_zzzzz_xyyyyzzz_0[j] + fr * tg_zzzzz_xyyyyzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_xyyyzzz_1[j];

                    tg_yzzzzz_xyyyzzzz_0[j] = pb_y * tg_zzzzz_xyyyzzzz_0[j] + fr * tg_zzzzz_xyyyzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_xyyzzzz_1[j];

                    tg_yzzzzz_xyyzzzzz_0[j] = pb_y * tg_zzzzz_xyyzzzzz_0[j] + fr * tg_zzzzz_xyyzzzzz_1[j] + fl1_fxn * tg_zzzzz_xyzzzzz_1[j];

                    tg_yzzzzz_xyzzzzzz_0[j] = pb_y * tg_zzzzz_xyzzzzzz_0[j] + fr * tg_zzzzz_xyzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_xzzzzzz_1[j];

                    tg_yzzzzz_xzzzzzzz_0[j] = pb_y * tg_zzzzz_xzzzzzzz_0[j] + fr * tg_zzzzz_xzzzzzzz_1[j];

                    tg_yzzzzz_yyyyyyyy_0[j] = pb_y * tg_zzzzz_yyyyyyyy_0[j] + fr * tg_zzzzz_yyyyyyyy_1[j] + 4.0 * fl1_fxn * tg_zzzzz_yyyyyyy_1[j];

                    tg_yzzzzz_yyyyyyyz_0[j] = pb_y * tg_zzzzz_yyyyyyyz_0[j] + fr * tg_zzzzz_yyyyyyyz_1[j] + 3.5 * fl1_fxn * tg_zzzzz_yyyyyyz_1[j];

                    tg_yzzzzz_yyyyyyzz_0[j] = pb_y * tg_zzzzz_yyyyyyzz_0[j] + fr * tg_zzzzz_yyyyyyzz_1[j] + 3.0 * fl1_fxn * tg_zzzzz_yyyyyzz_1[j];

                    tg_yzzzzz_yyyyyzzz_0[j] = pb_y * tg_zzzzz_yyyyyzzz_0[j] + fr * tg_zzzzz_yyyyyzzz_1[j] + 2.5 * fl1_fxn * tg_zzzzz_yyyyzzz_1[j];

                    tg_yzzzzz_yyyyzzzz_0[j] = pb_y * tg_zzzzz_yyyyzzzz_0[j] + fr * tg_zzzzz_yyyyzzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzz_yyyzzzz_1[j];

                    tg_yzzzzz_yyyzzzzz_0[j] = pb_y * tg_zzzzz_yyyzzzzz_0[j] + fr * tg_zzzzz_yyyzzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzz_yyzzzzz_1[j];

                    tg_yzzzzz_yyzzzzzz_0[j] = pb_y * tg_zzzzz_yyzzzzzz_0[j] + fr * tg_zzzzz_yyzzzzzz_1[j] + fl1_fxn * tg_zzzzz_yzzzzzz_1[j];

                    tg_yzzzzz_yzzzzzzz_0[j] = pb_y * tg_zzzzz_yzzzzzzz_0[j] + fr * tg_zzzzz_yzzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzz_zzzzzzz_1[j];

                    tg_yzzzzz_zzzzzzzz_0[j] = pb_y * tg_zzzzz_zzzzzzzz_0[j] + fr * tg_zzzzz_zzzzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzz_xxxxxxxx_0[j] = pb_z * tg_zzzzz_xxxxxxxx_0[j] + fr * tg_zzzzz_xxxxxxxx_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxxx_0[j] - tg_zzzz_xxxxxxxx_1[j] * fl1_fza);

                    tg_zzzzzz_xxxxxxxy_0[j] = pb_z * tg_zzzzz_xxxxxxxy_0[j] + fr * tg_zzzzz_xxxxxxxy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxxy_0[j] - tg_zzzz_xxxxxxxy_1[j] * fl1_fza);

                    tg_zzzzzz_xxxxxxxz_0[j] = pb_z * tg_zzzzz_xxxxxxxz_0[j] + fr * tg_zzzzz_xxxxxxxz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxxz_0[j] - tg_zzzz_xxxxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxxxxxx_1[j];

                    tg_zzzzzz_xxxxxxyy_0[j] = pb_z * tg_zzzzz_xxxxxxyy_0[j] + fr * tg_zzzzz_xxxxxxyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxyy_0[j] - tg_zzzz_xxxxxxyy_1[j] * fl1_fza);

                    tg_zzzzzz_xxxxxxyz_0[j] = pb_z * tg_zzzzz_xxxxxxyz_0[j] + fr * tg_zzzzz_xxxxxxyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxyz_0[j] - tg_zzzz_xxxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxxxxxy_1[j];

                    tg_zzzzzz_xxxxxxzz_0[j] = pb_z * tg_zzzzz_xxxxxxzz_0[j] + fr * tg_zzzzz_xxxxxxzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxxzz_0[j] - tg_zzzz_xxxxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xxxxxxz_1[j];

                    tg_zzzzzz_xxxxxyyy_0[j] = pb_z * tg_zzzzz_xxxxxyyy_0[j] + fr * tg_zzzzz_xxxxxyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxyyy_0[j] - tg_zzzz_xxxxxyyy_1[j] * fl1_fza);

                    tg_zzzzzz_xxxxxyyz_0[j] = pb_z * tg_zzzzz_xxxxxyyz_0[j] + fr * tg_zzzzz_xxxxxyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxyyz_0[j] - tg_zzzz_xxxxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxxxxyy_1[j];

                    tg_zzzzzz_xxxxxyzz_0[j] = pb_z * tg_zzzzz_xxxxxyzz_0[j] + fr * tg_zzzzz_xxxxxyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxyzz_0[j] - tg_zzzz_xxxxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xxxxxyz_1[j];

                    tg_zzzzzz_xxxxxzzz_0[j] = pb_z * tg_zzzzz_xxxxxzzz_0[j] + fr * tg_zzzzz_xxxxxzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxxzzz_0[j] - tg_zzzz_xxxxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_xxxxxzz_1[j];

                    tg_zzzzzz_xxxxyyyy_0[j] = pb_z * tg_zzzzz_xxxxyyyy_0[j] + fr * tg_zzzzz_xxxxyyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxyyyy_0[j] - tg_zzzz_xxxxyyyy_1[j] * fl1_fza);

                    tg_zzzzzz_xxxxyyyz_0[j] = pb_z * tg_zzzzz_xxxxyyyz_0[j] + fr * tg_zzzzz_xxxxyyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxyyyz_0[j] - tg_zzzz_xxxxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxxxyyy_1[j];

                    tg_zzzzzz_xxxxyyzz_0[j] = pb_z * tg_zzzzz_xxxxyyzz_0[j] + fr * tg_zzzzz_xxxxyyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxyyzz_0[j] - tg_zzzz_xxxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xxxxyyz_1[j];

                    tg_zzzzzz_xxxxyzzz_0[j] = pb_z * tg_zzzzz_xxxxyzzz_0[j] + fr * tg_zzzzz_xxxxyzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxyzzz_0[j] - tg_zzzz_xxxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_xxxxyzz_1[j];

                    tg_zzzzzz_xxxxzzzz_0[j] = pb_z * tg_zzzzz_xxxxzzzz_0[j] + fr * tg_zzzzz_xxxxzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxxzzzz_0[j] - tg_zzzz_xxxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzz_xxxxzzz_1[j];

                    tg_zzzzzz_xxxyyyyy_0[j] = pb_z * tg_zzzzz_xxxyyyyy_0[j] + fr * tg_zzzzz_xxxyyyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxyyyyy_0[j] - tg_zzzz_xxxyyyyy_1[j] * fl1_fza);

                    tg_zzzzzz_xxxyyyyz_0[j] = pb_z * tg_zzzzz_xxxyyyyz_0[j] + fr * tg_zzzzz_xxxyyyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxyyyyz_0[j] - tg_zzzz_xxxyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxxyyyy_1[j];

                    tg_zzzzzz_xxxyyyzz_0[j] = pb_z * tg_zzzzz_xxxyyyzz_0[j] + fr * tg_zzzzz_xxxyyyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxyyyzz_0[j] - tg_zzzz_xxxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xxxyyyz_1[j];

                    tg_zzzzzz_xxxyyzzz_0[j] = pb_z * tg_zzzzz_xxxyyzzz_0[j] + fr * tg_zzzzz_xxxyyzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxyyzzz_0[j] - tg_zzzz_xxxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_xxxyyzz_1[j];

                    tg_zzzzzz_xxxyzzzz_0[j] = pb_z * tg_zzzzz_xxxyzzzz_0[j] + fr * tg_zzzzz_xxxyzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxyzzzz_0[j] - tg_zzzz_xxxyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzz_xxxyzzz_1[j];

                    tg_zzzzzz_xxxzzzzz_0[j] = pb_z * tg_zzzzz_xxxzzzzz_0[j] + fr * tg_zzzzz_xxxzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxxzzzzz_0[j] - tg_zzzz_xxxzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzz_xxxzzzz_1[j];

                    tg_zzzzzz_xxyyyyyy_0[j] = pb_z * tg_zzzzz_xxyyyyyy_0[j] + fr * tg_zzzzz_xxyyyyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyyyyyy_0[j] - tg_zzzz_xxyyyyyy_1[j] * fl1_fza);

                    tg_zzzzzz_xxyyyyyz_0[j] = pb_z * tg_zzzzz_xxyyyyyz_0[j] + fr * tg_zzzzz_xxyyyyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyyyyyz_0[j] - tg_zzzz_xxyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xxyyyyy_1[j];

                    tg_zzzzzz_xxyyyyzz_0[j] = pb_z * tg_zzzzz_xxyyyyzz_0[j] + fr * tg_zzzzz_xxyyyyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyyyyzz_0[j] - tg_zzzz_xxyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xxyyyyz_1[j];

                    tg_zzzzzz_xxyyyzzz_0[j] = pb_z * tg_zzzzz_xxyyyzzz_0[j] + fr * tg_zzzzz_xxyyyzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyyyzzz_0[j] - tg_zzzz_xxyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_xxyyyzz_1[j];

                    tg_zzzzzz_xxyyzzzz_0[j] = pb_z * tg_zzzzz_xxyyzzzz_0[j] + fr * tg_zzzzz_xxyyzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyyzzzz_0[j] - tg_zzzz_xxyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzz_xxyyzzz_1[j];

                    tg_zzzzzz_xxyzzzzz_0[j] = pb_z * tg_zzzzz_xxyzzzzz_0[j] + fr * tg_zzzzz_xxyzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxyzzzzz_0[j] - tg_zzzz_xxyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzz_xxyzzzz_1[j];

                    tg_zzzzzz_xxzzzzzz_0[j] = pb_z * tg_zzzzz_xxzzzzzz_0[j] + fr * tg_zzzzz_xxzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xxzzzzzz_0[j] - tg_zzzz_xxzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzz_xxzzzzz_1[j];

                    tg_zzzzzz_xyyyyyyy_0[j] = pb_z * tg_zzzzz_xyyyyyyy_0[j] + fr * tg_zzzzz_xyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyyyyyy_0[j] - tg_zzzz_xyyyyyyy_1[j] * fl1_fza);

                    tg_zzzzzz_xyyyyyyz_0[j] = pb_z * tg_zzzzz_xyyyyyyz_0[j] + fr * tg_zzzzz_xyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyyyyyz_0[j] - tg_zzzz_xyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_xyyyyyy_1[j];

                    tg_zzzzzz_xyyyyyzz_0[j] = pb_z * tg_zzzzz_xyyyyyzz_0[j] + fr * tg_zzzzz_xyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyyyyzz_0[j] - tg_zzzz_xyyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_xyyyyyz_1[j];

                    tg_zzzzzz_xyyyyzzz_0[j] = pb_z * tg_zzzzz_xyyyyzzz_0[j] + fr * tg_zzzzz_xyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyyyzzz_0[j] - tg_zzzz_xyyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_xyyyyzz_1[j];

                    tg_zzzzzz_xyyyzzzz_0[j] = pb_z * tg_zzzzz_xyyyzzzz_0[j] + fr * tg_zzzzz_xyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyyzzzz_0[j] - tg_zzzz_xyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzz_xyyyzzz_1[j];

                    tg_zzzzzz_xyyzzzzz_0[j] = pb_z * tg_zzzzz_xyyzzzzz_0[j] + fr * tg_zzzzz_xyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyyzzzzz_0[j] - tg_zzzz_xyyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzz_xyyzzzz_1[j];

                    tg_zzzzzz_xyzzzzzz_0[j] = pb_z * tg_zzzzz_xyzzzzzz_0[j] + fr * tg_zzzzz_xyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xyzzzzzz_0[j] - tg_zzzz_xyzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzz_xyzzzzz_1[j];

                    tg_zzzzzz_xzzzzzzz_0[j] = pb_z * tg_zzzzz_xzzzzzzz_0[j] + fr * tg_zzzzz_xzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_xzzzzzzz_0[j] - tg_zzzz_xzzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_zzzzz_xzzzzzz_1[j];

                    tg_zzzzzz_yyyyyyyy_0[j] = pb_z * tg_zzzzz_yyyyyyyy_0[j] + fr * tg_zzzzz_yyyyyyyy_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyyyyyy_0[j] - tg_zzzz_yyyyyyyy_1[j] * fl1_fza);

                    tg_zzzzzz_yyyyyyyz_0[j] = pb_z * tg_zzzzz_yyyyyyyz_0[j] + fr * tg_zzzzz_yyyyyyyz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyyyyyz_0[j] - tg_zzzz_yyyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzz_yyyyyyy_1[j];

                    tg_zzzzzz_yyyyyyzz_0[j] = pb_z * tg_zzzzz_yyyyyyzz_0[j] + fr * tg_zzzzz_yyyyyyzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyyyyzz_0[j] - tg_zzzz_yyyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzz_yyyyyyz_1[j];

                    tg_zzzzzz_yyyyyzzz_0[j] = pb_z * tg_zzzzz_yyyyyzzz_0[j] + fr * tg_zzzzz_yyyyyzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyyyzzz_0[j] - tg_zzzz_yyyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzz_yyyyyzz_1[j];

                    tg_zzzzzz_yyyyzzzz_0[j] = pb_z * tg_zzzzz_yyyyzzzz_0[j] + fr * tg_zzzzz_yyyyzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyyzzzz_0[j] - tg_zzzz_yyyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzz_yyyyzzz_1[j];

                    tg_zzzzzz_yyyzzzzz_0[j] = pb_z * tg_zzzzz_yyyzzzzz_0[j] + fr * tg_zzzzz_yyyzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyyzzzzz_0[j] - tg_zzzz_yyyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzz_yyyzzzz_1[j];

                    tg_zzzzzz_yyzzzzzz_0[j] = pb_z * tg_zzzzz_yyzzzzzz_0[j] + fr * tg_zzzzz_yyzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yyzzzzzz_0[j] - tg_zzzz_yyzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzz_yyzzzzz_1[j];

                    tg_zzzzzz_yzzzzzzz_0[j] = pb_z * tg_zzzzz_yzzzzzzz_0[j] + fr * tg_zzzzz_yzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_yzzzzzzz_0[j] - tg_zzzz_yzzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_zzzzz_yzzzzzz_1[j];

                    tg_zzzzzz_zzzzzzzz_0[j] = pb_z * tg_zzzzz_zzzzzzzz_0[j] + fr * tg_zzzzz_zzzzzzzz_1[j] + 2.5 * fl1_fx * (tg_zzzz_zzzzzzzz_0[j] - tg_zzzz_zzzzzzzz_1[j] * fl1_fza) + 4.0 * fl1_fxn * tg_zzzzz_zzzzzzz_1[j];
                }

                idx++;
            }
        }
    }


} // erirecfunc namespace

