//
//                           VELOXCHEM 1.0-RC
//      ---------------------------------------------------
//                     An Electronic Structure Code
//
//  Copyright © 2018-2020 by VeloxChem developers. All rights reserved.
//  Contact: https://veloxchem.org/contact

#include "ElectronRepulsionRecFuncForKK.hpp"

namespace erirecfunc { // erirecfunc namespace

    void
    compElectronRepulsionForSKSK(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSKSK_0_100(primBuffer,
                                                       recursionMap,
                                                       osFactors,
                                                       wpDistances, 
                                                       braGtoPairsBlock,
                                                       ketGtoPairsBlock,
                                                       nKetPrimPairs,
                                                       iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_100_200(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_200_300(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_300_400(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_400_500(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_500_600(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_600_700(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_700_800(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_800_900(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_900_999(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_999_1098(primBuffer,
                                                          recursionMap,
                                                          osFactors,
                                                          wpDistances, 
                                                          braGtoPairsBlock,
                                                          ketGtoPairsBlock,
                                                          nKetPrimPairs,
                                                          iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_1098_1197(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 

        erirecfunc::compElectronRepulsionForSKSK_1197_1296(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 
    }

    void
    compElectronRepulsionForSKSK_0_100(      CMemBlock2D<double>* primBuffer,
                                       const CRecursionMap&       recursionMap,
                                       const CMemBlock2D<double>& osFactors,
                                       const CMemBlock2D<double>& wpDistances,
                                       const CGtoPairsBlock&      braGtoPairsBlock,
                                       const CGtoPairsBlock&      ketGtoPairsBlock,
                                       const int32_t              nKetPrimPairs,
                                       const int32_t              iContrPair)
    {
        // Batch of Integrals (0,100)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxx_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx); 

                auto tg_xxxxxx_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1); 

                auto tg_xxxxxx_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 2); 

                auto tg_xxxxxx_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 3); 

                auto tg_xxxxxx_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 4); 

                auto tg_xxxxxx_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 5); 

                auto tg_xxxxxx_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 6); 

                auto tg_xxxxxx_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 7); 

                auto tg_xxxxxx_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 8); 

                auto tg_xxxxxx_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 9); 

                auto tg_xxxxxx_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 10); 

                auto tg_xxxxxx_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 11); 

                auto tg_xxxxxx_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 12); 

                auto tg_xxxxxx_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 13); 

                auto tg_xxxxxx_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 14); 

                auto tg_xxxxxx_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 15); 

                auto tg_xxxxxx_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 16); 

                auto tg_xxxxxx_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 17); 

                auto tg_xxxxxx_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 18); 

                auto tg_xxxxxx_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 19); 

                auto tg_xxxxxx_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 20); 

                auto tg_xxxxxx_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 21); 

                auto tg_xxxxxx_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 22); 

                auto tg_xxxxxx_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 23); 

                auto tg_xxxxxx_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 24); 

                auto tg_xxxxxx_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 25); 

                auto tg_xxxxxx_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 26); 

                auto tg_xxxxxx_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 27); 

                auto tg_xxxxxx_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 28); 

                auto tg_xxxxxx_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 29); 

                auto tg_xxxxxx_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 30); 

                auto tg_xxxxxx_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 31); 

                auto tg_xxxxxx_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 32); 

                auto tg_xxxxxx_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 33); 

                auto tg_xxxxxx_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 34); 

                auto tg_xxxxxx_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 35); 

                auto tg_xxxxxy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 36); 

                auto tg_xxxxxy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 37); 

                auto tg_xxxxxy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 38); 

                auto tg_xxxxxy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 39); 

                auto tg_xxxxxy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 40); 

                auto tg_xxxxxy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 41); 

                auto tg_xxxxxy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 42); 

                auto tg_xxxxxy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 43); 

                auto tg_xxxxxy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 44); 

                auto tg_xxxxxy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 45); 

                auto tg_xxxxxy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 46); 

                auto tg_xxxxxy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 47); 

                auto tg_xxxxxy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 48); 

                auto tg_xxxxxy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 49); 

                auto tg_xxxxxy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 50); 

                auto tg_xxxxxy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 51); 

                auto tg_xxxxxy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 52); 

                auto tg_xxxxxy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 53); 

                auto tg_xxxxxy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 54); 

                auto tg_xxxxxy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 55); 

                auto tg_xxxxxy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 56); 

                auto tg_xxxxxy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 57); 

                auto tg_xxxxxy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 58); 

                auto tg_xxxxxy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 59); 

                auto tg_xxxxxy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 60); 

                auto tg_xxxxxy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 61); 

                auto tg_xxxxxy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 62); 

                auto tg_xxxxxy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 63); 

                auto tg_xxxxxy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 64); 

                auto tg_xxxxxy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 65); 

                auto tg_xxxxxy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 66); 

                auto tg_xxxxxy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 67); 

                auto tg_xxxxxy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 68); 

                auto tg_xxxxxy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 69); 

                auto tg_xxxxxy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 70); 

                auto tg_xxxxxy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 71); 

                auto tg_xxxxxz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 72); 

                auto tg_xxxxxz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 73); 

                auto tg_xxxxxz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 74); 

                auto tg_xxxxxz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 75); 

                auto tg_xxxxxz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 76); 

                auto tg_xxxxxz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 77); 

                auto tg_xxxxxz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 78); 

                auto tg_xxxxxz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 79); 

                auto tg_xxxxxz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 80); 

                auto tg_xxxxxz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 81); 

                auto tg_xxxxxz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 82); 

                auto tg_xxxxxz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 83); 

                auto tg_xxxxxz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 84); 

                auto tg_xxxxxz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 85); 

                auto tg_xxxxxz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 86); 

                auto tg_xxxxxz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 87); 

                auto tg_xxxxxz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 88); 

                auto tg_xxxxxz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 89); 

                auto tg_xxxxxz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 90); 

                auto tg_xxxxxz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 91); 

                auto tg_xxxxxz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 92); 

                auto tg_xxxxxz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 93); 

                auto tg_xxxxxz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 94); 

                auto tg_xxxxxz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 95); 

                auto tg_xxxxxz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 96); 

                auto tg_xxxxxz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 97); 

                auto tg_xxxxxz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 98); 

                auto tg_xxxxxz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 99); 

                auto tg_xxxxxx_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx); 

                auto tg_xxxxxx_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1); 

                auto tg_xxxxxx_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 2); 

                auto tg_xxxxxx_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 3); 

                auto tg_xxxxxx_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 4); 

                auto tg_xxxxxx_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 5); 

                auto tg_xxxxxx_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 6); 

                auto tg_xxxxxx_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 7); 

                auto tg_xxxxxx_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 8); 

                auto tg_xxxxxx_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 9); 

                auto tg_xxxxxx_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 10); 

                auto tg_xxxxxx_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 11); 

                auto tg_xxxxxx_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 12); 

                auto tg_xxxxxx_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 13); 

                auto tg_xxxxxx_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 14); 

                auto tg_xxxxxx_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 15); 

                auto tg_xxxxxx_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 16); 

                auto tg_xxxxxx_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 17); 

                auto tg_xxxxxx_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 18); 

                auto tg_xxxxxx_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 19); 

                auto tg_xxxxxx_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 20); 

                auto tg_xxxxxx_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 21); 

                auto tg_xxxxxx_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 22); 

                auto tg_xxxxxx_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 23); 

                auto tg_xxxxxx_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 24); 

                auto tg_xxxxxx_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 25); 

                auto tg_xxxxxx_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 26); 

                auto tg_xxxxxx_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 27); 

                auto tg_xxxxxx_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 28); 

                auto tg_xxxxxx_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 29); 

                auto tg_xxxxxx_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 30); 

                auto tg_xxxxxx_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 31); 

                auto tg_xxxxxx_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 32); 

                auto tg_xxxxxx_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 33); 

                auto tg_xxxxxx_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 34); 

                auto tg_xxxxxx_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 35); 

                auto tg_xxxxxy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 36); 

                auto tg_xxxxxy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 37); 

                auto tg_xxxxxy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 38); 

                auto tg_xxxxxy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 39); 

                auto tg_xxxxxy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 40); 

                auto tg_xxxxxy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 41); 

                auto tg_xxxxxy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 42); 

                auto tg_xxxxxy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 43); 

                auto tg_xxxxxy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 44); 

                auto tg_xxxxxy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 45); 

                auto tg_xxxxxy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 46); 

                auto tg_xxxxxy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 47); 

                auto tg_xxxxxy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 48); 

                auto tg_xxxxxy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 49); 

                auto tg_xxxxxy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 50); 

                auto tg_xxxxxy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 51); 

                auto tg_xxxxxy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 52); 

                auto tg_xxxxxy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 53); 

                auto tg_xxxxxy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 54); 

                auto tg_xxxxxy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 55); 

                auto tg_xxxxxy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 56); 

                auto tg_xxxxxy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 57); 

                auto tg_xxxxxy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 58); 

                auto tg_xxxxxy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 59); 

                auto tg_xxxxxy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 60); 

                auto tg_xxxxxy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 61); 

                auto tg_xxxxxy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 62); 

                auto tg_xxxxxy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 63); 

                auto tg_xxxxxy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 64); 

                auto tg_xxxxxy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 65); 

                auto tg_xxxxxy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 66); 

                auto tg_xxxxxy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 67); 

                auto tg_xxxxxy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 68); 

                auto tg_xxxxxy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 69); 

                auto tg_xxxxxy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 70); 

                auto tg_xxxxxy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 71); 

                auto tg_xxxxxz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 72); 

                auto tg_xxxxxz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 73); 

                auto tg_xxxxxz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 74); 

                auto tg_xxxxxz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 75); 

                auto tg_xxxxxz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 76); 

                auto tg_xxxxxz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 77); 

                auto tg_xxxxxz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 78); 

                auto tg_xxxxxz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 79); 

                auto tg_xxxxxz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 80); 

                auto tg_xxxxxz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 81); 

                auto tg_xxxxxz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 82); 

                auto tg_xxxxxz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 83); 

                auto tg_xxxxxz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 84); 

                auto tg_xxxxxz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 85); 

                auto tg_xxxxxz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 86); 

                auto tg_xxxxxz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 87); 

                auto tg_xxxxxz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 88); 

                auto tg_xxxxxz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 89); 

                auto tg_xxxxxz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 90); 

                auto tg_xxxxxz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 91); 

                auto tg_xxxxxz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 92); 

                auto tg_xxxxxz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 93); 

                auto tg_xxxxxz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 94); 

                auto tg_xxxxxz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 95); 

                auto tg_xxxxxz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 96); 

                auto tg_xxxxxz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 97); 

                auto tg_xxxxxz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 98); 

                auto tg_xxxxxz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 99); 

                auto tg_xxxxx_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx); 

                auto tg_xxxxx_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 1); 

                auto tg_xxxxx_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 2); 

                auto tg_xxxxx_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 3); 

                auto tg_xxxxx_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 4); 

                auto tg_xxxxx_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 5); 

                auto tg_xxxxx_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 6); 

                auto tg_xxxxx_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 7); 

                auto tg_xxxxx_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 8); 

                auto tg_xxxxx_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 9); 

                auto tg_xxxxx_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 10); 

                auto tg_xxxxx_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 11); 

                auto tg_xxxxx_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 12); 

                auto tg_xxxxx_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 13); 

                auto tg_xxxxx_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 14); 

                auto tg_xxxxx_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 15); 

                auto tg_xxxxx_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 16); 

                auto tg_xxxxx_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 17); 

                auto tg_xxxxx_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 18); 

                auto tg_xxxxx_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 19); 

                auto tg_xxxxx_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 20); 

                auto tg_xxxxx_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 21); 

                auto tg_xxxxx_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 22); 

                auto tg_xxxxx_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 23); 

                auto tg_xxxxx_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 24); 

                auto tg_xxxxx_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 25); 

                auto tg_xxxxx_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 26); 

                auto tg_xxxxx_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 27); 

                auto tg_xxxxx_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 28); 

                auto tg_xxxxx_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 29); 

                auto tg_xxxxx_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 30); 

                auto tg_xxxxx_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 31); 

                auto tg_xxxxx_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 32); 

                auto tg_xxxxx_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 33); 

                auto tg_xxxxx_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 34); 

                auto tg_xxxxx_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 35); 

                auto tg_xxxxy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 36); 

                auto tg_xxxxy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 37); 

                auto tg_xxxxy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 38); 

                auto tg_xxxxy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 39); 

                auto tg_xxxxy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 40); 

                auto tg_xxxxy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 41); 

                auto tg_xxxxy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 42); 

                auto tg_xxxxy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 43); 

                auto tg_xxxxy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 44); 

                auto tg_xxxxy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 45); 

                auto tg_xxxxy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 46); 

                auto tg_xxxxy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 47); 

                auto tg_xxxxy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 48); 

                auto tg_xxxxy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 49); 

                auto tg_xxxxy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 50); 

                auto tg_xxxxy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 51); 

                auto tg_xxxxy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 52); 

                auto tg_xxxxy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 53); 

                auto tg_xxxxy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 54); 

                auto tg_xxxxy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 55); 

                auto tg_xxxxy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 56); 

                auto tg_xxxxy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 57); 

                auto tg_xxxxy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 58); 

                auto tg_xxxxy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 59); 

                auto tg_xxxxy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 60); 

                auto tg_xxxxy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 61); 

                auto tg_xxxxy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 62); 

                auto tg_xxxxy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 63); 

                auto tg_xxxxy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 64); 

                auto tg_xxxxy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 65); 

                auto tg_xxxxy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 66); 

                auto tg_xxxxy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 67); 

                auto tg_xxxxy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 68); 

                auto tg_xxxxy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 69); 

                auto tg_xxxxy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 70); 

                auto tg_xxxxy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 71); 

                auto tg_xxxxz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 72); 

                auto tg_xxxxz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 73); 

                auto tg_xxxxz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 74); 

                auto tg_xxxxz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 75); 

                auto tg_xxxxz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 76); 

                auto tg_xxxxz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 77); 

                auto tg_xxxxz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 78); 

                auto tg_xxxxz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 79); 

                auto tg_xxxxz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 80); 

                auto tg_xxxxz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 81); 

                auto tg_xxxxz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 82); 

                auto tg_xxxxz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 83); 

                auto tg_xxxxz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 84); 

                auto tg_xxxxz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 85); 

                auto tg_xxxxz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 86); 

                auto tg_xxxxz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 87); 

                auto tg_xxxxz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 88); 

                auto tg_xxxxz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 89); 

                auto tg_xxxxz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 90); 

                auto tg_xxxxz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 91); 

                auto tg_xxxxz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 92); 

                auto tg_xxxxz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 93); 

                auto tg_xxxxz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 94); 

                auto tg_xxxxz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 95); 

                auto tg_xxxxz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 96); 

                auto tg_xxxxz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 97); 

                auto tg_xxxxz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 98); 

                auto tg_xxxxz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 99); 

                auto tg_xxxxx_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx); 

                auto tg_xxxxx_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 1); 

                auto tg_xxxxx_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 2); 

                auto tg_xxxxx_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 3); 

                auto tg_xxxxx_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 4); 

                auto tg_xxxxx_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 5); 

                auto tg_xxxxx_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 6); 

                auto tg_xxxxx_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 7); 

                auto tg_xxxxx_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 8); 

                auto tg_xxxxx_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 9); 

                auto tg_xxxxx_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 10); 

                auto tg_xxxxx_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 11); 

                auto tg_xxxxx_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 12); 

                auto tg_xxxxx_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 13); 

                auto tg_xxxxx_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 14); 

                auto tg_xxxxx_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 15); 

                auto tg_xxxxx_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 16); 

                auto tg_xxxxx_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 17); 

                auto tg_xxxxx_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 18); 

                auto tg_xxxxx_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 19); 

                auto tg_xxxxx_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 20); 

                auto tg_xxxxx_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 21); 

                auto tg_xxxxx_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 22); 

                auto tg_xxxxx_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 23); 

                auto tg_xxxxx_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 24); 

                auto tg_xxxxx_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 25); 

                auto tg_xxxxx_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 26); 

                auto tg_xxxxx_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 27); 

                auto tg_xxxxx_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 28); 

                auto tg_xxxxx_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 29); 

                auto tg_xxxxx_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 30); 

                auto tg_xxxxx_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 31); 

                auto tg_xxxxx_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 32); 

                auto tg_xxxxx_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 33); 

                auto tg_xxxxx_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 34); 

                auto tg_xxxxx_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 35); 

                auto tg_xxxxy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 36); 

                auto tg_xxxxy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 37); 

                auto tg_xxxxy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 38); 

                auto tg_xxxxy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 39); 

                auto tg_xxxxy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 40); 

                auto tg_xxxxy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 41); 

                auto tg_xxxxy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 42); 

                auto tg_xxxxy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 43); 

                auto tg_xxxxy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 44); 

                auto tg_xxxxy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 45); 

                auto tg_xxxxy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 46); 

                auto tg_xxxxy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 47); 

                auto tg_xxxxy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 48); 

                auto tg_xxxxy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 49); 

                auto tg_xxxxy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 50); 

                auto tg_xxxxy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 51); 

                auto tg_xxxxy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 52); 

                auto tg_xxxxy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 53); 

                auto tg_xxxxy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 54); 

                auto tg_xxxxy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 55); 

                auto tg_xxxxy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 56); 

                auto tg_xxxxy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 57); 

                auto tg_xxxxy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 58); 

                auto tg_xxxxy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 59); 

                auto tg_xxxxy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 60); 

                auto tg_xxxxy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 61); 

                auto tg_xxxxy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 62); 

                auto tg_xxxxy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 63); 

                auto tg_xxxxy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 64); 

                auto tg_xxxxy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 65); 

                auto tg_xxxxy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 66); 

                auto tg_xxxxy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 67); 

                auto tg_xxxxy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 68); 

                auto tg_xxxxy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 69); 

                auto tg_xxxxy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 70); 

                auto tg_xxxxy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 71); 

                auto tg_xxxxz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 72); 

                auto tg_xxxxz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 73); 

                auto tg_xxxxz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 74); 

                auto tg_xxxxz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 75); 

                auto tg_xxxxz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 76); 

                auto tg_xxxxz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 77); 

                auto tg_xxxxz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 78); 

                auto tg_xxxxz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 79); 

                auto tg_xxxxz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 80); 

                auto tg_xxxxz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 81); 

                auto tg_xxxxz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 82); 

                auto tg_xxxxz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 83); 

                auto tg_xxxxz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 84); 

                auto tg_xxxxz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 85); 

                auto tg_xxxxz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 86); 

                auto tg_xxxxz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 87); 

                auto tg_xxxxz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 88); 

                auto tg_xxxxz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 89); 

                auto tg_xxxxz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 90); 

                auto tg_xxxxz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 91); 

                auto tg_xxxxz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 92); 

                auto tg_xxxxz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 93); 

                auto tg_xxxxz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 94); 

                auto tg_xxxxz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 95); 

                auto tg_xxxxz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 96); 

                auto tg_xxxxz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 97); 

                auto tg_xxxxz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 98); 

                auto tg_xxxxz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 99); 

                auto tg_xxxxxx_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx); 

                auto tg_xxxxxx_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 1); 

                auto tg_xxxxxx_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 2); 

                auto tg_xxxxxx_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 3); 

                auto tg_xxxxxx_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 4); 

                auto tg_xxxxxx_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 5); 

                auto tg_xxxxxx_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 6); 

                auto tg_xxxxxx_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 7); 

                auto tg_xxxxxx_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 8); 

                auto tg_xxxxxx_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 9); 

                auto tg_xxxxxx_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 10); 

                auto tg_xxxxxx_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 11); 

                auto tg_xxxxxx_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 12); 

                auto tg_xxxxxx_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 13); 

                auto tg_xxxxxx_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 14); 

                auto tg_xxxxxx_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 15); 

                auto tg_xxxxxx_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 16); 

                auto tg_xxxxxx_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 17); 

                auto tg_xxxxxx_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 18); 

                auto tg_xxxxxx_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 19); 

                auto tg_xxxxxx_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 20); 

                auto tg_xxxxxx_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 21); 

                auto tg_xxxxxx_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 22); 

                auto tg_xxxxxx_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 23); 

                auto tg_xxxxxx_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 24); 

                auto tg_xxxxxx_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 25); 

                auto tg_xxxxxx_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 26); 

                auto tg_xxxxxx_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 27); 

                auto tg_xxxxxy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 28); 

                auto tg_xxxxxy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 29); 

                auto tg_xxxxxy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 30); 

                auto tg_xxxxxy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 31); 

                auto tg_xxxxxy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 32); 

                auto tg_xxxxxy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 33); 

                auto tg_xxxxxy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 34); 

                auto tg_xxxxxy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 35); 

                auto tg_xxxxxy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 36); 

                auto tg_xxxxxy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 37); 

                auto tg_xxxxxy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 38); 

                auto tg_xxxxxy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 39); 

                auto tg_xxxxxy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 40); 

                auto tg_xxxxxy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 41); 

                auto tg_xxxxxy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 42); 

                auto tg_xxxxxy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 43); 

                auto tg_xxxxxy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 44); 

                auto tg_xxxxxy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 45); 

                auto tg_xxxxxy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 46); 

                auto tg_xxxxxy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 47); 

                auto tg_xxxxxy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 48); 

                auto tg_xxxxxy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 49); 

                auto tg_xxxxxy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 50); 

                auto tg_xxxxxy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 51); 

                auto tg_xxxxxy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 52); 

                auto tg_xxxxxy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 53); 

                auto tg_xxxxxy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 54); 

                auto tg_xxxxxy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 55); 

                auto tg_xxxxxz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 56); 

                auto tg_xxxxxz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 57); 

                auto tg_xxxxxz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 58); 

                auto tg_xxxxxz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 59); 

                auto tg_xxxxxz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 60); 

                auto tg_xxxxxz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 61); 

                auto tg_xxxxxz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 62); 

                auto tg_xxxxxz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 63); 

                auto tg_xxxxxz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 64); 

                auto tg_xxxxxz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 65); 

                auto tg_xxxxxz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 66); 

                auto tg_xxxxxz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 67); 

                auto tg_xxxxxz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 68); 

                auto tg_xxxxxz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 69); 

                auto tg_xxxxxz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 70); 

                auto tg_xxxxxz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 71); 

                auto tg_xxxxxz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 72); 

                auto tg_xxxxxz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 73); 

                auto tg_xxxxxz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 74); 

                auto tg_xxxxxz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 75); 

                auto tg_xxxxxz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 76); 

                auto tg_xxxxxz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 77); 

                auto tg_xxxxxz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 78); 

                auto tg_xxxxxz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 79); 

                auto tg_xxxxxz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 80); 

                auto tg_xxxxxz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 81); 

                auto tg_xxxxxz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 82); 

                auto tg_xxxxxz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 83); 

                // set up pointers to integrals

                auto tg_xxxxxxx_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx); 

                auto tg_xxxxxxx_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1); 

                auto tg_xxxxxxx_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 2); 

                auto tg_xxxxxxx_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 3); 

                auto tg_xxxxxxx_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 4); 

                auto tg_xxxxxxx_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 5); 

                auto tg_xxxxxxx_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 6); 

                auto tg_xxxxxxx_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 7); 

                auto tg_xxxxxxx_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 8); 

                auto tg_xxxxxxx_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 9); 

                auto tg_xxxxxxx_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 10); 

                auto tg_xxxxxxx_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 11); 

                auto tg_xxxxxxx_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 12); 

                auto tg_xxxxxxx_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 13); 

                auto tg_xxxxxxx_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 14); 

                auto tg_xxxxxxx_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 15); 

                auto tg_xxxxxxx_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 16); 

                auto tg_xxxxxxx_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 17); 

                auto tg_xxxxxxx_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 18); 

                auto tg_xxxxxxx_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 19); 

                auto tg_xxxxxxx_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 20); 

                auto tg_xxxxxxx_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 21); 

                auto tg_xxxxxxx_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 22); 

                auto tg_xxxxxxx_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 23); 

                auto tg_xxxxxxx_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 24); 

                auto tg_xxxxxxx_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 25); 

                auto tg_xxxxxxx_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 26); 

                auto tg_xxxxxxx_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 27); 

                auto tg_xxxxxxx_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 28); 

                auto tg_xxxxxxx_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 29); 

                auto tg_xxxxxxx_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 30); 

                auto tg_xxxxxxx_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 31); 

                auto tg_xxxxxxx_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 32); 

                auto tg_xxxxxxx_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 33); 

                auto tg_xxxxxxx_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 34); 

                auto tg_xxxxxxx_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 35); 

                auto tg_xxxxxxy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 36); 

                auto tg_xxxxxxy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 37); 

                auto tg_xxxxxxy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 38); 

                auto tg_xxxxxxy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 39); 

                auto tg_xxxxxxy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 40); 

                auto tg_xxxxxxy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 41); 

                auto tg_xxxxxxy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 42); 

                auto tg_xxxxxxy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 43); 

                auto tg_xxxxxxy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 44); 

                auto tg_xxxxxxy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 45); 

                auto tg_xxxxxxy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 46); 

                auto tg_xxxxxxy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 47); 

                auto tg_xxxxxxy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 48); 

                auto tg_xxxxxxy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 49); 

                auto tg_xxxxxxy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 50); 

                auto tg_xxxxxxy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 51); 

                auto tg_xxxxxxy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 52); 

                auto tg_xxxxxxy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 53); 

                auto tg_xxxxxxy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 54); 

                auto tg_xxxxxxy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 55); 

                auto tg_xxxxxxy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 56); 

                auto tg_xxxxxxy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 57); 

                auto tg_xxxxxxy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 58); 

                auto tg_xxxxxxy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 59); 

                auto tg_xxxxxxy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 60); 

                auto tg_xxxxxxy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 61); 

                auto tg_xxxxxxy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 62); 

                auto tg_xxxxxxy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 63); 

                auto tg_xxxxxxy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 64); 

                auto tg_xxxxxxy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 65); 

                auto tg_xxxxxxy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 66); 

                auto tg_xxxxxxy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 67); 

                auto tg_xxxxxxy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 68); 

                auto tg_xxxxxxy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 69); 

                auto tg_xxxxxxy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 70); 

                auto tg_xxxxxxy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 71); 

                auto tg_xxxxxxz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 72); 

                auto tg_xxxxxxz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 73); 

                auto tg_xxxxxxz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 74); 

                auto tg_xxxxxxz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 75); 

                auto tg_xxxxxxz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 76); 

                auto tg_xxxxxxz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 77); 

                auto tg_xxxxxxz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 78); 

                auto tg_xxxxxxz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 79); 

                auto tg_xxxxxxz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 80); 

                auto tg_xxxxxxz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 81); 

                auto tg_xxxxxxz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 82); 

                auto tg_xxxxxxz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 83); 

                auto tg_xxxxxxz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 84); 

                auto tg_xxxxxxz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 85); 

                auto tg_xxxxxxz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 86); 

                auto tg_xxxxxxz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 87); 

                auto tg_xxxxxxz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 88); 

                auto tg_xxxxxxz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 89); 

                auto tg_xxxxxxz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 90); 

                auto tg_xxxxxxz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 91); 

                auto tg_xxxxxxz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 92); 

                auto tg_xxxxxxz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 93); 

                auto tg_xxxxxxz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 94); 

                auto tg_xxxxxxz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 95); 

                auto tg_xxxxxxz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 96); 

                auto tg_xxxxxxz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 97); 

                auto tg_xxxxxxz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 98); 

                auto tg_xxxxxxz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 99); 

                // Batch of Integrals (0,100)

                #pragma omp simd aligned(fxn, fza, tg_xxxxx_xxxxxxx_0, tg_xxxxx_xxxxxxx_1, tg_xxxxx_xxxxxxy_0, \
                                         tg_xxxxx_xxxxxxy_1, tg_xxxxx_xxxxxxz_0, tg_xxxxx_xxxxxxz_1, tg_xxxxx_xxxxxyy_0, \
                                         tg_xxxxx_xxxxxyy_1, tg_xxxxx_xxxxxyz_0, tg_xxxxx_xxxxxyz_1, tg_xxxxx_xxxxxzz_0, \
                                         tg_xxxxx_xxxxxzz_1, tg_xxxxx_xxxxyyy_0, tg_xxxxx_xxxxyyy_1, tg_xxxxx_xxxxyyz_0, \
                                         tg_xxxxx_xxxxyyz_1, tg_xxxxx_xxxxyzz_0, tg_xxxxx_xxxxyzz_1, tg_xxxxx_xxxxzzz_0, \
                                         tg_xxxxx_xxxxzzz_1, tg_xxxxx_xxxyyyy_0, tg_xxxxx_xxxyyyy_1, tg_xxxxx_xxxyyyz_0, \
                                         tg_xxxxx_xxxyyyz_1, tg_xxxxx_xxxyyzz_0, tg_xxxxx_xxxyyzz_1, tg_xxxxx_xxxyzzz_0, \
                                         tg_xxxxx_xxxyzzz_1, tg_xxxxx_xxxzzzz_0, tg_xxxxx_xxxzzzz_1, tg_xxxxx_xxyyyyy_0, \
                                         tg_xxxxx_xxyyyyy_1, tg_xxxxx_xxyyyyz_0, tg_xxxxx_xxyyyyz_1, tg_xxxxx_xxyyyzz_0, \
                                         tg_xxxxx_xxyyyzz_1, tg_xxxxx_xxyyzzz_0, tg_xxxxx_xxyyzzz_1, tg_xxxxx_xxyzzzz_0, \
                                         tg_xxxxx_xxyzzzz_1, tg_xxxxx_xxzzzzz_0, tg_xxxxx_xxzzzzz_1, tg_xxxxx_xyyyyyy_0, \
                                         tg_xxxxx_xyyyyyy_1, tg_xxxxx_xyyyyyz_0, tg_xxxxx_xyyyyyz_1, tg_xxxxx_xyyyyzz_0, \
                                         tg_xxxxx_xyyyyzz_1, tg_xxxxx_xyyyzzz_0, tg_xxxxx_xyyyzzz_1, tg_xxxxx_xyyzzzz_0, \
                                         tg_xxxxx_xyyzzzz_1, tg_xxxxx_xyzzzzz_0, tg_xxxxx_xyzzzzz_1, tg_xxxxx_xzzzzzz_0, \
                                         tg_xxxxx_xzzzzzz_1, tg_xxxxx_yyyyyyy_0, tg_xxxxx_yyyyyyy_1, tg_xxxxx_yyyyyyz_0, \
                                         tg_xxxxx_yyyyyyz_1, tg_xxxxx_yyyyyzz_0, tg_xxxxx_yyyyyzz_1, tg_xxxxx_yyyyzzz_0, \
                                         tg_xxxxx_yyyyzzz_1, tg_xxxxx_yyyzzzz_0, tg_xxxxx_yyyzzzz_1, tg_xxxxx_yyzzzzz_0, \
                                         tg_xxxxx_yyzzzzz_1, tg_xxxxx_yzzzzzz_0, tg_xxxxx_yzzzzzz_1, tg_xxxxx_zzzzzzz_0, \
                                         tg_xxxxx_zzzzzzz_1, tg_xxxxxx_xxxxxx_1, tg_xxxxxx_xxxxxxx_0, tg_xxxxxx_xxxxxxx_1, \
                                         tg_xxxxxx_xxxxxxy_0, tg_xxxxxx_xxxxxxy_1, tg_xxxxxx_xxxxxxz_0, tg_xxxxxx_xxxxxxz_1, \
                                         tg_xxxxxx_xxxxxy_1, tg_xxxxxx_xxxxxyy_0, tg_xxxxxx_xxxxxyy_1, tg_xxxxxx_xxxxxyz_0, \
                                         tg_xxxxxx_xxxxxyz_1, tg_xxxxxx_xxxxxz_1, tg_xxxxxx_xxxxxzz_0, tg_xxxxxx_xxxxxzz_1, \
                                         tg_xxxxxx_xxxxyy_1, tg_xxxxxx_xxxxyyy_0, tg_xxxxxx_xxxxyyy_1, tg_xxxxxx_xxxxyyz_0, \
                                         tg_xxxxxx_xxxxyyz_1, tg_xxxxxx_xxxxyz_1, tg_xxxxxx_xxxxyzz_0, tg_xxxxxx_xxxxyzz_1, \
                                         tg_xxxxxx_xxxxzz_1, tg_xxxxxx_xxxxzzz_0, tg_xxxxxx_xxxxzzz_1, tg_xxxxxx_xxxyyy_1, \
                                         tg_xxxxxx_xxxyyyy_0, tg_xxxxxx_xxxyyyy_1, tg_xxxxxx_xxxyyyz_0, tg_xxxxxx_xxxyyyz_1, \
                                         tg_xxxxxx_xxxyyz_1, tg_xxxxxx_xxxyyzz_0, tg_xxxxxx_xxxyyzz_1, tg_xxxxxx_xxxyzz_1, \
                                         tg_xxxxxx_xxxyzzz_0, tg_xxxxxx_xxxyzzz_1, tg_xxxxxx_xxxzzz_1, tg_xxxxxx_xxxzzzz_0, \
                                         tg_xxxxxx_xxxzzzz_1, tg_xxxxxx_xxyyyy_1, tg_xxxxxx_xxyyyyy_0, tg_xxxxxx_xxyyyyy_1, \
                                         tg_xxxxxx_xxyyyyz_0, tg_xxxxxx_xxyyyyz_1, tg_xxxxxx_xxyyyz_1, tg_xxxxxx_xxyyyzz_0, \
                                         tg_xxxxxx_xxyyyzz_1, tg_xxxxxx_xxyyzz_1, tg_xxxxxx_xxyyzzz_0, tg_xxxxxx_xxyyzzz_1, \
                                         tg_xxxxxx_xxyzzz_1, tg_xxxxxx_xxyzzzz_0, tg_xxxxxx_xxyzzzz_1, tg_xxxxxx_xxzzzz_1, \
                                         tg_xxxxxx_xxzzzzz_0, tg_xxxxxx_xxzzzzz_1, tg_xxxxxx_xyyyyy_1, tg_xxxxxx_xyyyyyy_0, \
                                         tg_xxxxxx_xyyyyyy_1, tg_xxxxxx_xyyyyyz_0, tg_xxxxxx_xyyyyyz_1, tg_xxxxxx_xyyyyz_1, \
                                         tg_xxxxxx_xyyyyzz_0, tg_xxxxxx_xyyyyzz_1, tg_xxxxxx_xyyyzz_1, tg_xxxxxx_xyyyzzz_0, \
                                         tg_xxxxxx_xyyyzzz_1, tg_xxxxxx_xyyzzz_1, tg_xxxxxx_xyyzzzz_0, tg_xxxxxx_xyyzzzz_1, \
                                         tg_xxxxxx_xyzzzz_1, tg_xxxxxx_xyzzzzz_0, tg_xxxxxx_xyzzzzz_1, tg_xxxxxx_xzzzzz_1, \
                                         tg_xxxxxx_xzzzzzz_0, tg_xxxxxx_xzzzzzz_1, tg_xxxxxx_yyyyyy_1, tg_xxxxxx_yyyyyyy_0, \
                                         tg_xxxxxx_yyyyyyy_1, tg_xxxxxx_yyyyyyz_0, tg_xxxxxx_yyyyyyz_1, tg_xxxxxx_yyyyyz_1, \
                                         tg_xxxxxx_yyyyyzz_0, tg_xxxxxx_yyyyyzz_1, tg_xxxxxx_yyyyzz_1, tg_xxxxxx_yyyyzzz_0, \
                                         tg_xxxxxx_yyyyzzz_1, tg_xxxxxx_yyyzzz_1, tg_xxxxxx_yyyzzzz_0, tg_xxxxxx_yyyzzzz_1, \
                                         tg_xxxxxx_yyzzzz_1, tg_xxxxxx_yyzzzzz_0, tg_xxxxxx_yyzzzzz_1, tg_xxxxxx_yzzzzz_1, \
                                         tg_xxxxxx_yzzzzzz_0, tg_xxxxxx_yzzzzzz_1, tg_xxxxxx_zzzzzz_1, tg_xxxxxx_zzzzzzz_0, \
                                         tg_xxxxxx_zzzzzzz_1, tg_xxxxxxx_xxxxxxx_0, tg_xxxxxxx_xxxxxxy_0, tg_xxxxxxx_xxxxxxz_0, \
                                         tg_xxxxxxx_xxxxxyy_0, tg_xxxxxxx_xxxxxyz_0, tg_xxxxxxx_xxxxxzz_0, tg_xxxxxxx_xxxxyyy_0, \
                                         tg_xxxxxxx_xxxxyyz_0, tg_xxxxxxx_xxxxyzz_0, tg_xxxxxxx_xxxxzzz_0, tg_xxxxxxx_xxxyyyy_0, \
                                         tg_xxxxxxx_xxxyyyz_0, tg_xxxxxxx_xxxyyzz_0, tg_xxxxxxx_xxxyzzz_0, tg_xxxxxxx_xxxzzzz_0, \
                                         tg_xxxxxxx_xxyyyyy_0, tg_xxxxxxx_xxyyyyz_0, tg_xxxxxxx_xxyyyzz_0, tg_xxxxxxx_xxyyzzz_0, \
                                         tg_xxxxxxx_xxyzzzz_0, tg_xxxxxxx_xxzzzzz_0, tg_xxxxxxx_xyyyyyy_0, tg_xxxxxxx_xyyyyyz_0, \
                                         tg_xxxxxxx_xyyyyzz_0, tg_xxxxxxx_xyyyzzz_0, tg_xxxxxxx_xyyzzzz_0, tg_xxxxxxx_xyzzzzz_0, \
                                         tg_xxxxxxx_xzzzzzz_0, tg_xxxxxxx_yyyyyyy_0, tg_xxxxxxx_yyyyyyz_0, tg_xxxxxxx_yyyyyzz_0, \
                                         tg_xxxxxxx_yyyyzzz_0, tg_xxxxxxx_yyyzzzz_0, tg_xxxxxxx_yyzzzzz_0, tg_xxxxxxx_yzzzzzz_0, \
                                         tg_xxxxxxx_zzzzzzz_0, tg_xxxxxxy_xxxxxxx_0, tg_xxxxxxy_xxxxxxy_0, tg_xxxxxxy_xxxxxxz_0, \
                                         tg_xxxxxxy_xxxxxyy_0, tg_xxxxxxy_xxxxxyz_0, tg_xxxxxxy_xxxxxzz_0, tg_xxxxxxy_xxxxyyy_0, \
                                         tg_xxxxxxy_xxxxyyz_0, tg_xxxxxxy_xxxxyzz_0, tg_xxxxxxy_xxxxzzz_0, tg_xxxxxxy_xxxyyyy_0, \
                                         tg_xxxxxxy_xxxyyyz_0, tg_xxxxxxy_xxxyyzz_0, tg_xxxxxxy_xxxyzzz_0, tg_xxxxxxy_xxxzzzz_0, \
                                         tg_xxxxxxy_xxyyyyy_0, tg_xxxxxxy_xxyyyyz_0, tg_xxxxxxy_xxyyyzz_0, tg_xxxxxxy_xxyyzzz_0, \
                                         tg_xxxxxxy_xxyzzzz_0, tg_xxxxxxy_xxzzzzz_0, tg_xxxxxxy_xyyyyyy_0, tg_xxxxxxy_xyyyyyz_0, \
                                         tg_xxxxxxy_xyyyyzz_0, tg_xxxxxxy_xyyyzzz_0, tg_xxxxxxy_xyyzzzz_0, tg_xxxxxxy_xyzzzzz_0, \
                                         tg_xxxxxxy_xzzzzzz_0, tg_xxxxxxy_yyyyyyy_0, tg_xxxxxxy_yyyyyyz_0, tg_xxxxxxy_yyyyyzz_0, \
                                         tg_xxxxxxy_yyyyzzz_0, tg_xxxxxxy_yyyzzzz_0, tg_xxxxxxy_yyzzzzz_0, tg_xxxxxxy_yzzzzzz_0, \
                                         tg_xxxxxxy_zzzzzzz_0, tg_xxxxxxz_xxxxxxx_0, tg_xxxxxxz_xxxxxxy_0, tg_xxxxxxz_xxxxxxz_0, \
                                         tg_xxxxxxz_xxxxxyy_0, tg_xxxxxxz_xxxxxyz_0, tg_xxxxxxz_xxxxxzz_0, tg_xxxxxxz_xxxxyyy_0, \
                                         tg_xxxxxxz_xxxxyyz_0, tg_xxxxxxz_xxxxyzz_0, tg_xxxxxxz_xxxxzzz_0, tg_xxxxxxz_xxxyyyy_0, \
                                         tg_xxxxxxz_xxxyyyz_0, tg_xxxxxxz_xxxyyzz_0, tg_xxxxxxz_xxxyzzz_0, tg_xxxxxxz_xxxzzzz_0, \
                                         tg_xxxxxxz_xxyyyyy_0, tg_xxxxxxz_xxyyyyz_0, tg_xxxxxxz_xxyyyzz_0, tg_xxxxxxz_xxyyzzz_0, \
                                         tg_xxxxxxz_xxyzzzz_0, tg_xxxxxxz_xxzzzzz_0, tg_xxxxxxz_xyyyyyy_0, tg_xxxxxxz_xyyyyyz_0, \
                                         tg_xxxxxxz_xyyyyzz_0, tg_xxxxxxz_xyyyzzz_0, tg_xxxxxxz_xyyzzzz_0, tg_xxxxxxz_xyzzzzz_0, \
                                         tg_xxxxxxz_xzzzzzz_0, tg_xxxxxy_xxxxxx_1, tg_xxxxxy_xxxxxxx_0, tg_xxxxxy_xxxxxxx_1, \
                                         tg_xxxxxy_xxxxxxy_0, tg_xxxxxy_xxxxxxy_1, tg_xxxxxy_xxxxxxz_0, tg_xxxxxy_xxxxxxz_1, \
                                         tg_xxxxxy_xxxxxy_1, tg_xxxxxy_xxxxxyy_0, tg_xxxxxy_xxxxxyy_1, tg_xxxxxy_xxxxxyz_0, \
                                         tg_xxxxxy_xxxxxyz_1, tg_xxxxxy_xxxxxz_1, tg_xxxxxy_xxxxxzz_0, tg_xxxxxy_xxxxxzz_1, \
                                         tg_xxxxxy_xxxxyy_1, tg_xxxxxy_xxxxyyy_0, tg_xxxxxy_xxxxyyy_1, tg_xxxxxy_xxxxyyz_0, \
                                         tg_xxxxxy_xxxxyyz_1, tg_xxxxxy_xxxxyz_1, tg_xxxxxy_xxxxyzz_0, tg_xxxxxy_xxxxyzz_1, \
                                         tg_xxxxxy_xxxxzz_1, tg_xxxxxy_xxxxzzz_0, tg_xxxxxy_xxxxzzz_1, tg_xxxxxy_xxxyyy_1, \
                                         tg_xxxxxy_xxxyyyy_0, tg_xxxxxy_xxxyyyy_1, tg_xxxxxy_xxxyyyz_0, tg_xxxxxy_xxxyyyz_1, \
                                         tg_xxxxxy_xxxyyz_1, tg_xxxxxy_xxxyyzz_0, tg_xxxxxy_xxxyyzz_1, tg_xxxxxy_xxxyzz_1, \
                                         tg_xxxxxy_xxxyzzz_0, tg_xxxxxy_xxxyzzz_1, tg_xxxxxy_xxxzzz_1, tg_xxxxxy_xxxzzzz_0, \
                                         tg_xxxxxy_xxxzzzz_1, tg_xxxxxy_xxyyyy_1, tg_xxxxxy_xxyyyyy_0, tg_xxxxxy_xxyyyyy_1, \
                                         tg_xxxxxy_xxyyyyz_0, tg_xxxxxy_xxyyyyz_1, tg_xxxxxy_xxyyyz_1, tg_xxxxxy_xxyyyzz_0, \
                                         tg_xxxxxy_xxyyyzz_1, tg_xxxxxy_xxyyzz_1, tg_xxxxxy_xxyyzzz_0, tg_xxxxxy_xxyyzzz_1, \
                                         tg_xxxxxy_xxyzzz_1, tg_xxxxxy_xxyzzzz_0, tg_xxxxxy_xxyzzzz_1, tg_xxxxxy_xxzzzz_1, \
                                         tg_xxxxxy_xxzzzzz_0, tg_xxxxxy_xxzzzzz_1, tg_xxxxxy_xyyyyy_1, tg_xxxxxy_xyyyyyy_0, \
                                         tg_xxxxxy_xyyyyyy_1, tg_xxxxxy_xyyyyyz_0, tg_xxxxxy_xyyyyyz_1, tg_xxxxxy_xyyyyz_1, \
                                         tg_xxxxxy_xyyyyzz_0, tg_xxxxxy_xyyyyzz_1, tg_xxxxxy_xyyyzz_1, tg_xxxxxy_xyyyzzz_0, \
                                         tg_xxxxxy_xyyyzzz_1, tg_xxxxxy_xyyzzz_1, tg_xxxxxy_xyyzzzz_0, tg_xxxxxy_xyyzzzz_1, \
                                         tg_xxxxxy_xyzzzz_1, tg_xxxxxy_xyzzzzz_0, tg_xxxxxy_xyzzzzz_1, tg_xxxxxy_xzzzzz_1, \
                                         tg_xxxxxy_xzzzzzz_0, tg_xxxxxy_xzzzzzz_1, tg_xxxxxy_yyyyyy_1, tg_xxxxxy_yyyyyyy_0, \
                                         tg_xxxxxy_yyyyyyy_1, tg_xxxxxy_yyyyyyz_0, tg_xxxxxy_yyyyyyz_1, tg_xxxxxy_yyyyyz_1, \
                                         tg_xxxxxy_yyyyyzz_0, tg_xxxxxy_yyyyyzz_1, tg_xxxxxy_yyyyzz_1, tg_xxxxxy_yyyyzzz_0, \
                                         tg_xxxxxy_yyyyzzz_1, tg_xxxxxy_yyyzzz_1, tg_xxxxxy_yyyzzzz_0, tg_xxxxxy_yyyzzzz_1, \
                                         tg_xxxxxy_yyzzzz_1, tg_xxxxxy_yyzzzzz_0, tg_xxxxxy_yyzzzzz_1, tg_xxxxxy_yzzzzz_1, \
                                         tg_xxxxxy_yzzzzzz_0, tg_xxxxxy_yzzzzzz_1, tg_xxxxxy_zzzzzz_1, tg_xxxxxy_zzzzzzz_0, \
                                         tg_xxxxxy_zzzzzzz_1, tg_xxxxxz_xxxxxx_1, tg_xxxxxz_xxxxxxx_0, tg_xxxxxz_xxxxxxx_1, \
                                         tg_xxxxxz_xxxxxxy_0, tg_xxxxxz_xxxxxxy_1, tg_xxxxxz_xxxxxxz_0, tg_xxxxxz_xxxxxxz_1, \
                                         tg_xxxxxz_xxxxxy_1, tg_xxxxxz_xxxxxyy_0, tg_xxxxxz_xxxxxyy_1, tg_xxxxxz_xxxxxyz_0, \
                                         tg_xxxxxz_xxxxxyz_1, tg_xxxxxz_xxxxxz_1, tg_xxxxxz_xxxxxzz_0, tg_xxxxxz_xxxxxzz_1, \
                                         tg_xxxxxz_xxxxyy_1, tg_xxxxxz_xxxxyyy_0, tg_xxxxxz_xxxxyyy_1, tg_xxxxxz_xxxxyyz_0, \
                                         tg_xxxxxz_xxxxyyz_1, tg_xxxxxz_xxxxyz_1, tg_xxxxxz_xxxxyzz_0, tg_xxxxxz_xxxxyzz_1, \
                                         tg_xxxxxz_xxxxzz_1, tg_xxxxxz_xxxxzzz_0, tg_xxxxxz_xxxxzzz_1, tg_xxxxxz_xxxyyy_1, \
                                         tg_xxxxxz_xxxyyyy_0, tg_xxxxxz_xxxyyyy_1, tg_xxxxxz_xxxyyyz_0, tg_xxxxxz_xxxyyyz_1, \
                                         tg_xxxxxz_xxxyyz_1, tg_xxxxxz_xxxyyzz_0, tg_xxxxxz_xxxyyzz_1, tg_xxxxxz_xxxyzz_1, \
                                         tg_xxxxxz_xxxyzzz_0, tg_xxxxxz_xxxyzzz_1, tg_xxxxxz_xxxzzz_1, tg_xxxxxz_xxxzzzz_0, \
                                         tg_xxxxxz_xxxzzzz_1, tg_xxxxxz_xxyyyy_1, tg_xxxxxz_xxyyyyy_0, tg_xxxxxz_xxyyyyy_1, \
                                         tg_xxxxxz_xxyyyyz_0, tg_xxxxxz_xxyyyyz_1, tg_xxxxxz_xxyyyz_1, tg_xxxxxz_xxyyyzz_0, \
                                         tg_xxxxxz_xxyyyzz_1, tg_xxxxxz_xxyyzz_1, tg_xxxxxz_xxyyzzz_0, tg_xxxxxz_xxyyzzz_1, \
                                         tg_xxxxxz_xxyzzz_1, tg_xxxxxz_xxyzzzz_0, tg_xxxxxz_xxyzzzz_1, tg_xxxxxz_xxzzzz_1, \
                                         tg_xxxxxz_xxzzzzz_0, tg_xxxxxz_xxzzzzz_1, tg_xxxxxz_xyyyyy_1, tg_xxxxxz_xyyyyyy_0, \
                                         tg_xxxxxz_xyyyyyy_1, tg_xxxxxz_xyyyyyz_0, tg_xxxxxz_xyyyyyz_1, tg_xxxxxz_xyyyyz_1, \
                                         tg_xxxxxz_xyyyyzz_0, tg_xxxxxz_xyyyyzz_1, tg_xxxxxz_xyyyzz_1, tg_xxxxxz_xyyyzzz_0, \
                                         tg_xxxxxz_xyyyzzz_1, tg_xxxxxz_xyyzzz_1, tg_xxxxxz_xyyzzzz_0, tg_xxxxxz_xyyzzzz_1, \
                                         tg_xxxxxz_xyzzzz_1, tg_xxxxxz_xyzzzzz_0, tg_xxxxxz_xyzzzzz_1, tg_xxxxxz_xzzzzz_1, \
                                         tg_xxxxxz_xzzzzzz_0, tg_xxxxxz_xzzzzzz_1, tg_xxxxxz_yyyyyy_1, tg_xxxxxz_yyyyyz_1, \
                                         tg_xxxxxz_yyyyzz_1, tg_xxxxxz_yyyzzz_1, tg_xxxxxz_yyzzzz_1, tg_xxxxxz_yzzzzz_1, \
                                         tg_xxxxxz_zzzzzz_1, tg_xxxxy_xxxxxxx_0, tg_xxxxy_xxxxxxx_1, tg_xxxxy_xxxxxxy_0, \
                                         tg_xxxxy_xxxxxxy_1, tg_xxxxy_xxxxxxz_0, tg_xxxxy_xxxxxxz_1, tg_xxxxy_xxxxxyy_0, \
                                         tg_xxxxy_xxxxxyy_1, tg_xxxxy_xxxxxyz_0, tg_xxxxy_xxxxxyz_1, tg_xxxxy_xxxxxzz_0, \
                                         tg_xxxxy_xxxxxzz_1, tg_xxxxy_xxxxyyy_0, tg_xxxxy_xxxxyyy_1, tg_xxxxy_xxxxyyz_0, \
                                         tg_xxxxy_xxxxyyz_1, tg_xxxxy_xxxxyzz_0, tg_xxxxy_xxxxyzz_1, tg_xxxxy_xxxxzzz_0, \
                                         tg_xxxxy_xxxxzzz_1, tg_xxxxy_xxxyyyy_0, tg_xxxxy_xxxyyyy_1, tg_xxxxy_xxxyyyz_0, \
                                         tg_xxxxy_xxxyyyz_1, tg_xxxxy_xxxyyzz_0, tg_xxxxy_xxxyyzz_1, tg_xxxxy_xxxyzzz_0, \
                                         tg_xxxxy_xxxyzzz_1, tg_xxxxy_xxxzzzz_0, tg_xxxxy_xxxzzzz_1, tg_xxxxy_xxyyyyy_0, \
                                         tg_xxxxy_xxyyyyy_1, tg_xxxxy_xxyyyyz_0, tg_xxxxy_xxyyyyz_1, tg_xxxxy_xxyyyzz_0, \
                                         tg_xxxxy_xxyyyzz_1, tg_xxxxy_xxyyzzz_0, tg_xxxxy_xxyyzzz_1, tg_xxxxy_xxyzzzz_0, \
                                         tg_xxxxy_xxyzzzz_1, tg_xxxxy_xxzzzzz_0, tg_xxxxy_xxzzzzz_1, tg_xxxxy_xyyyyyy_0, \
                                         tg_xxxxy_xyyyyyy_1, tg_xxxxy_xyyyyyz_0, tg_xxxxy_xyyyyyz_1, tg_xxxxy_xyyyyzz_0, \
                                         tg_xxxxy_xyyyyzz_1, tg_xxxxy_xyyyzzz_0, tg_xxxxy_xyyyzzz_1, tg_xxxxy_xyyzzzz_0, \
                                         tg_xxxxy_xyyzzzz_1, tg_xxxxy_xyzzzzz_0, tg_xxxxy_xyzzzzz_1, tg_xxxxy_xzzzzzz_0, \
                                         tg_xxxxy_xzzzzzz_1, tg_xxxxy_yyyyyyy_0, tg_xxxxy_yyyyyyy_1, tg_xxxxy_yyyyyyz_0, \
                                         tg_xxxxy_yyyyyyz_1, tg_xxxxy_yyyyyzz_0, tg_xxxxy_yyyyyzz_1, tg_xxxxy_yyyyzzz_0, \
                                         tg_xxxxy_yyyyzzz_1, tg_xxxxy_yyyzzzz_0, tg_xxxxy_yyyzzzz_1, tg_xxxxy_yyzzzzz_0, \
                                         tg_xxxxy_yyzzzzz_1, tg_xxxxy_yzzzzzz_0, tg_xxxxy_yzzzzzz_1, tg_xxxxy_zzzzzzz_0, \
                                         tg_xxxxy_zzzzzzz_1, tg_xxxxz_xxxxxxx_0, tg_xxxxz_xxxxxxx_1, tg_xxxxz_xxxxxxy_0, \
                                         tg_xxxxz_xxxxxxy_1, tg_xxxxz_xxxxxxz_0, tg_xxxxz_xxxxxxz_1, tg_xxxxz_xxxxxyy_0, \
                                         tg_xxxxz_xxxxxyy_1, tg_xxxxz_xxxxxyz_0, tg_xxxxz_xxxxxyz_1, tg_xxxxz_xxxxxzz_0, \
                                         tg_xxxxz_xxxxxzz_1, tg_xxxxz_xxxxyyy_0, tg_xxxxz_xxxxyyy_1, tg_xxxxz_xxxxyyz_0, \
                                         tg_xxxxz_xxxxyyz_1, tg_xxxxz_xxxxyzz_0, tg_xxxxz_xxxxyzz_1, tg_xxxxz_xxxxzzz_0, \
                                         tg_xxxxz_xxxxzzz_1, tg_xxxxz_xxxyyyy_0, tg_xxxxz_xxxyyyy_1, tg_xxxxz_xxxyyyz_0, \
                                         tg_xxxxz_xxxyyyz_1, tg_xxxxz_xxxyyzz_0, tg_xxxxz_xxxyyzz_1, tg_xxxxz_xxxyzzz_0, \
                                         tg_xxxxz_xxxyzzz_1, tg_xxxxz_xxxzzzz_0, tg_xxxxz_xxxzzzz_1, tg_xxxxz_xxyyyyy_0, \
                                         tg_xxxxz_xxyyyyy_1, tg_xxxxz_xxyyyyz_0, tg_xxxxz_xxyyyyz_1, tg_xxxxz_xxyyyzz_0, \
                                         tg_xxxxz_xxyyyzz_1, tg_xxxxz_xxyyzzz_0, tg_xxxxz_xxyyzzz_1, tg_xxxxz_xxyzzzz_0, \
                                         tg_xxxxz_xxyzzzz_1, tg_xxxxz_xxzzzzz_0, tg_xxxxz_xxzzzzz_1, tg_xxxxz_xyyyyyy_0, \
                                         tg_xxxxz_xyyyyyy_1, tg_xxxxz_xyyyyyz_0, tg_xxxxz_xyyyyyz_1, tg_xxxxz_xyyyyzz_0, \
                                         tg_xxxxz_xyyyyzz_1, tg_xxxxz_xyyyzzz_0, tg_xxxxz_xyyyzzz_1, tg_xxxxz_xyyzzzz_0, \
                                         tg_xxxxz_xyyzzzz_1, tg_xxxxz_xyzzzzz_0, tg_xxxxz_xyzzzzz_1, tg_xxxxz_xzzzzzz_0, \
                                         tg_xxxxz_xzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxx_xxxxxxx_0[j] = pb_x * tg_xxxxxx_xxxxxxx_0[j] + fr * tg_xxxxxx_xxxxxxx_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxxx_0[j] - tg_xxxxx_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxxx_xxxxxx_1[j];

                    tg_xxxxxxx_xxxxxxy_0[j] = pb_x * tg_xxxxxx_xxxxxxy_0[j] + fr * tg_xxxxxx_xxxxxxy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxxy_0[j] - tg_xxxxx_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxx_xxxxxy_1[j];

                    tg_xxxxxxx_xxxxxxz_0[j] = pb_x * tg_xxxxxx_xxxxxxz_0[j] + fr * tg_xxxxxx_xxxxxxz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxxz_0[j] - tg_xxxxx_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxx_xxxxxz_1[j];

                    tg_xxxxxxx_xxxxxyy_0[j] = pb_x * tg_xxxxxx_xxxxxyy_0[j] + fr * tg_xxxxxx_xxxxxyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxyy_0[j] - tg_xxxxx_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxx_xxxxyy_1[j];

                    tg_xxxxxxx_xxxxxyz_0[j] = pb_x * tg_xxxxxx_xxxxxyz_0[j] + fr * tg_xxxxxx_xxxxxyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxyz_0[j] - tg_xxxxx_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxx_xxxxyz_1[j];

                    tg_xxxxxxx_xxxxxzz_0[j] = pb_x * tg_xxxxxx_xxxxxzz_0[j] + fr * tg_xxxxxx_xxxxxzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxxzz_0[j] - tg_xxxxx_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxx_xxxxzz_1[j];

                    tg_xxxxxxx_xxxxyyy_0[j] = pb_x * tg_xxxxxx_xxxxyyy_0[j] + fr * tg_xxxxxx_xxxxyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxyyy_0[j] - tg_xxxxx_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxx_xxxyyy_1[j];

                    tg_xxxxxxx_xxxxyyz_0[j] = pb_x * tg_xxxxxx_xxxxyyz_0[j] + fr * tg_xxxxxx_xxxxyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxyyz_0[j] - tg_xxxxx_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxx_xxxyyz_1[j];

                    tg_xxxxxxx_xxxxyzz_0[j] = pb_x * tg_xxxxxx_xxxxyzz_0[j] + fr * tg_xxxxxx_xxxxyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxyzz_0[j] - tg_xxxxx_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxx_xxxyzz_1[j];

                    tg_xxxxxxx_xxxxzzz_0[j] = pb_x * tg_xxxxxx_xxxxzzz_0[j] + fr * tg_xxxxxx_xxxxzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxxzzz_0[j] - tg_xxxxx_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxx_xxxzzz_1[j];

                    tg_xxxxxxx_xxxyyyy_0[j] = pb_x * tg_xxxxxx_xxxyyyy_0[j] + fr * tg_xxxxxx_xxxyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxyyyy_0[j] - tg_xxxxx_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxx_xxyyyy_1[j];

                    tg_xxxxxxx_xxxyyyz_0[j] = pb_x * tg_xxxxxx_xxxyyyz_0[j] + fr * tg_xxxxxx_xxxyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxyyyz_0[j] - tg_xxxxx_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxx_xxyyyz_1[j];

                    tg_xxxxxxx_xxxyyzz_0[j] = pb_x * tg_xxxxxx_xxxyyzz_0[j] + fr * tg_xxxxxx_xxxyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxyyzz_0[j] - tg_xxxxx_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxx_xxyyzz_1[j];

                    tg_xxxxxxx_xxxyzzz_0[j] = pb_x * tg_xxxxxx_xxxyzzz_0[j] + fr * tg_xxxxxx_xxxyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxyzzz_0[j] - tg_xxxxx_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxx_xxyzzz_1[j];

                    tg_xxxxxxx_xxxzzzz_0[j] = pb_x * tg_xxxxxx_xxxzzzz_0[j] + fr * tg_xxxxxx_xxxzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxxzzzz_0[j] - tg_xxxxx_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxx_xxzzzz_1[j];

                    tg_xxxxxxx_xxyyyyy_0[j] = pb_x * tg_xxxxxx_xxyyyyy_0[j] + fr * tg_xxxxxx_xxyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxyyyyy_0[j] - tg_xxxxx_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xyyyyy_1[j];

                    tg_xxxxxxx_xxyyyyz_0[j] = pb_x * tg_xxxxxx_xxyyyyz_0[j] + fr * tg_xxxxxx_xxyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxyyyyz_0[j] - tg_xxxxx_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xyyyyz_1[j];

                    tg_xxxxxxx_xxyyyzz_0[j] = pb_x * tg_xxxxxx_xxyyyzz_0[j] + fr * tg_xxxxxx_xxyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxyyyzz_0[j] - tg_xxxxx_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xyyyzz_1[j];

                    tg_xxxxxxx_xxyyzzz_0[j] = pb_x * tg_xxxxxx_xxyyzzz_0[j] + fr * tg_xxxxxx_xxyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxyyzzz_0[j] - tg_xxxxx_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xyyzzz_1[j];

                    tg_xxxxxxx_xxyzzzz_0[j] = pb_x * tg_xxxxxx_xxyzzzz_0[j] + fr * tg_xxxxxx_xxyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxyzzzz_0[j] - tg_xxxxx_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xyzzzz_1[j];

                    tg_xxxxxxx_xxzzzzz_0[j] = pb_x * tg_xxxxxx_xxzzzzz_0[j] + fr * tg_xxxxxx_xxzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xxzzzzz_0[j] - tg_xxxxx_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxx_xzzzzz_1[j];

                    tg_xxxxxxx_xyyyyyy_0[j] = pb_x * tg_xxxxxx_xyyyyyy_0[j] + fr * tg_xxxxxx_xyyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyyyyyy_0[j] - tg_xxxxx_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yyyyyy_1[j];

                    tg_xxxxxxx_xyyyyyz_0[j] = pb_x * tg_xxxxxx_xyyyyyz_0[j] + fr * tg_xxxxxx_xyyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyyyyyz_0[j] - tg_xxxxx_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yyyyyz_1[j];

                    tg_xxxxxxx_xyyyyzz_0[j] = pb_x * tg_xxxxxx_xyyyyzz_0[j] + fr * tg_xxxxxx_xyyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyyyyzz_0[j] - tg_xxxxx_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yyyyzz_1[j];

                    tg_xxxxxxx_xyyyzzz_0[j] = pb_x * tg_xxxxxx_xyyyzzz_0[j] + fr * tg_xxxxxx_xyyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyyyzzz_0[j] - tg_xxxxx_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yyyzzz_1[j];

                    tg_xxxxxxx_xyyzzzz_0[j] = pb_x * tg_xxxxxx_xyyzzzz_0[j] + fr * tg_xxxxxx_xyyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyyzzzz_0[j] - tg_xxxxx_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yyzzzz_1[j];

                    tg_xxxxxxx_xyzzzzz_0[j] = pb_x * tg_xxxxxx_xyzzzzz_0[j] + fr * tg_xxxxxx_xyzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xyzzzzz_0[j] - tg_xxxxx_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_yzzzzz_1[j];

                    tg_xxxxxxx_xzzzzzz_0[j] = pb_x * tg_xxxxxx_xzzzzzz_0[j] + fr * tg_xxxxxx_xzzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_xzzzzzz_0[j] - tg_xxxxx_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxx_zzzzzz_1[j];

                    tg_xxxxxxx_yyyyyyy_0[j] = pb_x * tg_xxxxxx_yyyyyyy_0[j] + fr * tg_xxxxxx_yyyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyyyyyy_0[j] - tg_xxxxx_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxx_yyyyyyz_0[j] = pb_x * tg_xxxxxx_yyyyyyz_0[j] + fr * tg_xxxxxx_yyyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyyyyyz_0[j] - tg_xxxxx_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxx_yyyyyzz_0[j] = pb_x * tg_xxxxxx_yyyyyzz_0[j] + fr * tg_xxxxxx_yyyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyyyyzz_0[j] - tg_xxxxx_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxx_yyyyzzz_0[j] = pb_x * tg_xxxxxx_yyyyzzz_0[j] + fr * tg_xxxxxx_yyyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyyyzzz_0[j] - tg_xxxxx_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxx_yyyzzzz_0[j] = pb_x * tg_xxxxxx_yyyzzzz_0[j] + fr * tg_xxxxxx_yyyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyyzzzz_0[j] - tg_xxxxx_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxx_yyzzzzz_0[j] = pb_x * tg_xxxxxx_yyzzzzz_0[j] + fr * tg_xxxxxx_yyzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yyzzzzz_0[j] - tg_xxxxx_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxx_yzzzzzz_0[j] = pb_x * tg_xxxxxx_yzzzzzz_0[j] + fr * tg_xxxxxx_yzzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_yzzzzzz_0[j] - tg_xxxxx_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxx_zzzzzzz_0[j] = pb_x * tg_xxxxxx_zzzzzzz_0[j] + fr * tg_xxxxxx_zzzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxx_zzzzzzz_0[j] - tg_xxxxx_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxy_xxxxxxx_0[j] = pb_x * tg_xxxxxy_xxxxxxx_0[j] + fr * tg_xxxxxy_xxxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxxx_0[j] - tg_xxxxy_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxxy_xxxxxx_1[j];

                    tg_xxxxxxy_xxxxxxy_0[j] = pb_x * tg_xxxxxy_xxxxxxy_0[j] + fr * tg_xxxxxy_xxxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxxy_0[j] - tg_xxxxy_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxy_xxxxxy_1[j];

                    tg_xxxxxxy_xxxxxxz_0[j] = pb_x * tg_xxxxxy_xxxxxxz_0[j] + fr * tg_xxxxxy_xxxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxxz_0[j] - tg_xxxxy_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxy_xxxxxz_1[j];

                    tg_xxxxxxy_xxxxxyy_0[j] = pb_x * tg_xxxxxy_xxxxxyy_0[j] + fr * tg_xxxxxy_xxxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxyy_0[j] - tg_xxxxy_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxy_xxxxyy_1[j];

                    tg_xxxxxxy_xxxxxyz_0[j] = pb_x * tg_xxxxxy_xxxxxyz_0[j] + fr * tg_xxxxxy_xxxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxyz_0[j] - tg_xxxxy_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxy_xxxxyz_1[j];

                    tg_xxxxxxy_xxxxxzz_0[j] = pb_x * tg_xxxxxy_xxxxxzz_0[j] + fr * tg_xxxxxy_xxxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxxzz_0[j] - tg_xxxxy_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxy_xxxxzz_1[j];

                    tg_xxxxxxy_xxxxyyy_0[j] = pb_x * tg_xxxxxy_xxxxyyy_0[j] + fr * tg_xxxxxy_xxxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxyyy_0[j] - tg_xxxxy_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxy_xxxyyy_1[j];

                    tg_xxxxxxy_xxxxyyz_0[j] = pb_x * tg_xxxxxy_xxxxyyz_0[j] + fr * tg_xxxxxy_xxxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxyyz_0[j] - tg_xxxxy_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxy_xxxyyz_1[j];

                    tg_xxxxxxy_xxxxyzz_0[j] = pb_x * tg_xxxxxy_xxxxyzz_0[j] + fr * tg_xxxxxy_xxxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxyzz_0[j] - tg_xxxxy_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxy_xxxyzz_1[j];

                    tg_xxxxxxy_xxxxzzz_0[j] = pb_x * tg_xxxxxy_xxxxzzz_0[j] + fr * tg_xxxxxy_xxxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxxzzz_0[j] - tg_xxxxy_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxy_xxxzzz_1[j];

                    tg_xxxxxxy_xxxyyyy_0[j] = pb_x * tg_xxxxxy_xxxyyyy_0[j] + fr * tg_xxxxxy_xxxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxyyyy_0[j] - tg_xxxxy_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxy_xxyyyy_1[j];

                    tg_xxxxxxy_xxxyyyz_0[j] = pb_x * tg_xxxxxy_xxxyyyz_0[j] + fr * tg_xxxxxy_xxxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxyyyz_0[j] - tg_xxxxy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxy_xxyyyz_1[j];

                    tg_xxxxxxy_xxxyyzz_0[j] = pb_x * tg_xxxxxy_xxxyyzz_0[j] + fr * tg_xxxxxy_xxxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxyyzz_0[j] - tg_xxxxy_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxy_xxyyzz_1[j];

                    tg_xxxxxxy_xxxyzzz_0[j] = pb_x * tg_xxxxxy_xxxyzzz_0[j] + fr * tg_xxxxxy_xxxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxyzzz_0[j] - tg_xxxxy_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxy_xxyzzz_1[j];

                    tg_xxxxxxy_xxxzzzz_0[j] = pb_x * tg_xxxxxy_xxxzzzz_0[j] + fr * tg_xxxxxy_xxxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxxzzzz_0[j] - tg_xxxxy_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxy_xxzzzz_1[j];

                    tg_xxxxxxy_xxyyyyy_0[j] = pb_x * tg_xxxxxy_xxyyyyy_0[j] + fr * tg_xxxxxy_xxyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxyyyyy_0[j] - tg_xxxxy_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xyyyyy_1[j];

                    tg_xxxxxxy_xxyyyyz_0[j] = pb_x * tg_xxxxxy_xxyyyyz_0[j] + fr * tg_xxxxxy_xxyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxyyyyz_0[j] - tg_xxxxy_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xyyyyz_1[j];

                    tg_xxxxxxy_xxyyyzz_0[j] = pb_x * tg_xxxxxy_xxyyyzz_0[j] + fr * tg_xxxxxy_xxyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxyyyzz_0[j] - tg_xxxxy_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xyyyzz_1[j];

                    tg_xxxxxxy_xxyyzzz_0[j] = pb_x * tg_xxxxxy_xxyyzzz_0[j] + fr * tg_xxxxxy_xxyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxyyzzz_0[j] - tg_xxxxy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xyyzzz_1[j];

                    tg_xxxxxxy_xxyzzzz_0[j] = pb_x * tg_xxxxxy_xxyzzzz_0[j] + fr * tg_xxxxxy_xxyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxyzzzz_0[j] - tg_xxxxy_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xyzzzz_1[j];

                    tg_xxxxxxy_xxzzzzz_0[j] = pb_x * tg_xxxxxy_xxzzzzz_0[j] + fr * tg_xxxxxy_xxzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xxzzzzz_0[j] - tg_xxxxy_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxy_xzzzzz_1[j];

                    tg_xxxxxxy_xyyyyyy_0[j] = pb_x * tg_xxxxxy_xyyyyyy_0[j] + fr * tg_xxxxxy_xyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyyyyyy_0[j] - tg_xxxxy_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yyyyyy_1[j];

                    tg_xxxxxxy_xyyyyyz_0[j] = pb_x * tg_xxxxxy_xyyyyyz_0[j] + fr * tg_xxxxxy_xyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyyyyyz_0[j] - tg_xxxxy_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yyyyyz_1[j];

                    tg_xxxxxxy_xyyyyzz_0[j] = pb_x * tg_xxxxxy_xyyyyzz_0[j] + fr * tg_xxxxxy_xyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyyyyzz_0[j] - tg_xxxxy_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yyyyzz_1[j];

                    tg_xxxxxxy_xyyyzzz_0[j] = pb_x * tg_xxxxxy_xyyyzzz_0[j] + fr * tg_xxxxxy_xyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyyyzzz_0[j] - tg_xxxxy_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yyyzzz_1[j];

                    tg_xxxxxxy_xyyzzzz_0[j] = pb_x * tg_xxxxxy_xyyzzzz_0[j] + fr * tg_xxxxxy_xyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyyzzzz_0[j] - tg_xxxxy_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yyzzzz_1[j];

                    tg_xxxxxxy_xyzzzzz_0[j] = pb_x * tg_xxxxxy_xyzzzzz_0[j] + fr * tg_xxxxxy_xyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xyzzzzz_0[j] - tg_xxxxy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_yzzzzz_1[j];

                    tg_xxxxxxy_xzzzzzz_0[j] = pb_x * tg_xxxxxy_xzzzzzz_0[j] + fr * tg_xxxxxy_xzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_xzzzzzz_0[j] - tg_xxxxy_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxy_zzzzzz_1[j];

                    tg_xxxxxxy_yyyyyyy_0[j] = pb_x * tg_xxxxxy_yyyyyyy_0[j] + fr * tg_xxxxxy_yyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyyyyyy_0[j] - tg_xxxxy_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxy_yyyyyyz_0[j] = pb_x * tg_xxxxxy_yyyyyyz_0[j] + fr * tg_xxxxxy_yyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyyyyyz_0[j] - tg_xxxxy_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxy_yyyyyzz_0[j] = pb_x * tg_xxxxxy_yyyyyzz_0[j] + fr * tg_xxxxxy_yyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyyyyzz_0[j] - tg_xxxxy_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxy_yyyyzzz_0[j] = pb_x * tg_xxxxxy_yyyyzzz_0[j] + fr * tg_xxxxxy_yyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyyyzzz_0[j] - tg_xxxxy_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxy_yyyzzzz_0[j] = pb_x * tg_xxxxxy_yyyzzzz_0[j] + fr * tg_xxxxxy_yyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyyzzzz_0[j] - tg_xxxxy_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxy_yyzzzzz_0[j] = pb_x * tg_xxxxxy_yyzzzzz_0[j] + fr * tg_xxxxxy_yyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yyzzzzz_0[j] - tg_xxxxy_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxy_yzzzzzz_0[j] = pb_x * tg_xxxxxy_yzzzzzz_0[j] + fr * tg_xxxxxy_yzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_yzzzzzz_0[j] - tg_xxxxy_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxy_zzzzzzz_0[j] = pb_x * tg_xxxxxy_zzzzzzz_0[j] + fr * tg_xxxxxy_zzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxy_zzzzzzz_0[j] - tg_xxxxy_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxz_xxxxxxx_0[j] = pb_x * tg_xxxxxz_xxxxxxx_0[j] + fr * tg_xxxxxz_xxxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxxx_0[j] - tg_xxxxz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxxz_xxxxxx_1[j];

                    tg_xxxxxxz_xxxxxxy_0[j] = pb_x * tg_xxxxxz_xxxxxxy_0[j] + fr * tg_xxxxxz_xxxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxxy_0[j] - tg_xxxxz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxz_xxxxxy_1[j];

                    tg_xxxxxxz_xxxxxxz_0[j] = pb_x * tg_xxxxxz_xxxxxxz_0[j] + fr * tg_xxxxxz_xxxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxxz_0[j] - tg_xxxxz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxz_xxxxxz_1[j];

                    tg_xxxxxxz_xxxxxyy_0[j] = pb_x * tg_xxxxxz_xxxxxyy_0[j] + fr * tg_xxxxxz_xxxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxyy_0[j] - tg_xxxxz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxz_xxxxyy_1[j];

                    tg_xxxxxxz_xxxxxyz_0[j] = pb_x * tg_xxxxxz_xxxxxyz_0[j] + fr * tg_xxxxxz_xxxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxyz_0[j] - tg_xxxxz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxz_xxxxyz_1[j];

                    tg_xxxxxxz_xxxxxzz_0[j] = pb_x * tg_xxxxxz_xxxxxzz_0[j] + fr * tg_xxxxxz_xxxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxxzz_0[j] - tg_xxxxz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxz_xxxxzz_1[j];

                    tg_xxxxxxz_xxxxyyy_0[j] = pb_x * tg_xxxxxz_xxxxyyy_0[j] + fr * tg_xxxxxz_xxxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxyyy_0[j] - tg_xxxxz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxz_xxxyyy_1[j];

                    tg_xxxxxxz_xxxxyyz_0[j] = pb_x * tg_xxxxxz_xxxxyyz_0[j] + fr * tg_xxxxxz_xxxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxyyz_0[j] - tg_xxxxz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxz_xxxyyz_1[j];

                    tg_xxxxxxz_xxxxyzz_0[j] = pb_x * tg_xxxxxz_xxxxyzz_0[j] + fr * tg_xxxxxz_xxxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxyzz_0[j] - tg_xxxxz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxz_xxxyzz_1[j];

                    tg_xxxxxxz_xxxxzzz_0[j] = pb_x * tg_xxxxxz_xxxxzzz_0[j] + fr * tg_xxxxxz_xxxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxxzzz_0[j] - tg_xxxxz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxz_xxxzzz_1[j];

                    tg_xxxxxxz_xxxyyyy_0[j] = pb_x * tg_xxxxxz_xxxyyyy_0[j] + fr * tg_xxxxxz_xxxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxyyyy_0[j] - tg_xxxxz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxz_xxyyyy_1[j];

                    tg_xxxxxxz_xxxyyyz_0[j] = pb_x * tg_xxxxxz_xxxyyyz_0[j] + fr * tg_xxxxxz_xxxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxyyyz_0[j] - tg_xxxxz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxz_xxyyyz_1[j];

                    tg_xxxxxxz_xxxyyzz_0[j] = pb_x * tg_xxxxxz_xxxyyzz_0[j] + fr * tg_xxxxxz_xxxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxyyzz_0[j] - tg_xxxxz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxz_xxyyzz_1[j];

                    tg_xxxxxxz_xxxyzzz_0[j] = pb_x * tg_xxxxxz_xxxyzzz_0[j] + fr * tg_xxxxxz_xxxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxyzzz_0[j] - tg_xxxxz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxz_xxyzzz_1[j];

                    tg_xxxxxxz_xxxzzzz_0[j] = pb_x * tg_xxxxxz_xxxzzzz_0[j] + fr * tg_xxxxxz_xxxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxxzzzz_0[j] - tg_xxxxz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxz_xxzzzz_1[j];

                    tg_xxxxxxz_xxyyyyy_0[j] = pb_x * tg_xxxxxz_xxyyyyy_0[j] + fr * tg_xxxxxz_xxyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxyyyyy_0[j] - tg_xxxxz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xyyyyy_1[j];

                    tg_xxxxxxz_xxyyyyz_0[j] = pb_x * tg_xxxxxz_xxyyyyz_0[j] + fr * tg_xxxxxz_xxyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxyyyyz_0[j] - tg_xxxxz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xyyyyz_1[j];

                    tg_xxxxxxz_xxyyyzz_0[j] = pb_x * tg_xxxxxz_xxyyyzz_0[j] + fr * tg_xxxxxz_xxyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxyyyzz_0[j] - tg_xxxxz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xyyyzz_1[j];

                    tg_xxxxxxz_xxyyzzz_0[j] = pb_x * tg_xxxxxz_xxyyzzz_0[j] + fr * tg_xxxxxz_xxyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxyyzzz_0[j] - tg_xxxxz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xyyzzz_1[j];

                    tg_xxxxxxz_xxyzzzz_0[j] = pb_x * tg_xxxxxz_xxyzzzz_0[j] + fr * tg_xxxxxz_xxyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxyzzzz_0[j] - tg_xxxxz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xyzzzz_1[j];

                    tg_xxxxxxz_xxzzzzz_0[j] = pb_x * tg_xxxxxz_xxzzzzz_0[j] + fr * tg_xxxxxz_xxzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xxzzzzz_0[j] - tg_xxxxz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxz_xzzzzz_1[j];

                    tg_xxxxxxz_xyyyyyy_0[j] = pb_x * tg_xxxxxz_xyyyyyy_0[j] + fr * tg_xxxxxz_xyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyyyyyy_0[j] - tg_xxxxz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yyyyyy_1[j];

                    tg_xxxxxxz_xyyyyyz_0[j] = pb_x * tg_xxxxxz_xyyyyyz_0[j] + fr * tg_xxxxxz_xyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyyyyyz_0[j] - tg_xxxxz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yyyyyz_1[j];

                    tg_xxxxxxz_xyyyyzz_0[j] = pb_x * tg_xxxxxz_xyyyyzz_0[j] + fr * tg_xxxxxz_xyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyyyyzz_0[j] - tg_xxxxz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yyyyzz_1[j];

                    tg_xxxxxxz_xyyyzzz_0[j] = pb_x * tg_xxxxxz_xyyyzzz_0[j] + fr * tg_xxxxxz_xyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyyyzzz_0[j] - tg_xxxxz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yyyzzz_1[j];

                    tg_xxxxxxz_xyyzzzz_0[j] = pb_x * tg_xxxxxz_xyyzzzz_0[j] + fr * tg_xxxxxz_xyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyyzzzz_0[j] - tg_xxxxz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yyzzzz_1[j];

                    tg_xxxxxxz_xyzzzzz_0[j] = pb_x * tg_xxxxxz_xyzzzzz_0[j] + fr * tg_xxxxxz_xyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xyzzzzz_0[j] - tg_xxxxz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_yzzzzz_1[j];

                    tg_xxxxxxz_xzzzzzz_0[j] = pb_x * tg_xxxxxz_xzzzzzz_0[j] + fr * tg_xxxxxz_xzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_xzzzzzz_0[j] - tg_xxxxz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxz_zzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_100_200(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (100,200)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 100); 

                auto tg_xxxxxz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 101); 

                auto tg_xxxxxz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 102); 

                auto tg_xxxxxz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 103); 

                auto tg_xxxxxz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 104); 

                auto tg_xxxxxz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 105); 

                auto tg_xxxxxz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 106); 

                auto tg_xxxxxz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 107); 

                auto tg_xxxxyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 108); 

                auto tg_xxxxyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 109); 

                auto tg_xxxxyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 110); 

                auto tg_xxxxyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 111); 

                auto tg_xxxxyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 112); 

                auto tg_xxxxyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 113); 

                auto tg_xxxxyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 114); 

                auto tg_xxxxyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 115); 

                auto tg_xxxxyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 116); 

                auto tg_xxxxyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 117); 

                auto tg_xxxxyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 118); 

                auto tg_xxxxyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 119); 

                auto tg_xxxxyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 120); 

                auto tg_xxxxyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 121); 

                auto tg_xxxxyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 122); 

                auto tg_xxxxyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 123); 

                auto tg_xxxxyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 124); 

                auto tg_xxxxyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 125); 

                auto tg_xxxxyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 126); 

                auto tg_xxxxyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 127); 

                auto tg_xxxxyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 128); 

                auto tg_xxxxyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 129); 

                auto tg_xxxxyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 130); 

                auto tg_xxxxyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 131); 

                auto tg_xxxxyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 132); 

                auto tg_xxxxyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 133); 

                auto tg_xxxxyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 134); 

                auto tg_xxxxyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 135); 

                auto tg_xxxxyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 136); 

                auto tg_xxxxyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 137); 

                auto tg_xxxxyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 138); 

                auto tg_xxxxyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 139); 

                auto tg_xxxxyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 140); 

                auto tg_xxxxyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 141); 

                auto tg_xxxxyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 142); 

                auto tg_xxxxyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 143); 

                auto tg_xxxxyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 144); 

                auto tg_xxxxyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 145); 

                auto tg_xxxxyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 146); 

                auto tg_xxxxyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 147); 

                auto tg_xxxxyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 148); 

                auto tg_xxxxyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 149); 

                auto tg_xxxxyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 150); 

                auto tg_xxxxyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 151); 

                auto tg_xxxxyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 152); 

                auto tg_xxxxyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 153); 

                auto tg_xxxxyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 154); 

                auto tg_xxxxyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 155); 

                auto tg_xxxxyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 156); 

                auto tg_xxxxyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 157); 

                auto tg_xxxxyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 158); 

                auto tg_xxxxyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 159); 

                auto tg_xxxxyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 160); 

                auto tg_xxxxyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 161); 

                auto tg_xxxxyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 162); 

                auto tg_xxxxyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 163); 

                auto tg_xxxxyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 164); 

                auto tg_xxxxyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 165); 

                auto tg_xxxxyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 166); 

                auto tg_xxxxyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 167); 

                auto tg_xxxxyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 168); 

                auto tg_xxxxyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 169); 

                auto tg_xxxxyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 170); 

                auto tg_xxxxyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 171); 

                auto tg_xxxxyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 172); 

                auto tg_xxxxyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 173); 

                auto tg_xxxxyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 174); 

                auto tg_xxxxyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 175); 

                auto tg_xxxxyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 176); 

                auto tg_xxxxyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 177); 

                auto tg_xxxxyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 178); 

                auto tg_xxxxyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 179); 

                auto tg_xxxxzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 180); 

                auto tg_xxxxzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 181); 

                auto tg_xxxxzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 182); 

                auto tg_xxxxzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 183); 

                auto tg_xxxxzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 184); 

                auto tg_xxxxzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 185); 

                auto tg_xxxxzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 186); 

                auto tg_xxxxzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 187); 

                auto tg_xxxxzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 188); 

                auto tg_xxxxzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 189); 

                auto tg_xxxxzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 190); 

                auto tg_xxxxzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 191); 

                auto tg_xxxxzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 192); 

                auto tg_xxxxzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 193); 

                auto tg_xxxxzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 194); 

                auto tg_xxxxzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 195); 

                auto tg_xxxxzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 196); 

                auto tg_xxxxzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 197); 

                auto tg_xxxxzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 198); 

                auto tg_xxxxzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 199); 

                auto tg_xxxxxz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 100); 

                auto tg_xxxxxz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 101); 

                auto tg_xxxxxz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 102); 

                auto tg_xxxxxz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 103); 

                auto tg_xxxxxz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 104); 

                auto tg_xxxxxz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 105); 

                auto tg_xxxxxz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 106); 

                auto tg_xxxxxz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 107); 

                auto tg_xxxxyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 108); 

                auto tg_xxxxyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 109); 

                auto tg_xxxxyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 110); 

                auto tg_xxxxyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 111); 

                auto tg_xxxxyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 112); 

                auto tg_xxxxyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 113); 

                auto tg_xxxxyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 114); 

                auto tg_xxxxyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 115); 

                auto tg_xxxxyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 116); 

                auto tg_xxxxyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 117); 

                auto tg_xxxxyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 118); 

                auto tg_xxxxyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 119); 

                auto tg_xxxxyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 120); 

                auto tg_xxxxyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 121); 

                auto tg_xxxxyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 122); 

                auto tg_xxxxyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 123); 

                auto tg_xxxxyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 124); 

                auto tg_xxxxyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 125); 

                auto tg_xxxxyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 126); 

                auto tg_xxxxyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 127); 

                auto tg_xxxxyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 128); 

                auto tg_xxxxyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 129); 

                auto tg_xxxxyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 130); 

                auto tg_xxxxyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 131); 

                auto tg_xxxxyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 132); 

                auto tg_xxxxyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 133); 

                auto tg_xxxxyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 134); 

                auto tg_xxxxyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 135); 

                auto tg_xxxxyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 136); 

                auto tg_xxxxyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 137); 

                auto tg_xxxxyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 138); 

                auto tg_xxxxyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 139); 

                auto tg_xxxxyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 140); 

                auto tg_xxxxyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 141); 

                auto tg_xxxxyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 142); 

                auto tg_xxxxyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 143); 

                auto tg_xxxxyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 144); 

                auto tg_xxxxyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 145); 

                auto tg_xxxxyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 146); 

                auto tg_xxxxyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 147); 

                auto tg_xxxxyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 148); 

                auto tg_xxxxyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 149); 

                auto tg_xxxxyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 150); 

                auto tg_xxxxyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 151); 

                auto tg_xxxxyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 152); 

                auto tg_xxxxyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 153); 

                auto tg_xxxxyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 154); 

                auto tg_xxxxyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 155); 

                auto tg_xxxxyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 156); 

                auto tg_xxxxyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 157); 

                auto tg_xxxxyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 158); 

                auto tg_xxxxyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 159); 

                auto tg_xxxxyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 160); 

                auto tg_xxxxyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 161); 

                auto tg_xxxxyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 162); 

                auto tg_xxxxyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 163); 

                auto tg_xxxxyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 164); 

                auto tg_xxxxyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 165); 

                auto tg_xxxxyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 166); 

                auto tg_xxxxyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 167); 

                auto tg_xxxxyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 168); 

                auto tg_xxxxyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 169); 

                auto tg_xxxxyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 170); 

                auto tg_xxxxyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 171); 

                auto tg_xxxxyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 172); 

                auto tg_xxxxyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 173); 

                auto tg_xxxxyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 174); 

                auto tg_xxxxyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 175); 

                auto tg_xxxxyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 176); 

                auto tg_xxxxyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 177); 

                auto tg_xxxxyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 178); 

                auto tg_xxxxyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 179); 

                auto tg_xxxxzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 180); 

                auto tg_xxxxzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 181); 

                auto tg_xxxxzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 182); 

                auto tg_xxxxzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 183); 

                auto tg_xxxxzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 184); 

                auto tg_xxxxzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 185); 

                auto tg_xxxxzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 186); 

                auto tg_xxxxzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 187); 

                auto tg_xxxxzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 188); 

                auto tg_xxxxzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 189); 

                auto tg_xxxxzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 190); 

                auto tg_xxxxzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 191); 

                auto tg_xxxxzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 192); 

                auto tg_xxxxzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 193); 

                auto tg_xxxxzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 194); 

                auto tg_xxxxzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 195); 

                auto tg_xxxxzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 196); 

                auto tg_xxxxzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 197); 

                auto tg_xxxxzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 198); 

                auto tg_xxxxzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 199); 

                auto tg_xxxxz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 100); 

                auto tg_xxxxz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 101); 

                auto tg_xxxxz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 102); 

                auto tg_xxxxz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 103); 

                auto tg_xxxxz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 104); 

                auto tg_xxxxz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 105); 

                auto tg_xxxxz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 106); 

                auto tg_xxxxz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 107); 

                auto tg_xxxyy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 108); 

                auto tg_xxxyy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 109); 

                auto tg_xxxyy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 110); 

                auto tg_xxxyy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 111); 

                auto tg_xxxyy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 112); 

                auto tg_xxxyy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 113); 

                auto tg_xxxyy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 114); 

                auto tg_xxxyy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 115); 

                auto tg_xxxyy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 116); 

                auto tg_xxxyy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 117); 

                auto tg_xxxyy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 118); 

                auto tg_xxxyy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 119); 

                auto tg_xxxyy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 120); 

                auto tg_xxxyy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 121); 

                auto tg_xxxyy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 122); 

                auto tg_xxxyy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 123); 

                auto tg_xxxyy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 124); 

                auto tg_xxxyy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 125); 

                auto tg_xxxyy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 126); 

                auto tg_xxxyy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 127); 

                auto tg_xxxyy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 128); 

                auto tg_xxxyy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 129); 

                auto tg_xxxyy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 130); 

                auto tg_xxxyy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 131); 

                auto tg_xxxyy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 132); 

                auto tg_xxxyy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 133); 

                auto tg_xxxyy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 134); 

                auto tg_xxxyy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 135); 

                auto tg_xxxyy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 136); 

                auto tg_xxxyy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 137); 

                auto tg_xxxyy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 138); 

                auto tg_xxxyy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 139); 

                auto tg_xxxyy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 140); 

                auto tg_xxxyy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 141); 

                auto tg_xxxyy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 142); 

                auto tg_xxxyy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 143); 

                auto tg_xxxyz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 144); 

                auto tg_xxxyz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 145); 

                auto tg_xxxyz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 146); 

                auto tg_xxxyz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 147); 

                auto tg_xxxyz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 148); 

                auto tg_xxxyz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 149); 

                auto tg_xxxyz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 150); 

                auto tg_xxxyz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 151); 

                auto tg_xxxyz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 152); 

                auto tg_xxxyz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 153); 

                auto tg_xxxyz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 154); 

                auto tg_xxxyz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 155); 

                auto tg_xxxyz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 156); 

                auto tg_xxxyz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 157); 

                auto tg_xxxyz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 158); 

                auto tg_xxxyz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 159); 

                auto tg_xxxyz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 160); 

                auto tg_xxxyz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 161); 

                auto tg_xxxyz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 162); 

                auto tg_xxxyz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 163); 

                auto tg_xxxyz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 164); 

                auto tg_xxxyz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 165); 

                auto tg_xxxyz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 166); 

                auto tg_xxxyz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 167); 

                auto tg_xxxyz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 168); 

                auto tg_xxxyz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 169); 

                auto tg_xxxyz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 170); 

                auto tg_xxxyz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 171); 

                auto tg_xxxyz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 172); 

                auto tg_xxxyz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 173); 

                auto tg_xxxyz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 174); 

                auto tg_xxxyz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 175); 

                auto tg_xxxyz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 176); 

                auto tg_xxxyz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 177); 

                auto tg_xxxyz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 178); 

                auto tg_xxxyz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 179); 

                auto tg_xxxzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 180); 

                auto tg_xxxzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 181); 

                auto tg_xxxzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 182); 

                auto tg_xxxzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 183); 

                auto tg_xxxzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 184); 

                auto tg_xxxzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 185); 

                auto tg_xxxzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 186); 

                auto tg_xxxzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 187); 

                auto tg_xxxzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 188); 

                auto tg_xxxzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 189); 

                auto tg_xxxzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 190); 

                auto tg_xxxzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 191); 

                auto tg_xxxzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 192); 

                auto tg_xxxzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 193); 

                auto tg_xxxzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 194); 

                auto tg_xxxzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 195); 

                auto tg_xxxzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 196); 

                auto tg_xxxzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 197); 

                auto tg_xxxzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 198); 

                auto tg_xxxzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 199); 

                auto tg_xxxxz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 100); 

                auto tg_xxxxz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 101); 

                auto tg_xxxxz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 102); 

                auto tg_xxxxz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 103); 

                auto tg_xxxxz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 104); 

                auto tg_xxxxz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 105); 

                auto tg_xxxxz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 106); 

                auto tg_xxxxz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 107); 

                auto tg_xxxyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 108); 

                auto tg_xxxyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 109); 

                auto tg_xxxyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 110); 

                auto tg_xxxyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 111); 

                auto tg_xxxyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 112); 

                auto tg_xxxyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 113); 

                auto tg_xxxyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 114); 

                auto tg_xxxyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 115); 

                auto tg_xxxyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 116); 

                auto tg_xxxyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 117); 

                auto tg_xxxyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 118); 

                auto tg_xxxyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 119); 

                auto tg_xxxyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 120); 

                auto tg_xxxyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 121); 

                auto tg_xxxyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 122); 

                auto tg_xxxyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 123); 

                auto tg_xxxyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 124); 

                auto tg_xxxyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 125); 

                auto tg_xxxyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 126); 

                auto tg_xxxyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 127); 

                auto tg_xxxyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 128); 

                auto tg_xxxyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 129); 

                auto tg_xxxyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 130); 

                auto tg_xxxyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 131); 

                auto tg_xxxyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 132); 

                auto tg_xxxyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 133); 

                auto tg_xxxyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 134); 

                auto tg_xxxyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 135); 

                auto tg_xxxyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 136); 

                auto tg_xxxyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 137); 

                auto tg_xxxyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 138); 

                auto tg_xxxyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 139); 

                auto tg_xxxyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 140); 

                auto tg_xxxyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 141); 

                auto tg_xxxyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 142); 

                auto tg_xxxyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 143); 

                auto tg_xxxyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 144); 

                auto tg_xxxyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 145); 

                auto tg_xxxyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 146); 

                auto tg_xxxyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 147); 

                auto tg_xxxyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 148); 

                auto tg_xxxyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 149); 

                auto tg_xxxyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 150); 

                auto tg_xxxyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 151); 

                auto tg_xxxyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 152); 

                auto tg_xxxyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 153); 

                auto tg_xxxyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 154); 

                auto tg_xxxyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 155); 

                auto tg_xxxyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 156); 

                auto tg_xxxyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 157); 

                auto tg_xxxyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 158); 

                auto tg_xxxyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 159); 

                auto tg_xxxyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 160); 

                auto tg_xxxyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 161); 

                auto tg_xxxyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 162); 

                auto tg_xxxyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 163); 

                auto tg_xxxyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 164); 

                auto tg_xxxyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 165); 

                auto tg_xxxyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 166); 

                auto tg_xxxyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 167); 

                auto tg_xxxyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 168); 

                auto tg_xxxyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 169); 

                auto tg_xxxyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 170); 

                auto tg_xxxyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 171); 

                auto tg_xxxyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 172); 

                auto tg_xxxyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 173); 

                auto tg_xxxyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 174); 

                auto tg_xxxyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 175); 

                auto tg_xxxyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 176); 

                auto tg_xxxyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 177); 

                auto tg_xxxyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 178); 

                auto tg_xxxyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 179); 

                auto tg_xxxzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 180); 

                auto tg_xxxzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 181); 

                auto tg_xxxzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 182); 

                auto tg_xxxzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 183); 

                auto tg_xxxzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 184); 

                auto tg_xxxzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 185); 

                auto tg_xxxzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 186); 

                auto tg_xxxzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 187); 

                auto tg_xxxzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 188); 

                auto tg_xxxzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 189); 

                auto tg_xxxzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 190); 

                auto tg_xxxzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 191); 

                auto tg_xxxzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 192); 

                auto tg_xxxzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 193); 

                auto tg_xxxzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 194); 

                auto tg_xxxzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 195); 

                auto tg_xxxzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 196); 

                auto tg_xxxzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 197); 

                auto tg_xxxzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 198); 

                auto tg_xxxzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 199); 

                auto tg_xxxxyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 84); 

                auto tg_xxxxyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 85); 

                auto tg_xxxxyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 86); 

                auto tg_xxxxyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 87); 

                auto tg_xxxxyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 88); 

                auto tg_xxxxyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 89); 

                auto tg_xxxxyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 90); 

                auto tg_xxxxyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 91); 

                auto tg_xxxxyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 92); 

                auto tg_xxxxyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 93); 

                auto tg_xxxxyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 94); 

                auto tg_xxxxyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 95); 

                auto tg_xxxxyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 96); 

                auto tg_xxxxyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 97); 

                auto tg_xxxxyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 98); 

                auto tg_xxxxyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 99); 

                auto tg_xxxxyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 100); 

                auto tg_xxxxyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 101); 

                auto tg_xxxxyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 102); 

                auto tg_xxxxyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 103); 

                auto tg_xxxxyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 104); 

                auto tg_xxxxyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 105); 

                auto tg_xxxxyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 106); 

                auto tg_xxxxyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 107); 

                auto tg_xxxxyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 108); 

                auto tg_xxxxyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 109); 

                auto tg_xxxxyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 110); 

                auto tg_xxxxyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 111); 

                auto tg_xxxxyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 112); 

                auto tg_xxxxyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 113); 

                auto tg_xxxxyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 114); 

                auto tg_xxxxyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 115); 

                auto tg_xxxxyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 116); 

                auto tg_xxxxyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 117); 

                auto tg_xxxxyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 118); 

                auto tg_xxxxyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 119); 

                auto tg_xxxxyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 120); 

                auto tg_xxxxyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 121); 

                auto tg_xxxxyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 122); 

                auto tg_xxxxyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 123); 

                auto tg_xxxxyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 124); 

                auto tg_xxxxyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 125); 

                auto tg_xxxxyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 126); 

                auto tg_xxxxyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 127); 

                auto tg_xxxxyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 128); 

                auto tg_xxxxyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 129); 

                auto tg_xxxxyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 130); 

                auto tg_xxxxyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 131); 

                auto tg_xxxxyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 132); 

                auto tg_xxxxyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 133); 

                auto tg_xxxxyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 134); 

                auto tg_xxxxyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 135); 

                auto tg_xxxxyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 136); 

                auto tg_xxxxyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 137); 

                auto tg_xxxxyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 138); 

                auto tg_xxxxyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 139); 

                auto tg_xxxxzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 140); 

                auto tg_xxxxzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 141); 

                auto tg_xxxxzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 142); 

                auto tg_xxxxzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 143); 

                auto tg_xxxxzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 144); 

                auto tg_xxxxzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 145); 

                auto tg_xxxxzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 146); 

                auto tg_xxxxzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 147); 

                auto tg_xxxxzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 148); 

                auto tg_xxxxzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 149); 

                auto tg_xxxxzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 150); 

                auto tg_xxxxzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 151); 

                auto tg_xxxxzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 152); 

                auto tg_xxxxzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 153); 

                auto tg_xxxxzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 154); 

                auto tg_xxxxzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 155); 

                auto tg_xxxxzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 156); 

                auto tg_xxxxzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 157); 

                auto tg_xxxxzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 158); 

                auto tg_xxxxzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 159); 

                // set up pointers to integrals

                auto tg_xxxxxxz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 100); 

                auto tg_xxxxxxz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 101); 

                auto tg_xxxxxxz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 102); 

                auto tg_xxxxxxz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 103); 

                auto tg_xxxxxxz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 104); 

                auto tg_xxxxxxz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 105); 

                auto tg_xxxxxxz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 106); 

                auto tg_xxxxxxz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 107); 

                auto tg_xxxxxyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 108); 

                auto tg_xxxxxyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 109); 

                auto tg_xxxxxyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 110); 

                auto tg_xxxxxyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 111); 

                auto tg_xxxxxyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 112); 

                auto tg_xxxxxyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 113); 

                auto tg_xxxxxyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 114); 

                auto tg_xxxxxyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 115); 

                auto tg_xxxxxyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 116); 

                auto tg_xxxxxyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 117); 

                auto tg_xxxxxyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 118); 

                auto tg_xxxxxyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 119); 

                auto tg_xxxxxyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 120); 

                auto tg_xxxxxyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 121); 

                auto tg_xxxxxyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 122); 

                auto tg_xxxxxyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 123); 

                auto tg_xxxxxyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 124); 

                auto tg_xxxxxyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 125); 

                auto tg_xxxxxyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 126); 

                auto tg_xxxxxyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 127); 

                auto tg_xxxxxyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 128); 

                auto tg_xxxxxyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 129); 

                auto tg_xxxxxyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 130); 

                auto tg_xxxxxyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 131); 

                auto tg_xxxxxyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 132); 

                auto tg_xxxxxyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 133); 

                auto tg_xxxxxyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 134); 

                auto tg_xxxxxyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 135); 

                auto tg_xxxxxyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 136); 

                auto tg_xxxxxyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 137); 

                auto tg_xxxxxyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 138); 

                auto tg_xxxxxyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 139); 

                auto tg_xxxxxyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 140); 

                auto tg_xxxxxyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 141); 

                auto tg_xxxxxyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 142); 

                auto tg_xxxxxyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 143); 

                auto tg_xxxxxyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 144); 

                auto tg_xxxxxyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 145); 

                auto tg_xxxxxyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 146); 

                auto tg_xxxxxyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 147); 

                auto tg_xxxxxyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 148); 

                auto tg_xxxxxyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 149); 

                auto tg_xxxxxyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 150); 

                auto tg_xxxxxyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 151); 

                auto tg_xxxxxyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 152); 

                auto tg_xxxxxyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 153); 

                auto tg_xxxxxyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 154); 

                auto tg_xxxxxyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 155); 

                auto tg_xxxxxyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 156); 

                auto tg_xxxxxyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 157); 

                auto tg_xxxxxyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 158); 

                auto tg_xxxxxyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 159); 

                auto tg_xxxxxyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 160); 

                auto tg_xxxxxyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 161); 

                auto tg_xxxxxyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 162); 

                auto tg_xxxxxyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 163); 

                auto tg_xxxxxyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 164); 

                auto tg_xxxxxyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 165); 

                auto tg_xxxxxyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 166); 

                auto tg_xxxxxyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 167); 

                auto tg_xxxxxyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 168); 

                auto tg_xxxxxyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 169); 

                auto tg_xxxxxyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 170); 

                auto tg_xxxxxyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 171); 

                auto tg_xxxxxyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 172); 

                auto tg_xxxxxyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 173); 

                auto tg_xxxxxyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 174); 

                auto tg_xxxxxyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 175); 

                auto tg_xxxxxyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 176); 

                auto tg_xxxxxyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 177); 

                auto tg_xxxxxyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 178); 

                auto tg_xxxxxyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 179); 

                auto tg_xxxxxzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 180); 

                auto tg_xxxxxzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 181); 

                auto tg_xxxxxzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 182); 

                auto tg_xxxxxzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 183); 

                auto tg_xxxxxzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 184); 

                auto tg_xxxxxzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 185); 

                auto tg_xxxxxzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 186); 

                auto tg_xxxxxzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 187); 

                auto tg_xxxxxzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 188); 

                auto tg_xxxxxzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 189); 

                auto tg_xxxxxzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 190); 

                auto tg_xxxxxzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 191); 

                auto tg_xxxxxzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 192); 

                auto tg_xxxxxzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 193); 

                auto tg_xxxxxzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 194); 

                auto tg_xxxxxzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 195); 

                auto tg_xxxxxzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 196); 

                auto tg_xxxxxzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 197); 

                auto tg_xxxxxzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 198); 

                auto tg_xxxxxzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 199); 

                // Batch of Integrals (100,200)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxxz_yyyyyyy_0, tg_xxxxxxz_yyyyyyz_0, \
                                         tg_xxxxxxz_yyyyyzz_0, tg_xxxxxxz_yyyyzzz_0, tg_xxxxxxz_yyyzzzz_0, tg_xxxxxxz_yyzzzzz_0, \
                                         tg_xxxxxxz_yzzzzzz_0, tg_xxxxxxz_zzzzzzz_0, tg_xxxxxyy_xxxxxxx_0, tg_xxxxxyy_xxxxxxy_0, \
                                         tg_xxxxxyy_xxxxxxz_0, tg_xxxxxyy_xxxxxyy_0, tg_xxxxxyy_xxxxxyz_0, tg_xxxxxyy_xxxxxzz_0, \
                                         tg_xxxxxyy_xxxxyyy_0, tg_xxxxxyy_xxxxyyz_0, tg_xxxxxyy_xxxxyzz_0, tg_xxxxxyy_xxxxzzz_0, \
                                         tg_xxxxxyy_xxxyyyy_0, tg_xxxxxyy_xxxyyyz_0, tg_xxxxxyy_xxxyyzz_0, tg_xxxxxyy_xxxyzzz_0, \
                                         tg_xxxxxyy_xxxzzzz_0, tg_xxxxxyy_xxyyyyy_0, tg_xxxxxyy_xxyyyyz_0, tg_xxxxxyy_xxyyyzz_0, \
                                         tg_xxxxxyy_xxyyzzz_0, tg_xxxxxyy_xxyzzzz_0, tg_xxxxxyy_xxzzzzz_0, tg_xxxxxyy_xyyyyyy_0, \
                                         tg_xxxxxyy_xyyyyyz_0, tg_xxxxxyy_xyyyyzz_0, tg_xxxxxyy_xyyyzzz_0, tg_xxxxxyy_xyyzzzz_0, \
                                         tg_xxxxxyy_xyzzzzz_0, tg_xxxxxyy_xzzzzzz_0, tg_xxxxxyy_yyyyyyy_0, tg_xxxxxyy_yyyyyyz_0, \
                                         tg_xxxxxyy_yyyyyzz_0, tg_xxxxxyy_yyyyzzz_0, tg_xxxxxyy_yyyzzzz_0, tg_xxxxxyy_yyzzzzz_0, \
                                         tg_xxxxxyy_yzzzzzz_0, tg_xxxxxyy_zzzzzzz_0, tg_xxxxxyz_xxxxxxx_0, tg_xxxxxyz_xxxxxxy_0, \
                                         tg_xxxxxyz_xxxxxxz_0, tg_xxxxxyz_xxxxxyy_0, tg_xxxxxyz_xxxxxyz_0, tg_xxxxxyz_xxxxxzz_0, \
                                         tg_xxxxxyz_xxxxyyy_0, tg_xxxxxyz_xxxxyyz_0, tg_xxxxxyz_xxxxyzz_0, tg_xxxxxyz_xxxxzzz_0, \
                                         tg_xxxxxyz_xxxyyyy_0, tg_xxxxxyz_xxxyyyz_0, tg_xxxxxyz_xxxyyzz_0, tg_xxxxxyz_xxxyzzz_0, \
                                         tg_xxxxxyz_xxxzzzz_0, tg_xxxxxyz_xxyyyyy_0, tg_xxxxxyz_xxyyyyz_0, tg_xxxxxyz_xxyyyzz_0, \
                                         tg_xxxxxyz_xxyyzzz_0, tg_xxxxxyz_xxyzzzz_0, tg_xxxxxyz_xxzzzzz_0, tg_xxxxxyz_xyyyyyy_0, \
                                         tg_xxxxxyz_xyyyyyz_0, tg_xxxxxyz_xyyyyzz_0, tg_xxxxxyz_xyyyzzz_0, tg_xxxxxyz_xyyzzzz_0, \
                                         tg_xxxxxyz_xyzzzzz_0, tg_xxxxxyz_xzzzzzz_0, tg_xxxxxyz_yyyyyyy_0, tg_xxxxxyz_yyyyyyz_0, \
                                         tg_xxxxxyz_yyyyyzz_0, tg_xxxxxyz_yyyyzzz_0, tg_xxxxxyz_yyyzzzz_0, tg_xxxxxyz_yyzzzzz_0, \
                                         tg_xxxxxyz_yzzzzzz_0, tg_xxxxxyz_zzzzzzz_0, tg_xxxxxz_yyyyyyy_0, tg_xxxxxz_yyyyyyy_1, \
                                         tg_xxxxxz_yyyyyyz_0, tg_xxxxxz_yyyyyyz_1, tg_xxxxxz_yyyyyzz_0, tg_xxxxxz_yyyyyzz_1, \
                                         tg_xxxxxz_yyyyzzz_0, tg_xxxxxz_yyyyzzz_1, tg_xxxxxz_yyyzzzz_0, tg_xxxxxz_yyyzzzz_1, \
                                         tg_xxxxxz_yyzzzzz_0, tg_xxxxxz_yyzzzzz_1, tg_xxxxxz_yzzzzzz_0, tg_xxxxxz_yzzzzzz_1, \
                                         tg_xxxxxz_zzzzzzz_0, tg_xxxxxz_zzzzzzz_1, tg_xxxxxzz_xxxxxxx_0, tg_xxxxxzz_xxxxxxy_0, \
                                         tg_xxxxxzz_xxxxxxz_0, tg_xxxxxzz_xxxxxyy_0, tg_xxxxxzz_xxxxxyz_0, tg_xxxxxzz_xxxxxzz_0, \
                                         tg_xxxxxzz_xxxxyyy_0, tg_xxxxxzz_xxxxyyz_0, tg_xxxxxzz_xxxxyzz_0, tg_xxxxxzz_xxxxzzz_0, \
                                         tg_xxxxxzz_xxxyyyy_0, tg_xxxxxzz_xxxyyyz_0, tg_xxxxxzz_xxxyyzz_0, tg_xxxxxzz_xxxyzzz_0, \
                                         tg_xxxxxzz_xxxzzzz_0, tg_xxxxxzz_xxyyyyy_0, tg_xxxxxzz_xxyyyyz_0, tg_xxxxxzz_xxyyyzz_0, \
                                         tg_xxxxxzz_xxyyzzz_0, tg_xxxxxzz_xxyzzzz_0, tg_xxxxyy_xxxxxx_1, tg_xxxxyy_xxxxxxx_0, \
                                         tg_xxxxyy_xxxxxxx_1, tg_xxxxyy_xxxxxxy_0, tg_xxxxyy_xxxxxxy_1, tg_xxxxyy_xxxxxxz_0, \
                                         tg_xxxxyy_xxxxxxz_1, tg_xxxxyy_xxxxxy_1, tg_xxxxyy_xxxxxyy_0, tg_xxxxyy_xxxxxyy_1, \
                                         tg_xxxxyy_xxxxxyz_0, tg_xxxxyy_xxxxxyz_1, tg_xxxxyy_xxxxxz_1, tg_xxxxyy_xxxxxzz_0, \
                                         tg_xxxxyy_xxxxxzz_1, tg_xxxxyy_xxxxyy_1, tg_xxxxyy_xxxxyyy_0, tg_xxxxyy_xxxxyyy_1, \
                                         tg_xxxxyy_xxxxyyz_0, tg_xxxxyy_xxxxyyz_1, tg_xxxxyy_xxxxyz_1, tg_xxxxyy_xxxxyzz_0, \
                                         tg_xxxxyy_xxxxyzz_1, tg_xxxxyy_xxxxzz_1, tg_xxxxyy_xxxxzzz_0, tg_xxxxyy_xxxxzzz_1, \
                                         tg_xxxxyy_xxxyyy_1, tg_xxxxyy_xxxyyyy_0, tg_xxxxyy_xxxyyyy_1, tg_xxxxyy_xxxyyyz_0, \
                                         tg_xxxxyy_xxxyyyz_1, tg_xxxxyy_xxxyyz_1, tg_xxxxyy_xxxyyzz_0, tg_xxxxyy_xxxyyzz_1, \
                                         tg_xxxxyy_xxxyzz_1, tg_xxxxyy_xxxyzzz_0, tg_xxxxyy_xxxyzzz_1, tg_xxxxyy_xxxzzz_1, \
                                         tg_xxxxyy_xxxzzzz_0, tg_xxxxyy_xxxzzzz_1, tg_xxxxyy_xxyyyy_1, tg_xxxxyy_xxyyyyy_0, \
                                         tg_xxxxyy_xxyyyyy_1, tg_xxxxyy_xxyyyyz_0, tg_xxxxyy_xxyyyyz_1, tg_xxxxyy_xxyyyz_1, \
                                         tg_xxxxyy_xxyyyzz_0, tg_xxxxyy_xxyyyzz_1, tg_xxxxyy_xxyyzz_1, tg_xxxxyy_xxyyzzz_0, \
                                         tg_xxxxyy_xxyyzzz_1, tg_xxxxyy_xxyzzz_1, tg_xxxxyy_xxyzzzz_0, tg_xxxxyy_xxyzzzz_1, \
                                         tg_xxxxyy_xxzzzz_1, tg_xxxxyy_xxzzzzz_0, tg_xxxxyy_xxzzzzz_1, tg_xxxxyy_xyyyyy_1, \
                                         tg_xxxxyy_xyyyyyy_0, tg_xxxxyy_xyyyyyy_1, tg_xxxxyy_xyyyyyz_0, tg_xxxxyy_xyyyyyz_1, \
                                         tg_xxxxyy_xyyyyz_1, tg_xxxxyy_xyyyyzz_0, tg_xxxxyy_xyyyyzz_1, tg_xxxxyy_xyyyzz_1, \
                                         tg_xxxxyy_xyyyzzz_0, tg_xxxxyy_xyyyzzz_1, tg_xxxxyy_xyyzzz_1, tg_xxxxyy_xyyzzzz_0, \
                                         tg_xxxxyy_xyyzzzz_1, tg_xxxxyy_xyzzzz_1, tg_xxxxyy_xyzzzzz_0, tg_xxxxyy_xyzzzzz_1, \
                                         tg_xxxxyy_xzzzzz_1, tg_xxxxyy_xzzzzzz_0, tg_xxxxyy_xzzzzzz_1, tg_xxxxyy_yyyyyy_1, \
                                         tg_xxxxyy_yyyyyyy_0, tg_xxxxyy_yyyyyyy_1, tg_xxxxyy_yyyyyyz_0, tg_xxxxyy_yyyyyyz_1, \
                                         tg_xxxxyy_yyyyyz_1, tg_xxxxyy_yyyyyzz_0, tg_xxxxyy_yyyyyzz_1, tg_xxxxyy_yyyyzz_1, \
                                         tg_xxxxyy_yyyyzzz_0, tg_xxxxyy_yyyyzzz_1, tg_xxxxyy_yyyzzz_1, tg_xxxxyy_yyyzzzz_0, \
                                         tg_xxxxyy_yyyzzzz_1, tg_xxxxyy_yyzzzz_1, tg_xxxxyy_yyzzzzz_0, tg_xxxxyy_yyzzzzz_1, \
                                         tg_xxxxyy_yzzzzz_1, tg_xxxxyy_yzzzzzz_0, tg_xxxxyy_yzzzzzz_1, tg_xxxxyy_zzzzzz_1, \
                                         tg_xxxxyy_zzzzzzz_0, tg_xxxxyy_zzzzzzz_1, tg_xxxxyz_xxxxxx_1, tg_xxxxyz_xxxxxxx_0, \
                                         tg_xxxxyz_xxxxxxx_1, tg_xxxxyz_xxxxxxy_0, tg_xxxxyz_xxxxxxy_1, tg_xxxxyz_xxxxxxz_0, \
                                         tg_xxxxyz_xxxxxxz_1, tg_xxxxyz_xxxxxy_1, tg_xxxxyz_xxxxxyy_0, tg_xxxxyz_xxxxxyy_1, \
                                         tg_xxxxyz_xxxxxyz_0, tg_xxxxyz_xxxxxyz_1, tg_xxxxyz_xxxxxz_1, tg_xxxxyz_xxxxxzz_0, \
                                         tg_xxxxyz_xxxxxzz_1, tg_xxxxyz_xxxxyy_1, tg_xxxxyz_xxxxyyy_0, tg_xxxxyz_xxxxyyy_1, \
                                         tg_xxxxyz_xxxxyyz_0, tg_xxxxyz_xxxxyyz_1, tg_xxxxyz_xxxxyz_1, tg_xxxxyz_xxxxyzz_0, \
                                         tg_xxxxyz_xxxxyzz_1, tg_xxxxyz_xxxxzz_1, tg_xxxxyz_xxxxzzz_0, tg_xxxxyz_xxxxzzz_1, \
                                         tg_xxxxyz_xxxyyy_1, tg_xxxxyz_xxxyyyy_0, tg_xxxxyz_xxxyyyy_1, tg_xxxxyz_xxxyyyz_0, \
                                         tg_xxxxyz_xxxyyyz_1, tg_xxxxyz_xxxyyz_1, tg_xxxxyz_xxxyyzz_0, tg_xxxxyz_xxxyyzz_1, \
                                         tg_xxxxyz_xxxyzz_1, tg_xxxxyz_xxxyzzz_0, tg_xxxxyz_xxxyzzz_1, tg_xxxxyz_xxxzzz_1, \
                                         tg_xxxxyz_xxxzzzz_0, tg_xxxxyz_xxxzzzz_1, tg_xxxxyz_xxyyyy_1, tg_xxxxyz_xxyyyyy_0, \
                                         tg_xxxxyz_xxyyyyy_1, tg_xxxxyz_xxyyyyz_0, tg_xxxxyz_xxyyyyz_1, tg_xxxxyz_xxyyyz_1, \
                                         tg_xxxxyz_xxyyyzz_0, tg_xxxxyz_xxyyyzz_1, tg_xxxxyz_xxyyzz_1, tg_xxxxyz_xxyyzzz_0, \
                                         tg_xxxxyz_xxyyzzz_1, tg_xxxxyz_xxyzzz_1, tg_xxxxyz_xxyzzzz_0, tg_xxxxyz_xxyzzzz_1, \
                                         tg_xxxxyz_xxzzzz_1, tg_xxxxyz_xxzzzzz_0, tg_xxxxyz_xxzzzzz_1, tg_xxxxyz_xyyyyy_1, \
                                         tg_xxxxyz_xyyyyyy_0, tg_xxxxyz_xyyyyyy_1, tg_xxxxyz_xyyyyyz_0, tg_xxxxyz_xyyyyyz_1, \
                                         tg_xxxxyz_xyyyyz_1, tg_xxxxyz_xyyyyzz_0, tg_xxxxyz_xyyyyzz_1, tg_xxxxyz_xyyyzz_1, \
                                         tg_xxxxyz_xyyyzzz_0, tg_xxxxyz_xyyyzzz_1, tg_xxxxyz_xyyzzz_1, tg_xxxxyz_xyyzzzz_0, \
                                         tg_xxxxyz_xyyzzzz_1, tg_xxxxyz_xyzzzz_1, tg_xxxxyz_xyzzzzz_0, tg_xxxxyz_xyzzzzz_1, \
                                         tg_xxxxyz_xzzzzz_1, tg_xxxxyz_xzzzzzz_0, tg_xxxxyz_xzzzzzz_1, tg_xxxxyz_yyyyyy_1, \
                                         tg_xxxxyz_yyyyyyy_0, tg_xxxxyz_yyyyyyy_1, tg_xxxxyz_yyyyyyz_0, tg_xxxxyz_yyyyyyz_1, \
                                         tg_xxxxyz_yyyyyz_1, tg_xxxxyz_yyyyyzz_0, tg_xxxxyz_yyyyyzz_1, tg_xxxxyz_yyyyzz_1, \
                                         tg_xxxxyz_yyyyzzz_0, tg_xxxxyz_yyyyzzz_1, tg_xxxxyz_yyyzzz_1, tg_xxxxyz_yyyzzzz_0, \
                                         tg_xxxxyz_yyyzzzz_1, tg_xxxxyz_yyzzzz_1, tg_xxxxyz_yyzzzzz_0, tg_xxxxyz_yyzzzzz_1, \
                                         tg_xxxxyz_yzzzzz_1, tg_xxxxyz_yzzzzzz_0, tg_xxxxyz_yzzzzzz_1, tg_xxxxyz_zzzzzz_1, \
                                         tg_xxxxyz_zzzzzzz_0, tg_xxxxyz_zzzzzzz_1, tg_xxxxz_yyyyyyy_0, tg_xxxxz_yyyyyyy_1, \
                                         tg_xxxxz_yyyyyyz_0, tg_xxxxz_yyyyyyz_1, tg_xxxxz_yyyyyzz_0, tg_xxxxz_yyyyyzz_1, \
                                         tg_xxxxz_yyyyzzz_0, tg_xxxxz_yyyyzzz_1, tg_xxxxz_yyyzzzz_0, tg_xxxxz_yyyzzzz_1, \
                                         tg_xxxxz_yyzzzzz_0, tg_xxxxz_yyzzzzz_1, tg_xxxxz_yzzzzzz_0, tg_xxxxz_yzzzzzz_1, \
                                         tg_xxxxz_zzzzzzz_0, tg_xxxxz_zzzzzzz_1, tg_xxxxzz_xxxxxx_1, tg_xxxxzz_xxxxxxx_0, \
                                         tg_xxxxzz_xxxxxxx_1, tg_xxxxzz_xxxxxxy_0, tg_xxxxzz_xxxxxxy_1, tg_xxxxzz_xxxxxxz_0, \
                                         tg_xxxxzz_xxxxxxz_1, tg_xxxxzz_xxxxxy_1, tg_xxxxzz_xxxxxyy_0, tg_xxxxzz_xxxxxyy_1, \
                                         tg_xxxxzz_xxxxxyz_0, tg_xxxxzz_xxxxxyz_1, tg_xxxxzz_xxxxxz_1, tg_xxxxzz_xxxxxzz_0, \
                                         tg_xxxxzz_xxxxxzz_1, tg_xxxxzz_xxxxyy_1, tg_xxxxzz_xxxxyyy_0, tg_xxxxzz_xxxxyyy_1, \
                                         tg_xxxxzz_xxxxyyz_0, tg_xxxxzz_xxxxyyz_1, tg_xxxxzz_xxxxyz_1, tg_xxxxzz_xxxxyzz_0, \
                                         tg_xxxxzz_xxxxyzz_1, tg_xxxxzz_xxxxzz_1, tg_xxxxzz_xxxxzzz_0, tg_xxxxzz_xxxxzzz_1, \
                                         tg_xxxxzz_xxxyyy_1, tg_xxxxzz_xxxyyyy_0, tg_xxxxzz_xxxyyyy_1, tg_xxxxzz_xxxyyyz_0, \
                                         tg_xxxxzz_xxxyyyz_1, tg_xxxxzz_xxxyyz_1, tg_xxxxzz_xxxyyzz_0, tg_xxxxzz_xxxyyzz_1, \
                                         tg_xxxxzz_xxxyzz_1, tg_xxxxzz_xxxyzzz_0, tg_xxxxzz_xxxyzzz_1, tg_xxxxzz_xxxzzz_1, \
                                         tg_xxxxzz_xxxzzzz_0, tg_xxxxzz_xxxzzzz_1, tg_xxxxzz_xxyyyy_1, tg_xxxxzz_xxyyyyy_0, \
                                         tg_xxxxzz_xxyyyyy_1, tg_xxxxzz_xxyyyyz_0, tg_xxxxzz_xxyyyyz_1, tg_xxxxzz_xxyyyz_1, \
                                         tg_xxxxzz_xxyyyzz_0, tg_xxxxzz_xxyyyzz_1, tg_xxxxzz_xxyyzz_1, tg_xxxxzz_xxyyzzz_0, \
                                         tg_xxxxzz_xxyyzzz_1, tg_xxxxzz_xxyzzz_1, tg_xxxxzz_xxyzzzz_0, tg_xxxxzz_xxyzzzz_1, \
                                         tg_xxxxzz_xxzzzz_1, tg_xxxxzz_xyyyyy_1, tg_xxxxzz_xyyyyz_1, tg_xxxxzz_xyyyzz_1, \
                                         tg_xxxxzz_xyyzzz_1, tg_xxxxzz_xyzzzz_1, tg_xxxyy_xxxxxxx_0, tg_xxxyy_xxxxxxx_1, \
                                         tg_xxxyy_xxxxxxy_0, tg_xxxyy_xxxxxxy_1, tg_xxxyy_xxxxxxz_0, tg_xxxyy_xxxxxxz_1, \
                                         tg_xxxyy_xxxxxyy_0, tg_xxxyy_xxxxxyy_1, tg_xxxyy_xxxxxyz_0, tg_xxxyy_xxxxxyz_1, \
                                         tg_xxxyy_xxxxxzz_0, tg_xxxyy_xxxxxzz_1, tg_xxxyy_xxxxyyy_0, tg_xxxyy_xxxxyyy_1, \
                                         tg_xxxyy_xxxxyyz_0, tg_xxxyy_xxxxyyz_1, tg_xxxyy_xxxxyzz_0, tg_xxxyy_xxxxyzz_1, \
                                         tg_xxxyy_xxxxzzz_0, tg_xxxyy_xxxxzzz_1, tg_xxxyy_xxxyyyy_0, tg_xxxyy_xxxyyyy_1, \
                                         tg_xxxyy_xxxyyyz_0, tg_xxxyy_xxxyyyz_1, tg_xxxyy_xxxyyzz_0, tg_xxxyy_xxxyyzz_1, \
                                         tg_xxxyy_xxxyzzz_0, tg_xxxyy_xxxyzzz_1, tg_xxxyy_xxxzzzz_0, tg_xxxyy_xxxzzzz_1, \
                                         tg_xxxyy_xxyyyyy_0, tg_xxxyy_xxyyyyy_1, tg_xxxyy_xxyyyyz_0, tg_xxxyy_xxyyyyz_1, \
                                         tg_xxxyy_xxyyyzz_0, tg_xxxyy_xxyyyzz_1, tg_xxxyy_xxyyzzz_0, tg_xxxyy_xxyyzzz_1, \
                                         tg_xxxyy_xxyzzzz_0, tg_xxxyy_xxyzzzz_1, tg_xxxyy_xxzzzzz_0, tg_xxxyy_xxzzzzz_1, \
                                         tg_xxxyy_xyyyyyy_0, tg_xxxyy_xyyyyyy_1, tg_xxxyy_xyyyyyz_0, tg_xxxyy_xyyyyyz_1, \
                                         tg_xxxyy_xyyyyzz_0, tg_xxxyy_xyyyyzz_1, tg_xxxyy_xyyyzzz_0, tg_xxxyy_xyyyzzz_1, \
                                         tg_xxxyy_xyyzzzz_0, tg_xxxyy_xyyzzzz_1, tg_xxxyy_xyzzzzz_0, tg_xxxyy_xyzzzzz_1, \
                                         tg_xxxyy_xzzzzzz_0, tg_xxxyy_xzzzzzz_1, tg_xxxyy_yyyyyyy_0, tg_xxxyy_yyyyyyy_1, \
                                         tg_xxxyy_yyyyyyz_0, tg_xxxyy_yyyyyyz_1, tg_xxxyy_yyyyyzz_0, tg_xxxyy_yyyyyzz_1, \
                                         tg_xxxyy_yyyyzzz_0, tg_xxxyy_yyyyzzz_1, tg_xxxyy_yyyzzzz_0, tg_xxxyy_yyyzzzz_1, \
                                         tg_xxxyy_yyzzzzz_0, tg_xxxyy_yyzzzzz_1, tg_xxxyy_yzzzzzz_0, tg_xxxyy_yzzzzzz_1, \
                                         tg_xxxyy_zzzzzzz_0, tg_xxxyy_zzzzzzz_1, tg_xxxyz_xxxxxxx_0, tg_xxxyz_xxxxxxx_1, \
                                         tg_xxxyz_xxxxxxy_0, tg_xxxyz_xxxxxxy_1, tg_xxxyz_xxxxxxz_0, tg_xxxyz_xxxxxxz_1, \
                                         tg_xxxyz_xxxxxyy_0, tg_xxxyz_xxxxxyy_1, tg_xxxyz_xxxxxyz_0, tg_xxxyz_xxxxxyz_1, \
                                         tg_xxxyz_xxxxxzz_0, tg_xxxyz_xxxxxzz_1, tg_xxxyz_xxxxyyy_0, tg_xxxyz_xxxxyyy_1, \
                                         tg_xxxyz_xxxxyyz_0, tg_xxxyz_xxxxyyz_1, tg_xxxyz_xxxxyzz_0, tg_xxxyz_xxxxyzz_1, \
                                         tg_xxxyz_xxxxzzz_0, tg_xxxyz_xxxxzzz_1, tg_xxxyz_xxxyyyy_0, tg_xxxyz_xxxyyyy_1, \
                                         tg_xxxyz_xxxyyyz_0, tg_xxxyz_xxxyyyz_1, tg_xxxyz_xxxyyzz_0, tg_xxxyz_xxxyyzz_1, \
                                         tg_xxxyz_xxxyzzz_0, tg_xxxyz_xxxyzzz_1, tg_xxxyz_xxxzzzz_0, tg_xxxyz_xxxzzzz_1, \
                                         tg_xxxyz_xxyyyyy_0, tg_xxxyz_xxyyyyy_1, tg_xxxyz_xxyyyyz_0, tg_xxxyz_xxyyyyz_1, \
                                         tg_xxxyz_xxyyyzz_0, tg_xxxyz_xxyyyzz_1, tg_xxxyz_xxyyzzz_0, tg_xxxyz_xxyyzzz_1, \
                                         tg_xxxyz_xxyzzzz_0, tg_xxxyz_xxyzzzz_1, tg_xxxyz_xxzzzzz_0, tg_xxxyz_xxzzzzz_1, \
                                         tg_xxxyz_xyyyyyy_0, tg_xxxyz_xyyyyyy_1, tg_xxxyz_xyyyyyz_0, tg_xxxyz_xyyyyyz_1, \
                                         tg_xxxyz_xyyyyzz_0, tg_xxxyz_xyyyyzz_1, tg_xxxyz_xyyyzzz_0, tg_xxxyz_xyyyzzz_1, \
                                         tg_xxxyz_xyyzzzz_0, tg_xxxyz_xyyzzzz_1, tg_xxxyz_xyzzzzz_0, tg_xxxyz_xyzzzzz_1, \
                                         tg_xxxyz_xzzzzzz_0, tg_xxxyz_xzzzzzz_1, tg_xxxyz_yyyyyyy_0, tg_xxxyz_yyyyyyy_1, \
                                         tg_xxxyz_yyyyyyz_0, tg_xxxyz_yyyyyyz_1, tg_xxxyz_yyyyyzz_0, tg_xxxyz_yyyyyzz_1, \
                                         tg_xxxyz_yyyyzzz_0, tg_xxxyz_yyyyzzz_1, tg_xxxyz_yyyzzzz_0, tg_xxxyz_yyyzzzz_1, \
                                         tg_xxxyz_yyzzzzz_0, tg_xxxyz_yyzzzzz_1, tg_xxxyz_yzzzzzz_0, tg_xxxyz_yzzzzzz_1, \
                                         tg_xxxyz_zzzzzzz_0, tg_xxxyz_zzzzzzz_1, tg_xxxzz_xxxxxxx_0, tg_xxxzz_xxxxxxx_1, \
                                         tg_xxxzz_xxxxxxy_0, tg_xxxzz_xxxxxxy_1, tg_xxxzz_xxxxxxz_0, tg_xxxzz_xxxxxxz_1, \
                                         tg_xxxzz_xxxxxyy_0, tg_xxxzz_xxxxxyy_1, tg_xxxzz_xxxxxyz_0, tg_xxxzz_xxxxxyz_1, \
                                         tg_xxxzz_xxxxxzz_0, tg_xxxzz_xxxxxzz_1, tg_xxxzz_xxxxyyy_0, tg_xxxzz_xxxxyyy_1, \
                                         tg_xxxzz_xxxxyyz_0, tg_xxxzz_xxxxyyz_1, tg_xxxzz_xxxxyzz_0, tg_xxxzz_xxxxyzz_1, \
                                         tg_xxxzz_xxxxzzz_0, tg_xxxzz_xxxxzzz_1, tg_xxxzz_xxxyyyy_0, tg_xxxzz_xxxyyyy_1, \
                                         tg_xxxzz_xxxyyyz_0, tg_xxxzz_xxxyyyz_1, tg_xxxzz_xxxyyzz_0, tg_xxxzz_xxxyyzz_1, \
                                         tg_xxxzz_xxxyzzz_0, tg_xxxzz_xxxyzzz_1, tg_xxxzz_xxxzzzz_0, tg_xxxzz_xxxzzzz_1, \
                                         tg_xxxzz_xxyyyyy_0, tg_xxxzz_xxyyyyy_1, tg_xxxzz_xxyyyyz_0, tg_xxxzz_xxyyyyz_1, \
                                         tg_xxxzz_xxyyyzz_0, tg_xxxzz_xxyyyzz_1, tg_xxxzz_xxyyzzz_0, tg_xxxzz_xxyyzzz_1, \
                                         tg_xxxzz_xxyzzzz_0, tg_xxxzz_xxyzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxz_yyyyyyy_0[j] = pb_x * tg_xxxxxz_yyyyyyy_0[j] + fr * tg_xxxxxz_yyyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyyyyyy_0[j] - tg_xxxxz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxz_yyyyyyz_0[j] = pb_x * tg_xxxxxz_yyyyyyz_0[j] + fr * tg_xxxxxz_yyyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyyyyyz_0[j] - tg_xxxxz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxz_yyyyyzz_0[j] = pb_x * tg_xxxxxz_yyyyyzz_0[j] + fr * tg_xxxxxz_yyyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyyyyzz_0[j] - tg_xxxxz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxz_yyyyzzz_0[j] = pb_x * tg_xxxxxz_yyyyzzz_0[j] + fr * tg_xxxxxz_yyyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyyyzzz_0[j] - tg_xxxxz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxz_yyyzzzz_0[j] = pb_x * tg_xxxxxz_yyyzzzz_0[j] + fr * tg_xxxxxz_yyyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyyzzzz_0[j] - tg_xxxxz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxz_yyzzzzz_0[j] = pb_x * tg_xxxxxz_yyzzzzz_0[j] + fr * tg_xxxxxz_yyzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yyzzzzz_0[j] - tg_xxxxz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxz_yzzzzzz_0[j] = pb_x * tg_xxxxxz_yzzzzzz_0[j] + fr * tg_xxxxxz_yzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_yzzzzzz_0[j] - tg_xxxxz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxz_zzzzzzz_0[j] = pb_x * tg_xxxxxz_zzzzzzz_0[j] + fr * tg_xxxxxz_zzzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxz_zzzzzzz_0[j] - tg_xxxxz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyy_xxxxxxx_0[j] = pb_x * tg_xxxxyy_xxxxxxx_0[j] + fr * tg_xxxxyy_xxxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxxx_0[j] - tg_xxxyy_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxyy_xxxxxx_1[j];

                    tg_xxxxxyy_xxxxxxy_0[j] = pb_x * tg_xxxxyy_xxxxxxy_0[j] + fr * tg_xxxxyy_xxxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxxy_0[j] - tg_xxxyy_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyy_xxxxxy_1[j];

                    tg_xxxxxyy_xxxxxxz_0[j] = pb_x * tg_xxxxyy_xxxxxxz_0[j] + fr * tg_xxxxyy_xxxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxxz_0[j] - tg_xxxyy_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyy_xxxxxz_1[j];

                    tg_xxxxxyy_xxxxxyy_0[j] = pb_x * tg_xxxxyy_xxxxxyy_0[j] + fr * tg_xxxxyy_xxxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxyy_0[j] - tg_xxxyy_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyy_xxxxyy_1[j];

                    tg_xxxxxyy_xxxxxyz_0[j] = pb_x * tg_xxxxyy_xxxxxyz_0[j] + fr * tg_xxxxyy_xxxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxyz_0[j] - tg_xxxyy_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyy_xxxxyz_1[j];

                    tg_xxxxxyy_xxxxxzz_0[j] = pb_x * tg_xxxxyy_xxxxxzz_0[j] + fr * tg_xxxxyy_xxxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxxzz_0[j] - tg_xxxyy_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyy_xxxxzz_1[j];

                    tg_xxxxxyy_xxxxyyy_0[j] = pb_x * tg_xxxxyy_xxxxyyy_0[j] + fr * tg_xxxxyy_xxxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxyyy_0[j] - tg_xxxyy_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyy_xxxyyy_1[j];

                    tg_xxxxxyy_xxxxyyz_0[j] = pb_x * tg_xxxxyy_xxxxyyz_0[j] + fr * tg_xxxxyy_xxxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxyyz_0[j] - tg_xxxyy_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyy_xxxyyz_1[j];

                    tg_xxxxxyy_xxxxyzz_0[j] = pb_x * tg_xxxxyy_xxxxyzz_0[j] + fr * tg_xxxxyy_xxxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxyzz_0[j] - tg_xxxyy_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyy_xxxyzz_1[j];

                    tg_xxxxxyy_xxxxzzz_0[j] = pb_x * tg_xxxxyy_xxxxzzz_0[j] + fr * tg_xxxxyy_xxxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxxzzz_0[j] - tg_xxxyy_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyy_xxxzzz_1[j];

                    tg_xxxxxyy_xxxyyyy_0[j] = pb_x * tg_xxxxyy_xxxyyyy_0[j] + fr * tg_xxxxyy_xxxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxyyyy_0[j] - tg_xxxyy_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyy_xxyyyy_1[j];

                    tg_xxxxxyy_xxxyyyz_0[j] = pb_x * tg_xxxxyy_xxxyyyz_0[j] + fr * tg_xxxxyy_xxxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxyyyz_0[j] - tg_xxxyy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyy_xxyyyz_1[j];

                    tg_xxxxxyy_xxxyyzz_0[j] = pb_x * tg_xxxxyy_xxxyyzz_0[j] + fr * tg_xxxxyy_xxxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxyyzz_0[j] - tg_xxxyy_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyy_xxyyzz_1[j];

                    tg_xxxxxyy_xxxyzzz_0[j] = pb_x * tg_xxxxyy_xxxyzzz_0[j] + fr * tg_xxxxyy_xxxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxyzzz_0[j] - tg_xxxyy_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyy_xxyzzz_1[j];

                    tg_xxxxxyy_xxxzzzz_0[j] = pb_x * tg_xxxxyy_xxxzzzz_0[j] + fr * tg_xxxxyy_xxxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxxzzzz_0[j] - tg_xxxyy_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyy_xxzzzz_1[j];

                    tg_xxxxxyy_xxyyyyy_0[j] = pb_x * tg_xxxxyy_xxyyyyy_0[j] + fr * tg_xxxxyy_xxyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxyyyyy_0[j] - tg_xxxyy_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xyyyyy_1[j];

                    tg_xxxxxyy_xxyyyyz_0[j] = pb_x * tg_xxxxyy_xxyyyyz_0[j] + fr * tg_xxxxyy_xxyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxyyyyz_0[j] - tg_xxxyy_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xyyyyz_1[j];

                    tg_xxxxxyy_xxyyyzz_0[j] = pb_x * tg_xxxxyy_xxyyyzz_0[j] + fr * tg_xxxxyy_xxyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxyyyzz_0[j] - tg_xxxyy_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xyyyzz_1[j];

                    tg_xxxxxyy_xxyyzzz_0[j] = pb_x * tg_xxxxyy_xxyyzzz_0[j] + fr * tg_xxxxyy_xxyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxyyzzz_0[j] - tg_xxxyy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xyyzzz_1[j];

                    tg_xxxxxyy_xxyzzzz_0[j] = pb_x * tg_xxxxyy_xxyzzzz_0[j] + fr * tg_xxxxyy_xxyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxyzzzz_0[j] - tg_xxxyy_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xyzzzz_1[j];

                    tg_xxxxxyy_xxzzzzz_0[j] = pb_x * tg_xxxxyy_xxzzzzz_0[j] + fr * tg_xxxxyy_xxzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xxzzzzz_0[j] - tg_xxxyy_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyy_xzzzzz_1[j];

                    tg_xxxxxyy_xyyyyyy_0[j] = pb_x * tg_xxxxyy_xyyyyyy_0[j] + fr * tg_xxxxyy_xyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyyyyyy_0[j] - tg_xxxyy_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yyyyyy_1[j];

                    tg_xxxxxyy_xyyyyyz_0[j] = pb_x * tg_xxxxyy_xyyyyyz_0[j] + fr * tg_xxxxyy_xyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyyyyyz_0[j] - tg_xxxyy_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yyyyyz_1[j];

                    tg_xxxxxyy_xyyyyzz_0[j] = pb_x * tg_xxxxyy_xyyyyzz_0[j] + fr * tg_xxxxyy_xyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyyyyzz_0[j] - tg_xxxyy_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yyyyzz_1[j];

                    tg_xxxxxyy_xyyyzzz_0[j] = pb_x * tg_xxxxyy_xyyyzzz_0[j] + fr * tg_xxxxyy_xyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyyyzzz_0[j] - tg_xxxyy_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yyyzzz_1[j];

                    tg_xxxxxyy_xyyzzzz_0[j] = pb_x * tg_xxxxyy_xyyzzzz_0[j] + fr * tg_xxxxyy_xyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyyzzzz_0[j] - tg_xxxyy_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yyzzzz_1[j];

                    tg_xxxxxyy_xyzzzzz_0[j] = pb_x * tg_xxxxyy_xyzzzzz_0[j] + fr * tg_xxxxyy_xyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xyzzzzz_0[j] - tg_xxxyy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_yzzzzz_1[j];

                    tg_xxxxxyy_xzzzzzz_0[j] = pb_x * tg_xxxxyy_xzzzzzz_0[j] + fr * tg_xxxxyy_xzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_xzzzzzz_0[j] - tg_xxxyy_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyy_zzzzzz_1[j];

                    tg_xxxxxyy_yyyyyyy_0[j] = pb_x * tg_xxxxyy_yyyyyyy_0[j] + fr * tg_xxxxyy_yyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyyyyyy_0[j] - tg_xxxyy_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxyy_yyyyyyz_0[j] = pb_x * tg_xxxxyy_yyyyyyz_0[j] + fr * tg_xxxxyy_yyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyyyyyz_0[j] - tg_xxxyy_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxyy_yyyyyzz_0[j] = pb_x * tg_xxxxyy_yyyyyzz_0[j] + fr * tg_xxxxyy_yyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyyyyzz_0[j] - tg_xxxyy_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxyy_yyyyzzz_0[j] = pb_x * tg_xxxxyy_yyyyzzz_0[j] + fr * tg_xxxxyy_yyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyyyzzz_0[j] - tg_xxxyy_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxyy_yyyzzzz_0[j] = pb_x * tg_xxxxyy_yyyzzzz_0[j] + fr * tg_xxxxyy_yyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyyzzzz_0[j] - tg_xxxyy_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxyy_yyzzzzz_0[j] = pb_x * tg_xxxxyy_yyzzzzz_0[j] + fr * tg_xxxxyy_yyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yyzzzzz_0[j] - tg_xxxyy_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyy_yzzzzzz_0[j] = pb_x * tg_xxxxyy_yzzzzzz_0[j] + fr * tg_xxxxyy_yzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_yzzzzzz_0[j] - tg_xxxyy_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyy_zzzzzzz_0[j] = pb_x * tg_xxxxyy_zzzzzzz_0[j] + fr * tg_xxxxyy_zzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyy_zzzzzzz_0[j] - tg_xxxyy_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyz_xxxxxxx_0[j] = pb_x * tg_xxxxyz_xxxxxxx_0[j] + fr * tg_xxxxyz_xxxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxxx_0[j] - tg_xxxyz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxyz_xxxxxx_1[j];

                    tg_xxxxxyz_xxxxxxy_0[j] = pb_x * tg_xxxxyz_xxxxxxy_0[j] + fr * tg_xxxxyz_xxxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxxy_0[j] - tg_xxxyz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyz_xxxxxy_1[j];

                    tg_xxxxxyz_xxxxxxz_0[j] = pb_x * tg_xxxxyz_xxxxxxz_0[j] + fr * tg_xxxxyz_xxxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxxz_0[j] - tg_xxxyz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyz_xxxxxz_1[j];

                    tg_xxxxxyz_xxxxxyy_0[j] = pb_x * tg_xxxxyz_xxxxxyy_0[j] + fr * tg_xxxxyz_xxxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxyy_0[j] - tg_xxxyz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyz_xxxxyy_1[j];

                    tg_xxxxxyz_xxxxxyz_0[j] = pb_x * tg_xxxxyz_xxxxxyz_0[j] + fr * tg_xxxxyz_xxxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxyz_0[j] - tg_xxxyz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyz_xxxxyz_1[j];

                    tg_xxxxxyz_xxxxxzz_0[j] = pb_x * tg_xxxxyz_xxxxxzz_0[j] + fr * tg_xxxxyz_xxxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxxzz_0[j] - tg_xxxyz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyz_xxxxzz_1[j];

                    tg_xxxxxyz_xxxxyyy_0[j] = pb_x * tg_xxxxyz_xxxxyyy_0[j] + fr * tg_xxxxyz_xxxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxyyy_0[j] - tg_xxxyz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyz_xxxyyy_1[j];

                    tg_xxxxxyz_xxxxyyz_0[j] = pb_x * tg_xxxxyz_xxxxyyz_0[j] + fr * tg_xxxxyz_xxxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxyyz_0[j] - tg_xxxyz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyz_xxxyyz_1[j];

                    tg_xxxxxyz_xxxxyzz_0[j] = pb_x * tg_xxxxyz_xxxxyzz_0[j] + fr * tg_xxxxyz_xxxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxyzz_0[j] - tg_xxxyz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyz_xxxyzz_1[j];

                    tg_xxxxxyz_xxxxzzz_0[j] = pb_x * tg_xxxxyz_xxxxzzz_0[j] + fr * tg_xxxxyz_xxxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxxzzz_0[j] - tg_xxxyz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyz_xxxzzz_1[j];

                    tg_xxxxxyz_xxxyyyy_0[j] = pb_x * tg_xxxxyz_xxxyyyy_0[j] + fr * tg_xxxxyz_xxxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxyyyy_0[j] - tg_xxxyz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyz_xxyyyy_1[j];

                    tg_xxxxxyz_xxxyyyz_0[j] = pb_x * tg_xxxxyz_xxxyyyz_0[j] + fr * tg_xxxxyz_xxxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxyyyz_0[j] - tg_xxxyz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyz_xxyyyz_1[j];

                    tg_xxxxxyz_xxxyyzz_0[j] = pb_x * tg_xxxxyz_xxxyyzz_0[j] + fr * tg_xxxxyz_xxxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxyyzz_0[j] - tg_xxxyz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyz_xxyyzz_1[j];

                    tg_xxxxxyz_xxxyzzz_0[j] = pb_x * tg_xxxxyz_xxxyzzz_0[j] + fr * tg_xxxxyz_xxxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxyzzz_0[j] - tg_xxxyz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyz_xxyzzz_1[j];

                    tg_xxxxxyz_xxxzzzz_0[j] = pb_x * tg_xxxxyz_xxxzzzz_0[j] + fr * tg_xxxxyz_xxxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxxzzzz_0[j] - tg_xxxyz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyz_xxzzzz_1[j];

                    tg_xxxxxyz_xxyyyyy_0[j] = pb_x * tg_xxxxyz_xxyyyyy_0[j] + fr * tg_xxxxyz_xxyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxyyyyy_0[j] - tg_xxxyz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xyyyyy_1[j];

                    tg_xxxxxyz_xxyyyyz_0[j] = pb_x * tg_xxxxyz_xxyyyyz_0[j] + fr * tg_xxxxyz_xxyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxyyyyz_0[j] - tg_xxxyz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xyyyyz_1[j];

                    tg_xxxxxyz_xxyyyzz_0[j] = pb_x * tg_xxxxyz_xxyyyzz_0[j] + fr * tg_xxxxyz_xxyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxyyyzz_0[j] - tg_xxxyz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xyyyzz_1[j];

                    tg_xxxxxyz_xxyyzzz_0[j] = pb_x * tg_xxxxyz_xxyyzzz_0[j] + fr * tg_xxxxyz_xxyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxyyzzz_0[j] - tg_xxxyz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xyyzzz_1[j];

                    tg_xxxxxyz_xxyzzzz_0[j] = pb_x * tg_xxxxyz_xxyzzzz_0[j] + fr * tg_xxxxyz_xxyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxyzzzz_0[j] - tg_xxxyz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xyzzzz_1[j];

                    tg_xxxxxyz_xxzzzzz_0[j] = pb_x * tg_xxxxyz_xxzzzzz_0[j] + fr * tg_xxxxyz_xxzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xxzzzzz_0[j] - tg_xxxyz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyz_xzzzzz_1[j];

                    tg_xxxxxyz_xyyyyyy_0[j] = pb_x * tg_xxxxyz_xyyyyyy_0[j] + fr * tg_xxxxyz_xyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyyyyyy_0[j] - tg_xxxyz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yyyyyy_1[j];

                    tg_xxxxxyz_xyyyyyz_0[j] = pb_x * tg_xxxxyz_xyyyyyz_0[j] + fr * tg_xxxxyz_xyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyyyyyz_0[j] - tg_xxxyz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yyyyyz_1[j];

                    tg_xxxxxyz_xyyyyzz_0[j] = pb_x * tg_xxxxyz_xyyyyzz_0[j] + fr * tg_xxxxyz_xyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyyyyzz_0[j] - tg_xxxyz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yyyyzz_1[j];

                    tg_xxxxxyz_xyyyzzz_0[j] = pb_x * tg_xxxxyz_xyyyzzz_0[j] + fr * tg_xxxxyz_xyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyyyzzz_0[j] - tg_xxxyz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yyyzzz_1[j];

                    tg_xxxxxyz_xyyzzzz_0[j] = pb_x * tg_xxxxyz_xyyzzzz_0[j] + fr * tg_xxxxyz_xyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyyzzzz_0[j] - tg_xxxyz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yyzzzz_1[j];

                    tg_xxxxxyz_xyzzzzz_0[j] = pb_x * tg_xxxxyz_xyzzzzz_0[j] + fr * tg_xxxxyz_xyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xyzzzzz_0[j] - tg_xxxyz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_yzzzzz_1[j];

                    tg_xxxxxyz_xzzzzzz_0[j] = pb_x * tg_xxxxyz_xzzzzzz_0[j] + fr * tg_xxxxyz_xzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_xzzzzzz_0[j] - tg_xxxyz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyz_zzzzzz_1[j];

                    tg_xxxxxyz_yyyyyyy_0[j] = pb_x * tg_xxxxyz_yyyyyyy_0[j] + fr * tg_xxxxyz_yyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyyyyyy_0[j] - tg_xxxyz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxyz_yyyyyyz_0[j] = pb_x * tg_xxxxyz_yyyyyyz_0[j] + fr * tg_xxxxyz_yyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyyyyyz_0[j] - tg_xxxyz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxyz_yyyyyzz_0[j] = pb_x * tg_xxxxyz_yyyyyzz_0[j] + fr * tg_xxxxyz_yyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyyyyzz_0[j] - tg_xxxyz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxyz_yyyyzzz_0[j] = pb_x * tg_xxxxyz_yyyyzzz_0[j] + fr * tg_xxxxyz_yyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyyyzzz_0[j] - tg_xxxyz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxyz_yyyzzzz_0[j] = pb_x * tg_xxxxyz_yyyzzzz_0[j] + fr * tg_xxxxyz_yyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyyzzzz_0[j] - tg_xxxyz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxyz_yyzzzzz_0[j] = pb_x * tg_xxxxyz_yyzzzzz_0[j] + fr * tg_xxxxyz_yyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yyzzzzz_0[j] - tg_xxxyz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyz_yzzzzzz_0[j] = pb_x * tg_xxxxyz_yzzzzzz_0[j] + fr * tg_xxxxyz_yzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_yzzzzzz_0[j] - tg_xxxyz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyz_zzzzzzz_0[j] = pb_x * tg_xxxxyz_zzzzzzz_0[j] + fr * tg_xxxxyz_zzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyz_zzzzzzz_0[j] - tg_xxxyz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxzz_xxxxxxx_0[j] = pb_x * tg_xxxxzz_xxxxxxx_0[j] + fr * tg_xxxxzz_xxxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxxx_0[j] - tg_xxxzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxxzz_xxxxxx_1[j];

                    tg_xxxxxzz_xxxxxxy_0[j] = pb_x * tg_xxxxzz_xxxxxxy_0[j] + fr * tg_xxxxzz_xxxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxxy_0[j] - tg_xxxzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxzz_xxxxxy_1[j];

                    tg_xxxxxzz_xxxxxxz_0[j] = pb_x * tg_xxxxzz_xxxxxxz_0[j] + fr * tg_xxxxzz_xxxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxxz_0[j] - tg_xxxzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxzz_xxxxxz_1[j];

                    tg_xxxxxzz_xxxxxyy_0[j] = pb_x * tg_xxxxzz_xxxxxyy_0[j] + fr * tg_xxxxzz_xxxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxyy_0[j] - tg_xxxzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxzz_xxxxyy_1[j];

                    tg_xxxxxzz_xxxxxyz_0[j] = pb_x * tg_xxxxzz_xxxxxyz_0[j] + fr * tg_xxxxzz_xxxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxyz_0[j] - tg_xxxzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxzz_xxxxyz_1[j];

                    tg_xxxxxzz_xxxxxzz_0[j] = pb_x * tg_xxxxzz_xxxxxzz_0[j] + fr * tg_xxxxzz_xxxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxxzz_0[j] - tg_xxxzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxzz_xxxxzz_1[j];

                    tg_xxxxxzz_xxxxyyy_0[j] = pb_x * tg_xxxxzz_xxxxyyy_0[j] + fr * tg_xxxxzz_xxxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxyyy_0[j] - tg_xxxzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzz_xxxyyy_1[j];

                    tg_xxxxxzz_xxxxyyz_0[j] = pb_x * tg_xxxxzz_xxxxyyz_0[j] + fr * tg_xxxxzz_xxxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxyyz_0[j] - tg_xxxzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzz_xxxyyz_1[j];

                    tg_xxxxxzz_xxxxyzz_0[j] = pb_x * tg_xxxxzz_xxxxyzz_0[j] + fr * tg_xxxxzz_xxxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxyzz_0[j] - tg_xxxzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzz_xxxyzz_1[j];

                    tg_xxxxxzz_xxxxzzz_0[j] = pb_x * tg_xxxxzz_xxxxzzz_0[j] + fr * tg_xxxxzz_xxxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxxzzz_0[j] - tg_xxxzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzz_xxxzzz_1[j];

                    tg_xxxxxzz_xxxyyyy_0[j] = pb_x * tg_xxxxzz_xxxyyyy_0[j] + fr * tg_xxxxzz_xxxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxyyyy_0[j] - tg_xxxzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzz_xxyyyy_1[j];

                    tg_xxxxxzz_xxxyyyz_0[j] = pb_x * tg_xxxxzz_xxxyyyz_0[j] + fr * tg_xxxxzz_xxxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxyyyz_0[j] - tg_xxxzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzz_xxyyyz_1[j];

                    tg_xxxxxzz_xxxyyzz_0[j] = pb_x * tg_xxxxzz_xxxyyzz_0[j] + fr * tg_xxxxzz_xxxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxyyzz_0[j] - tg_xxxzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzz_xxyyzz_1[j];

                    tg_xxxxxzz_xxxyzzz_0[j] = pb_x * tg_xxxxzz_xxxyzzz_0[j] + fr * tg_xxxxzz_xxxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxyzzz_0[j] - tg_xxxzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzz_xxyzzz_1[j];

                    tg_xxxxxzz_xxxzzzz_0[j] = pb_x * tg_xxxxzz_xxxzzzz_0[j] + fr * tg_xxxxzz_xxxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxxzzzz_0[j] - tg_xxxzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzz_xxzzzz_1[j];

                    tg_xxxxxzz_xxyyyyy_0[j] = pb_x * tg_xxxxzz_xxyyyyy_0[j] + fr * tg_xxxxzz_xxyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxyyyyy_0[j] - tg_xxxzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xyyyyy_1[j];

                    tg_xxxxxzz_xxyyyyz_0[j] = pb_x * tg_xxxxzz_xxyyyyz_0[j] + fr * tg_xxxxzz_xxyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxyyyyz_0[j] - tg_xxxzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xyyyyz_1[j];

                    tg_xxxxxzz_xxyyyzz_0[j] = pb_x * tg_xxxxzz_xxyyyzz_0[j] + fr * tg_xxxxzz_xxyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxyyyzz_0[j] - tg_xxxzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xyyyzz_1[j];

                    tg_xxxxxzz_xxyyzzz_0[j] = pb_x * tg_xxxxzz_xxyyzzz_0[j] + fr * tg_xxxxzz_xxyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxyyzzz_0[j] - tg_xxxzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xyyzzz_1[j];

                    tg_xxxxxzz_xxyzzzz_0[j] = pb_x * tg_xxxxzz_xxyzzzz_0[j] + fr * tg_xxxxzz_xxyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxyzzzz_0[j] - tg_xxxzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xyzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_200_300(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (200,300)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 200); 

                auto tg_xxxxzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 201); 

                auto tg_xxxxzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 202); 

                auto tg_xxxxzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 203); 

                auto tg_xxxxzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 204); 

                auto tg_xxxxzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 205); 

                auto tg_xxxxzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 206); 

                auto tg_xxxxzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 207); 

                auto tg_xxxxzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 208); 

                auto tg_xxxxzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 209); 

                auto tg_xxxxzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 210); 

                auto tg_xxxxzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 211); 

                auto tg_xxxxzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 212); 

                auto tg_xxxxzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 213); 

                auto tg_xxxxzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 214); 

                auto tg_xxxxzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 215); 

                auto tg_xxxyyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 216); 

                auto tg_xxxyyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 217); 

                auto tg_xxxyyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 218); 

                auto tg_xxxyyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 219); 

                auto tg_xxxyyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 220); 

                auto tg_xxxyyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 221); 

                auto tg_xxxyyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 222); 

                auto tg_xxxyyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 223); 

                auto tg_xxxyyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 224); 

                auto tg_xxxyyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 225); 

                auto tg_xxxyyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 226); 

                auto tg_xxxyyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 227); 

                auto tg_xxxyyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 228); 

                auto tg_xxxyyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 229); 

                auto tg_xxxyyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 230); 

                auto tg_xxxyyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 231); 

                auto tg_xxxyyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 232); 

                auto tg_xxxyyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 233); 

                auto tg_xxxyyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 234); 

                auto tg_xxxyyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 235); 

                auto tg_xxxyyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 236); 

                auto tg_xxxyyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 237); 

                auto tg_xxxyyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 238); 

                auto tg_xxxyyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 239); 

                auto tg_xxxyyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 240); 

                auto tg_xxxyyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 241); 

                auto tg_xxxyyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 242); 

                auto tg_xxxyyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 243); 

                auto tg_xxxyyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 244); 

                auto tg_xxxyyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 245); 

                auto tg_xxxyyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 246); 

                auto tg_xxxyyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 247); 

                auto tg_xxxyyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 248); 

                auto tg_xxxyyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 249); 

                auto tg_xxxyyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 250); 

                auto tg_xxxyyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 251); 

                auto tg_xxxyyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 252); 

                auto tg_xxxyyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 253); 

                auto tg_xxxyyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 254); 

                auto tg_xxxyyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 255); 

                auto tg_xxxyyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 256); 

                auto tg_xxxyyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 257); 

                auto tg_xxxyyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 258); 

                auto tg_xxxyyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 259); 

                auto tg_xxxyyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 260); 

                auto tg_xxxyyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 261); 

                auto tg_xxxyyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 262); 

                auto tg_xxxyyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 263); 

                auto tg_xxxyyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 264); 

                auto tg_xxxyyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 265); 

                auto tg_xxxyyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 266); 

                auto tg_xxxyyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 267); 

                auto tg_xxxyyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 268); 

                auto tg_xxxyyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 269); 

                auto tg_xxxyyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 270); 

                auto tg_xxxyyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 271); 

                auto tg_xxxyyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 272); 

                auto tg_xxxyyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 273); 

                auto tg_xxxyyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 274); 

                auto tg_xxxyyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 275); 

                auto tg_xxxyyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 276); 

                auto tg_xxxyyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 277); 

                auto tg_xxxyyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 278); 

                auto tg_xxxyyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 279); 

                auto tg_xxxyyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 280); 

                auto tg_xxxyyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 281); 

                auto tg_xxxyyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 282); 

                auto tg_xxxyyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 283); 

                auto tg_xxxyyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 284); 

                auto tg_xxxyyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 285); 

                auto tg_xxxyyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 286); 

                auto tg_xxxyyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 287); 

                auto tg_xxxyzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 288); 

                auto tg_xxxyzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 289); 

                auto tg_xxxyzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 290); 

                auto tg_xxxyzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 291); 

                auto tg_xxxyzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 292); 

                auto tg_xxxyzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 293); 

                auto tg_xxxyzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 294); 

                auto tg_xxxyzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 295); 

                auto tg_xxxyzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 296); 

                auto tg_xxxyzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 297); 

                auto tg_xxxyzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 298); 

                auto tg_xxxyzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 299); 

                auto tg_xxxxzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 200); 

                auto tg_xxxxzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 201); 

                auto tg_xxxxzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 202); 

                auto tg_xxxxzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 203); 

                auto tg_xxxxzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 204); 

                auto tg_xxxxzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 205); 

                auto tg_xxxxzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 206); 

                auto tg_xxxxzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 207); 

                auto tg_xxxxzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 208); 

                auto tg_xxxxzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 209); 

                auto tg_xxxxzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 210); 

                auto tg_xxxxzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 211); 

                auto tg_xxxxzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 212); 

                auto tg_xxxxzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 213); 

                auto tg_xxxxzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 214); 

                auto tg_xxxxzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 215); 

                auto tg_xxxyyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 216); 

                auto tg_xxxyyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 217); 

                auto tg_xxxyyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 218); 

                auto tg_xxxyyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 219); 

                auto tg_xxxyyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 220); 

                auto tg_xxxyyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 221); 

                auto tg_xxxyyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 222); 

                auto tg_xxxyyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 223); 

                auto tg_xxxyyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 224); 

                auto tg_xxxyyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 225); 

                auto tg_xxxyyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 226); 

                auto tg_xxxyyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 227); 

                auto tg_xxxyyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 228); 

                auto tg_xxxyyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 229); 

                auto tg_xxxyyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 230); 

                auto tg_xxxyyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 231); 

                auto tg_xxxyyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 232); 

                auto tg_xxxyyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 233); 

                auto tg_xxxyyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 234); 

                auto tg_xxxyyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 235); 

                auto tg_xxxyyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 236); 

                auto tg_xxxyyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 237); 

                auto tg_xxxyyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 238); 

                auto tg_xxxyyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 239); 

                auto tg_xxxyyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 240); 

                auto tg_xxxyyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 241); 

                auto tg_xxxyyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 242); 

                auto tg_xxxyyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 243); 

                auto tg_xxxyyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 244); 

                auto tg_xxxyyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 245); 

                auto tg_xxxyyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 246); 

                auto tg_xxxyyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 247); 

                auto tg_xxxyyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 248); 

                auto tg_xxxyyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 249); 

                auto tg_xxxyyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 250); 

                auto tg_xxxyyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 251); 

                auto tg_xxxyyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 252); 

                auto tg_xxxyyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 253); 

                auto tg_xxxyyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 254); 

                auto tg_xxxyyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 255); 

                auto tg_xxxyyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 256); 

                auto tg_xxxyyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 257); 

                auto tg_xxxyyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 258); 

                auto tg_xxxyyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 259); 

                auto tg_xxxyyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 260); 

                auto tg_xxxyyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 261); 

                auto tg_xxxyyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 262); 

                auto tg_xxxyyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 263); 

                auto tg_xxxyyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 264); 

                auto tg_xxxyyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 265); 

                auto tg_xxxyyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 266); 

                auto tg_xxxyyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 267); 

                auto tg_xxxyyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 268); 

                auto tg_xxxyyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 269); 

                auto tg_xxxyyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 270); 

                auto tg_xxxyyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 271); 

                auto tg_xxxyyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 272); 

                auto tg_xxxyyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 273); 

                auto tg_xxxyyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 274); 

                auto tg_xxxyyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 275); 

                auto tg_xxxyyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 276); 

                auto tg_xxxyyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 277); 

                auto tg_xxxyyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 278); 

                auto tg_xxxyyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 279); 

                auto tg_xxxyyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 280); 

                auto tg_xxxyyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 281); 

                auto tg_xxxyyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 282); 

                auto tg_xxxyyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 283); 

                auto tg_xxxyyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 284); 

                auto tg_xxxyyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 285); 

                auto tg_xxxyyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 286); 

                auto tg_xxxyyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 287); 

                auto tg_xxxyzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 288); 

                auto tg_xxxyzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 289); 

                auto tg_xxxyzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 290); 

                auto tg_xxxyzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 291); 

                auto tg_xxxyzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 292); 

                auto tg_xxxyzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 293); 

                auto tg_xxxyzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 294); 

                auto tg_xxxyzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 295); 

                auto tg_xxxyzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 296); 

                auto tg_xxxyzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 297); 

                auto tg_xxxyzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 298); 

                auto tg_xxxyzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 299); 

                auto tg_xxxzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 200); 

                auto tg_xxxzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 201); 

                auto tg_xxxzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 202); 

                auto tg_xxxzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 203); 

                auto tg_xxxzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 204); 

                auto tg_xxxzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 205); 

                auto tg_xxxzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 206); 

                auto tg_xxxzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 207); 

                auto tg_xxxzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 208); 

                auto tg_xxxzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 209); 

                auto tg_xxxzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 210); 

                auto tg_xxxzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 211); 

                auto tg_xxxzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 212); 

                auto tg_xxxzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 213); 

                auto tg_xxxzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 214); 

                auto tg_xxxzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 215); 

                auto tg_xxyyy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 216); 

                auto tg_xxyyy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 217); 

                auto tg_xxyyy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 218); 

                auto tg_xxyyy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 219); 

                auto tg_xxyyy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 220); 

                auto tg_xxyyy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 221); 

                auto tg_xxyyy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 222); 

                auto tg_xxyyy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 223); 

                auto tg_xxyyy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 224); 

                auto tg_xxyyy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 225); 

                auto tg_xxyyy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 226); 

                auto tg_xxyyy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 227); 

                auto tg_xxyyy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 228); 

                auto tg_xxyyy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 229); 

                auto tg_xxyyy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 230); 

                auto tg_xxyyy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 231); 

                auto tg_xxyyy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 232); 

                auto tg_xxyyy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 233); 

                auto tg_xxyyy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 234); 

                auto tg_xxyyy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 235); 

                auto tg_xxyyy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 236); 

                auto tg_xxyyy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 237); 

                auto tg_xxyyy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 238); 

                auto tg_xxyyy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 239); 

                auto tg_xxyyy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 240); 

                auto tg_xxyyy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 241); 

                auto tg_xxyyy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 242); 

                auto tg_xxyyy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 243); 

                auto tg_xxyyy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 244); 

                auto tg_xxyyy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 245); 

                auto tg_xxyyy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 246); 

                auto tg_xxyyy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 247); 

                auto tg_xxyyy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 248); 

                auto tg_xxyyy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 249); 

                auto tg_xxyyy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 250); 

                auto tg_xxyyy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 251); 

                auto tg_xxyyz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 252); 

                auto tg_xxyyz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 253); 

                auto tg_xxyyz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 254); 

                auto tg_xxyyz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 255); 

                auto tg_xxyyz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 256); 

                auto tg_xxyyz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 257); 

                auto tg_xxyyz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 258); 

                auto tg_xxyyz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 259); 

                auto tg_xxyyz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 260); 

                auto tg_xxyyz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 261); 

                auto tg_xxyyz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 262); 

                auto tg_xxyyz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 263); 

                auto tg_xxyyz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 264); 

                auto tg_xxyyz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 265); 

                auto tg_xxyyz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 266); 

                auto tg_xxyyz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 267); 

                auto tg_xxyyz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 268); 

                auto tg_xxyyz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 269); 

                auto tg_xxyyz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 270); 

                auto tg_xxyyz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 271); 

                auto tg_xxyyz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 272); 

                auto tg_xxyyz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 273); 

                auto tg_xxyyz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 274); 

                auto tg_xxyyz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 275); 

                auto tg_xxyyz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 276); 

                auto tg_xxyyz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 277); 

                auto tg_xxyyz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 278); 

                auto tg_xxyyz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 279); 

                auto tg_xxyyz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 280); 

                auto tg_xxyyz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 281); 

                auto tg_xxyyz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 282); 

                auto tg_xxyyz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 283); 

                auto tg_xxyyz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 284); 

                auto tg_xxyyz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 285); 

                auto tg_xxyyz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 286); 

                auto tg_xxyyz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 287); 

                auto tg_xxyzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 288); 

                auto tg_xxyzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 289); 

                auto tg_xxyzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 290); 

                auto tg_xxyzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 291); 

                auto tg_xxyzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 292); 

                auto tg_xxyzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 293); 

                auto tg_xxyzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 294); 

                auto tg_xxyzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 295); 

                auto tg_xxyzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 296); 

                auto tg_xxyzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 297); 

                auto tg_xxyzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 298); 

                auto tg_xxyzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 299); 

                auto tg_xxxzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 200); 

                auto tg_xxxzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 201); 

                auto tg_xxxzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 202); 

                auto tg_xxxzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 203); 

                auto tg_xxxzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 204); 

                auto tg_xxxzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 205); 

                auto tg_xxxzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 206); 

                auto tg_xxxzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 207); 

                auto tg_xxxzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 208); 

                auto tg_xxxzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 209); 

                auto tg_xxxzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 210); 

                auto tg_xxxzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 211); 

                auto tg_xxxzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 212); 

                auto tg_xxxzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 213); 

                auto tg_xxxzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 214); 

                auto tg_xxxzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 215); 

                auto tg_xxyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 216); 

                auto tg_xxyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 217); 

                auto tg_xxyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 218); 

                auto tg_xxyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 219); 

                auto tg_xxyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 220); 

                auto tg_xxyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 221); 

                auto tg_xxyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 222); 

                auto tg_xxyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 223); 

                auto tg_xxyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 224); 

                auto tg_xxyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 225); 

                auto tg_xxyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 226); 

                auto tg_xxyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 227); 

                auto tg_xxyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 228); 

                auto tg_xxyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 229); 

                auto tg_xxyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 230); 

                auto tg_xxyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 231); 

                auto tg_xxyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 232); 

                auto tg_xxyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 233); 

                auto tg_xxyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 234); 

                auto tg_xxyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 235); 

                auto tg_xxyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 236); 

                auto tg_xxyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 237); 

                auto tg_xxyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 238); 

                auto tg_xxyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 239); 

                auto tg_xxyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 240); 

                auto tg_xxyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 241); 

                auto tg_xxyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 242); 

                auto tg_xxyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 243); 

                auto tg_xxyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 244); 

                auto tg_xxyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 245); 

                auto tg_xxyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 246); 

                auto tg_xxyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 247); 

                auto tg_xxyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 248); 

                auto tg_xxyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 249); 

                auto tg_xxyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 250); 

                auto tg_xxyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 251); 

                auto tg_xxyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 252); 

                auto tg_xxyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 253); 

                auto tg_xxyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 254); 

                auto tg_xxyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 255); 

                auto tg_xxyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 256); 

                auto tg_xxyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 257); 

                auto tg_xxyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 258); 

                auto tg_xxyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 259); 

                auto tg_xxyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 260); 

                auto tg_xxyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 261); 

                auto tg_xxyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 262); 

                auto tg_xxyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 263); 

                auto tg_xxyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 264); 

                auto tg_xxyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 265); 

                auto tg_xxyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 266); 

                auto tg_xxyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 267); 

                auto tg_xxyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 268); 

                auto tg_xxyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 269); 

                auto tg_xxyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 270); 

                auto tg_xxyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 271); 

                auto tg_xxyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 272); 

                auto tg_xxyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 273); 

                auto tg_xxyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 274); 

                auto tg_xxyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 275); 

                auto tg_xxyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 276); 

                auto tg_xxyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 277); 

                auto tg_xxyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 278); 

                auto tg_xxyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 279); 

                auto tg_xxyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 280); 

                auto tg_xxyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 281); 

                auto tg_xxyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 282); 

                auto tg_xxyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 283); 

                auto tg_xxyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 284); 

                auto tg_xxyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 285); 

                auto tg_xxyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 286); 

                auto tg_xxyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 287); 

                auto tg_xxyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 288); 

                auto tg_xxyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 289); 

                auto tg_xxyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 290); 

                auto tg_xxyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 291); 

                auto tg_xxyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 292); 

                auto tg_xxyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 293); 

                auto tg_xxyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 294); 

                auto tg_xxyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 295); 

                auto tg_xxyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 296); 

                auto tg_xxyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 297); 

                auto tg_xxyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 298); 

                auto tg_xxyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 299); 

                auto tg_xxxxzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 160); 

                auto tg_xxxxzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 161); 

                auto tg_xxxxzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 162); 

                auto tg_xxxxzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 163); 

                auto tg_xxxxzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 164); 

                auto tg_xxxxzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 165); 

                auto tg_xxxxzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 166); 

                auto tg_xxxxzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 167); 

                auto tg_xxxyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 168); 

                auto tg_xxxyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 169); 

                auto tg_xxxyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 170); 

                auto tg_xxxyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 171); 

                auto tg_xxxyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 172); 

                auto tg_xxxyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 173); 

                auto tg_xxxyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 174); 

                auto tg_xxxyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 175); 

                auto tg_xxxyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 176); 

                auto tg_xxxyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 177); 

                auto tg_xxxyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 178); 

                auto tg_xxxyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 179); 

                auto tg_xxxyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 180); 

                auto tg_xxxyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 181); 

                auto tg_xxxyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 182); 

                auto tg_xxxyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 183); 

                auto tg_xxxyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 184); 

                auto tg_xxxyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 185); 

                auto tg_xxxyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 186); 

                auto tg_xxxyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 187); 

                auto tg_xxxyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 188); 

                auto tg_xxxyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 189); 

                auto tg_xxxyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 190); 

                auto tg_xxxyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 191); 

                auto tg_xxxyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 192); 

                auto tg_xxxyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 193); 

                auto tg_xxxyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 194); 

                auto tg_xxxyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 195); 

                auto tg_xxxyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 196); 

                auto tg_xxxyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 197); 

                auto tg_xxxyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 198); 

                auto tg_xxxyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 199); 

                auto tg_xxxyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 200); 

                auto tg_xxxyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 201); 

                auto tg_xxxyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 202); 

                auto tg_xxxyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 203); 

                auto tg_xxxyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 204); 

                auto tg_xxxyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 205); 

                auto tg_xxxyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 206); 

                auto tg_xxxyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 207); 

                auto tg_xxxyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 208); 

                auto tg_xxxyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 209); 

                auto tg_xxxyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 210); 

                auto tg_xxxyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 211); 

                auto tg_xxxyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 212); 

                auto tg_xxxyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 213); 

                auto tg_xxxyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 214); 

                auto tg_xxxyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 215); 

                auto tg_xxxyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 216); 

                auto tg_xxxyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 217); 

                auto tg_xxxyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 218); 

                auto tg_xxxyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 219); 

                auto tg_xxxyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 220); 

                auto tg_xxxyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 221); 

                auto tg_xxxyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 222); 

                auto tg_xxxyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 223); 

                auto tg_xxxyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 224); 

                auto tg_xxxyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 225); 

                auto tg_xxxyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 226); 

                auto tg_xxxyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 227); 

                auto tg_xxxyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 228); 

                auto tg_xxxyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 229); 

                auto tg_xxxyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 230); 

                auto tg_xxxyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 231); 

                auto tg_xxxyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 232); 

                auto tg_xxxyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 233); 

                auto tg_xxxyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 234); 

                auto tg_xxxyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 235); 

                // set up pointers to integrals

                auto tg_xxxxxzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 200); 

                auto tg_xxxxxzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 201); 

                auto tg_xxxxxzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 202); 

                auto tg_xxxxxzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 203); 

                auto tg_xxxxxzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 204); 

                auto tg_xxxxxzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 205); 

                auto tg_xxxxxzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 206); 

                auto tg_xxxxxzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 207); 

                auto tg_xxxxxzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 208); 

                auto tg_xxxxxzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 209); 

                auto tg_xxxxxzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 210); 

                auto tg_xxxxxzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 211); 

                auto tg_xxxxxzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 212); 

                auto tg_xxxxxzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 213); 

                auto tg_xxxxxzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 214); 

                auto tg_xxxxxzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 215); 

                auto tg_xxxxyyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 216); 

                auto tg_xxxxyyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 217); 

                auto tg_xxxxyyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 218); 

                auto tg_xxxxyyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 219); 

                auto tg_xxxxyyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 220); 

                auto tg_xxxxyyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 221); 

                auto tg_xxxxyyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 222); 

                auto tg_xxxxyyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 223); 

                auto tg_xxxxyyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 224); 

                auto tg_xxxxyyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 225); 

                auto tg_xxxxyyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 226); 

                auto tg_xxxxyyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 227); 

                auto tg_xxxxyyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 228); 

                auto tg_xxxxyyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 229); 

                auto tg_xxxxyyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 230); 

                auto tg_xxxxyyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 231); 

                auto tg_xxxxyyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 232); 

                auto tg_xxxxyyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 233); 

                auto tg_xxxxyyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 234); 

                auto tg_xxxxyyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 235); 

                auto tg_xxxxyyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 236); 

                auto tg_xxxxyyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 237); 

                auto tg_xxxxyyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 238); 

                auto tg_xxxxyyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 239); 

                auto tg_xxxxyyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 240); 

                auto tg_xxxxyyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 241); 

                auto tg_xxxxyyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 242); 

                auto tg_xxxxyyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 243); 

                auto tg_xxxxyyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 244); 

                auto tg_xxxxyyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 245); 

                auto tg_xxxxyyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 246); 

                auto tg_xxxxyyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 247); 

                auto tg_xxxxyyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 248); 

                auto tg_xxxxyyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 249); 

                auto tg_xxxxyyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 250); 

                auto tg_xxxxyyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 251); 

                auto tg_xxxxyyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 252); 

                auto tg_xxxxyyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 253); 

                auto tg_xxxxyyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 254); 

                auto tg_xxxxyyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 255); 

                auto tg_xxxxyyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 256); 

                auto tg_xxxxyyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 257); 

                auto tg_xxxxyyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 258); 

                auto tg_xxxxyyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 259); 

                auto tg_xxxxyyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 260); 

                auto tg_xxxxyyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 261); 

                auto tg_xxxxyyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 262); 

                auto tg_xxxxyyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 263); 

                auto tg_xxxxyyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 264); 

                auto tg_xxxxyyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 265); 

                auto tg_xxxxyyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 266); 

                auto tg_xxxxyyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 267); 

                auto tg_xxxxyyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 268); 

                auto tg_xxxxyyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 269); 

                auto tg_xxxxyyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 270); 

                auto tg_xxxxyyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 271); 

                auto tg_xxxxyyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 272); 

                auto tg_xxxxyyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 273); 

                auto tg_xxxxyyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 274); 

                auto tg_xxxxyyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 275); 

                auto tg_xxxxyyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 276); 

                auto tg_xxxxyyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 277); 

                auto tg_xxxxyyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 278); 

                auto tg_xxxxyyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 279); 

                auto tg_xxxxyyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 280); 

                auto tg_xxxxyyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 281); 

                auto tg_xxxxyyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 282); 

                auto tg_xxxxyyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 283); 

                auto tg_xxxxyyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 284); 

                auto tg_xxxxyyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 285); 

                auto tg_xxxxyyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 286); 

                auto tg_xxxxyyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 287); 

                auto tg_xxxxyzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 288); 

                auto tg_xxxxyzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 289); 

                auto tg_xxxxyzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 290); 

                auto tg_xxxxyzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 291); 

                auto tg_xxxxyzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 292); 

                auto tg_xxxxyzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 293); 

                auto tg_xxxxyzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 294); 

                auto tg_xxxxyzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 295); 

                auto tg_xxxxyzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 296); 

                auto tg_xxxxyzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 297); 

                auto tg_xxxxyzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 298); 

                auto tg_xxxxyzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 299); 

                // Batch of Integrals (200,300)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxzz_xxzzzzz_0, tg_xxxxxzz_xyyyyyy_0, \
                                         tg_xxxxxzz_xyyyyyz_0, tg_xxxxxzz_xyyyyzz_0, tg_xxxxxzz_xyyyzzz_0, tg_xxxxxzz_xyyzzzz_0, \
                                         tg_xxxxxzz_xyzzzzz_0, tg_xxxxxzz_xzzzzzz_0, tg_xxxxxzz_yyyyyyy_0, tg_xxxxxzz_yyyyyyz_0, \
                                         tg_xxxxxzz_yyyyyzz_0, tg_xxxxxzz_yyyyzzz_0, tg_xxxxxzz_yyyzzzz_0, tg_xxxxxzz_yyzzzzz_0, \
                                         tg_xxxxxzz_yzzzzzz_0, tg_xxxxxzz_zzzzzzz_0, tg_xxxxyyy_xxxxxxx_0, tg_xxxxyyy_xxxxxxy_0, \
                                         tg_xxxxyyy_xxxxxxz_0, tg_xxxxyyy_xxxxxyy_0, tg_xxxxyyy_xxxxxyz_0, tg_xxxxyyy_xxxxxzz_0, \
                                         tg_xxxxyyy_xxxxyyy_0, tg_xxxxyyy_xxxxyyz_0, tg_xxxxyyy_xxxxyzz_0, tg_xxxxyyy_xxxxzzz_0, \
                                         tg_xxxxyyy_xxxyyyy_0, tg_xxxxyyy_xxxyyyz_0, tg_xxxxyyy_xxxyyzz_0, tg_xxxxyyy_xxxyzzz_0, \
                                         tg_xxxxyyy_xxxzzzz_0, tg_xxxxyyy_xxyyyyy_0, tg_xxxxyyy_xxyyyyz_0, tg_xxxxyyy_xxyyyzz_0, \
                                         tg_xxxxyyy_xxyyzzz_0, tg_xxxxyyy_xxyzzzz_0, tg_xxxxyyy_xxzzzzz_0, tg_xxxxyyy_xyyyyyy_0, \
                                         tg_xxxxyyy_xyyyyyz_0, tg_xxxxyyy_xyyyyzz_0, tg_xxxxyyy_xyyyzzz_0, tg_xxxxyyy_xyyzzzz_0, \
                                         tg_xxxxyyy_xyzzzzz_0, tg_xxxxyyy_xzzzzzz_0, tg_xxxxyyy_yyyyyyy_0, tg_xxxxyyy_yyyyyyz_0, \
                                         tg_xxxxyyy_yyyyyzz_0, tg_xxxxyyy_yyyyzzz_0, tg_xxxxyyy_yyyzzzz_0, tg_xxxxyyy_yyzzzzz_0, \
                                         tg_xxxxyyy_yzzzzzz_0, tg_xxxxyyy_zzzzzzz_0, tg_xxxxyyz_xxxxxxx_0, tg_xxxxyyz_xxxxxxy_0, \
                                         tg_xxxxyyz_xxxxxxz_0, tg_xxxxyyz_xxxxxyy_0, tg_xxxxyyz_xxxxxyz_0, tg_xxxxyyz_xxxxxzz_0, \
                                         tg_xxxxyyz_xxxxyyy_0, tg_xxxxyyz_xxxxyyz_0, tg_xxxxyyz_xxxxyzz_0, tg_xxxxyyz_xxxxzzz_0, \
                                         tg_xxxxyyz_xxxyyyy_0, tg_xxxxyyz_xxxyyyz_0, tg_xxxxyyz_xxxyyzz_0, tg_xxxxyyz_xxxyzzz_0, \
                                         tg_xxxxyyz_xxxzzzz_0, tg_xxxxyyz_xxyyyyy_0, tg_xxxxyyz_xxyyyyz_0, tg_xxxxyyz_xxyyyzz_0, \
                                         tg_xxxxyyz_xxyyzzz_0, tg_xxxxyyz_xxyzzzz_0, tg_xxxxyyz_xxzzzzz_0, tg_xxxxyyz_xyyyyyy_0, \
                                         tg_xxxxyyz_xyyyyyz_0, tg_xxxxyyz_xyyyyzz_0, tg_xxxxyyz_xyyyzzz_0, tg_xxxxyyz_xyyzzzz_0, \
                                         tg_xxxxyyz_xyzzzzz_0, tg_xxxxyyz_xzzzzzz_0, tg_xxxxyyz_yyyyyyy_0, tg_xxxxyyz_yyyyyyz_0, \
                                         tg_xxxxyyz_yyyyyzz_0, tg_xxxxyyz_yyyyzzz_0, tg_xxxxyyz_yyyzzzz_0, tg_xxxxyyz_yyzzzzz_0, \
                                         tg_xxxxyyz_yzzzzzz_0, tg_xxxxyyz_zzzzzzz_0, tg_xxxxyzz_xxxxxxx_0, tg_xxxxyzz_xxxxxxy_0, \
                                         tg_xxxxyzz_xxxxxxz_0, tg_xxxxyzz_xxxxxyy_0, tg_xxxxyzz_xxxxxyz_0, tg_xxxxyzz_xxxxxzz_0, \
                                         tg_xxxxyzz_xxxxyyy_0, tg_xxxxyzz_xxxxyyz_0, tg_xxxxyzz_xxxxyzz_0, tg_xxxxyzz_xxxxzzz_0, \
                                         tg_xxxxyzz_xxxyyyy_0, tg_xxxxyzz_xxxyyyz_0, tg_xxxxzz_xxzzzzz_0, tg_xxxxzz_xxzzzzz_1, \
                                         tg_xxxxzz_xyyyyyy_0, tg_xxxxzz_xyyyyyy_1, tg_xxxxzz_xyyyyyz_0, tg_xxxxzz_xyyyyyz_1, \
                                         tg_xxxxzz_xyyyyzz_0, tg_xxxxzz_xyyyyzz_1, tg_xxxxzz_xyyyzzz_0, tg_xxxxzz_xyyyzzz_1, \
                                         tg_xxxxzz_xyyzzzz_0, tg_xxxxzz_xyyzzzz_1, tg_xxxxzz_xyzzzzz_0, tg_xxxxzz_xyzzzzz_1, \
                                         tg_xxxxzz_xzzzzz_1, tg_xxxxzz_xzzzzzz_0, tg_xxxxzz_xzzzzzz_1, tg_xxxxzz_yyyyyy_1, \
                                         tg_xxxxzz_yyyyyyy_0, tg_xxxxzz_yyyyyyy_1, tg_xxxxzz_yyyyyyz_0, tg_xxxxzz_yyyyyyz_1, \
                                         tg_xxxxzz_yyyyyz_1, tg_xxxxzz_yyyyyzz_0, tg_xxxxzz_yyyyyzz_1, tg_xxxxzz_yyyyzz_1, \
                                         tg_xxxxzz_yyyyzzz_0, tg_xxxxzz_yyyyzzz_1, tg_xxxxzz_yyyzzz_1, tg_xxxxzz_yyyzzzz_0, \
                                         tg_xxxxzz_yyyzzzz_1, tg_xxxxzz_yyzzzz_1, tg_xxxxzz_yyzzzzz_0, tg_xxxxzz_yyzzzzz_1, \
                                         tg_xxxxzz_yzzzzz_1, tg_xxxxzz_yzzzzzz_0, tg_xxxxzz_yzzzzzz_1, tg_xxxxzz_zzzzzz_1, \
                                         tg_xxxxzz_zzzzzzz_0, tg_xxxxzz_zzzzzzz_1, tg_xxxyyy_xxxxxx_1, tg_xxxyyy_xxxxxxx_0, \
                                         tg_xxxyyy_xxxxxxx_1, tg_xxxyyy_xxxxxxy_0, tg_xxxyyy_xxxxxxy_1, tg_xxxyyy_xxxxxxz_0, \
                                         tg_xxxyyy_xxxxxxz_1, tg_xxxyyy_xxxxxy_1, tg_xxxyyy_xxxxxyy_0, tg_xxxyyy_xxxxxyy_1, \
                                         tg_xxxyyy_xxxxxyz_0, tg_xxxyyy_xxxxxyz_1, tg_xxxyyy_xxxxxz_1, tg_xxxyyy_xxxxxzz_0, \
                                         tg_xxxyyy_xxxxxzz_1, tg_xxxyyy_xxxxyy_1, tg_xxxyyy_xxxxyyy_0, tg_xxxyyy_xxxxyyy_1, \
                                         tg_xxxyyy_xxxxyyz_0, tg_xxxyyy_xxxxyyz_1, tg_xxxyyy_xxxxyz_1, tg_xxxyyy_xxxxyzz_0, \
                                         tg_xxxyyy_xxxxyzz_1, tg_xxxyyy_xxxxzz_1, tg_xxxyyy_xxxxzzz_0, tg_xxxyyy_xxxxzzz_1, \
                                         tg_xxxyyy_xxxyyy_1, tg_xxxyyy_xxxyyyy_0, tg_xxxyyy_xxxyyyy_1, tg_xxxyyy_xxxyyyz_0, \
                                         tg_xxxyyy_xxxyyyz_1, tg_xxxyyy_xxxyyz_1, tg_xxxyyy_xxxyyzz_0, tg_xxxyyy_xxxyyzz_1, \
                                         tg_xxxyyy_xxxyzz_1, tg_xxxyyy_xxxyzzz_0, tg_xxxyyy_xxxyzzz_1, tg_xxxyyy_xxxzzz_1, \
                                         tg_xxxyyy_xxxzzzz_0, tg_xxxyyy_xxxzzzz_1, tg_xxxyyy_xxyyyy_1, tg_xxxyyy_xxyyyyy_0, \
                                         tg_xxxyyy_xxyyyyy_1, tg_xxxyyy_xxyyyyz_0, tg_xxxyyy_xxyyyyz_1, tg_xxxyyy_xxyyyz_1, \
                                         tg_xxxyyy_xxyyyzz_0, tg_xxxyyy_xxyyyzz_1, tg_xxxyyy_xxyyzz_1, tg_xxxyyy_xxyyzzz_0, \
                                         tg_xxxyyy_xxyyzzz_1, tg_xxxyyy_xxyzzz_1, tg_xxxyyy_xxyzzzz_0, tg_xxxyyy_xxyzzzz_1, \
                                         tg_xxxyyy_xxzzzz_1, tg_xxxyyy_xxzzzzz_0, tg_xxxyyy_xxzzzzz_1, tg_xxxyyy_xyyyyy_1, \
                                         tg_xxxyyy_xyyyyyy_0, tg_xxxyyy_xyyyyyy_1, tg_xxxyyy_xyyyyyz_0, tg_xxxyyy_xyyyyyz_1, \
                                         tg_xxxyyy_xyyyyz_1, tg_xxxyyy_xyyyyzz_0, tg_xxxyyy_xyyyyzz_1, tg_xxxyyy_xyyyzz_1, \
                                         tg_xxxyyy_xyyyzzz_0, tg_xxxyyy_xyyyzzz_1, tg_xxxyyy_xyyzzz_1, tg_xxxyyy_xyyzzzz_0, \
                                         tg_xxxyyy_xyyzzzz_1, tg_xxxyyy_xyzzzz_1, tg_xxxyyy_xyzzzzz_0, tg_xxxyyy_xyzzzzz_1, \
                                         tg_xxxyyy_xzzzzz_1, tg_xxxyyy_xzzzzzz_0, tg_xxxyyy_xzzzzzz_1, tg_xxxyyy_yyyyyy_1, \
                                         tg_xxxyyy_yyyyyyy_0, tg_xxxyyy_yyyyyyy_1, tg_xxxyyy_yyyyyyz_0, tg_xxxyyy_yyyyyyz_1, \
                                         tg_xxxyyy_yyyyyz_1, tg_xxxyyy_yyyyyzz_0, tg_xxxyyy_yyyyyzz_1, tg_xxxyyy_yyyyzz_1, \
                                         tg_xxxyyy_yyyyzzz_0, tg_xxxyyy_yyyyzzz_1, tg_xxxyyy_yyyzzz_1, tg_xxxyyy_yyyzzzz_0, \
                                         tg_xxxyyy_yyyzzzz_1, tg_xxxyyy_yyzzzz_1, tg_xxxyyy_yyzzzzz_0, tg_xxxyyy_yyzzzzz_1, \
                                         tg_xxxyyy_yzzzzz_1, tg_xxxyyy_yzzzzzz_0, tg_xxxyyy_yzzzzzz_1, tg_xxxyyy_zzzzzz_1, \
                                         tg_xxxyyy_zzzzzzz_0, tg_xxxyyy_zzzzzzz_1, tg_xxxyyz_xxxxxx_1, tg_xxxyyz_xxxxxxx_0, \
                                         tg_xxxyyz_xxxxxxx_1, tg_xxxyyz_xxxxxxy_0, tg_xxxyyz_xxxxxxy_1, tg_xxxyyz_xxxxxxz_0, \
                                         tg_xxxyyz_xxxxxxz_1, tg_xxxyyz_xxxxxy_1, tg_xxxyyz_xxxxxyy_0, tg_xxxyyz_xxxxxyy_1, \
                                         tg_xxxyyz_xxxxxyz_0, tg_xxxyyz_xxxxxyz_1, tg_xxxyyz_xxxxxz_1, tg_xxxyyz_xxxxxzz_0, \
                                         tg_xxxyyz_xxxxxzz_1, tg_xxxyyz_xxxxyy_1, tg_xxxyyz_xxxxyyy_0, tg_xxxyyz_xxxxyyy_1, \
                                         tg_xxxyyz_xxxxyyz_0, tg_xxxyyz_xxxxyyz_1, tg_xxxyyz_xxxxyz_1, tg_xxxyyz_xxxxyzz_0, \
                                         tg_xxxyyz_xxxxyzz_1, tg_xxxyyz_xxxxzz_1, tg_xxxyyz_xxxxzzz_0, tg_xxxyyz_xxxxzzz_1, \
                                         tg_xxxyyz_xxxyyy_1, tg_xxxyyz_xxxyyyy_0, tg_xxxyyz_xxxyyyy_1, tg_xxxyyz_xxxyyyz_0, \
                                         tg_xxxyyz_xxxyyyz_1, tg_xxxyyz_xxxyyz_1, tg_xxxyyz_xxxyyzz_0, tg_xxxyyz_xxxyyzz_1, \
                                         tg_xxxyyz_xxxyzz_1, tg_xxxyyz_xxxyzzz_0, tg_xxxyyz_xxxyzzz_1, tg_xxxyyz_xxxzzz_1, \
                                         tg_xxxyyz_xxxzzzz_0, tg_xxxyyz_xxxzzzz_1, tg_xxxyyz_xxyyyy_1, tg_xxxyyz_xxyyyyy_0, \
                                         tg_xxxyyz_xxyyyyy_1, tg_xxxyyz_xxyyyyz_0, tg_xxxyyz_xxyyyyz_1, tg_xxxyyz_xxyyyz_1, \
                                         tg_xxxyyz_xxyyyzz_0, tg_xxxyyz_xxyyyzz_1, tg_xxxyyz_xxyyzz_1, tg_xxxyyz_xxyyzzz_0, \
                                         tg_xxxyyz_xxyyzzz_1, tg_xxxyyz_xxyzzz_1, tg_xxxyyz_xxyzzzz_0, tg_xxxyyz_xxyzzzz_1, \
                                         tg_xxxyyz_xxzzzz_1, tg_xxxyyz_xxzzzzz_0, tg_xxxyyz_xxzzzzz_1, tg_xxxyyz_xyyyyy_1, \
                                         tg_xxxyyz_xyyyyyy_0, tg_xxxyyz_xyyyyyy_1, tg_xxxyyz_xyyyyyz_0, tg_xxxyyz_xyyyyyz_1, \
                                         tg_xxxyyz_xyyyyz_1, tg_xxxyyz_xyyyyzz_0, tg_xxxyyz_xyyyyzz_1, tg_xxxyyz_xyyyzz_1, \
                                         tg_xxxyyz_xyyyzzz_0, tg_xxxyyz_xyyyzzz_1, tg_xxxyyz_xyyzzz_1, tg_xxxyyz_xyyzzzz_0, \
                                         tg_xxxyyz_xyyzzzz_1, tg_xxxyyz_xyzzzz_1, tg_xxxyyz_xyzzzzz_0, tg_xxxyyz_xyzzzzz_1, \
                                         tg_xxxyyz_xzzzzz_1, tg_xxxyyz_xzzzzzz_0, tg_xxxyyz_xzzzzzz_1, tg_xxxyyz_yyyyyy_1, \
                                         tg_xxxyyz_yyyyyyy_0, tg_xxxyyz_yyyyyyy_1, tg_xxxyyz_yyyyyyz_0, tg_xxxyyz_yyyyyyz_1, \
                                         tg_xxxyyz_yyyyyz_1, tg_xxxyyz_yyyyyzz_0, tg_xxxyyz_yyyyyzz_1, tg_xxxyyz_yyyyzz_1, \
                                         tg_xxxyyz_yyyyzzz_0, tg_xxxyyz_yyyyzzz_1, tg_xxxyyz_yyyzzz_1, tg_xxxyyz_yyyzzzz_0, \
                                         tg_xxxyyz_yyyzzzz_1, tg_xxxyyz_yyzzzz_1, tg_xxxyyz_yyzzzzz_0, tg_xxxyyz_yyzzzzz_1, \
                                         tg_xxxyyz_yzzzzz_1, tg_xxxyyz_yzzzzzz_0, tg_xxxyyz_yzzzzzz_1, tg_xxxyyz_zzzzzz_1, \
                                         tg_xxxyyz_zzzzzzz_0, tg_xxxyyz_zzzzzzz_1, tg_xxxyzz_xxxxxx_1, tg_xxxyzz_xxxxxxx_0, \
                                         tg_xxxyzz_xxxxxxx_1, tg_xxxyzz_xxxxxxy_0, tg_xxxyzz_xxxxxxy_1, tg_xxxyzz_xxxxxxz_0, \
                                         tg_xxxyzz_xxxxxxz_1, tg_xxxyzz_xxxxxy_1, tg_xxxyzz_xxxxxyy_0, tg_xxxyzz_xxxxxyy_1, \
                                         tg_xxxyzz_xxxxxyz_0, tg_xxxyzz_xxxxxyz_1, tg_xxxyzz_xxxxxz_1, tg_xxxyzz_xxxxxzz_0, \
                                         tg_xxxyzz_xxxxxzz_1, tg_xxxyzz_xxxxyy_1, tg_xxxyzz_xxxxyyy_0, tg_xxxyzz_xxxxyyy_1, \
                                         tg_xxxyzz_xxxxyyz_0, tg_xxxyzz_xxxxyyz_1, tg_xxxyzz_xxxxyz_1, tg_xxxyzz_xxxxyzz_0, \
                                         tg_xxxyzz_xxxxyzz_1, tg_xxxyzz_xxxxzz_1, tg_xxxyzz_xxxxzzz_0, tg_xxxyzz_xxxxzzz_1, \
                                         tg_xxxyzz_xxxyyy_1, tg_xxxyzz_xxxyyyy_0, tg_xxxyzz_xxxyyyy_1, tg_xxxyzz_xxxyyyz_0, \
                                         tg_xxxyzz_xxxyyyz_1, tg_xxxyzz_xxxyyz_1, tg_xxxyzz_xxxyzz_1, tg_xxxyzz_xxxzzz_1, \
                                         tg_xxxyzz_xxyyyy_1, tg_xxxyzz_xxyyyz_1, tg_xxxzz_xxzzzzz_0, tg_xxxzz_xxzzzzz_1, \
                                         tg_xxxzz_xyyyyyy_0, tg_xxxzz_xyyyyyy_1, tg_xxxzz_xyyyyyz_0, tg_xxxzz_xyyyyyz_1, \
                                         tg_xxxzz_xyyyyzz_0, tg_xxxzz_xyyyyzz_1, tg_xxxzz_xyyyzzz_0, tg_xxxzz_xyyyzzz_1, \
                                         tg_xxxzz_xyyzzzz_0, tg_xxxzz_xyyzzzz_1, tg_xxxzz_xyzzzzz_0, tg_xxxzz_xyzzzzz_1, \
                                         tg_xxxzz_xzzzzzz_0, tg_xxxzz_xzzzzzz_1, tg_xxxzz_yyyyyyy_0, tg_xxxzz_yyyyyyy_1, \
                                         tg_xxxzz_yyyyyyz_0, tg_xxxzz_yyyyyyz_1, tg_xxxzz_yyyyyzz_0, tg_xxxzz_yyyyyzz_1, \
                                         tg_xxxzz_yyyyzzz_0, tg_xxxzz_yyyyzzz_1, tg_xxxzz_yyyzzzz_0, tg_xxxzz_yyyzzzz_1, \
                                         tg_xxxzz_yyzzzzz_0, tg_xxxzz_yyzzzzz_1, tg_xxxzz_yzzzzzz_0, tg_xxxzz_yzzzzzz_1, \
                                         tg_xxxzz_zzzzzzz_0, tg_xxxzz_zzzzzzz_1, tg_xxyyy_xxxxxxx_0, tg_xxyyy_xxxxxxx_1, \
                                         tg_xxyyy_xxxxxxy_0, tg_xxyyy_xxxxxxy_1, tg_xxyyy_xxxxxxz_0, tg_xxyyy_xxxxxxz_1, \
                                         tg_xxyyy_xxxxxyy_0, tg_xxyyy_xxxxxyy_1, tg_xxyyy_xxxxxyz_0, tg_xxyyy_xxxxxyz_1, \
                                         tg_xxyyy_xxxxxzz_0, tg_xxyyy_xxxxxzz_1, tg_xxyyy_xxxxyyy_0, tg_xxyyy_xxxxyyy_1, \
                                         tg_xxyyy_xxxxyyz_0, tg_xxyyy_xxxxyyz_1, tg_xxyyy_xxxxyzz_0, tg_xxyyy_xxxxyzz_1, \
                                         tg_xxyyy_xxxxzzz_0, tg_xxyyy_xxxxzzz_1, tg_xxyyy_xxxyyyy_0, tg_xxyyy_xxxyyyy_1, \
                                         tg_xxyyy_xxxyyyz_0, tg_xxyyy_xxxyyyz_1, tg_xxyyy_xxxyyzz_0, tg_xxyyy_xxxyyzz_1, \
                                         tg_xxyyy_xxxyzzz_0, tg_xxyyy_xxxyzzz_1, tg_xxyyy_xxxzzzz_0, tg_xxyyy_xxxzzzz_1, \
                                         tg_xxyyy_xxyyyyy_0, tg_xxyyy_xxyyyyy_1, tg_xxyyy_xxyyyyz_0, tg_xxyyy_xxyyyyz_1, \
                                         tg_xxyyy_xxyyyzz_0, tg_xxyyy_xxyyyzz_1, tg_xxyyy_xxyyzzz_0, tg_xxyyy_xxyyzzz_1, \
                                         tg_xxyyy_xxyzzzz_0, tg_xxyyy_xxyzzzz_1, tg_xxyyy_xxzzzzz_0, tg_xxyyy_xxzzzzz_1, \
                                         tg_xxyyy_xyyyyyy_0, tg_xxyyy_xyyyyyy_1, tg_xxyyy_xyyyyyz_0, tg_xxyyy_xyyyyyz_1, \
                                         tg_xxyyy_xyyyyzz_0, tg_xxyyy_xyyyyzz_1, tg_xxyyy_xyyyzzz_0, tg_xxyyy_xyyyzzz_1, \
                                         tg_xxyyy_xyyzzzz_0, tg_xxyyy_xyyzzzz_1, tg_xxyyy_xyzzzzz_0, tg_xxyyy_xyzzzzz_1, \
                                         tg_xxyyy_xzzzzzz_0, tg_xxyyy_xzzzzzz_1, tg_xxyyy_yyyyyyy_0, tg_xxyyy_yyyyyyy_1, \
                                         tg_xxyyy_yyyyyyz_0, tg_xxyyy_yyyyyyz_1, tg_xxyyy_yyyyyzz_0, tg_xxyyy_yyyyyzz_1, \
                                         tg_xxyyy_yyyyzzz_0, tg_xxyyy_yyyyzzz_1, tg_xxyyy_yyyzzzz_0, tg_xxyyy_yyyzzzz_1, \
                                         tg_xxyyy_yyzzzzz_0, tg_xxyyy_yyzzzzz_1, tg_xxyyy_yzzzzzz_0, tg_xxyyy_yzzzzzz_1, \
                                         tg_xxyyy_zzzzzzz_0, tg_xxyyy_zzzzzzz_1, tg_xxyyz_xxxxxxx_0, tg_xxyyz_xxxxxxx_1, \
                                         tg_xxyyz_xxxxxxy_0, tg_xxyyz_xxxxxxy_1, tg_xxyyz_xxxxxxz_0, tg_xxyyz_xxxxxxz_1, \
                                         tg_xxyyz_xxxxxyy_0, tg_xxyyz_xxxxxyy_1, tg_xxyyz_xxxxxyz_0, tg_xxyyz_xxxxxyz_1, \
                                         tg_xxyyz_xxxxxzz_0, tg_xxyyz_xxxxxzz_1, tg_xxyyz_xxxxyyy_0, tg_xxyyz_xxxxyyy_1, \
                                         tg_xxyyz_xxxxyyz_0, tg_xxyyz_xxxxyyz_1, tg_xxyyz_xxxxyzz_0, tg_xxyyz_xxxxyzz_1, \
                                         tg_xxyyz_xxxxzzz_0, tg_xxyyz_xxxxzzz_1, tg_xxyyz_xxxyyyy_0, tg_xxyyz_xxxyyyy_1, \
                                         tg_xxyyz_xxxyyyz_0, tg_xxyyz_xxxyyyz_1, tg_xxyyz_xxxyyzz_0, tg_xxyyz_xxxyyzz_1, \
                                         tg_xxyyz_xxxyzzz_0, tg_xxyyz_xxxyzzz_1, tg_xxyyz_xxxzzzz_0, tg_xxyyz_xxxzzzz_1, \
                                         tg_xxyyz_xxyyyyy_0, tg_xxyyz_xxyyyyy_1, tg_xxyyz_xxyyyyz_0, tg_xxyyz_xxyyyyz_1, \
                                         tg_xxyyz_xxyyyzz_0, tg_xxyyz_xxyyyzz_1, tg_xxyyz_xxyyzzz_0, tg_xxyyz_xxyyzzz_1, \
                                         tg_xxyyz_xxyzzzz_0, tg_xxyyz_xxyzzzz_1, tg_xxyyz_xxzzzzz_0, tg_xxyyz_xxzzzzz_1, \
                                         tg_xxyyz_xyyyyyy_0, tg_xxyyz_xyyyyyy_1, tg_xxyyz_xyyyyyz_0, tg_xxyyz_xyyyyyz_1, \
                                         tg_xxyyz_xyyyyzz_0, tg_xxyyz_xyyyyzz_1, tg_xxyyz_xyyyzzz_0, tg_xxyyz_xyyyzzz_1, \
                                         tg_xxyyz_xyyzzzz_0, tg_xxyyz_xyyzzzz_1, tg_xxyyz_xyzzzzz_0, tg_xxyyz_xyzzzzz_1, \
                                         tg_xxyyz_xzzzzzz_0, tg_xxyyz_xzzzzzz_1, tg_xxyyz_yyyyyyy_0, tg_xxyyz_yyyyyyy_1, \
                                         tg_xxyyz_yyyyyyz_0, tg_xxyyz_yyyyyyz_1, tg_xxyyz_yyyyyzz_0, tg_xxyyz_yyyyyzz_1, \
                                         tg_xxyyz_yyyyzzz_0, tg_xxyyz_yyyyzzz_1, tg_xxyyz_yyyzzzz_0, tg_xxyyz_yyyzzzz_1, \
                                         tg_xxyyz_yyzzzzz_0, tg_xxyyz_yyzzzzz_1, tg_xxyyz_yzzzzzz_0, tg_xxyyz_yzzzzzz_1, \
                                         tg_xxyyz_zzzzzzz_0, tg_xxyyz_zzzzzzz_1, tg_xxyzz_xxxxxxx_0, tg_xxyzz_xxxxxxx_1, \
                                         tg_xxyzz_xxxxxxy_0, tg_xxyzz_xxxxxxy_1, tg_xxyzz_xxxxxxz_0, tg_xxyzz_xxxxxxz_1, \
                                         tg_xxyzz_xxxxxyy_0, tg_xxyzz_xxxxxyy_1, tg_xxyzz_xxxxxyz_0, tg_xxyzz_xxxxxyz_1, \
                                         tg_xxyzz_xxxxxzz_0, tg_xxyzz_xxxxxzz_1, tg_xxyzz_xxxxyyy_0, tg_xxyzz_xxxxyyy_1, \
                                         tg_xxyzz_xxxxyyz_0, tg_xxyzz_xxxxyyz_1, tg_xxyzz_xxxxyzz_0, tg_xxyzz_xxxxyzz_1, \
                                         tg_xxyzz_xxxxzzz_0, tg_xxyzz_xxxxzzz_1, tg_xxyzz_xxxyyyy_0, tg_xxyzz_xxxyyyy_1, \
                                         tg_xxyzz_xxxyyyz_0, tg_xxyzz_xxxyyyz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxzz_xxzzzzz_0[j] = pb_x * tg_xxxxzz_xxzzzzz_0[j] + fr * tg_xxxxzz_xxzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xxzzzzz_0[j] - tg_xxxzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzz_xzzzzz_1[j];

                    tg_xxxxxzz_xyyyyyy_0[j] = pb_x * tg_xxxxzz_xyyyyyy_0[j] + fr * tg_xxxxzz_xyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyyyyyy_0[j] - tg_xxxzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yyyyyy_1[j];

                    tg_xxxxxzz_xyyyyyz_0[j] = pb_x * tg_xxxxzz_xyyyyyz_0[j] + fr * tg_xxxxzz_xyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyyyyyz_0[j] - tg_xxxzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yyyyyz_1[j];

                    tg_xxxxxzz_xyyyyzz_0[j] = pb_x * tg_xxxxzz_xyyyyzz_0[j] + fr * tg_xxxxzz_xyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyyyyzz_0[j] - tg_xxxzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yyyyzz_1[j];

                    tg_xxxxxzz_xyyyzzz_0[j] = pb_x * tg_xxxxzz_xyyyzzz_0[j] + fr * tg_xxxxzz_xyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyyyzzz_0[j] - tg_xxxzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yyyzzz_1[j];

                    tg_xxxxxzz_xyyzzzz_0[j] = pb_x * tg_xxxxzz_xyyzzzz_0[j] + fr * tg_xxxxzz_xyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyyzzzz_0[j] - tg_xxxzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yyzzzz_1[j];

                    tg_xxxxxzz_xyzzzzz_0[j] = pb_x * tg_xxxxzz_xyzzzzz_0[j] + fr * tg_xxxxzz_xyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xyzzzzz_0[j] - tg_xxxzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_yzzzzz_1[j];

                    tg_xxxxxzz_xzzzzzz_0[j] = pb_x * tg_xxxxzz_xzzzzzz_0[j] + fr * tg_xxxxzz_xzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_xzzzzzz_0[j] - tg_xxxzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzz_zzzzzz_1[j];

                    tg_xxxxxzz_yyyyyyy_0[j] = pb_x * tg_xxxxzz_yyyyyyy_0[j] + fr * tg_xxxxzz_yyyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyyyyyy_0[j] - tg_xxxzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxxzz_yyyyyyz_0[j] = pb_x * tg_xxxxzz_yyyyyyz_0[j] + fr * tg_xxxxzz_yyyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyyyyyz_0[j] - tg_xxxzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxxzz_yyyyyzz_0[j] = pb_x * tg_xxxxzz_yyyyyzz_0[j] + fr * tg_xxxxzz_yyyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyyyyzz_0[j] - tg_xxxzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxxzz_yyyyzzz_0[j] = pb_x * tg_xxxxzz_yyyyzzz_0[j] + fr * tg_xxxxzz_yyyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyyyzzz_0[j] - tg_xxxzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxxzz_yyyzzzz_0[j] = pb_x * tg_xxxxzz_yyyzzzz_0[j] + fr * tg_xxxxzz_yyyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyyzzzz_0[j] - tg_xxxzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxxzz_yyzzzzz_0[j] = pb_x * tg_xxxxzz_yyzzzzz_0[j] + fr * tg_xxxxzz_yyzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yyzzzzz_0[j] - tg_xxxzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxxzz_yzzzzzz_0[j] = pb_x * tg_xxxxzz_yzzzzzz_0[j] + fr * tg_xxxxzz_yzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_yzzzzzz_0[j] - tg_xxxzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxxzz_zzzzzzz_0[j] = pb_x * tg_xxxxzz_zzzzzzz_0[j] + fr * tg_xxxxzz_zzzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzz_zzzzzzz_0[j] - tg_xxxzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyy_xxxxxxx_0[j] = pb_x * tg_xxxyyy_xxxxxxx_0[j] + fr * tg_xxxyyy_xxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxxx_0[j] - tg_xxyyy_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyyy_xxxxxx_1[j];

                    tg_xxxxyyy_xxxxxxy_0[j] = pb_x * tg_xxxyyy_xxxxxxy_0[j] + fr * tg_xxxyyy_xxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxxy_0[j] - tg_xxyyy_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyy_xxxxxy_1[j];

                    tg_xxxxyyy_xxxxxxz_0[j] = pb_x * tg_xxxyyy_xxxxxxz_0[j] + fr * tg_xxxyyy_xxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxxz_0[j] - tg_xxyyy_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyy_xxxxxz_1[j];

                    tg_xxxxyyy_xxxxxyy_0[j] = pb_x * tg_xxxyyy_xxxxxyy_0[j] + fr * tg_xxxyyy_xxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxyy_0[j] - tg_xxyyy_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyy_xxxxyy_1[j];

                    tg_xxxxyyy_xxxxxyz_0[j] = pb_x * tg_xxxyyy_xxxxxyz_0[j] + fr * tg_xxxyyy_xxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxyz_0[j] - tg_xxyyy_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyy_xxxxyz_1[j];

                    tg_xxxxyyy_xxxxxzz_0[j] = pb_x * tg_xxxyyy_xxxxxzz_0[j] + fr * tg_xxxyyy_xxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxxzz_0[j] - tg_xxyyy_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyy_xxxxzz_1[j];

                    tg_xxxxyyy_xxxxyyy_0[j] = pb_x * tg_xxxyyy_xxxxyyy_0[j] + fr * tg_xxxyyy_xxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxyyy_0[j] - tg_xxyyy_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyy_xxxyyy_1[j];

                    tg_xxxxyyy_xxxxyyz_0[j] = pb_x * tg_xxxyyy_xxxxyyz_0[j] + fr * tg_xxxyyy_xxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxyyz_0[j] - tg_xxyyy_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyy_xxxyyz_1[j];

                    tg_xxxxyyy_xxxxyzz_0[j] = pb_x * tg_xxxyyy_xxxxyzz_0[j] + fr * tg_xxxyyy_xxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxyzz_0[j] - tg_xxyyy_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyy_xxxyzz_1[j];

                    tg_xxxxyyy_xxxxzzz_0[j] = pb_x * tg_xxxyyy_xxxxzzz_0[j] + fr * tg_xxxyyy_xxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxxzzz_0[j] - tg_xxyyy_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyy_xxxzzz_1[j];

                    tg_xxxxyyy_xxxyyyy_0[j] = pb_x * tg_xxxyyy_xxxyyyy_0[j] + fr * tg_xxxyyy_xxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxyyyy_0[j] - tg_xxyyy_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyy_xxyyyy_1[j];

                    tg_xxxxyyy_xxxyyyz_0[j] = pb_x * tg_xxxyyy_xxxyyyz_0[j] + fr * tg_xxxyyy_xxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxyyyz_0[j] - tg_xxyyy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyy_xxyyyz_1[j];

                    tg_xxxxyyy_xxxyyzz_0[j] = pb_x * tg_xxxyyy_xxxyyzz_0[j] + fr * tg_xxxyyy_xxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxyyzz_0[j] - tg_xxyyy_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyy_xxyyzz_1[j];

                    tg_xxxxyyy_xxxyzzz_0[j] = pb_x * tg_xxxyyy_xxxyzzz_0[j] + fr * tg_xxxyyy_xxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxyzzz_0[j] - tg_xxyyy_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyy_xxyzzz_1[j];

                    tg_xxxxyyy_xxxzzzz_0[j] = pb_x * tg_xxxyyy_xxxzzzz_0[j] + fr * tg_xxxyyy_xxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxxzzzz_0[j] - tg_xxyyy_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyy_xxzzzz_1[j];

                    tg_xxxxyyy_xxyyyyy_0[j] = pb_x * tg_xxxyyy_xxyyyyy_0[j] + fr * tg_xxxyyy_xxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxyyyyy_0[j] - tg_xxyyy_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xyyyyy_1[j];

                    tg_xxxxyyy_xxyyyyz_0[j] = pb_x * tg_xxxyyy_xxyyyyz_0[j] + fr * tg_xxxyyy_xxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxyyyyz_0[j] - tg_xxyyy_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xyyyyz_1[j];

                    tg_xxxxyyy_xxyyyzz_0[j] = pb_x * tg_xxxyyy_xxyyyzz_0[j] + fr * tg_xxxyyy_xxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxyyyzz_0[j] - tg_xxyyy_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xyyyzz_1[j];

                    tg_xxxxyyy_xxyyzzz_0[j] = pb_x * tg_xxxyyy_xxyyzzz_0[j] + fr * tg_xxxyyy_xxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxyyzzz_0[j] - tg_xxyyy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xyyzzz_1[j];

                    tg_xxxxyyy_xxyzzzz_0[j] = pb_x * tg_xxxyyy_xxyzzzz_0[j] + fr * tg_xxxyyy_xxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxyzzzz_0[j] - tg_xxyyy_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xyzzzz_1[j];

                    tg_xxxxyyy_xxzzzzz_0[j] = pb_x * tg_xxxyyy_xxzzzzz_0[j] + fr * tg_xxxyyy_xxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xxzzzzz_0[j] - tg_xxyyy_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyy_xzzzzz_1[j];

                    tg_xxxxyyy_xyyyyyy_0[j] = pb_x * tg_xxxyyy_xyyyyyy_0[j] + fr * tg_xxxyyy_xyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyyyyyy_0[j] - tg_xxyyy_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yyyyyy_1[j];

                    tg_xxxxyyy_xyyyyyz_0[j] = pb_x * tg_xxxyyy_xyyyyyz_0[j] + fr * tg_xxxyyy_xyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyyyyyz_0[j] - tg_xxyyy_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yyyyyz_1[j];

                    tg_xxxxyyy_xyyyyzz_0[j] = pb_x * tg_xxxyyy_xyyyyzz_0[j] + fr * tg_xxxyyy_xyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyyyyzz_0[j] - tg_xxyyy_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yyyyzz_1[j];

                    tg_xxxxyyy_xyyyzzz_0[j] = pb_x * tg_xxxyyy_xyyyzzz_0[j] + fr * tg_xxxyyy_xyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyyyzzz_0[j] - tg_xxyyy_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yyyzzz_1[j];

                    tg_xxxxyyy_xyyzzzz_0[j] = pb_x * tg_xxxyyy_xyyzzzz_0[j] + fr * tg_xxxyyy_xyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyyzzzz_0[j] - tg_xxyyy_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yyzzzz_1[j];

                    tg_xxxxyyy_xyzzzzz_0[j] = pb_x * tg_xxxyyy_xyzzzzz_0[j] + fr * tg_xxxyyy_xyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xyzzzzz_0[j] - tg_xxyyy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_yzzzzz_1[j];

                    tg_xxxxyyy_xzzzzzz_0[j] = pb_x * tg_xxxyyy_xzzzzzz_0[j] + fr * tg_xxxyyy_xzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_xzzzzzz_0[j] - tg_xxyyy_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyy_zzzzzz_1[j];

                    tg_xxxxyyy_yyyyyyy_0[j] = pb_x * tg_xxxyyy_yyyyyyy_0[j] + fr * tg_xxxyyy_yyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyyyyyy_0[j] - tg_xxyyy_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxyyy_yyyyyyz_0[j] = pb_x * tg_xxxyyy_yyyyyyz_0[j] + fr * tg_xxxyyy_yyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyyyyyz_0[j] - tg_xxyyy_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxyyy_yyyyyzz_0[j] = pb_x * tg_xxxyyy_yyyyyzz_0[j] + fr * tg_xxxyyy_yyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyyyyzz_0[j] - tg_xxyyy_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxyyy_yyyyzzz_0[j] = pb_x * tg_xxxyyy_yyyyzzz_0[j] + fr * tg_xxxyyy_yyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyyyzzz_0[j] - tg_xxyyy_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxyyy_yyyzzzz_0[j] = pb_x * tg_xxxyyy_yyyzzzz_0[j] + fr * tg_xxxyyy_yyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyyzzzz_0[j] - tg_xxyyy_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxyyy_yyzzzzz_0[j] = pb_x * tg_xxxyyy_yyzzzzz_0[j] + fr * tg_xxxyyy_yyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yyzzzzz_0[j] - tg_xxyyy_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyy_yzzzzzz_0[j] = pb_x * tg_xxxyyy_yzzzzzz_0[j] + fr * tg_xxxyyy_yzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_yzzzzzz_0[j] - tg_xxyyy_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyy_zzzzzzz_0[j] = pb_x * tg_xxxyyy_zzzzzzz_0[j] + fr * tg_xxxyyy_zzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyy_zzzzzzz_0[j] - tg_xxyyy_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyz_xxxxxxx_0[j] = pb_x * tg_xxxyyz_xxxxxxx_0[j] + fr * tg_xxxyyz_xxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxxx_0[j] - tg_xxyyz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyyz_xxxxxx_1[j];

                    tg_xxxxyyz_xxxxxxy_0[j] = pb_x * tg_xxxyyz_xxxxxxy_0[j] + fr * tg_xxxyyz_xxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxxy_0[j] - tg_xxyyz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyz_xxxxxy_1[j];

                    tg_xxxxyyz_xxxxxxz_0[j] = pb_x * tg_xxxyyz_xxxxxxz_0[j] + fr * tg_xxxyyz_xxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxxz_0[j] - tg_xxyyz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyz_xxxxxz_1[j];

                    tg_xxxxyyz_xxxxxyy_0[j] = pb_x * tg_xxxyyz_xxxxxyy_0[j] + fr * tg_xxxyyz_xxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxyy_0[j] - tg_xxyyz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyz_xxxxyy_1[j];

                    tg_xxxxyyz_xxxxxyz_0[j] = pb_x * tg_xxxyyz_xxxxxyz_0[j] + fr * tg_xxxyyz_xxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxyz_0[j] - tg_xxyyz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyz_xxxxyz_1[j];

                    tg_xxxxyyz_xxxxxzz_0[j] = pb_x * tg_xxxyyz_xxxxxzz_0[j] + fr * tg_xxxyyz_xxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxxzz_0[j] - tg_xxyyz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyz_xxxxzz_1[j];

                    tg_xxxxyyz_xxxxyyy_0[j] = pb_x * tg_xxxyyz_xxxxyyy_0[j] + fr * tg_xxxyyz_xxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxyyy_0[j] - tg_xxyyz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyz_xxxyyy_1[j];

                    tg_xxxxyyz_xxxxyyz_0[j] = pb_x * tg_xxxyyz_xxxxyyz_0[j] + fr * tg_xxxyyz_xxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxyyz_0[j] - tg_xxyyz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyz_xxxyyz_1[j];

                    tg_xxxxyyz_xxxxyzz_0[j] = pb_x * tg_xxxyyz_xxxxyzz_0[j] + fr * tg_xxxyyz_xxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxyzz_0[j] - tg_xxyyz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyz_xxxyzz_1[j];

                    tg_xxxxyyz_xxxxzzz_0[j] = pb_x * tg_xxxyyz_xxxxzzz_0[j] + fr * tg_xxxyyz_xxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxxzzz_0[j] - tg_xxyyz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyz_xxxzzz_1[j];

                    tg_xxxxyyz_xxxyyyy_0[j] = pb_x * tg_xxxyyz_xxxyyyy_0[j] + fr * tg_xxxyyz_xxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxyyyy_0[j] - tg_xxyyz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyz_xxyyyy_1[j];

                    tg_xxxxyyz_xxxyyyz_0[j] = pb_x * tg_xxxyyz_xxxyyyz_0[j] + fr * tg_xxxyyz_xxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxyyyz_0[j] - tg_xxyyz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyz_xxyyyz_1[j];

                    tg_xxxxyyz_xxxyyzz_0[j] = pb_x * tg_xxxyyz_xxxyyzz_0[j] + fr * tg_xxxyyz_xxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxyyzz_0[j] - tg_xxyyz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyz_xxyyzz_1[j];

                    tg_xxxxyyz_xxxyzzz_0[j] = pb_x * tg_xxxyyz_xxxyzzz_0[j] + fr * tg_xxxyyz_xxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxyzzz_0[j] - tg_xxyyz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyz_xxyzzz_1[j];

                    tg_xxxxyyz_xxxzzzz_0[j] = pb_x * tg_xxxyyz_xxxzzzz_0[j] + fr * tg_xxxyyz_xxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxxzzzz_0[j] - tg_xxyyz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyz_xxzzzz_1[j];

                    tg_xxxxyyz_xxyyyyy_0[j] = pb_x * tg_xxxyyz_xxyyyyy_0[j] + fr * tg_xxxyyz_xxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxyyyyy_0[j] - tg_xxyyz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xyyyyy_1[j];

                    tg_xxxxyyz_xxyyyyz_0[j] = pb_x * tg_xxxyyz_xxyyyyz_0[j] + fr * tg_xxxyyz_xxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxyyyyz_0[j] - tg_xxyyz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xyyyyz_1[j];

                    tg_xxxxyyz_xxyyyzz_0[j] = pb_x * tg_xxxyyz_xxyyyzz_0[j] + fr * tg_xxxyyz_xxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxyyyzz_0[j] - tg_xxyyz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xyyyzz_1[j];

                    tg_xxxxyyz_xxyyzzz_0[j] = pb_x * tg_xxxyyz_xxyyzzz_0[j] + fr * tg_xxxyyz_xxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxyyzzz_0[j] - tg_xxyyz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xyyzzz_1[j];

                    tg_xxxxyyz_xxyzzzz_0[j] = pb_x * tg_xxxyyz_xxyzzzz_0[j] + fr * tg_xxxyyz_xxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxyzzzz_0[j] - tg_xxyyz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xyzzzz_1[j];

                    tg_xxxxyyz_xxzzzzz_0[j] = pb_x * tg_xxxyyz_xxzzzzz_0[j] + fr * tg_xxxyyz_xxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xxzzzzz_0[j] - tg_xxyyz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyz_xzzzzz_1[j];

                    tg_xxxxyyz_xyyyyyy_0[j] = pb_x * tg_xxxyyz_xyyyyyy_0[j] + fr * tg_xxxyyz_xyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyyyyyy_0[j] - tg_xxyyz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yyyyyy_1[j];

                    tg_xxxxyyz_xyyyyyz_0[j] = pb_x * tg_xxxyyz_xyyyyyz_0[j] + fr * tg_xxxyyz_xyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyyyyyz_0[j] - tg_xxyyz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yyyyyz_1[j];

                    tg_xxxxyyz_xyyyyzz_0[j] = pb_x * tg_xxxyyz_xyyyyzz_0[j] + fr * tg_xxxyyz_xyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyyyyzz_0[j] - tg_xxyyz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yyyyzz_1[j];

                    tg_xxxxyyz_xyyyzzz_0[j] = pb_x * tg_xxxyyz_xyyyzzz_0[j] + fr * tg_xxxyyz_xyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyyyzzz_0[j] - tg_xxyyz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yyyzzz_1[j];

                    tg_xxxxyyz_xyyzzzz_0[j] = pb_x * tg_xxxyyz_xyyzzzz_0[j] + fr * tg_xxxyyz_xyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyyzzzz_0[j] - tg_xxyyz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yyzzzz_1[j];

                    tg_xxxxyyz_xyzzzzz_0[j] = pb_x * tg_xxxyyz_xyzzzzz_0[j] + fr * tg_xxxyyz_xyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xyzzzzz_0[j] - tg_xxyyz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_yzzzzz_1[j];

                    tg_xxxxyyz_xzzzzzz_0[j] = pb_x * tg_xxxyyz_xzzzzzz_0[j] + fr * tg_xxxyyz_xzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_xzzzzzz_0[j] - tg_xxyyz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyz_zzzzzz_1[j];

                    tg_xxxxyyz_yyyyyyy_0[j] = pb_x * tg_xxxyyz_yyyyyyy_0[j] + fr * tg_xxxyyz_yyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyyyyyy_0[j] - tg_xxyyz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxyyz_yyyyyyz_0[j] = pb_x * tg_xxxyyz_yyyyyyz_0[j] + fr * tg_xxxyyz_yyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyyyyyz_0[j] - tg_xxyyz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxyyz_yyyyyzz_0[j] = pb_x * tg_xxxyyz_yyyyyzz_0[j] + fr * tg_xxxyyz_yyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyyyyzz_0[j] - tg_xxyyz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxyyz_yyyyzzz_0[j] = pb_x * tg_xxxyyz_yyyyzzz_0[j] + fr * tg_xxxyyz_yyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyyyzzz_0[j] - tg_xxyyz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxyyz_yyyzzzz_0[j] = pb_x * tg_xxxyyz_yyyzzzz_0[j] + fr * tg_xxxyyz_yyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyyzzzz_0[j] - tg_xxyyz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxyyz_yyzzzzz_0[j] = pb_x * tg_xxxyyz_yyzzzzz_0[j] + fr * tg_xxxyyz_yyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yyzzzzz_0[j] - tg_xxyyz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyz_yzzzzzz_0[j] = pb_x * tg_xxxyyz_yzzzzzz_0[j] + fr * tg_xxxyyz_yzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_yzzzzzz_0[j] - tg_xxyyz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyz_zzzzzzz_0[j] = pb_x * tg_xxxyyz_zzzzzzz_0[j] + fr * tg_xxxyyz_zzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyz_zzzzzzz_0[j] - tg_xxyyz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyzz_xxxxxxx_0[j] = pb_x * tg_xxxyzz_xxxxxxx_0[j] + fr * tg_xxxyzz_xxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxxx_0[j] - tg_xxyzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxyzz_xxxxxx_1[j];

                    tg_xxxxyzz_xxxxxxy_0[j] = pb_x * tg_xxxyzz_xxxxxxy_0[j] + fr * tg_xxxyzz_xxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxxy_0[j] - tg_xxyzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyzz_xxxxxy_1[j];

                    tg_xxxxyzz_xxxxxxz_0[j] = pb_x * tg_xxxyzz_xxxxxxz_0[j] + fr * tg_xxxyzz_xxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxxz_0[j] - tg_xxyzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyzz_xxxxxz_1[j];

                    tg_xxxxyzz_xxxxxyy_0[j] = pb_x * tg_xxxyzz_xxxxxyy_0[j] + fr * tg_xxxyzz_xxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxyy_0[j] - tg_xxyzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyzz_xxxxyy_1[j];

                    tg_xxxxyzz_xxxxxyz_0[j] = pb_x * tg_xxxyzz_xxxxxyz_0[j] + fr * tg_xxxyzz_xxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxyz_0[j] - tg_xxyzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyzz_xxxxyz_1[j];

                    tg_xxxxyzz_xxxxxzz_0[j] = pb_x * tg_xxxyzz_xxxxxzz_0[j] + fr * tg_xxxyzz_xxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxxzz_0[j] - tg_xxyzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyzz_xxxxzz_1[j];

                    tg_xxxxyzz_xxxxyyy_0[j] = pb_x * tg_xxxyzz_xxxxyyy_0[j] + fr * tg_xxxyzz_xxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxyyy_0[j] - tg_xxyzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzz_xxxyyy_1[j];

                    tg_xxxxyzz_xxxxyyz_0[j] = pb_x * tg_xxxyzz_xxxxyyz_0[j] + fr * tg_xxxyzz_xxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxyyz_0[j] - tg_xxyzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzz_xxxyyz_1[j];

                    tg_xxxxyzz_xxxxyzz_0[j] = pb_x * tg_xxxyzz_xxxxyzz_0[j] + fr * tg_xxxyzz_xxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxyzz_0[j] - tg_xxyzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzz_xxxyzz_1[j];

                    tg_xxxxyzz_xxxxzzz_0[j] = pb_x * tg_xxxyzz_xxxxzzz_0[j] + fr * tg_xxxyzz_xxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxxzzz_0[j] - tg_xxyzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzz_xxxzzz_1[j];

                    tg_xxxxyzz_xxxyyyy_0[j] = pb_x * tg_xxxyzz_xxxyyyy_0[j] + fr * tg_xxxyzz_xxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxyyyy_0[j] - tg_xxyzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzz_xxyyyy_1[j];

                    tg_xxxxyzz_xxxyyyz_0[j] = pb_x * tg_xxxyzz_xxxyyyz_0[j] + fr * tg_xxxyzz_xxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxyyyz_0[j] - tg_xxyzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzz_xxyyyz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_300_400(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (300,400)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxyzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 300); 

                auto tg_xxxyzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 301); 

                auto tg_xxxyzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 302); 

                auto tg_xxxyzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 303); 

                auto tg_xxxyzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 304); 

                auto tg_xxxyzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 305); 

                auto tg_xxxyzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 306); 

                auto tg_xxxyzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 307); 

                auto tg_xxxyzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 308); 

                auto tg_xxxyzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 309); 

                auto tg_xxxyzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 310); 

                auto tg_xxxyzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 311); 

                auto tg_xxxyzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 312); 

                auto tg_xxxyzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 313); 

                auto tg_xxxyzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 314); 

                auto tg_xxxyzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 315); 

                auto tg_xxxyzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 316); 

                auto tg_xxxyzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 317); 

                auto tg_xxxyzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 318); 

                auto tg_xxxyzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 319); 

                auto tg_xxxyzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 320); 

                auto tg_xxxyzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 321); 

                auto tg_xxxyzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 322); 

                auto tg_xxxyzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 323); 

                auto tg_xxxzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 324); 

                auto tg_xxxzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 325); 

                auto tg_xxxzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 326); 

                auto tg_xxxzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 327); 

                auto tg_xxxzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 328); 

                auto tg_xxxzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 329); 

                auto tg_xxxzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 330); 

                auto tg_xxxzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 331); 

                auto tg_xxxzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 332); 

                auto tg_xxxzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 333); 

                auto tg_xxxzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 334); 

                auto tg_xxxzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 335); 

                auto tg_xxxzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 336); 

                auto tg_xxxzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 337); 

                auto tg_xxxzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 338); 

                auto tg_xxxzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 339); 

                auto tg_xxxzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 340); 

                auto tg_xxxzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 341); 

                auto tg_xxxzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 342); 

                auto tg_xxxzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 343); 

                auto tg_xxxzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 344); 

                auto tg_xxxzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 345); 

                auto tg_xxxzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 346); 

                auto tg_xxxzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 347); 

                auto tg_xxxzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 348); 

                auto tg_xxxzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 349); 

                auto tg_xxxzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 350); 

                auto tg_xxxzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 351); 

                auto tg_xxxzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 352); 

                auto tg_xxxzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 353); 

                auto tg_xxxzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 354); 

                auto tg_xxxzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 355); 

                auto tg_xxxzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 356); 

                auto tg_xxxzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 357); 

                auto tg_xxxzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 358); 

                auto tg_xxxzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 359); 

                auto tg_xxyyyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 360); 

                auto tg_xxyyyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 361); 

                auto tg_xxyyyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 362); 

                auto tg_xxyyyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 363); 

                auto tg_xxyyyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 364); 

                auto tg_xxyyyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 365); 

                auto tg_xxyyyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 366); 

                auto tg_xxyyyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 367); 

                auto tg_xxyyyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 368); 

                auto tg_xxyyyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 369); 

                auto tg_xxyyyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 370); 

                auto tg_xxyyyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 371); 

                auto tg_xxyyyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 372); 

                auto tg_xxyyyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 373); 

                auto tg_xxyyyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 374); 

                auto tg_xxyyyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 375); 

                auto tg_xxyyyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 376); 

                auto tg_xxyyyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 377); 

                auto tg_xxyyyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 378); 

                auto tg_xxyyyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 379); 

                auto tg_xxyyyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 380); 

                auto tg_xxyyyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 381); 

                auto tg_xxyyyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 382); 

                auto tg_xxyyyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 383); 

                auto tg_xxyyyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 384); 

                auto tg_xxyyyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 385); 

                auto tg_xxyyyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 386); 

                auto tg_xxyyyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 387); 

                auto tg_xxyyyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 388); 

                auto tg_xxyyyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 389); 

                auto tg_xxyyyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 390); 

                auto tg_xxyyyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 391); 

                auto tg_xxyyyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 392); 

                auto tg_xxyyyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 393); 

                auto tg_xxyyyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 394); 

                auto tg_xxyyyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 395); 

                auto tg_xxyyyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 396); 

                auto tg_xxyyyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 397); 

                auto tg_xxyyyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 398); 

                auto tg_xxyyyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 399); 

                auto tg_xxxyzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 300); 

                auto tg_xxxyzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 301); 

                auto tg_xxxyzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 302); 

                auto tg_xxxyzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 303); 

                auto tg_xxxyzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 304); 

                auto tg_xxxyzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 305); 

                auto tg_xxxyzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 306); 

                auto tg_xxxyzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 307); 

                auto tg_xxxyzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 308); 

                auto tg_xxxyzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 309); 

                auto tg_xxxyzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 310); 

                auto tg_xxxyzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 311); 

                auto tg_xxxyzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 312); 

                auto tg_xxxyzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 313); 

                auto tg_xxxyzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 314); 

                auto tg_xxxyzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 315); 

                auto tg_xxxyzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 316); 

                auto tg_xxxyzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 317); 

                auto tg_xxxyzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 318); 

                auto tg_xxxyzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 319); 

                auto tg_xxxyzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 320); 

                auto tg_xxxyzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 321); 

                auto tg_xxxyzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 322); 

                auto tg_xxxyzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 323); 

                auto tg_xxxzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 324); 

                auto tg_xxxzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 325); 

                auto tg_xxxzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 326); 

                auto tg_xxxzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 327); 

                auto tg_xxxzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 328); 

                auto tg_xxxzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 329); 

                auto tg_xxxzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 330); 

                auto tg_xxxzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 331); 

                auto tg_xxxzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 332); 

                auto tg_xxxzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 333); 

                auto tg_xxxzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 334); 

                auto tg_xxxzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 335); 

                auto tg_xxxzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 336); 

                auto tg_xxxzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 337); 

                auto tg_xxxzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 338); 

                auto tg_xxxzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 339); 

                auto tg_xxxzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 340); 

                auto tg_xxxzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 341); 

                auto tg_xxxzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 342); 

                auto tg_xxxzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 343); 

                auto tg_xxxzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 344); 

                auto tg_xxxzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 345); 

                auto tg_xxxzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 346); 

                auto tg_xxxzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 347); 

                auto tg_xxxzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 348); 

                auto tg_xxxzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 349); 

                auto tg_xxxzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 350); 

                auto tg_xxxzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 351); 

                auto tg_xxxzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 352); 

                auto tg_xxxzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 353); 

                auto tg_xxxzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 354); 

                auto tg_xxxzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 355); 

                auto tg_xxxzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 356); 

                auto tg_xxxzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 357); 

                auto tg_xxxzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 358); 

                auto tg_xxxzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 359); 

                auto tg_xxyyyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 360); 

                auto tg_xxyyyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 361); 

                auto tg_xxyyyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 362); 

                auto tg_xxyyyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 363); 

                auto tg_xxyyyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 364); 

                auto tg_xxyyyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 365); 

                auto tg_xxyyyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 366); 

                auto tg_xxyyyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 367); 

                auto tg_xxyyyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 368); 

                auto tg_xxyyyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 369); 

                auto tg_xxyyyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 370); 

                auto tg_xxyyyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 371); 

                auto tg_xxyyyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 372); 

                auto tg_xxyyyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 373); 

                auto tg_xxyyyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 374); 

                auto tg_xxyyyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 375); 

                auto tg_xxyyyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 376); 

                auto tg_xxyyyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 377); 

                auto tg_xxyyyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 378); 

                auto tg_xxyyyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 379); 

                auto tg_xxyyyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 380); 

                auto tg_xxyyyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 381); 

                auto tg_xxyyyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 382); 

                auto tg_xxyyyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 383); 

                auto tg_xxyyyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 384); 

                auto tg_xxyyyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 385); 

                auto tg_xxyyyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 386); 

                auto tg_xxyyyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 387); 

                auto tg_xxyyyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 388); 

                auto tg_xxyyyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 389); 

                auto tg_xxyyyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 390); 

                auto tg_xxyyyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 391); 

                auto tg_xxyyyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 392); 

                auto tg_xxyyyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 393); 

                auto tg_xxyyyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 394); 

                auto tg_xxyyyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 395); 

                auto tg_xxyyyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 396); 

                auto tg_xxyyyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 397); 

                auto tg_xxyyyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 398); 

                auto tg_xxyyyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 399); 

                auto tg_xxyzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 300); 

                auto tg_xxyzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 301); 

                auto tg_xxyzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 302); 

                auto tg_xxyzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 303); 

                auto tg_xxyzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 304); 

                auto tg_xxyzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 305); 

                auto tg_xxyzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 306); 

                auto tg_xxyzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 307); 

                auto tg_xxyzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 308); 

                auto tg_xxyzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 309); 

                auto tg_xxyzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 310); 

                auto tg_xxyzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 311); 

                auto tg_xxyzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 312); 

                auto tg_xxyzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 313); 

                auto tg_xxyzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 314); 

                auto tg_xxyzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 315); 

                auto tg_xxyzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 316); 

                auto tg_xxyzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 317); 

                auto tg_xxyzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 318); 

                auto tg_xxyzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 319); 

                auto tg_xxyzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 320); 

                auto tg_xxyzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 321); 

                auto tg_xxyzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 322); 

                auto tg_xxyzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 323); 

                auto tg_xxzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 324); 

                auto tg_xxzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 325); 

                auto tg_xxzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 326); 

                auto tg_xxzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 327); 

                auto tg_xxzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 328); 

                auto tg_xxzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 329); 

                auto tg_xxzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 330); 

                auto tg_xxzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 331); 

                auto tg_xxzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 332); 

                auto tg_xxzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 333); 

                auto tg_xxzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 334); 

                auto tg_xxzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 335); 

                auto tg_xxzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 336); 

                auto tg_xxzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 337); 

                auto tg_xxzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 338); 

                auto tg_xxzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 339); 

                auto tg_xxzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 340); 

                auto tg_xxzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 341); 

                auto tg_xxzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 342); 

                auto tg_xxzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 343); 

                auto tg_xxzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 344); 

                auto tg_xxzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 345); 

                auto tg_xxzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 346); 

                auto tg_xxzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 347); 

                auto tg_xxzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 348); 

                auto tg_xxzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 349); 

                auto tg_xxzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 350); 

                auto tg_xxzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 351); 

                auto tg_xxzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 352); 

                auto tg_xxzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 353); 

                auto tg_xxzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 354); 

                auto tg_xxzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 355); 

                auto tg_xxzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 356); 

                auto tg_xxzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 357); 

                auto tg_xxzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 358); 

                auto tg_xxzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 359); 

                auto tg_xyyyy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 360); 

                auto tg_xyyyy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 361); 

                auto tg_xyyyy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 362); 

                auto tg_xyyyy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 363); 

                auto tg_xyyyy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 364); 

                auto tg_xyyyy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 365); 

                auto tg_xyyyy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 366); 

                auto tg_xyyyy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 367); 

                auto tg_xyyyy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 368); 

                auto tg_xyyyy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 369); 

                auto tg_xyyyy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 370); 

                auto tg_xyyyy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 371); 

                auto tg_xyyyy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 372); 

                auto tg_xyyyy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 373); 

                auto tg_xyyyy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 374); 

                auto tg_xyyyy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 375); 

                auto tg_xyyyy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 376); 

                auto tg_xyyyy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 377); 

                auto tg_xyyyy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 378); 

                auto tg_xyyyy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 379); 

                auto tg_xyyyy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 380); 

                auto tg_xyyyy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 381); 

                auto tg_xyyyy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 382); 

                auto tg_xyyyy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 383); 

                auto tg_xyyyy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 384); 

                auto tg_xyyyy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 385); 

                auto tg_xyyyy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 386); 

                auto tg_xyyyy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 387); 

                auto tg_xyyyy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 388); 

                auto tg_xyyyy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 389); 

                auto tg_xyyyy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 390); 

                auto tg_xyyyy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 391); 

                auto tg_xyyyy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 392); 

                auto tg_xyyyy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 393); 

                auto tg_xyyyy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 394); 

                auto tg_xyyyy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 395); 

                auto tg_xyyyz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 396); 

                auto tg_xyyyz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 397); 

                auto tg_xyyyz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 398); 

                auto tg_xyyyz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 399); 

                auto tg_xxyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 300); 

                auto tg_xxyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 301); 

                auto tg_xxyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 302); 

                auto tg_xxyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 303); 

                auto tg_xxyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 304); 

                auto tg_xxyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 305); 

                auto tg_xxyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 306); 

                auto tg_xxyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 307); 

                auto tg_xxyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 308); 

                auto tg_xxyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 309); 

                auto tg_xxyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 310); 

                auto tg_xxyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 311); 

                auto tg_xxyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 312); 

                auto tg_xxyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 313); 

                auto tg_xxyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 314); 

                auto tg_xxyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 315); 

                auto tg_xxyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 316); 

                auto tg_xxyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 317); 

                auto tg_xxyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 318); 

                auto tg_xxyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 319); 

                auto tg_xxyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 320); 

                auto tg_xxyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 321); 

                auto tg_xxyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 322); 

                auto tg_xxyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 323); 

                auto tg_xxzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 324); 

                auto tg_xxzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 325); 

                auto tg_xxzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 326); 

                auto tg_xxzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 327); 

                auto tg_xxzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 328); 

                auto tg_xxzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 329); 

                auto tg_xxzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 330); 

                auto tg_xxzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 331); 

                auto tg_xxzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 332); 

                auto tg_xxzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 333); 

                auto tg_xxzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 334); 

                auto tg_xxzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 335); 

                auto tg_xxzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 336); 

                auto tg_xxzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 337); 

                auto tg_xxzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 338); 

                auto tg_xxzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 339); 

                auto tg_xxzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 340); 

                auto tg_xxzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 341); 

                auto tg_xxzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 342); 

                auto tg_xxzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 343); 

                auto tg_xxzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 344); 

                auto tg_xxzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 345); 

                auto tg_xxzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 346); 

                auto tg_xxzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 347); 

                auto tg_xxzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 348); 

                auto tg_xxzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 349); 

                auto tg_xxzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 350); 

                auto tg_xxzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 351); 

                auto tg_xxzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 352); 

                auto tg_xxzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 353); 

                auto tg_xxzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 354); 

                auto tg_xxzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 355); 

                auto tg_xxzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 356); 

                auto tg_xxzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 357); 

                auto tg_xxzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 358); 

                auto tg_xxzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 359); 

                auto tg_xyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 360); 

                auto tg_xyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 361); 

                auto tg_xyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 362); 

                auto tg_xyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 363); 

                auto tg_xyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 364); 

                auto tg_xyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 365); 

                auto tg_xyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 366); 

                auto tg_xyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 367); 

                auto tg_xyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 368); 

                auto tg_xyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 369); 

                auto tg_xyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 370); 

                auto tg_xyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 371); 

                auto tg_xyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 372); 

                auto tg_xyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 373); 

                auto tg_xyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 374); 

                auto tg_xyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 375); 

                auto tg_xyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 376); 

                auto tg_xyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 377); 

                auto tg_xyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 378); 

                auto tg_xyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 379); 

                auto tg_xyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 380); 

                auto tg_xyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 381); 

                auto tg_xyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 382); 

                auto tg_xyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 383); 

                auto tg_xyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 384); 

                auto tg_xyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 385); 

                auto tg_xyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 386); 

                auto tg_xyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 387); 

                auto tg_xyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 388); 

                auto tg_xyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 389); 

                auto tg_xyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 390); 

                auto tg_xyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 391); 

                auto tg_xyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 392); 

                auto tg_xyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 393); 

                auto tg_xyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 394); 

                auto tg_xyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 395); 

                auto tg_xyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 396); 

                auto tg_xyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 397); 

                auto tg_xyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 398); 

                auto tg_xyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 399); 

                auto tg_xxxyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 236); 

                auto tg_xxxyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 237); 

                auto tg_xxxyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 238); 

                auto tg_xxxyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 239); 

                auto tg_xxxyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 240); 

                auto tg_xxxyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 241); 

                auto tg_xxxyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 242); 

                auto tg_xxxyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 243); 

                auto tg_xxxyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 244); 

                auto tg_xxxyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 245); 

                auto tg_xxxyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 246); 

                auto tg_xxxyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 247); 

                auto tg_xxxyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 248); 

                auto tg_xxxyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 249); 

                auto tg_xxxyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 250); 

                auto tg_xxxyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 251); 

                auto tg_xxxzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 252); 

                auto tg_xxxzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 253); 

                auto tg_xxxzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 254); 

                auto tg_xxxzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 255); 

                auto tg_xxxzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 256); 

                auto tg_xxxzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 257); 

                auto tg_xxxzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 258); 

                auto tg_xxxzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 259); 

                auto tg_xxxzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 260); 

                auto tg_xxxzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 261); 

                auto tg_xxxzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 262); 

                auto tg_xxxzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 263); 

                auto tg_xxxzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 264); 

                auto tg_xxxzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 265); 

                auto tg_xxxzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 266); 

                auto tg_xxxzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 267); 

                auto tg_xxxzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 268); 

                auto tg_xxxzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 269); 

                auto tg_xxxzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 270); 

                auto tg_xxxzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 271); 

                auto tg_xxxzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 272); 

                auto tg_xxxzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 273); 

                auto tg_xxxzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 274); 

                auto tg_xxxzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 275); 

                auto tg_xxxzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 276); 

                auto tg_xxxzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 277); 

                auto tg_xxxzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 278); 

                auto tg_xxxzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 279); 

                auto tg_xxyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 280); 

                auto tg_xxyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 281); 

                auto tg_xxyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 282); 

                auto tg_xxyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 283); 

                auto tg_xxyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 284); 

                auto tg_xxyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 285); 

                auto tg_xxyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 286); 

                auto tg_xxyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 287); 

                auto tg_xxyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 288); 

                auto tg_xxyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 289); 

                auto tg_xxyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 290); 

                auto tg_xxyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 291); 

                auto tg_xxyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 292); 

                auto tg_xxyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 293); 

                auto tg_xxyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 294); 

                auto tg_xxyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 295); 

                auto tg_xxyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 296); 

                auto tg_xxyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 297); 

                auto tg_xxyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 298); 

                auto tg_xxyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 299); 

                auto tg_xxyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 300); 

                auto tg_xxyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 301); 

                auto tg_xxyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 302); 

                auto tg_xxyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 303); 

                auto tg_xxyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 304); 

                auto tg_xxyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 305); 

                auto tg_xxyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 306); 

                auto tg_xxyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 307); 

                auto tg_xxyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 308); 

                auto tg_xxyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 309); 

                auto tg_xxyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 310); 

                auto tg_xxyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 311); 

                // set up pointers to integrals

                auto tg_xxxxyzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 300); 

                auto tg_xxxxyzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 301); 

                auto tg_xxxxyzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 302); 

                auto tg_xxxxyzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 303); 

                auto tg_xxxxyzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 304); 

                auto tg_xxxxyzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 305); 

                auto tg_xxxxyzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 306); 

                auto tg_xxxxyzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 307); 

                auto tg_xxxxyzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 308); 

                auto tg_xxxxyzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 309); 

                auto tg_xxxxyzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 310); 

                auto tg_xxxxyzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 311); 

                auto tg_xxxxyzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 312); 

                auto tg_xxxxyzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 313); 

                auto tg_xxxxyzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 314); 

                auto tg_xxxxyzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 315); 

                auto tg_xxxxyzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 316); 

                auto tg_xxxxyzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 317); 

                auto tg_xxxxyzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 318); 

                auto tg_xxxxyzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 319); 

                auto tg_xxxxyzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 320); 

                auto tg_xxxxyzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 321); 

                auto tg_xxxxyzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 322); 

                auto tg_xxxxyzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 323); 

                auto tg_xxxxzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 324); 

                auto tg_xxxxzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 325); 

                auto tg_xxxxzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 326); 

                auto tg_xxxxzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 327); 

                auto tg_xxxxzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 328); 

                auto tg_xxxxzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 329); 

                auto tg_xxxxzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 330); 

                auto tg_xxxxzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 331); 

                auto tg_xxxxzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 332); 

                auto tg_xxxxzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 333); 

                auto tg_xxxxzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 334); 

                auto tg_xxxxzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 335); 

                auto tg_xxxxzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 336); 

                auto tg_xxxxzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 337); 

                auto tg_xxxxzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 338); 

                auto tg_xxxxzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 339); 

                auto tg_xxxxzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 340); 

                auto tg_xxxxzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 341); 

                auto tg_xxxxzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 342); 

                auto tg_xxxxzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 343); 

                auto tg_xxxxzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 344); 

                auto tg_xxxxzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 345); 

                auto tg_xxxxzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 346); 

                auto tg_xxxxzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 347); 

                auto tg_xxxxzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 348); 

                auto tg_xxxxzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 349); 

                auto tg_xxxxzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 350); 

                auto tg_xxxxzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 351); 

                auto tg_xxxxzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 352); 

                auto tg_xxxxzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 353); 

                auto tg_xxxxzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 354); 

                auto tg_xxxxzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 355); 

                auto tg_xxxxzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 356); 

                auto tg_xxxxzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 357); 

                auto tg_xxxxzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 358); 

                auto tg_xxxxzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 359); 

                auto tg_xxxyyyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 360); 

                auto tg_xxxyyyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 361); 

                auto tg_xxxyyyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 362); 

                auto tg_xxxyyyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 363); 

                auto tg_xxxyyyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 364); 

                auto tg_xxxyyyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 365); 

                auto tg_xxxyyyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 366); 

                auto tg_xxxyyyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 367); 

                auto tg_xxxyyyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 368); 

                auto tg_xxxyyyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 369); 

                auto tg_xxxyyyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 370); 

                auto tg_xxxyyyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 371); 

                auto tg_xxxyyyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 372); 

                auto tg_xxxyyyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 373); 

                auto tg_xxxyyyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 374); 

                auto tg_xxxyyyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 375); 

                auto tg_xxxyyyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 376); 

                auto tg_xxxyyyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 377); 

                auto tg_xxxyyyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 378); 

                auto tg_xxxyyyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 379); 

                auto tg_xxxyyyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 380); 

                auto tg_xxxyyyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 381); 

                auto tg_xxxyyyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 382); 

                auto tg_xxxyyyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 383); 

                auto tg_xxxyyyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 384); 

                auto tg_xxxyyyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 385); 

                auto tg_xxxyyyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 386); 

                auto tg_xxxyyyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 387); 

                auto tg_xxxyyyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 388); 

                auto tg_xxxyyyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 389); 

                auto tg_xxxyyyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 390); 

                auto tg_xxxyyyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 391); 

                auto tg_xxxyyyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 392); 

                auto tg_xxxyyyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 393); 

                auto tg_xxxyyyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 394); 

                auto tg_xxxyyyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 395); 

                auto tg_xxxyyyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 396); 

                auto tg_xxxyyyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 397); 

                auto tg_xxxyyyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 398); 

                auto tg_xxxyyyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 399); 

                // Batch of Integrals (300,400)

                #pragma omp simd aligned(fxn, fza, tg_xxxxyzz_xxxyyzz_0, tg_xxxxyzz_xxxyzzz_0, \
                                         tg_xxxxyzz_xxxzzzz_0, tg_xxxxyzz_xxyyyyy_0, tg_xxxxyzz_xxyyyyz_0, tg_xxxxyzz_xxyyyzz_0, \
                                         tg_xxxxyzz_xxyyzzz_0, tg_xxxxyzz_xxyzzzz_0, tg_xxxxyzz_xxzzzzz_0, tg_xxxxyzz_xyyyyyy_0, \
                                         tg_xxxxyzz_xyyyyyz_0, tg_xxxxyzz_xyyyyzz_0, tg_xxxxyzz_xyyyzzz_0, tg_xxxxyzz_xyyzzzz_0, \
                                         tg_xxxxyzz_xyzzzzz_0, tg_xxxxyzz_xzzzzzz_0, tg_xxxxyzz_yyyyyyy_0, tg_xxxxyzz_yyyyyyz_0, \
                                         tg_xxxxyzz_yyyyyzz_0, tg_xxxxyzz_yyyyzzz_0, tg_xxxxyzz_yyyzzzz_0, tg_xxxxyzz_yyzzzzz_0, \
                                         tg_xxxxyzz_yzzzzzz_0, tg_xxxxyzz_zzzzzzz_0, tg_xxxxzzz_xxxxxxx_0, tg_xxxxzzz_xxxxxxy_0, \
                                         tg_xxxxzzz_xxxxxxz_0, tg_xxxxzzz_xxxxxyy_0, tg_xxxxzzz_xxxxxyz_0, tg_xxxxzzz_xxxxxzz_0, \
                                         tg_xxxxzzz_xxxxyyy_0, tg_xxxxzzz_xxxxyyz_0, tg_xxxxzzz_xxxxyzz_0, tg_xxxxzzz_xxxxzzz_0, \
                                         tg_xxxxzzz_xxxyyyy_0, tg_xxxxzzz_xxxyyyz_0, tg_xxxxzzz_xxxyyzz_0, tg_xxxxzzz_xxxyzzz_0, \
                                         tg_xxxxzzz_xxxzzzz_0, tg_xxxxzzz_xxyyyyy_0, tg_xxxxzzz_xxyyyyz_0, tg_xxxxzzz_xxyyyzz_0, \
                                         tg_xxxxzzz_xxyyzzz_0, tg_xxxxzzz_xxyzzzz_0, tg_xxxxzzz_xxzzzzz_0, tg_xxxxzzz_xyyyyyy_0, \
                                         tg_xxxxzzz_xyyyyyz_0, tg_xxxxzzz_xyyyyzz_0, tg_xxxxzzz_xyyyzzz_0, tg_xxxxzzz_xyyzzzz_0, \
                                         tg_xxxxzzz_xyzzzzz_0, tg_xxxxzzz_xzzzzzz_0, tg_xxxxzzz_yyyyyyy_0, tg_xxxxzzz_yyyyyyz_0, \
                                         tg_xxxxzzz_yyyyyzz_0, tg_xxxxzzz_yyyyzzz_0, tg_xxxxzzz_yyyzzzz_0, tg_xxxxzzz_yyzzzzz_0, \
                                         tg_xxxxzzz_yzzzzzz_0, tg_xxxxzzz_zzzzzzz_0, tg_xxxyyyy_xxxxxxx_0, tg_xxxyyyy_xxxxxxy_0, \
                                         tg_xxxyyyy_xxxxxxz_0, tg_xxxyyyy_xxxxxyy_0, tg_xxxyyyy_xxxxxyz_0, tg_xxxyyyy_xxxxxzz_0, \
                                         tg_xxxyyyy_xxxxyyy_0, tg_xxxyyyy_xxxxyyz_0, tg_xxxyyyy_xxxxyzz_0, tg_xxxyyyy_xxxxzzz_0, \
                                         tg_xxxyyyy_xxxyyyy_0, tg_xxxyyyy_xxxyyyz_0, tg_xxxyyyy_xxxyyzz_0, tg_xxxyyyy_xxxyzzz_0, \
                                         tg_xxxyyyy_xxxzzzz_0, tg_xxxyyyy_xxyyyyy_0, tg_xxxyyyy_xxyyyyz_0, tg_xxxyyyy_xxyyyzz_0, \
                                         tg_xxxyyyy_xxyyzzz_0, tg_xxxyyyy_xxyzzzz_0, tg_xxxyyyy_xxzzzzz_0, tg_xxxyyyy_xyyyyyy_0, \
                                         tg_xxxyyyy_xyyyyyz_0, tg_xxxyyyy_xyyyyzz_0, tg_xxxyyyy_xyyyzzz_0, tg_xxxyyyy_xyyzzzz_0, \
                                         tg_xxxyyyy_xyzzzzz_0, tg_xxxyyyy_xzzzzzz_0, tg_xxxyyyy_yyyyyyy_0, tg_xxxyyyy_yyyyyyz_0, \
                                         tg_xxxyyyy_yyyyyzz_0, tg_xxxyyyy_yyyyzzz_0, tg_xxxyyyy_yyyzzzz_0, tg_xxxyyyy_yyzzzzz_0, \
                                         tg_xxxyyyy_yzzzzzz_0, tg_xxxyyyy_zzzzzzz_0, tg_xxxyyyz_xxxxxxx_0, tg_xxxyyyz_xxxxxxy_0, \
                                         tg_xxxyyyz_xxxxxxz_0, tg_xxxyyyz_xxxxxyy_0, tg_xxxyzz_xxxyyzz_0, tg_xxxyzz_xxxyyzz_1, \
                                         tg_xxxyzz_xxxyzzz_0, tg_xxxyzz_xxxyzzz_1, tg_xxxyzz_xxxzzzz_0, tg_xxxyzz_xxxzzzz_1, \
                                         tg_xxxyzz_xxyyyyy_0, tg_xxxyzz_xxyyyyy_1, tg_xxxyzz_xxyyyyz_0, tg_xxxyzz_xxyyyyz_1, \
                                         tg_xxxyzz_xxyyyzz_0, tg_xxxyzz_xxyyyzz_1, tg_xxxyzz_xxyyzz_1, tg_xxxyzz_xxyyzzz_0, \
                                         tg_xxxyzz_xxyyzzz_1, tg_xxxyzz_xxyzzz_1, tg_xxxyzz_xxyzzzz_0, tg_xxxyzz_xxyzzzz_1, \
                                         tg_xxxyzz_xxzzzz_1, tg_xxxyzz_xxzzzzz_0, tg_xxxyzz_xxzzzzz_1, tg_xxxyzz_xyyyyy_1, \
                                         tg_xxxyzz_xyyyyyy_0, tg_xxxyzz_xyyyyyy_1, tg_xxxyzz_xyyyyyz_0, tg_xxxyzz_xyyyyyz_1, \
                                         tg_xxxyzz_xyyyyz_1, tg_xxxyzz_xyyyyzz_0, tg_xxxyzz_xyyyyzz_1, tg_xxxyzz_xyyyzz_1, \
                                         tg_xxxyzz_xyyyzzz_0, tg_xxxyzz_xyyyzzz_1, tg_xxxyzz_xyyzzz_1, tg_xxxyzz_xyyzzzz_0, \
                                         tg_xxxyzz_xyyzzzz_1, tg_xxxyzz_xyzzzz_1, tg_xxxyzz_xyzzzzz_0, tg_xxxyzz_xyzzzzz_1, \
                                         tg_xxxyzz_xzzzzz_1, tg_xxxyzz_xzzzzzz_0, tg_xxxyzz_xzzzzzz_1, tg_xxxyzz_yyyyyy_1, \
                                         tg_xxxyzz_yyyyyyy_0, tg_xxxyzz_yyyyyyy_1, tg_xxxyzz_yyyyyyz_0, tg_xxxyzz_yyyyyyz_1, \
                                         tg_xxxyzz_yyyyyz_1, tg_xxxyzz_yyyyyzz_0, tg_xxxyzz_yyyyyzz_1, tg_xxxyzz_yyyyzz_1, \
                                         tg_xxxyzz_yyyyzzz_0, tg_xxxyzz_yyyyzzz_1, tg_xxxyzz_yyyzzz_1, tg_xxxyzz_yyyzzzz_0, \
                                         tg_xxxyzz_yyyzzzz_1, tg_xxxyzz_yyzzzz_1, tg_xxxyzz_yyzzzzz_0, tg_xxxyzz_yyzzzzz_1, \
                                         tg_xxxyzz_yzzzzz_1, tg_xxxyzz_yzzzzzz_0, tg_xxxyzz_yzzzzzz_1, tg_xxxyzz_zzzzzz_1, \
                                         tg_xxxyzz_zzzzzzz_0, tg_xxxyzz_zzzzzzz_1, tg_xxxzzz_xxxxxx_1, tg_xxxzzz_xxxxxxx_0, \
                                         tg_xxxzzz_xxxxxxx_1, tg_xxxzzz_xxxxxxy_0, tg_xxxzzz_xxxxxxy_1, tg_xxxzzz_xxxxxxz_0, \
                                         tg_xxxzzz_xxxxxxz_1, tg_xxxzzz_xxxxxy_1, tg_xxxzzz_xxxxxyy_0, tg_xxxzzz_xxxxxyy_1, \
                                         tg_xxxzzz_xxxxxyz_0, tg_xxxzzz_xxxxxyz_1, tg_xxxzzz_xxxxxz_1, tg_xxxzzz_xxxxxzz_0, \
                                         tg_xxxzzz_xxxxxzz_1, tg_xxxzzz_xxxxyy_1, tg_xxxzzz_xxxxyyy_0, tg_xxxzzz_xxxxyyy_1, \
                                         tg_xxxzzz_xxxxyyz_0, tg_xxxzzz_xxxxyyz_1, tg_xxxzzz_xxxxyz_1, tg_xxxzzz_xxxxyzz_0, \
                                         tg_xxxzzz_xxxxyzz_1, tg_xxxzzz_xxxxzz_1, tg_xxxzzz_xxxxzzz_0, tg_xxxzzz_xxxxzzz_1, \
                                         tg_xxxzzz_xxxyyy_1, tg_xxxzzz_xxxyyyy_0, tg_xxxzzz_xxxyyyy_1, tg_xxxzzz_xxxyyyz_0, \
                                         tg_xxxzzz_xxxyyyz_1, tg_xxxzzz_xxxyyz_1, tg_xxxzzz_xxxyyzz_0, tg_xxxzzz_xxxyyzz_1, \
                                         tg_xxxzzz_xxxyzz_1, tg_xxxzzz_xxxyzzz_0, tg_xxxzzz_xxxyzzz_1, tg_xxxzzz_xxxzzz_1, \
                                         tg_xxxzzz_xxxzzzz_0, tg_xxxzzz_xxxzzzz_1, tg_xxxzzz_xxyyyy_1, tg_xxxzzz_xxyyyyy_0, \
                                         tg_xxxzzz_xxyyyyy_1, tg_xxxzzz_xxyyyyz_0, tg_xxxzzz_xxyyyyz_1, tg_xxxzzz_xxyyyz_1, \
                                         tg_xxxzzz_xxyyyzz_0, tg_xxxzzz_xxyyyzz_1, tg_xxxzzz_xxyyzz_1, tg_xxxzzz_xxyyzzz_0, \
                                         tg_xxxzzz_xxyyzzz_1, tg_xxxzzz_xxyzzz_1, tg_xxxzzz_xxyzzzz_0, tg_xxxzzz_xxyzzzz_1, \
                                         tg_xxxzzz_xxzzzz_1, tg_xxxzzz_xxzzzzz_0, tg_xxxzzz_xxzzzzz_1, tg_xxxzzz_xyyyyy_1, \
                                         tg_xxxzzz_xyyyyyy_0, tg_xxxzzz_xyyyyyy_1, tg_xxxzzz_xyyyyyz_0, tg_xxxzzz_xyyyyyz_1, \
                                         tg_xxxzzz_xyyyyz_1, tg_xxxzzz_xyyyyzz_0, tg_xxxzzz_xyyyyzz_1, tg_xxxzzz_xyyyzz_1, \
                                         tg_xxxzzz_xyyyzzz_0, tg_xxxzzz_xyyyzzz_1, tg_xxxzzz_xyyzzz_1, tg_xxxzzz_xyyzzzz_0, \
                                         tg_xxxzzz_xyyzzzz_1, tg_xxxzzz_xyzzzz_1, tg_xxxzzz_xyzzzzz_0, tg_xxxzzz_xyzzzzz_1, \
                                         tg_xxxzzz_xzzzzz_1, tg_xxxzzz_xzzzzzz_0, tg_xxxzzz_xzzzzzz_1, tg_xxxzzz_yyyyyy_1, \
                                         tg_xxxzzz_yyyyyyy_0, tg_xxxzzz_yyyyyyy_1, tg_xxxzzz_yyyyyyz_0, tg_xxxzzz_yyyyyyz_1, \
                                         tg_xxxzzz_yyyyyz_1, tg_xxxzzz_yyyyyzz_0, tg_xxxzzz_yyyyyzz_1, tg_xxxzzz_yyyyzz_1, \
                                         tg_xxxzzz_yyyyzzz_0, tg_xxxzzz_yyyyzzz_1, tg_xxxzzz_yyyzzz_1, tg_xxxzzz_yyyzzzz_0, \
                                         tg_xxxzzz_yyyzzzz_1, tg_xxxzzz_yyzzzz_1, tg_xxxzzz_yyzzzzz_0, tg_xxxzzz_yyzzzzz_1, \
                                         tg_xxxzzz_yzzzzz_1, tg_xxxzzz_yzzzzzz_0, tg_xxxzzz_yzzzzzz_1, tg_xxxzzz_zzzzzz_1, \
                                         tg_xxxzzz_zzzzzzz_0, tg_xxxzzz_zzzzzzz_1, tg_xxyyyy_xxxxxx_1, tg_xxyyyy_xxxxxxx_0, \
                                         tg_xxyyyy_xxxxxxx_1, tg_xxyyyy_xxxxxxy_0, tg_xxyyyy_xxxxxxy_1, tg_xxyyyy_xxxxxxz_0, \
                                         tg_xxyyyy_xxxxxxz_1, tg_xxyyyy_xxxxxy_1, tg_xxyyyy_xxxxxyy_0, tg_xxyyyy_xxxxxyy_1, \
                                         tg_xxyyyy_xxxxxyz_0, tg_xxyyyy_xxxxxyz_1, tg_xxyyyy_xxxxxz_1, tg_xxyyyy_xxxxxzz_0, \
                                         tg_xxyyyy_xxxxxzz_1, tg_xxyyyy_xxxxyy_1, tg_xxyyyy_xxxxyyy_0, tg_xxyyyy_xxxxyyy_1, \
                                         tg_xxyyyy_xxxxyyz_0, tg_xxyyyy_xxxxyyz_1, tg_xxyyyy_xxxxyz_1, tg_xxyyyy_xxxxyzz_0, \
                                         tg_xxyyyy_xxxxyzz_1, tg_xxyyyy_xxxxzz_1, tg_xxyyyy_xxxxzzz_0, tg_xxyyyy_xxxxzzz_1, \
                                         tg_xxyyyy_xxxyyy_1, tg_xxyyyy_xxxyyyy_0, tg_xxyyyy_xxxyyyy_1, tg_xxyyyy_xxxyyyz_0, \
                                         tg_xxyyyy_xxxyyyz_1, tg_xxyyyy_xxxyyz_1, tg_xxyyyy_xxxyyzz_0, tg_xxyyyy_xxxyyzz_1, \
                                         tg_xxyyyy_xxxyzz_1, tg_xxyyyy_xxxyzzz_0, tg_xxyyyy_xxxyzzz_1, tg_xxyyyy_xxxzzz_1, \
                                         tg_xxyyyy_xxxzzzz_0, tg_xxyyyy_xxxzzzz_1, tg_xxyyyy_xxyyyy_1, tg_xxyyyy_xxyyyyy_0, \
                                         tg_xxyyyy_xxyyyyy_1, tg_xxyyyy_xxyyyyz_0, tg_xxyyyy_xxyyyyz_1, tg_xxyyyy_xxyyyz_1, \
                                         tg_xxyyyy_xxyyyzz_0, tg_xxyyyy_xxyyyzz_1, tg_xxyyyy_xxyyzz_1, tg_xxyyyy_xxyyzzz_0, \
                                         tg_xxyyyy_xxyyzzz_1, tg_xxyyyy_xxyzzz_1, tg_xxyyyy_xxyzzzz_0, tg_xxyyyy_xxyzzzz_1, \
                                         tg_xxyyyy_xxzzzz_1, tg_xxyyyy_xxzzzzz_0, tg_xxyyyy_xxzzzzz_1, tg_xxyyyy_xyyyyy_1, \
                                         tg_xxyyyy_xyyyyyy_0, tg_xxyyyy_xyyyyyy_1, tg_xxyyyy_xyyyyyz_0, tg_xxyyyy_xyyyyyz_1, \
                                         tg_xxyyyy_xyyyyz_1, tg_xxyyyy_xyyyyzz_0, tg_xxyyyy_xyyyyzz_1, tg_xxyyyy_xyyyzz_1, \
                                         tg_xxyyyy_xyyyzzz_0, tg_xxyyyy_xyyyzzz_1, tg_xxyyyy_xyyzzz_1, tg_xxyyyy_xyyzzzz_0, \
                                         tg_xxyyyy_xyyzzzz_1, tg_xxyyyy_xyzzzz_1, tg_xxyyyy_xyzzzzz_0, tg_xxyyyy_xyzzzzz_1, \
                                         tg_xxyyyy_xzzzzz_1, tg_xxyyyy_xzzzzzz_0, tg_xxyyyy_xzzzzzz_1, tg_xxyyyy_yyyyyy_1, \
                                         tg_xxyyyy_yyyyyyy_0, tg_xxyyyy_yyyyyyy_1, tg_xxyyyy_yyyyyyz_0, tg_xxyyyy_yyyyyyz_1, \
                                         tg_xxyyyy_yyyyyz_1, tg_xxyyyy_yyyyyzz_0, tg_xxyyyy_yyyyyzz_1, tg_xxyyyy_yyyyzz_1, \
                                         tg_xxyyyy_yyyyzzz_0, tg_xxyyyy_yyyyzzz_1, tg_xxyyyy_yyyzzz_1, tg_xxyyyy_yyyzzzz_0, \
                                         tg_xxyyyy_yyyzzzz_1, tg_xxyyyy_yyzzzz_1, tg_xxyyyy_yyzzzzz_0, tg_xxyyyy_yyzzzzz_1, \
                                         tg_xxyyyy_yzzzzz_1, tg_xxyyyy_yzzzzzz_0, tg_xxyyyy_yzzzzzz_1, tg_xxyyyy_zzzzzz_1, \
                                         tg_xxyyyy_zzzzzzz_0, tg_xxyyyy_zzzzzzz_1, tg_xxyyyz_xxxxxx_1, tg_xxyyyz_xxxxxxx_0, \
                                         tg_xxyyyz_xxxxxxx_1, tg_xxyyyz_xxxxxxy_0, tg_xxyyyz_xxxxxxy_1, tg_xxyyyz_xxxxxxz_0, \
                                         tg_xxyyyz_xxxxxxz_1, tg_xxyyyz_xxxxxy_1, tg_xxyyyz_xxxxxyy_0, tg_xxyyyz_xxxxxyy_1, \
                                         tg_xxyyyz_xxxxxz_1, tg_xxyyyz_xxxxyy_1, tg_xxyzz_xxxyyzz_0, tg_xxyzz_xxxyyzz_1, \
                                         tg_xxyzz_xxxyzzz_0, tg_xxyzz_xxxyzzz_1, tg_xxyzz_xxxzzzz_0, tg_xxyzz_xxxzzzz_1, \
                                         tg_xxyzz_xxyyyyy_0, tg_xxyzz_xxyyyyy_1, tg_xxyzz_xxyyyyz_0, tg_xxyzz_xxyyyyz_1, \
                                         tg_xxyzz_xxyyyzz_0, tg_xxyzz_xxyyyzz_1, tg_xxyzz_xxyyzzz_0, tg_xxyzz_xxyyzzz_1, \
                                         tg_xxyzz_xxyzzzz_0, tg_xxyzz_xxyzzzz_1, tg_xxyzz_xxzzzzz_0, tg_xxyzz_xxzzzzz_1, \
                                         tg_xxyzz_xyyyyyy_0, tg_xxyzz_xyyyyyy_1, tg_xxyzz_xyyyyyz_0, tg_xxyzz_xyyyyyz_1, \
                                         tg_xxyzz_xyyyyzz_0, tg_xxyzz_xyyyyzz_1, tg_xxyzz_xyyyzzz_0, tg_xxyzz_xyyyzzz_1, \
                                         tg_xxyzz_xyyzzzz_0, tg_xxyzz_xyyzzzz_1, tg_xxyzz_xyzzzzz_0, tg_xxyzz_xyzzzzz_1, \
                                         tg_xxyzz_xzzzzzz_0, tg_xxyzz_xzzzzzz_1, tg_xxyzz_yyyyyyy_0, tg_xxyzz_yyyyyyy_1, \
                                         tg_xxyzz_yyyyyyz_0, tg_xxyzz_yyyyyyz_1, tg_xxyzz_yyyyyzz_0, tg_xxyzz_yyyyyzz_1, \
                                         tg_xxyzz_yyyyzzz_0, tg_xxyzz_yyyyzzz_1, tg_xxyzz_yyyzzzz_0, tg_xxyzz_yyyzzzz_1, \
                                         tg_xxyzz_yyzzzzz_0, tg_xxyzz_yyzzzzz_1, tg_xxyzz_yzzzzzz_0, tg_xxyzz_yzzzzzz_1, \
                                         tg_xxyzz_zzzzzzz_0, tg_xxyzz_zzzzzzz_1, tg_xxzzz_xxxxxxx_0, tg_xxzzz_xxxxxxx_1, \
                                         tg_xxzzz_xxxxxxy_0, tg_xxzzz_xxxxxxy_1, tg_xxzzz_xxxxxxz_0, tg_xxzzz_xxxxxxz_1, \
                                         tg_xxzzz_xxxxxyy_0, tg_xxzzz_xxxxxyy_1, tg_xxzzz_xxxxxyz_0, tg_xxzzz_xxxxxyz_1, \
                                         tg_xxzzz_xxxxxzz_0, tg_xxzzz_xxxxxzz_1, tg_xxzzz_xxxxyyy_0, tg_xxzzz_xxxxyyy_1, \
                                         tg_xxzzz_xxxxyyz_0, tg_xxzzz_xxxxyyz_1, tg_xxzzz_xxxxyzz_0, tg_xxzzz_xxxxyzz_1, \
                                         tg_xxzzz_xxxxzzz_0, tg_xxzzz_xxxxzzz_1, tg_xxzzz_xxxyyyy_0, tg_xxzzz_xxxyyyy_1, \
                                         tg_xxzzz_xxxyyyz_0, tg_xxzzz_xxxyyyz_1, tg_xxzzz_xxxyyzz_0, tg_xxzzz_xxxyyzz_1, \
                                         tg_xxzzz_xxxyzzz_0, tg_xxzzz_xxxyzzz_1, tg_xxzzz_xxxzzzz_0, tg_xxzzz_xxxzzzz_1, \
                                         tg_xxzzz_xxyyyyy_0, tg_xxzzz_xxyyyyy_1, tg_xxzzz_xxyyyyz_0, tg_xxzzz_xxyyyyz_1, \
                                         tg_xxzzz_xxyyyzz_0, tg_xxzzz_xxyyyzz_1, tg_xxzzz_xxyyzzz_0, tg_xxzzz_xxyyzzz_1, \
                                         tg_xxzzz_xxyzzzz_0, tg_xxzzz_xxyzzzz_1, tg_xxzzz_xxzzzzz_0, tg_xxzzz_xxzzzzz_1, \
                                         tg_xxzzz_xyyyyyy_0, tg_xxzzz_xyyyyyy_1, tg_xxzzz_xyyyyyz_0, tg_xxzzz_xyyyyyz_1, \
                                         tg_xxzzz_xyyyyzz_0, tg_xxzzz_xyyyyzz_1, tg_xxzzz_xyyyzzz_0, tg_xxzzz_xyyyzzz_1, \
                                         tg_xxzzz_xyyzzzz_0, tg_xxzzz_xyyzzzz_1, tg_xxzzz_xyzzzzz_0, tg_xxzzz_xyzzzzz_1, \
                                         tg_xxzzz_xzzzzzz_0, tg_xxzzz_xzzzzzz_1, tg_xxzzz_yyyyyyy_0, tg_xxzzz_yyyyyyy_1, \
                                         tg_xxzzz_yyyyyyz_0, tg_xxzzz_yyyyyyz_1, tg_xxzzz_yyyyyzz_0, tg_xxzzz_yyyyyzz_1, \
                                         tg_xxzzz_yyyyzzz_0, tg_xxzzz_yyyyzzz_1, tg_xxzzz_yyyzzzz_0, tg_xxzzz_yyyzzzz_1, \
                                         tg_xxzzz_yyzzzzz_0, tg_xxzzz_yyzzzzz_1, tg_xxzzz_yzzzzzz_0, tg_xxzzz_yzzzzzz_1, \
                                         tg_xxzzz_zzzzzzz_0, tg_xxzzz_zzzzzzz_1, tg_xyyyy_xxxxxxx_0, tg_xyyyy_xxxxxxx_1, \
                                         tg_xyyyy_xxxxxxy_0, tg_xyyyy_xxxxxxy_1, tg_xyyyy_xxxxxxz_0, tg_xyyyy_xxxxxxz_1, \
                                         tg_xyyyy_xxxxxyy_0, tg_xyyyy_xxxxxyy_1, tg_xyyyy_xxxxxyz_0, tg_xyyyy_xxxxxyz_1, \
                                         tg_xyyyy_xxxxxzz_0, tg_xyyyy_xxxxxzz_1, tg_xyyyy_xxxxyyy_0, tg_xyyyy_xxxxyyy_1, \
                                         tg_xyyyy_xxxxyyz_0, tg_xyyyy_xxxxyyz_1, tg_xyyyy_xxxxyzz_0, tg_xyyyy_xxxxyzz_1, \
                                         tg_xyyyy_xxxxzzz_0, tg_xyyyy_xxxxzzz_1, tg_xyyyy_xxxyyyy_0, tg_xyyyy_xxxyyyy_1, \
                                         tg_xyyyy_xxxyyyz_0, tg_xyyyy_xxxyyyz_1, tg_xyyyy_xxxyyzz_0, tg_xyyyy_xxxyyzz_1, \
                                         tg_xyyyy_xxxyzzz_0, tg_xyyyy_xxxyzzz_1, tg_xyyyy_xxxzzzz_0, tg_xyyyy_xxxzzzz_1, \
                                         tg_xyyyy_xxyyyyy_0, tg_xyyyy_xxyyyyy_1, tg_xyyyy_xxyyyyz_0, tg_xyyyy_xxyyyyz_1, \
                                         tg_xyyyy_xxyyyzz_0, tg_xyyyy_xxyyyzz_1, tg_xyyyy_xxyyzzz_0, tg_xyyyy_xxyyzzz_1, \
                                         tg_xyyyy_xxyzzzz_0, tg_xyyyy_xxyzzzz_1, tg_xyyyy_xxzzzzz_0, tg_xyyyy_xxzzzzz_1, \
                                         tg_xyyyy_xyyyyyy_0, tg_xyyyy_xyyyyyy_1, tg_xyyyy_xyyyyyz_0, tg_xyyyy_xyyyyyz_1, \
                                         tg_xyyyy_xyyyyzz_0, tg_xyyyy_xyyyyzz_1, tg_xyyyy_xyyyzzz_0, tg_xyyyy_xyyyzzz_1, \
                                         tg_xyyyy_xyyzzzz_0, tg_xyyyy_xyyzzzz_1, tg_xyyyy_xyzzzzz_0, tg_xyyyy_xyzzzzz_1, \
                                         tg_xyyyy_xzzzzzz_0, tg_xyyyy_xzzzzzz_1, tg_xyyyy_yyyyyyy_0, tg_xyyyy_yyyyyyy_1, \
                                         tg_xyyyy_yyyyyyz_0, tg_xyyyy_yyyyyyz_1, tg_xyyyy_yyyyyzz_0, tg_xyyyy_yyyyyzz_1, \
                                         tg_xyyyy_yyyyzzz_0, tg_xyyyy_yyyyzzz_1, tg_xyyyy_yyyzzzz_0, tg_xyyyy_yyyzzzz_1, \
                                         tg_xyyyy_yyzzzzz_0, tg_xyyyy_yyzzzzz_1, tg_xyyyy_yzzzzzz_0, tg_xyyyy_yzzzzzz_1, \
                                         tg_xyyyy_zzzzzzz_0, tg_xyyyy_zzzzzzz_1, tg_xyyyz_xxxxxxx_0, tg_xyyyz_xxxxxxx_1, \
                                         tg_xyyyz_xxxxxxy_0, tg_xyyyz_xxxxxxy_1, tg_xyyyz_xxxxxxz_0, tg_xyyyz_xxxxxxz_1, \
                                         tg_xyyyz_xxxxxyy_0, tg_xyyyz_xxxxxyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxyzz_xxxyyzz_0[j] = pb_x * tg_xxxyzz_xxxyyzz_0[j] + fr * tg_xxxyzz_xxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxyyzz_0[j] - tg_xxyzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzz_xxyyzz_1[j];

                    tg_xxxxyzz_xxxyzzz_0[j] = pb_x * tg_xxxyzz_xxxyzzz_0[j] + fr * tg_xxxyzz_xxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxyzzz_0[j] - tg_xxyzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzz_xxyzzz_1[j];

                    tg_xxxxyzz_xxxzzzz_0[j] = pb_x * tg_xxxyzz_xxxzzzz_0[j] + fr * tg_xxxyzz_xxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxxzzzz_0[j] - tg_xxyzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzz_xxzzzz_1[j];

                    tg_xxxxyzz_xxyyyyy_0[j] = pb_x * tg_xxxyzz_xxyyyyy_0[j] + fr * tg_xxxyzz_xxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxyyyyy_0[j] - tg_xxyzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xyyyyy_1[j];

                    tg_xxxxyzz_xxyyyyz_0[j] = pb_x * tg_xxxyzz_xxyyyyz_0[j] + fr * tg_xxxyzz_xxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxyyyyz_0[j] - tg_xxyzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xyyyyz_1[j];

                    tg_xxxxyzz_xxyyyzz_0[j] = pb_x * tg_xxxyzz_xxyyyzz_0[j] + fr * tg_xxxyzz_xxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxyyyzz_0[j] - tg_xxyzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xyyyzz_1[j];

                    tg_xxxxyzz_xxyyzzz_0[j] = pb_x * tg_xxxyzz_xxyyzzz_0[j] + fr * tg_xxxyzz_xxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxyyzzz_0[j] - tg_xxyzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xyyzzz_1[j];

                    tg_xxxxyzz_xxyzzzz_0[j] = pb_x * tg_xxxyzz_xxyzzzz_0[j] + fr * tg_xxxyzz_xxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxyzzzz_0[j] - tg_xxyzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xyzzzz_1[j];

                    tg_xxxxyzz_xxzzzzz_0[j] = pb_x * tg_xxxyzz_xxzzzzz_0[j] + fr * tg_xxxyzz_xxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xxzzzzz_0[j] - tg_xxyzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzz_xzzzzz_1[j];

                    tg_xxxxyzz_xyyyyyy_0[j] = pb_x * tg_xxxyzz_xyyyyyy_0[j] + fr * tg_xxxyzz_xyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyyyyyy_0[j] - tg_xxyzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yyyyyy_1[j];

                    tg_xxxxyzz_xyyyyyz_0[j] = pb_x * tg_xxxyzz_xyyyyyz_0[j] + fr * tg_xxxyzz_xyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyyyyyz_0[j] - tg_xxyzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yyyyyz_1[j];

                    tg_xxxxyzz_xyyyyzz_0[j] = pb_x * tg_xxxyzz_xyyyyzz_0[j] + fr * tg_xxxyzz_xyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyyyyzz_0[j] - tg_xxyzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yyyyzz_1[j];

                    tg_xxxxyzz_xyyyzzz_0[j] = pb_x * tg_xxxyzz_xyyyzzz_0[j] + fr * tg_xxxyzz_xyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyyyzzz_0[j] - tg_xxyzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yyyzzz_1[j];

                    tg_xxxxyzz_xyyzzzz_0[j] = pb_x * tg_xxxyzz_xyyzzzz_0[j] + fr * tg_xxxyzz_xyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyyzzzz_0[j] - tg_xxyzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yyzzzz_1[j];

                    tg_xxxxyzz_xyzzzzz_0[j] = pb_x * tg_xxxyzz_xyzzzzz_0[j] + fr * tg_xxxyzz_xyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xyzzzzz_0[j] - tg_xxyzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_yzzzzz_1[j];

                    tg_xxxxyzz_xzzzzzz_0[j] = pb_x * tg_xxxyzz_xzzzzzz_0[j] + fr * tg_xxxyzz_xzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_xzzzzzz_0[j] - tg_xxyzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzz_zzzzzz_1[j];

                    tg_xxxxyzz_yyyyyyy_0[j] = pb_x * tg_xxxyzz_yyyyyyy_0[j] + fr * tg_xxxyzz_yyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyyyyyy_0[j] - tg_xxyzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxyzz_yyyyyyz_0[j] = pb_x * tg_xxxyzz_yyyyyyz_0[j] + fr * tg_xxxyzz_yyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyyyyyz_0[j] - tg_xxyzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxyzz_yyyyyzz_0[j] = pb_x * tg_xxxyzz_yyyyyzz_0[j] + fr * tg_xxxyzz_yyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyyyyzz_0[j] - tg_xxyzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxyzz_yyyyzzz_0[j] = pb_x * tg_xxxyzz_yyyyzzz_0[j] + fr * tg_xxxyzz_yyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyyyzzz_0[j] - tg_xxyzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxyzz_yyyzzzz_0[j] = pb_x * tg_xxxyzz_yyyzzzz_0[j] + fr * tg_xxxyzz_yyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyyzzzz_0[j] - tg_xxyzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxyzz_yyzzzzz_0[j] = pb_x * tg_xxxyzz_yyzzzzz_0[j] + fr * tg_xxxyzz_yyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yyzzzzz_0[j] - tg_xxyzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxyzz_yzzzzzz_0[j] = pb_x * tg_xxxyzz_yzzzzzz_0[j] + fr * tg_xxxyzz_yzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_yzzzzzz_0[j] - tg_xxyzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxyzz_zzzzzzz_0[j] = pb_x * tg_xxxyzz_zzzzzzz_0[j] + fr * tg_xxxyzz_zzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzz_zzzzzzz_0[j] - tg_xxyzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxxzzz_xxxxxxx_0[j] = pb_x * tg_xxxzzz_xxxxxxx_0[j] + fr * tg_xxxzzz_xxxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxxx_0[j] - tg_xxzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxxzzz_xxxxxx_1[j];

                    tg_xxxxzzz_xxxxxxy_0[j] = pb_x * tg_xxxzzz_xxxxxxy_0[j] + fr * tg_xxxzzz_xxxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxxy_0[j] - tg_xxzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzzz_xxxxxy_1[j];

                    tg_xxxxzzz_xxxxxxz_0[j] = pb_x * tg_xxxzzz_xxxxxxz_0[j] + fr * tg_xxxzzz_xxxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxxz_0[j] - tg_xxzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzzz_xxxxxz_1[j];

                    tg_xxxxzzz_xxxxxyy_0[j] = pb_x * tg_xxxzzz_xxxxxyy_0[j] + fr * tg_xxxzzz_xxxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxyy_0[j] - tg_xxzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzzz_xxxxyy_1[j];

                    tg_xxxxzzz_xxxxxyz_0[j] = pb_x * tg_xxxzzz_xxxxxyz_0[j] + fr * tg_xxxzzz_xxxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxyz_0[j] - tg_xxzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzzz_xxxxyz_1[j];

                    tg_xxxxzzz_xxxxxzz_0[j] = pb_x * tg_xxxzzz_xxxxxzz_0[j] + fr * tg_xxxzzz_xxxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxxzz_0[j] - tg_xxzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzzz_xxxxzz_1[j];

                    tg_xxxxzzz_xxxxyyy_0[j] = pb_x * tg_xxxzzz_xxxxyyy_0[j] + fr * tg_xxxzzz_xxxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxyyy_0[j] - tg_xxzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzz_xxxyyy_1[j];

                    tg_xxxxzzz_xxxxyyz_0[j] = pb_x * tg_xxxzzz_xxxxyyz_0[j] + fr * tg_xxxzzz_xxxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxyyz_0[j] - tg_xxzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzz_xxxyyz_1[j];

                    tg_xxxxzzz_xxxxyzz_0[j] = pb_x * tg_xxxzzz_xxxxyzz_0[j] + fr * tg_xxxzzz_xxxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxyzz_0[j] - tg_xxzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzz_xxxyzz_1[j];

                    tg_xxxxzzz_xxxxzzz_0[j] = pb_x * tg_xxxzzz_xxxxzzz_0[j] + fr * tg_xxxzzz_xxxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxxzzz_0[j] - tg_xxzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzz_xxxzzz_1[j];

                    tg_xxxxzzz_xxxyyyy_0[j] = pb_x * tg_xxxzzz_xxxyyyy_0[j] + fr * tg_xxxzzz_xxxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxyyyy_0[j] - tg_xxzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzz_xxyyyy_1[j];

                    tg_xxxxzzz_xxxyyyz_0[j] = pb_x * tg_xxxzzz_xxxyyyz_0[j] + fr * tg_xxxzzz_xxxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxyyyz_0[j] - tg_xxzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzz_xxyyyz_1[j];

                    tg_xxxxzzz_xxxyyzz_0[j] = pb_x * tg_xxxzzz_xxxyyzz_0[j] + fr * tg_xxxzzz_xxxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxyyzz_0[j] - tg_xxzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzz_xxyyzz_1[j];

                    tg_xxxxzzz_xxxyzzz_0[j] = pb_x * tg_xxxzzz_xxxyzzz_0[j] + fr * tg_xxxzzz_xxxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxyzzz_0[j] - tg_xxzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzz_xxyzzz_1[j];

                    tg_xxxxzzz_xxxzzzz_0[j] = pb_x * tg_xxxzzz_xxxzzzz_0[j] + fr * tg_xxxzzz_xxxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxxzzzz_0[j] - tg_xxzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzz_xxzzzz_1[j];

                    tg_xxxxzzz_xxyyyyy_0[j] = pb_x * tg_xxxzzz_xxyyyyy_0[j] + fr * tg_xxxzzz_xxyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxyyyyy_0[j] - tg_xxzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xyyyyy_1[j];

                    tg_xxxxzzz_xxyyyyz_0[j] = pb_x * tg_xxxzzz_xxyyyyz_0[j] + fr * tg_xxxzzz_xxyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxyyyyz_0[j] - tg_xxzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xyyyyz_1[j];

                    tg_xxxxzzz_xxyyyzz_0[j] = pb_x * tg_xxxzzz_xxyyyzz_0[j] + fr * tg_xxxzzz_xxyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxyyyzz_0[j] - tg_xxzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xyyyzz_1[j];

                    tg_xxxxzzz_xxyyzzz_0[j] = pb_x * tg_xxxzzz_xxyyzzz_0[j] + fr * tg_xxxzzz_xxyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxyyzzz_0[j] - tg_xxzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xyyzzz_1[j];

                    tg_xxxxzzz_xxyzzzz_0[j] = pb_x * tg_xxxzzz_xxyzzzz_0[j] + fr * tg_xxxzzz_xxyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxyzzzz_0[j] - tg_xxzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xyzzzz_1[j];

                    tg_xxxxzzz_xxzzzzz_0[j] = pb_x * tg_xxxzzz_xxzzzzz_0[j] + fr * tg_xxxzzz_xxzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xxzzzzz_0[j] - tg_xxzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzz_xzzzzz_1[j];

                    tg_xxxxzzz_xyyyyyy_0[j] = pb_x * tg_xxxzzz_xyyyyyy_0[j] + fr * tg_xxxzzz_xyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyyyyyy_0[j] - tg_xxzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yyyyyy_1[j];

                    tg_xxxxzzz_xyyyyyz_0[j] = pb_x * tg_xxxzzz_xyyyyyz_0[j] + fr * tg_xxxzzz_xyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyyyyyz_0[j] - tg_xxzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yyyyyz_1[j];

                    tg_xxxxzzz_xyyyyzz_0[j] = pb_x * tg_xxxzzz_xyyyyzz_0[j] + fr * tg_xxxzzz_xyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyyyyzz_0[j] - tg_xxzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yyyyzz_1[j];

                    tg_xxxxzzz_xyyyzzz_0[j] = pb_x * tg_xxxzzz_xyyyzzz_0[j] + fr * tg_xxxzzz_xyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyyyzzz_0[j] - tg_xxzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yyyzzz_1[j];

                    tg_xxxxzzz_xyyzzzz_0[j] = pb_x * tg_xxxzzz_xyyzzzz_0[j] + fr * tg_xxxzzz_xyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyyzzzz_0[j] - tg_xxzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yyzzzz_1[j];

                    tg_xxxxzzz_xyzzzzz_0[j] = pb_x * tg_xxxzzz_xyzzzzz_0[j] + fr * tg_xxxzzz_xyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xyzzzzz_0[j] - tg_xxzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_yzzzzz_1[j];

                    tg_xxxxzzz_xzzzzzz_0[j] = pb_x * tg_xxxzzz_xzzzzzz_0[j] + fr * tg_xxxzzz_xzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_xzzzzzz_0[j] - tg_xxzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzz_zzzzzz_1[j];

                    tg_xxxxzzz_yyyyyyy_0[j] = pb_x * tg_xxxzzz_yyyyyyy_0[j] + fr * tg_xxxzzz_yyyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyyyyyy_0[j] - tg_xxzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxxzzz_yyyyyyz_0[j] = pb_x * tg_xxxzzz_yyyyyyz_0[j] + fr * tg_xxxzzz_yyyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyyyyyz_0[j] - tg_xxzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxxzzz_yyyyyzz_0[j] = pb_x * tg_xxxzzz_yyyyyzz_0[j] + fr * tg_xxxzzz_yyyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyyyyzz_0[j] - tg_xxzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxxzzz_yyyyzzz_0[j] = pb_x * tg_xxxzzz_yyyyzzz_0[j] + fr * tg_xxxzzz_yyyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyyyzzz_0[j] - tg_xxzzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxxzzz_yyyzzzz_0[j] = pb_x * tg_xxxzzz_yyyzzzz_0[j] + fr * tg_xxxzzz_yyyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyyzzzz_0[j] - tg_xxzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxxzzz_yyzzzzz_0[j] = pb_x * tg_xxxzzz_yyzzzzz_0[j] + fr * tg_xxxzzz_yyzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yyzzzzz_0[j] - tg_xxzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxxzzz_yzzzzzz_0[j] = pb_x * tg_xxxzzz_yzzzzzz_0[j] + fr * tg_xxxzzz_yzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_yzzzzzz_0[j] - tg_xxzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxxzzz_zzzzzzz_0[j] = pb_x * tg_xxxzzz_zzzzzzz_0[j] + fr * tg_xxxzzz_zzzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzz_zzzzzzz_0[j] - tg_xxzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyy_xxxxxxx_0[j] = pb_x * tg_xxyyyy_xxxxxxx_0[j] + fr * tg_xxyyyy_xxxxxxx_1[j] + fl1_fx * (tg_xyyyy_xxxxxxx_0[j] - tg_xyyyy_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyyy_xxxxxx_1[j];

                    tg_xxxyyyy_xxxxxxy_0[j] = pb_x * tg_xxyyyy_xxxxxxy_0[j] + fr * tg_xxyyyy_xxxxxxy_1[j] + fl1_fx * (tg_xyyyy_xxxxxxy_0[j] - tg_xyyyy_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyy_xxxxxy_1[j];

                    tg_xxxyyyy_xxxxxxz_0[j] = pb_x * tg_xxyyyy_xxxxxxz_0[j] + fr * tg_xxyyyy_xxxxxxz_1[j] + fl1_fx * (tg_xyyyy_xxxxxxz_0[j] - tg_xyyyy_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyy_xxxxxz_1[j];

                    tg_xxxyyyy_xxxxxyy_0[j] = pb_x * tg_xxyyyy_xxxxxyy_0[j] + fr * tg_xxyyyy_xxxxxyy_1[j] + fl1_fx * (tg_xyyyy_xxxxxyy_0[j] - tg_xyyyy_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyy_xxxxyy_1[j];

                    tg_xxxyyyy_xxxxxyz_0[j] = pb_x * tg_xxyyyy_xxxxxyz_0[j] + fr * tg_xxyyyy_xxxxxyz_1[j] + fl1_fx * (tg_xyyyy_xxxxxyz_0[j] - tg_xyyyy_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyy_xxxxyz_1[j];

                    tg_xxxyyyy_xxxxxzz_0[j] = pb_x * tg_xxyyyy_xxxxxzz_0[j] + fr * tg_xxyyyy_xxxxxzz_1[j] + fl1_fx * (tg_xyyyy_xxxxxzz_0[j] - tg_xyyyy_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyy_xxxxzz_1[j];

                    tg_xxxyyyy_xxxxyyy_0[j] = pb_x * tg_xxyyyy_xxxxyyy_0[j] + fr * tg_xxyyyy_xxxxyyy_1[j] + fl1_fx * (tg_xyyyy_xxxxyyy_0[j] - tg_xyyyy_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyy_xxxyyy_1[j];

                    tg_xxxyyyy_xxxxyyz_0[j] = pb_x * tg_xxyyyy_xxxxyyz_0[j] + fr * tg_xxyyyy_xxxxyyz_1[j] + fl1_fx * (tg_xyyyy_xxxxyyz_0[j] - tg_xyyyy_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyy_xxxyyz_1[j];

                    tg_xxxyyyy_xxxxyzz_0[j] = pb_x * tg_xxyyyy_xxxxyzz_0[j] + fr * tg_xxyyyy_xxxxyzz_1[j] + fl1_fx * (tg_xyyyy_xxxxyzz_0[j] - tg_xyyyy_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyy_xxxyzz_1[j];

                    tg_xxxyyyy_xxxxzzz_0[j] = pb_x * tg_xxyyyy_xxxxzzz_0[j] + fr * tg_xxyyyy_xxxxzzz_1[j] + fl1_fx * (tg_xyyyy_xxxxzzz_0[j] - tg_xyyyy_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyy_xxxzzz_1[j];

                    tg_xxxyyyy_xxxyyyy_0[j] = pb_x * tg_xxyyyy_xxxyyyy_0[j] + fr * tg_xxyyyy_xxxyyyy_1[j] + fl1_fx * (tg_xyyyy_xxxyyyy_0[j] - tg_xyyyy_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyy_xxyyyy_1[j];

                    tg_xxxyyyy_xxxyyyz_0[j] = pb_x * tg_xxyyyy_xxxyyyz_0[j] + fr * tg_xxyyyy_xxxyyyz_1[j] + fl1_fx * (tg_xyyyy_xxxyyyz_0[j] - tg_xyyyy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyy_xxyyyz_1[j];

                    tg_xxxyyyy_xxxyyzz_0[j] = pb_x * tg_xxyyyy_xxxyyzz_0[j] + fr * tg_xxyyyy_xxxyyzz_1[j] + fl1_fx * (tg_xyyyy_xxxyyzz_0[j] - tg_xyyyy_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyy_xxyyzz_1[j];

                    tg_xxxyyyy_xxxyzzz_0[j] = pb_x * tg_xxyyyy_xxxyzzz_0[j] + fr * tg_xxyyyy_xxxyzzz_1[j] + fl1_fx * (tg_xyyyy_xxxyzzz_0[j] - tg_xyyyy_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyy_xxyzzz_1[j];

                    tg_xxxyyyy_xxxzzzz_0[j] = pb_x * tg_xxyyyy_xxxzzzz_0[j] + fr * tg_xxyyyy_xxxzzzz_1[j] + fl1_fx * (tg_xyyyy_xxxzzzz_0[j] - tg_xyyyy_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyy_xxzzzz_1[j];

                    tg_xxxyyyy_xxyyyyy_0[j] = pb_x * tg_xxyyyy_xxyyyyy_0[j] + fr * tg_xxyyyy_xxyyyyy_1[j] + fl1_fx * (tg_xyyyy_xxyyyyy_0[j] - tg_xyyyy_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xyyyyy_1[j];

                    tg_xxxyyyy_xxyyyyz_0[j] = pb_x * tg_xxyyyy_xxyyyyz_0[j] + fr * tg_xxyyyy_xxyyyyz_1[j] + fl1_fx * (tg_xyyyy_xxyyyyz_0[j] - tg_xyyyy_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xyyyyz_1[j];

                    tg_xxxyyyy_xxyyyzz_0[j] = pb_x * tg_xxyyyy_xxyyyzz_0[j] + fr * tg_xxyyyy_xxyyyzz_1[j] + fl1_fx * (tg_xyyyy_xxyyyzz_0[j] - tg_xyyyy_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xyyyzz_1[j];

                    tg_xxxyyyy_xxyyzzz_0[j] = pb_x * tg_xxyyyy_xxyyzzz_0[j] + fr * tg_xxyyyy_xxyyzzz_1[j] + fl1_fx * (tg_xyyyy_xxyyzzz_0[j] - tg_xyyyy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xyyzzz_1[j];

                    tg_xxxyyyy_xxyzzzz_0[j] = pb_x * tg_xxyyyy_xxyzzzz_0[j] + fr * tg_xxyyyy_xxyzzzz_1[j] + fl1_fx * (tg_xyyyy_xxyzzzz_0[j] - tg_xyyyy_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xyzzzz_1[j];

                    tg_xxxyyyy_xxzzzzz_0[j] = pb_x * tg_xxyyyy_xxzzzzz_0[j] + fr * tg_xxyyyy_xxzzzzz_1[j] + fl1_fx * (tg_xyyyy_xxzzzzz_0[j] - tg_xyyyy_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyy_xzzzzz_1[j];

                    tg_xxxyyyy_xyyyyyy_0[j] = pb_x * tg_xxyyyy_xyyyyyy_0[j] + fr * tg_xxyyyy_xyyyyyy_1[j] + fl1_fx * (tg_xyyyy_xyyyyyy_0[j] - tg_xyyyy_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yyyyyy_1[j];

                    tg_xxxyyyy_xyyyyyz_0[j] = pb_x * tg_xxyyyy_xyyyyyz_0[j] + fr * tg_xxyyyy_xyyyyyz_1[j] + fl1_fx * (tg_xyyyy_xyyyyyz_0[j] - tg_xyyyy_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yyyyyz_1[j];

                    tg_xxxyyyy_xyyyyzz_0[j] = pb_x * tg_xxyyyy_xyyyyzz_0[j] + fr * tg_xxyyyy_xyyyyzz_1[j] + fl1_fx * (tg_xyyyy_xyyyyzz_0[j] - tg_xyyyy_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yyyyzz_1[j];

                    tg_xxxyyyy_xyyyzzz_0[j] = pb_x * tg_xxyyyy_xyyyzzz_0[j] + fr * tg_xxyyyy_xyyyzzz_1[j] + fl1_fx * (tg_xyyyy_xyyyzzz_0[j] - tg_xyyyy_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yyyzzz_1[j];

                    tg_xxxyyyy_xyyzzzz_0[j] = pb_x * tg_xxyyyy_xyyzzzz_0[j] + fr * tg_xxyyyy_xyyzzzz_1[j] + fl1_fx * (tg_xyyyy_xyyzzzz_0[j] - tg_xyyyy_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yyzzzz_1[j];

                    tg_xxxyyyy_xyzzzzz_0[j] = pb_x * tg_xxyyyy_xyzzzzz_0[j] + fr * tg_xxyyyy_xyzzzzz_1[j] + fl1_fx * (tg_xyyyy_xyzzzzz_0[j] - tg_xyyyy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_yzzzzz_1[j];

                    tg_xxxyyyy_xzzzzzz_0[j] = pb_x * tg_xxyyyy_xzzzzzz_0[j] + fr * tg_xxyyyy_xzzzzzz_1[j] + fl1_fx * (tg_xyyyy_xzzzzzz_0[j] - tg_xyyyy_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyy_zzzzzz_1[j];

                    tg_xxxyyyy_yyyyyyy_0[j] = pb_x * tg_xxyyyy_yyyyyyy_0[j] + fr * tg_xxyyyy_yyyyyyy_1[j] + fl1_fx * (tg_xyyyy_yyyyyyy_0[j] - tg_xyyyy_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxyyyy_yyyyyyz_0[j] = pb_x * tg_xxyyyy_yyyyyyz_0[j] + fr * tg_xxyyyy_yyyyyyz_1[j] + fl1_fx * (tg_xyyyy_yyyyyyz_0[j] - tg_xyyyy_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxyyyy_yyyyyzz_0[j] = pb_x * tg_xxyyyy_yyyyyzz_0[j] + fr * tg_xxyyyy_yyyyyzz_1[j] + fl1_fx * (tg_xyyyy_yyyyyzz_0[j] - tg_xyyyy_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxyyyy_yyyyzzz_0[j] = pb_x * tg_xxyyyy_yyyyzzz_0[j] + fr * tg_xxyyyy_yyyyzzz_1[j] + fl1_fx * (tg_xyyyy_yyyyzzz_0[j] - tg_xyyyy_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxyyyy_yyyzzzz_0[j] = pb_x * tg_xxyyyy_yyyzzzz_0[j] + fr * tg_xxyyyy_yyyzzzz_1[j] + fl1_fx * (tg_xyyyy_yyyzzzz_0[j] - tg_xyyyy_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxyyyy_yyzzzzz_0[j] = pb_x * tg_xxyyyy_yyzzzzz_0[j] + fr * tg_xxyyyy_yyzzzzz_1[j] + fl1_fx * (tg_xyyyy_yyzzzzz_0[j] - tg_xyyyy_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyy_yzzzzzz_0[j] = pb_x * tg_xxyyyy_yzzzzzz_0[j] + fr * tg_xxyyyy_yzzzzzz_1[j] + fl1_fx * (tg_xyyyy_yzzzzzz_0[j] - tg_xyyyy_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyy_zzzzzzz_0[j] = pb_x * tg_xxyyyy_zzzzzzz_0[j] + fr * tg_xxyyyy_zzzzzzz_1[j] + fl1_fx * (tg_xyyyy_zzzzzzz_0[j] - tg_xyyyy_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyz_xxxxxxx_0[j] = pb_x * tg_xxyyyz_xxxxxxx_0[j] + fr * tg_xxyyyz_xxxxxxx_1[j] + fl1_fx * (tg_xyyyz_xxxxxxx_0[j] - tg_xyyyz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyyz_xxxxxx_1[j];

                    tg_xxxyyyz_xxxxxxy_0[j] = pb_x * tg_xxyyyz_xxxxxxy_0[j] + fr * tg_xxyyyz_xxxxxxy_1[j] + fl1_fx * (tg_xyyyz_xxxxxxy_0[j] - tg_xyyyz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyz_xxxxxy_1[j];

                    tg_xxxyyyz_xxxxxxz_0[j] = pb_x * tg_xxyyyz_xxxxxxz_0[j] + fr * tg_xxyyyz_xxxxxxz_1[j] + fl1_fx * (tg_xyyyz_xxxxxxz_0[j] - tg_xyyyz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyz_xxxxxz_1[j];

                    tg_xxxyyyz_xxxxxyy_0[j] = pb_x * tg_xxyyyz_xxxxxyy_0[j] + fr * tg_xxyyyz_xxxxxyy_1[j] + fl1_fx * (tg_xyyyz_xxxxxyy_0[j] - tg_xyyyz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyz_xxxxyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_400_500(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (400,500)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyyyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 400); 

                auto tg_xxyyyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 401); 

                auto tg_xxyyyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 402); 

                auto tg_xxyyyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 403); 

                auto tg_xxyyyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 404); 

                auto tg_xxyyyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 405); 

                auto tg_xxyyyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 406); 

                auto tg_xxyyyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 407); 

                auto tg_xxyyyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 408); 

                auto tg_xxyyyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 409); 

                auto tg_xxyyyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 410); 

                auto tg_xxyyyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 411); 

                auto tg_xxyyyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 412); 

                auto tg_xxyyyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 413); 

                auto tg_xxyyyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 414); 

                auto tg_xxyyyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 415); 

                auto tg_xxyyyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 416); 

                auto tg_xxyyyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 417); 

                auto tg_xxyyyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 418); 

                auto tg_xxyyyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 419); 

                auto tg_xxyyyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 420); 

                auto tg_xxyyyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 421); 

                auto tg_xxyyyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 422); 

                auto tg_xxyyyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 423); 

                auto tg_xxyyyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 424); 

                auto tg_xxyyyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 425); 

                auto tg_xxyyyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 426); 

                auto tg_xxyyyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 427); 

                auto tg_xxyyyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 428); 

                auto tg_xxyyyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 429); 

                auto tg_xxyyyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 430); 

                auto tg_xxyyyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 431); 

                auto tg_xxyyzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 432); 

                auto tg_xxyyzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 433); 

                auto tg_xxyyzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 434); 

                auto tg_xxyyzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 435); 

                auto tg_xxyyzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 436); 

                auto tg_xxyyzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 437); 

                auto tg_xxyyzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 438); 

                auto tg_xxyyzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 439); 

                auto tg_xxyyzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 440); 

                auto tg_xxyyzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 441); 

                auto tg_xxyyzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 442); 

                auto tg_xxyyzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 443); 

                auto tg_xxyyzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 444); 

                auto tg_xxyyzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 445); 

                auto tg_xxyyzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 446); 

                auto tg_xxyyzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 447); 

                auto tg_xxyyzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 448); 

                auto tg_xxyyzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 449); 

                auto tg_xxyyzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 450); 

                auto tg_xxyyzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 451); 

                auto tg_xxyyzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 452); 

                auto tg_xxyyzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 453); 

                auto tg_xxyyzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 454); 

                auto tg_xxyyzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 455); 

                auto tg_xxyyzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 456); 

                auto tg_xxyyzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 457); 

                auto tg_xxyyzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 458); 

                auto tg_xxyyzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 459); 

                auto tg_xxyyzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 460); 

                auto tg_xxyyzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 461); 

                auto tg_xxyyzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 462); 

                auto tg_xxyyzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 463); 

                auto tg_xxyyzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 464); 

                auto tg_xxyyzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 465); 

                auto tg_xxyyzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 466); 

                auto tg_xxyyzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 467); 

                auto tg_xxyzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 468); 

                auto tg_xxyzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 469); 

                auto tg_xxyzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 470); 

                auto tg_xxyzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 471); 

                auto tg_xxyzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 472); 

                auto tg_xxyzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 473); 

                auto tg_xxyzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 474); 

                auto tg_xxyzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 475); 

                auto tg_xxyzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 476); 

                auto tg_xxyzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 477); 

                auto tg_xxyzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 478); 

                auto tg_xxyzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 479); 

                auto tg_xxyzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 480); 

                auto tg_xxyzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 481); 

                auto tg_xxyzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 482); 

                auto tg_xxyzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 483); 

                auto tg_xxyzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 484); 

                auto tg_xxyzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 485); 

                auto tg_xxyzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 486); 

                auto tg_xxyzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 487); 

                auto tg_xxyzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 488); 

                auto tg_xxyzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 489); 

                auto tg_xxyzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 490); 

                auto tg_xxyzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 491); 

                auto tg_xxyzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 492); 

                auto tg_xxyzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 493); 

                auto tg_xxyzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 494); 

                auto tg_xxyzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 495); 

                auto tg_xxyzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 496); 

                auto tg_xxyzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 497); 

                auto tg_xxyzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 498); 

                auto tg_xxyzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 499); 

                auto tg_xxyyyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 400); 

                auto tg_xxyyyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 401); 

                auto tg_xxyyyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 402); 

                auto tg_xxyyyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 403); 

                auto tg_xxyyyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 404); 

                auto tg_xxyyyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 405); 

                auto tg_xxyyyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 406); 

                auto tg_xxyyyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 407); 

                auto tg_xxyyyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 408); 

                auto tg_xxyyyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 409); 

                auto tg_xxyyyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 410); 

                auto tg_xxyyyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 411); 

                auto tg_xxyyyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 412); 

                auto tg_xxyyyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 413); 

                auto tg_xxyyyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 414); 

                auto tg_xxyyyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 415); 

                auto tg_xxyyyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 416); 

                auto tg_xxyyyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 417); 

                auto tg_xxyyyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 418); 

                auto tg_xxyyyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 419); 

                auto tg_xxyyyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 420); 

                auto tg_xxyyyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 421); 

                auto tg_xxyyyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 422); 

                auto tg_xxyyyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 423); 

                auto tg_xxyyyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 424); 

                auto tg_xxyyyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 425); 

                auto tg_xxyyyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 426); 

                auto tg_xxyyyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 427); 

                auto tg_xxyyyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 428); 

                auto tg_xxyyyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 429); 

                auto tg_xxyyyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 430); 

                auto tg_xxyyyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 431); 

                auto tg_xxyyzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 432); 

                auto tg_xxyyzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 433); 

                auto tg_xxyyzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 434); 

                auto tg_xxyyzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 435); 

                auto tg_xxyyzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 436); 

                auto tg_xxyyzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 437); 

                auto tg_xxyyzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 438); 

                auto tg_xxyyzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 439); 

                auto tg_xxyyzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 440); 

                auto tg_xxyyzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 441); 

                auto tg_xxyyzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 442); 

                auto tg_xxyyzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 443); 

                auto tg_xxyyzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 444); 

                auto tg_xxyyzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 445); 

                auto tg_xxyyzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 446); 

                auto tg_xxyyzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 447); 

                auto tg_xxyyzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 448); 

                auto tg_xxyyzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 449); 

                auto tg_xxyyzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 450); 

                auto tg_xxyyzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 451); 

                auto tg_xxyyzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 452); 

                auto tg_xxyyzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 453); 

                auto tg_xxyyzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 454); 

                auto tg_xxyyzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 455); 

                auto tg_xxyyzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 456); 

                auto tg_xxyyzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 457); 

                auto tg_xxyyzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 458); 

                auto tg_xxyyzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 459); 

                auto tg_xxyyzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 460); 

                auto tg_xxyyzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 461); 

                auto tg_xxyyzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 462); 

                auto tg_xxyyzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 463); 

                auto tg_xxyyzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 464); 

                auto tg_xxyyzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 465); 

                auto tg_xxyyzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 466); 

                auto tg_xxyyzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 467); 

                auto tg_xxyzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 468); 

                auto tg_xxyzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 469); 

                auto tg_xxyzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 470); 

                auto tg_xxyzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 471); 

                auto tg_xxyzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 472); 

                auto tg_xxyzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 473); 

                auto tg_xxyzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 474); 

                auto tg_xxyzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 475); 

                auto tg_xxyzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 476); 

                auto tg_xxyzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 477); 

                auto tg_xxyzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 478); 

                auto tg_xxyzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 479); 

                auto tg_xxyzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 480); 

                auto tg_xxyzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 481); 

                auto tg_xxyzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 482); 

                auto tg_xxyzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 483); 

                auto tg_xxyzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 484); 

                auto tg_xxyzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 485); 

                auto tg_xxyzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 486); 

                auto tg_xxyzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 487); 

                auto tg_xxyzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 488); 

                auto tg_xxyzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 489); 

                auto tg_xxyzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 490); 

                auto tg_xxyzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 491); 

                auto tg_xxyzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 492); 

                auto tg_xxyzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 493); 

                auto tg_xxyzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 494); 

                auto tg_xxyzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 495); 

                auto tg_xxyzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 496); 

                auto tg_xxyzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 497); 

                auto tg_xxyzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 498); 

                auto tg_xxyzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 499); 

                auto tg_xyyyz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 400); 

                auto tg_xyyyz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 401); 

                auto tg_xyyyz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 402); 

                auto tg_xyyyz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 403); 

                auto tg_xyyyz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 404); 

                auto tg_xyyyz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 405); 

                auto tg_xyyyz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 406); 

                auto tg_xyyyz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 407); 

                auto tg_xyyyz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 408); 

                auto tg_xyyyz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 409); 

                auto tg_xyyyz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 410); 

                auto tg_xyyyz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 411); 

                auto tg_xyyyz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 412); 

                auto tg_xyyyz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 413); 

                auto tg_xyyyz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 414); 

                auto tg_xyyyz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 415); 

                auto tg_xyyyz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 416); 

                auto tg_xyyyz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 417); 

                auto tg_xyyyz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 418); 

                auto tg_xyyyz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 419); 

                auto tg_xyyyz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 420); 

                auto tg_xyyyz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 421); 

                auto tg_xyyyz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 422); 

                auto tg_xyyyz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 423); 

                auto tg_xyyyz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 424); 

                auto tg_xyyyz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 425); 

                auto tg_xyyyz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 426); 

                auto tg_xyyyz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 427); 

                auto tg_xyyyz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 428); 

                auto tg_xyyyz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 429); 

                auto tg_xyyyz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 430); 

                auto tg_xyyyz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 431); 

                auto tg_xyyzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 432); 

                auto tg_xyyzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 433); 

                auto tg_xyyzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 434); 

                auto tg_xyyzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 435); 

                auto tg_xyyzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 436); 

                auto tg_xyyzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 437); 

                auto tg_xyyzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 438); 

                auto tg_xyyzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 439); 

                auto tg_xyyzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 440); 

                auto tg_xyyzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 441); 

                auto tg_xyyzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 442); 

                auto tg_xyyzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 443); 

                auto tg_xyyzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 444); 

                auto tg_xyyzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 445); 

                auto tg_xyyzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 446); 

                auto tg_xyyzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 447); 

                auto tg_xyyzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 448); 

                auto tg_xyyzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 449); 

                auto tg_xyyzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 450); 

                auto tg_xyyzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 451); 

                auto tg_xyyzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 452); 

                auto tg_xyyzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 453); 

                auto tg_xyyzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 454); 

                auto tg_xyyzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 455); 

                auto tg_xyyzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 456); 

                auto tg_xyyzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 457); 

                auto tg_xyyzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 458); 

                auto tg_xyyzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 459); 

                auto tg_xyyzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 460); 

                auto tg_xyyzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 461); 

                auto tg_xyyzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 462); 

                auto tg_xyyzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 463); 

                auto tg_xyyzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 464); 

                auto tg_xyyzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 465); 

                auto tg_xyyzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 466); 

                auto tg_xyyzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 467); 

                auto tg_xyzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 468); 

                auto tg_xyzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 469); 

                auto tg_xyzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 470); 

                auto tg_xyzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 471); 

                auto tg_xyzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 472); 

                auto tg_xyzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 473); 

                auto tg_xyzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 474); 

                auto tg_xyzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 475); 

                auto tg_xyzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 476); 

                auto tg_xyzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 477); 

                auto tg_xyzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 478); 

                auto tg_xyzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 479); 

                auto tg_xyzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 480); 

                auto tg_xyzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 481); 

                auto tg_xyzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 482); 

                auto tg_xyzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 483); 

                auto tg_xyzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 484); 

                auto tg_xyzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 485); 

                auto tg_xyzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 486); 

                auto tg_xyzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 487); 

                auto tg_xyzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 488); 

                auto tg_xyzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 489); 

                auto tg_xyzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 490); 

                auto tg_xyzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 491); 

                auto tg_xyzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 492); 

                auto tg_xyzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 493); 

                auto tg_xyzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 494); 

                auto tg_xyzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 495); 

                auto tg_xyzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 496); 

                auto tg_xyzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 497); 

                auto tg_xyzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 498); 

                auto tg_xyzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 499); 

                auto tg_xyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 400); 

                auto tg_xyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 401); 

                auto tg_xyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 402); 

                auto tg_xyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 403); 

                auto tg_xyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 404); 

                auto tg_xyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 405); 

                auto tg_xyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 406); 

                auto tg_xyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 407); 

                auto tg_xyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 408); 

                auto tg_xyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 409); 

                auto tg_xyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 410); 

                auto tg_xyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 411); 

                auto tg_xyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 412); 

                auto tg_xyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 413); 

                auto tg_xyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 414); 

                auto tg_xyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 415); 

                auto tg_xyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 416); 

                auto tg_xyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 417); 

                auto tg_xyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 418); 

                auto tg_xyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 419); 

                auto tg_xyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 420); 

                auto tg_xyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 421); 

                auto tg_xyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 422); 

                auto tg_xyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 423); 

                auto tg_xyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 424); 

                auto tg_xyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 425); 

                auto tg_xyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 426); 

                auto tg_xyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 427); 

                auto tg_xyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 428); 

                auto tg_xyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 429); 

                auto tg_xyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 430); 

                auto tg_xyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 431); 

                auto tg_xyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 432); 

                auto tg_xyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 433); 

                auto tg_xyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 434); 

                auto tg_xyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 435); 

                auto tg_xyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 436); 

                auto tg_xyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 437); 

                auto tg_xyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 438); 

                auto tg_xyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 439); 

                auto tg_xyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 440); 

                auto tg_xyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 441); 

                auto tg_xyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 442); 

                auto tg_xyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 443); 

                auto tg_xyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 444); 

                auto tg_xyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 445); 

                auto tg_xyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 446); 

                auto tg_xyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 447); 

                auto tg_xyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 448); 

                auto tg_xyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 449); 

                auto tg_xyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 450); 

                auto tg_xyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 451); 

                auto tg_xyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 452); 

                auto tg_xyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 453); 

                auto tg_xyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 454); 

                auto tg_xyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 455); 

                auto tg_xyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 456); 

                auto tg_xyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 457); 

                auto tg_xyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 458); 

                auto tg_xyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 459); 

                auto tg_xyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 460); 

                auto tg_xyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 461); 

                auto tg_xyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 462); 

                auto tg_xyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 463); 

                auto tg_xyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 464); 

                auto tg_xyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 465); 

                auto tg_xyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 466); 

                auto tg_xyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 467); 

                auto tg_xyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 468); 

                auto tg_xyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 469); 

                auto tg_xyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 470); 

                auto tg_xyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 471); 

                auto tg_xyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 472); 

                auto tg_xyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 473); 

                auto tg_xyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 474); 

                auto tg_xyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 475); 

                auto tg_xyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 476); 

                auto tg_xyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 477); 

                auto tg_xyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 478); 

                auto tg_xyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 479); 

                auto tg_xyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 480); 

                auto tg_xyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 481); 

                auto tg_xyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 482); 

                auto tg_xyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 483); 

                auto tg_xyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 484); 

                auto tg_xyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 485); 

                auto tg_xyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 486); 

                auto tg_xyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 487); 

                auto tg_xyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 488); 

                auto tg_xyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 489); 

                auto tg_xyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 490); 

                auto tg_xyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 491); 

                auto tg_xyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 492); 

                auto tg_xyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 493); 

                auto tg_xyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 494); 

                auto tg_xyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 495); 

                auto tg_xyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 496); 

                auto tg_xyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 497); 

                auto tg_xyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 498); 

                auto tg_xyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 499); 

                auto tg_xxyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 312); 

                auto tg_xxyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 313); 

                auto tg_xxyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 314); 

                auto tg_xxyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 315); 

                auto tg_xxyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 316); 

                auto tg_xxyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 317); 

                auto tg_xxyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 318); 

                auto tg_xxyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 319); 

                auto tg_xxyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 320); 

                auto tg_xxyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 321); 

                auto tg_xxyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 322); 

                auto tg_xxyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 323); 

                auto tg_xxyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 324); 

                auto tg_xxyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 325); 

                auto tg_xxyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 326); 

                auto tg_xxyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 327); 

                auto tg_xxyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 328); 

                auto tg_xxyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 329); 

                auto tg_xxyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 330); 

                auto tg_xxyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 331); 

                auto tg_xxyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 332); 

                auto tg_xxyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 333); 

                auto tg_xxyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 334); 

                auto tg_xxyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 335); 

                auto tg_xxyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 336); 

                auto tg_xxyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 337); 

                auto tg_xxyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 338); 

                auto tg_xxyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 339); 

                auto tg_xxyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 340); 

                auto tg_xxyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 341); 

                auto tg_xxyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 342); 

                auto tg_xxyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 343); 

                auto tg_xxyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 344); 

                auto tg_xxyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 345); 

                auto tg_xxyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 346); 

                auto tg_xxyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 347); 

                auto tg_xxyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 348); 

                auto tg_xxyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 349); 

                auto tg_xxyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 350); 

                auto tg_xxyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 351); 

                auto tg_xxyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 352); 

                auto tg_xxyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 353); 

                auto tg_xxyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 354); 

                auto tg_xxyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 355); 

                auto tg_xxyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 356); 

                auto tg_xxyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 357); 

                auto tg_xxyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 358); 

                auto tg_xxyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 359); 

                auto tg_xxyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 360); 

                auto tg_xxyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 361); 

                auto tg_xxyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 362); 

                auto tg_xxyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 363); 

                auto tg_xxyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 364); 

                auto tg_xxyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 365); 

                auto tg_xxyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 366); 

                auto tg_xxyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 367); 

                auto tg_xxyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 368); 

                auto tg_xxyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 369); 

                auto tg_xxyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 370); 

                auto tg_xxyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 371); 

                auto tg_xxyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 372); 

                auto tg_xxyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 373); 

                auto tg_xxyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 374); 

                auto tg_xxyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 375); 

                auto tg_xxyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 376); 

                auto tg_xxyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 377); 

                auto tg_xxyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 378); 

                auto tg_xxyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 379); 

                auto tg_xxyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 380); 

                auto tg_xxyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 381); 

                auto tg_xxyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 382); 

                auto tg_xxyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 383); 

                auto tg_xxyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 384); 

                auto tg_xxyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 385); 

                auto tg_xxyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 386); 

                auto tg_xxyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 387); 

                auto tg_xxyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 388); 

                auto tg_xxyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 389); 

                auto tg_xxyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 390); 

                auto tg_xxyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 391); 

                // set up pointers to integrals

                auto tg_xxxyyyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 400); 

                auto tg_xxxyyyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 401); 

                auto tg_xxxyyyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 402); 

                auto tg_xxxyyyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 403); 

                auto tg_xxxyyyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 404); 

                auto tg_xxxyyyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 405); 

                auto tg_xxxyyyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 406); 

                auto tg_xxxyyyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 407); 

                auto tg_xxxyyyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 408); 

                auto tg_xxxyyyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 409); 

                auto tg_xxxyyyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 410); 

                auto tg_xxxyyyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 411); 

                auto tg_xxxyyyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 412); 

                auto tg_xxxyyyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 413); 

                auto tg_xxxyyyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 414); 

                auto tg_xxxyyyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 415); 

                auto tg_xxxyyyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 416); 

                auto tg_xxxyyyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 417); 

                auto tg_xxxyyyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 418); 

                auto tg_xxxyyyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 419); 

                auto tg_xxxyyyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 420); 

                auto tg_xxxyyyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 421); 

                auto tg_xxxyyyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 422); 

                auto tg_xxxyyyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 423); 

                auto tg_xxxyyyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 424); 

                auto tg_xxxyyyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 425); 

                auto tg_xxxyyyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 426); 

                auto tg_xxxyyyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 427); 

                auto tg_xxxyyyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 428); 

                auto tg_xxxyyyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 429); 

                auto tg_xxxyyyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 430); 

                auto tg_xxxyyyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 431); 

                auto tg_xxxyyzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 432); 

                auto tg_xxxyyzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 433); 

                auto tg_xxxyyzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 434); 

                auto tg_xxxyyzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 435); 

                auto tg_xxxyyzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 436); 

                auto tg_xxxyyzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 437); 

                auto tg_xxxyyzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 438); 

                auto tg_xxxyyzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 439); 

                auto tg_xxxyyzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 440); 

                auto tg_xxxyyzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 441); 

                auto tg_xxxyyzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 442); 

                auto tg_xxxyyzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 443); 

                auto tg_xxxyyzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 444); 

                auto tg_xxxyyzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 445); 

                auto tg_xxxyyzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 446); 

                auto tg_xxxyyzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 447); 

                auto tg_xxxyyzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 448); 

                auto tg_xxxyyzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 449); 

                auto tg_xxxyyzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 450); 

                auto tg_xxxyyzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 451); 

                auto tg_xxxyyzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 452); 

                auto tg_xxxyyzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 453); 

                auto tg_xxxyyzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 454); 

                auto tg_xxxyyzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 455); 

                auto tg_xxxyyzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 456); 

                auto tg_xxxyyzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 457); 

                auto tg_xxxyyzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 458); 

                auto tg_xxxyyzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 459); 

                auto tg_xxxyyzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 460); 

                auto tg_xxxyyzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 461); 

                auto tg_xxxyyzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 462); 

                auto tg_xxxyyzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 463); 

                auto tg_xxxyyzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 464); 

                auto tg_xxxyyzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 465); 

                auto tg_xxxyyzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 466); 

                auto tg_xxxyyzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 467); 

                auto tg_xxxyzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 468); 

                auto tg_xxxyzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 469); 

                auto tg_xxxyzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 470); 

                auto tg_xxxyzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 471); 

                auto tg_xxxyzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 472); 

                auto tg_xxxyzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 473); 

                auto tg_xxxyzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 474); 

                auto tg_xxxyzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 475); 

                auto tg_xxxyzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 476); 

                auto tg_xxxyzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 477); 

                auto tg_xxxyzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 478); 

                auto tg_xxxyzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 479); 

                auto tg_xxxyzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 480); 

                auto tg_xxxyzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 481); 

                auto tg_xxxyzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 482); 

                auto tg_xxxyzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 483); 

                auto tg_xxxyzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 484); 

                auto tg_xxxyzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 485); 

                auto tg_xxxyzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 486); 

                auto tg_xxxyzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 487); 

                auto tg_xxxyzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 488); 

                auto tg_xxxyzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 489); 

                auto tg_xxxyzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 490); 

                auto tg_xxxyzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 491); 

                auto tg_xxxyzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 492); 

                auto tg_xxxyzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 493); 

                auto tg_xxxyzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 494); 

                auto tg_xxxyzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 495); 

                auto tg_xxxyzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 496); 

                auto tg_xxxyzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 497); 

                auto tg_xxxyzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 498); 

                auto tg_xxxyzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 499); 

                // Batch of Integrals (400,500)

                #pragma omp simd aligned(fxn, fza, tg_xxxyyyz_xxxxxyz_0, tg_xxxyyyz_xxxxxzz_0, \
                                         tg_xxxyyyz_xxxxyyy_0, tg_xxxyyyz_xxxxyyz_0, tg_xxxyyyz_xxxxyzz_0, tg_xxxyyyz_xxxxzzz_0, \
                                         tg_xxxyyyz_xxxyyyy_0, tg_xxxyyyz_xxxyyyz_0, tg_xxxyyyz_xxxyyzz_0, tg_xxxyyyz_xxxyzzz_0, \
                                         tg_xxxyyyz_xxxzzzz_0, tg_xxxyyyz_xxyyyyy_0, tg_xxxyyyz_xxyyyyz_0, tg_xxxyyyz_xxyyyzz_0, \
                                         tg_xxxyyyz_xxyyzzz_0, tg_xxxyyyz_xxyzzzz_0, tg_xxxyyyz_xxzzzzz_0, tg_xxxyyyz_xyyyyyy_0, \
                                         tg_xxxyyyz_xyyyyyz_0, tg_xxxyyyz_xyyyyzz_0, tg_xxxyyyz_xyyyzzz_0, tg_xxxyyyz_xyyzzzz_0, \
                                         tg_xxxyyyz_xyzzzzz_0, tg_xxxyyyz_xzzzzzz_0, tg_xxxyyyz_yyyyyyy_0, tg_xxxyyyz_yyyyyyz_0, \
                                         tg_xxxyyyz_yyyyyzz_0, tg_xxxyyyz_yyyyzzz_0, tg_xxxyyyz_yyyzzzz_0, tg_xxxyyyz_yyzzzzz_0, \
                                         tg_xxxyyyz_yzzzzzz_0, tg_xxxyyyz_zzzzzzz_0, tg_xxxyyzz_xxxxxxx_0, tg_xxxyyzz_xxxxxxy_0, \
                                         tg_xxxyyzz_xxxxxxz_0, tg_xxxyyzz_xxxxxyy_0, tg_xxxyyzz_xxxxxyz_0, tg_xxxyyzz_xxxxxzz_0, \
                                         tg_xxxyyzz_xxxxyyy_0, tg_xxxyyzz_xxxxyyz_0, tg_xxxyyzz_xxxxyzz_0, tg_xxxyyzz_xxxxzzz_0, \
                                         tg_xxxyyzz_xxxyyyy_0, tg_xxxyyzz_xxxyyyz_0, tg_xxxyyzz_xxxyyzz_0, tg_xxxyyzz_xxxyzzz_0, \
                                         tg_xxxyyzz_xxxzzzz_0, tg_xxxyyzz_xxyyyyy_0, tg_xxxyyzz_xxyyyyz_0, tg_xxxyyzz_xxyyyzz_0, \
                                         tg_xxxyyzz_xxyyzzz_0, tg_xxxyyzz_xxyzzzz_0, tg_xxxyyzz_xxzzzzz_0, tg_xxxyyzz_xyyyyyy_0, \
                                         tg_xxxyyzz_xyyyyyz_0, tg_xxxyyzz_xyyyyzz_0, tg_xxxyyzz_xyyyzzz_0, tg_xxxyyzz_xyyzzzz_0, \
                                         tg_xxxyyzz_xyzzzzz_0, tg_xxxyyzz_xzzzzzz_0, tg_xxxyyzz_yyyyyyy_0, tg_xxxyyzz_yyyyyyz_0, \
                                         tg_xxxyyzz_yyyyyzz_0, tg_xxxyyzz_yyyyzzz_0, tg_xxxyyzz_yyyzzzz_0, tg_xxxyyzz_yyzzzzz_0, \
                                         tg_xxxyyzz_yzzzzzz_0, tg_xxxyyzz_zzzzzzz_0, tg_xxxyzzz_xxxxxxx_0, tg_xxxyzzz_xxxxxxy_0, \
                                         tg_xxxyzzz_xxxxxxz_0, tg_xxxyzzz_xxxxxyy_0, tg_xxxyzzz_xxxxxyz_0, tg_xxxyzzz_xxxxxzz_0, \
                                         tg_xxxyzzz_xxxxyyy_0, tg_xxxyzzz_xxxxyyz_0, tg_xxxyzzz_xxxxyzz_0, tg_xxxyzzz_xxxxzzz_0, \
                                         tg_xxxyzzz_xxxyyyy_0, tg_xxxyzzz_xxxyyyz_0, tg_xxxyzzz_xxxyyzz_0, tg_xxxyzzz_xxxyzzz_0, \
                                         tg_xxxyzzz_xxxzzzz_0, tg_xxxyzzz_xxyyyyy_0, tg_xxxyzzz_xxyyyyz_0, tg_xxxyzzz_xxyyyzz_0, \
                                         tg_xxxyzzz_xxyyzzz_0, tg_xxxyzzz_xxyzzzz_0, tg_xxxyzzz_xxzzzzz_0, tg_xxxyzzz_xyyyyyy_0, \
                                         tg_xxxyzzz_xyyyyyz_0, tg_xxxyzzz_xyyyyzz_0, tg_xxxyzzz_xyyyzzz_0, tg_xxxyzzz_xyyzzzz_0, \
                                         tg_xxxyzzz_xyzzzzz_0, tg_xxxyzzz_xzzzzzz_0, tg_xxxyzzz_yyyyyyy_0, tg_xxxyzzz_yyyyyyz_0, \
                                         tg_xxxyzzz_yyyyyzz_0, tg_xxxyzzz_yyyyzzz_0, tg_xxyyyz_xxxxxyz_0, tg_xxyyyz_xxxxxyz_1, \
                                         tg_xxyyyz_xxxxxzz_0, tg_xxyyyz_xxxxxzz_1, tg_xxyyyz_xxxxyyy_0, tg_xxyyyz_xxxxyyy_1, \
                                         tg_xxyyyz_xxxxyyz_0, tg_xxyyyz_xxxxyyz_1, tg_xxyyyz_xxxxyz_1, tg_xxyyyz_xxxxyzz_0, \
                                         tg_xxyyyz_xxxxyzz_1, tg_xxyyyz_xxxxzz_1, tg_xxyyyz_xxxxzzz_0, tg_xxyyyz_xxxxzzz_1, \
                                         tg_xxyyyz_xxxyyy_1, tg_xxyyyz_xxxyyyy_0, tg_xxyyyz_xxxyyyy_1, tg_xxyyyz_xxxyyyz_0, \
                                         tg_xxyyyz_xxxyyyz_1, tg_xxyyyz_xxxyyz_1, tg_xxyyyz_xxxyyzz_0, tg_xxyyyz_xxxyyzz_1, \
                                         tg_xxyyyz_xxxyzz_1, tg_xxyyyz_xxxyzzz_0, tg_xxyyyz_xxxyzzz_1, tg_xxyyyz_xxxzzz_1, \
                                         tg_xxyyyz_xxxzzzz_0, tg_xxyyyz_xxxzzzz_1, tg_xxyyyz_xxyyyy_1, tg_xxyyyz_xxyyyyy_0, \
                                         tg_xxyyyz_xxyyyyy_1, tg_xxyyyz_xxyyyyz_0, tg_xxyyyz_xxyyyyz_1, tg_xxyyyz_xxyyyz_1, \
                                         tg_xxyyyz_xxyyyzz_0, tg_xxyyyz_xxyyyzz_1, tg_xxyyyz_xxyyzz_1, tg_xxyyyz_xxyyzzz_0, \
                                         tg_xxyyyz_xxyyzzz_1, tg_xxyyyz_xxyzzz_1, tg_xxyyyz_xxyzzzz_0, tg_xxyyyz_xxyzzzz_1, \
                                         tg_xxyyyz_xxzzzz_1, tg_xxyyyz_xxzzzzz_0, tg_xxyyyz_xxzzzzz_1, tg_xxyyyz_xyyyyy_1, \
                                         tg_xxyyyz_xyyyyyy_0, tg_xxyyyz_xyyyyyy_1, tg_xxyyyz_xyyyyyz_0, tg_xxyyyz_xyyyyyz_1, \
                                         tg_xxyyyz_xyyyyz_1, tg_xxyyyz_xyyyyzz_0, tg_xxyyyz_xyyyyzz_1, tg_xxyyyz_xyyyzz_1, \
                                         tg_xxyyyz_xyyyzzz_0, tg_xxyyyz_xyyyzzz_1, tg_xxyyyz_xyyzzz_1, tg_xxyyyz_xyyzzzz_0, \
                                         tg_xxyyyz_xyyzzzz_1, tg_xxyyyz_xyzzzz_1, tg_xxyyyz_xyzzzzz_0, tg_xxyyyz_xyzzzzz_1, \
                                         tg_xxyyyz_xzzzzz_1, tg_xxyyyz_xzzzzzz_0, tg_xxyyyz_xzzzzzz_1, tg_xxyyyz_yyyyyy_1, \
                                         tg_xxyyyz_yyyyyyy_0, tg_xxyyyz_yyyyyyy_1, tg_xxyyyz_yyyyyyz_0, tg_xxyyyz_yyyyyyz_1, \
                                         tg_xxyyyz_yyyyyz_1, tg_xxyyyz_yyyyyzz_0, tg_xxyyyz_yyyyyzz_1, tg_xxyyyz_yyyyzz_1, \
                                         tg_xxyyyz_yyyyzzz_0, tg_xxyyyz_yyyyzzz_1, tg_xxyyyz_yyyzzz_1, tg_xxyyyz_yyyzzzz_0, \
                                         tg_xxyyyz_yyyzzzz_1, tg_xxyyyz_yyzzzz_1, tg_xxyyyz_yyzzzzz_0, tg_xxyyyz_yyzzzzz_1, \
                                         tg_xxyyyz_yzzzzz_1, tg_xxyyyz_yzzzzzz_0, tg_xxyyyz_yzzzzzz_1, tg_xxyyyz_zzzzzz_1, \
                                         tg_xxyyyz_zzzzzzz_0, tg_xxyyyz_zzzzzzz_1, tg_xxyyzz_xxxxxx_1, tg_xxyyzz_xxxxxxx_0, \
                                         tg_xxyyzz_xxxxxxx_1, tg_xxyyzz_xxxxxxy_0, tg_xxyyzz_xxxxxxy_1, tg_xxyyzz_xxxxxxz_0, \
                                         tg_xxyyzz_xxxxxxz_1, tg_xxyyzz_xxxxxy_1, tg_xxyyzz_xxxxxyy_0, tg_xxyyzz_xxxxxyy_1, \
                                         tg_xxyyzz_xxxxxyz_0, tg_xxyyzz_xxxxxyz_1, tg_xxyyzz_xxxxxz_1, tg_xxyyzz_xxxxxzz_0, \
                                         tg_xxyyzz_xxxxxzz_1, tg_xxyyzz_xxxxyy_1, tg_xxyyzz_xxxxyyy_0, tg_xxyyzz_xxxxyyy_1, \
                                         tg_xxyyzz_xxxxyyz_0, tg_xxyyzz_xxxxyyz_1, tg_xxyyzz_xxxxyz_1, tg_xxyyzz_xxxxyzz_0, \
                                         tg_xxyyzz_xxxxyzz_1, tg_xxyyzz_xxxxzz_1, tg_xxyyzz_xxxxzzz_0, tg_xxyyzz_xxxxzzz_1, \
                                         tg_xxyyzz_xxxyyy_1, tg_xxyyzz_xxxyyyy_0, tg_xxyyzz_xxxyyyy_1, tg_xxyyzz_xxxyyyz_0, \
                                         tg_xxyyzz_xxxyyyz_1, tg_xxyyzz_xxxyyz_1, tg_xxyyzz_xxxyyzz_0, tg_xxyyzz_xxxyyzz_1, \
                                         tg_xxyyzz_xxxyzz_1, tg_xxyyzz_xxxyzzz_0, tg_xxyyzz_xxxyzzz_1, tg_xxyyzz_xxxzzz_1, \
                                         tg_xxyyzz_xxxzzzz_0, tg_xxyyzz_xxxzzzz_1, tg_xxyyzz_xxyyyy_1, tg_xxyyzz_xxyyyyy_0, \
                                         tg_xxyyzz_xxyyyyy_1, tg_xxyyzz_xxyyyyz_0, tg_xxyyzz_xxyyyyz_1, tg_xxyyzz_xxyyyz_1, \
                                         tg_xxyyzz_xxyyyzz_0, tg_xxyyzz_xxyyyzz_1, tg_xxyyzz_xxyyzz_1, tg_xxyyzz_xxyyzzz_0, \
                                         tg_xxyyzz_xxyyzzz_1, tg_xxyyzz_xxyzzz_1, tg_xxyyzz_xxyzzzz_0, tg_xxyyzz_xxyzzzz_1, \
                                         tg_xxyyzz_xxzzzz_1, tg_xxyyzz_xxzzzzz_0, tg_xxyyzz_xxzzzzz_1, tg_xxyyzz_xyyyyy_1, \
                                         tg_xxyyzz_xyyyyyy_0, tg_xxyyzz_xyyyyyy_1, tg_xxyyzz_xyyyyyz_0, tg_xxyyzz_xyyyyyz_1, \
                                         tg_xxyyzz_xyyyyz_1, tg_xxyyzz_xyyyyzz_0, tg_xxyyzz_xyyyyzz_1, tg_xxyyzz_xyyyzz_1, \
                                         tg_xxyyzz_xyyyzzz_0, tg_xxyyzz_xyyyzzz_1, tg_xxyyzz_xyyzzz_1, tg_xxyyzz_xyyzzzz_0, \
                                         tg_xxyyzz_xyyzzzz_1, tg_xxyyzz_xyzzzz_1, tg_xxyyzz_xyzzzzz_0, tg_xxyyzz_xyzzzzz_1, \
                                         tg_xxyyzz_xzzzzz_1, tg_xxyyzz_xzzzzzz_0, tg_xxyyzz_xzzzzzz_1, tg_xxyyzz_yyyyyy_1, \
                                         tg_xxyyzz_yyyyyyy_0, tg_xxyyzz_yyyyyyy_1, tg_xxyyzz_yyyyyyz_0, tg_xxyyzz_yyyyyyz_1, \
                                         tg_xxyyzz_yyyyyz_1, tg_xxyyzz_yyyyyzz_0, tg_xxyyzz_yyyyyzz_1, tg_xxyyzz_yyyyzz_1, \
                                         tg_xxyyzz_yyyyzzz_0, tg_xxyyzz_yyyyzzz_1, tg_xxyyzz_yyyzzz_1, tg_xxyyzz_yyyzzzz_0, \
                                         tg_xxyyzz_yyyzzzz_1, tg_xxyyzz_yyzzzz_1, tg_xxyyzz_yyzzzzz_0, tg_xxyyzz_yyzzzzz_1, \
                                         tg_xxyyzz_yzzzzz_1, tg_xxyyzz_yzzzzzz_0, tg_xxyyzz_yzzzzzz_1, tg_xxyyzz_zzzzzz_1, \
                                         tg_xxyyzz_zzzzzzz_0, tg_xxyyzz_zzzzzzz_1, tg_xxyzzz_xxxxxx_1, tg_xxyzzz_xxxxxxx_0, \
                                         tg_xxyzzz_xxxxxxx_1, tg_xxyzzz_xxxxxxy_0, tg_xxyzzz_xxxxxxy_1, tg_xxyzzz_xxxxxxz_0, \
                                         tg_xxyzzz_xxxxxxz_1, tg_xxyzzz_xxxxxy_1, tg_xxyzzz_xxxxxyy_0, tg_xxyzzz_xxxxxyy_1, \
                                         tg_xxyzzz_xxxxxyz_0, tg_xxyzzz_xxxxxyz_1, tg_xxyzzz_xxxxxz_1, tg_xxyzzz_xxxxxzz_0, \
                                         tg_xxyzzz_xxxxxzz_1, tg_xxyzzz_xxxxyy_1, tg_xxyzzz_xxxxyyy_0, tg_xxyzzz_xxxxyyy_1, \
                                         tg_xxyzzz_xxxxyyz_0, tg_xxyzzz_xxxxyyz_1, tg_xxyzzz_xxxxyz_1, tg_xxyzzz_xxxxyzz_0, \
                                         tg_xxyzzz_xxxxyzz_1, tg_xxyzzz_xxxxzz_1, tg_xxyzzz_xxxxzzz_0, tg_xxyzzz_xxxxzzz_1, \
                                         tg_xxyzzz_xxxyyy_1, tg_xxyzzz_xxxyyyy_0, tg_xxyzzz_xxxyyyy_1, tg_xxyzzz_xxxyyyz_0, \
                                         tg_xxyzzz_xxxyyyz_1, tg_xxyzzz_xxxyyz_1, tg_xxyzzz_xxxyyzz_0, tg_xxyzzz_xxxyyzz_1, \
                                         tg_xxyzzz_xxxyzz_1, tg_xxyzzz_xxxyzzz_0, tg_xxyzzz_xxxyzzz_1, tg_xxyzzz_xxxzzz_1, \
                                         tg_xxyzzz_xxxzzzz_0, tg_xxyzzz_xxxzzzz_1, tg_xxyzzz_xxyyyy_1, tg_xxyzzz_xxyyyyy_0, \
                                         tg_xxyzzz_xxyyyyy_1, tg_xxyzzz_xxyyyyz_0, tg_xxyzzz_xxyyyyz_1, tg_xxyzzz_xxyyyz_1, \
                                         tg_xxyzzz_xxyyyzz_0, tg_xxyzzz_xxyyyzz_1, tg_xxyzzz_xxyyzz_1, tg_xxyzzz_xxyyzzz_0, \
                                         tg_xxyzzz_xxyyzzz_1, tg_xxyzzz_xxyzzz_1, tg_xxyzzz_xxyzzzz_0, tg_xxyzzz_xxyzzzz_1, \
                                         tg_xxyzzz_xxzzzz_1, tg_xxyzzz_xxzzzzz_0, tg_xxyzzz_xxzzzzz_1, tg_xxyzzz_xyyyyy_1, \
                                         tg_xxyzzz_xyyyyyy_0, tg_xxyzzz_xyyyyyy_1, tg_xxyzzz_xyyyyyz_0, tg_xxyzzz_xyyyyyz_1, \
                                         tg_xxyzzz_xyyyyz_1, tg_xxyzzz_xyyyyzz_0, tg_xxyzzz_xyyyyzz_1, tg_xxyzzz_xyyyzz_1, \
                                         tg_xxyzzz_xyyyzzz_0, tg_xxyzzz_xyyyzzz_1, tg_xxyzzz_xyyzzz_1, tg_xxyzzz_xyyzzzz_0, \
                                         tg_xxyzzz_xyyzzzz_1, tg_xxyzzz_xyzzzz_1, tg_xxyzzz_xyzzzzz_0, tg_xxyzzz_xyzzzzz_1, \
                                         tg_xxyzzz_xzzzzz_1, tg_xxyzzz_xzzzzzz_0, tg_xxyzzz_xzzzzzz_1, tg_xxyzzz_yyyyyy_1, \
                                         tg_xxyzzz_yyyyyyy_0, tg_xxyzzz_yyyyyyy_1, tg_xxyzzz_yyyyyyz_0, tg_xxyzzz_yyyyyyz_1, \
                                         tg_xxyzzz_yyyyyz_1, tg_xxyzzz_yyyyyzz_0, tg_xxyzzz_yyyyyzz_1, tg_xxyzzz_yyyyzz_1, \
                                         tg_xxyzzz_yyyyzzz_0, tg_xxyzzz_yyyyzzz_1, tg_xxyzzz_yyyzzz_1, tg_xxyzzz_yyzzzz_1, \
                                         tg_xxyzzz_yzzzzz_1, tg_xxyzzz_zzzzzz_1, tg_xyyyz_xxxxxyz_0, tg_xyyyz_xxxxxyz_1, \
                                         tg_xyyyz_xxxxxzz_0, tg_xyyyz_xxxxxzz_1, tg_xyyyz_xxxxyyy_0, tg_xyyyz_xxxxyyy_1, \
                                         tg_xyyyz_xxxxyyz_0, tg_xyyyz_xxxxyyz_1, tg_xyyyz_xxxxyzz_0, tg_xyyyz_xxxxyzz_1, \
                                         tg_xyyyz_xxxxzzz_0, tg_xyyyz_xxxxzzz_1, tg_xyyyz_xxxyyyy_0, tg_xyyyz_xxxyyyy_1, \
                                         tg_xyyyz_xxxyyyz_0, tg_xyyyz_xxxyyyz_1, tg_xyyyz_xxxyyzz_0, tg_xyyyz_xxxyyzz_1, \
                                         tg_xyyyz_xxxyzzz_0, tg_xyyyz_xxxyzzz_1, tg_xyyyz_xxxzzzz_0, tg_xyyyz_xxxzzzz_1, \
                                         tg_xyyyz_xxyyyyy_0, tg_xyyyz_xxyyyyy_1, tg_xyyyz_xxyyyyz_0, tg_xyyyz_xxyyyyz_1, \
                                         tg_xyyyz_xxyyyzz_0, tg_xyyyz_xxyyyzz_1, tg_xyyyz_xxyyzzz_0, tg_xyyyz_xxyyzzz_1, \
                                         tg_xyyyz_xxyzzzz_0, tg_xyyyz_xxyzzzz_1, tg_xyyyz_xxzzzzz_0, tg_xyyyz_xxzzzzz_1, \
                                         tg_xyyyz_xyyyyyy_0, tg_xyyyz_xyyyyyy_1, tg_xyyyz_xyyyyyz_0, tg_xyyyz_xyyyyyz_1, \
                                         tg_xyyyz_xyyyyzz_0, tg_xyyyz_xyyyyzz_1, tg_xyyyz_xyyyzzz_0, tg_xyyyz_xyyyzzz_1, \
                                         tg_xyyyz_xyyzzzz_0, tg_xyyyz_xyyzzzz_1, tg_xyyyz_xyzzzzz_0, tg_xyyyz_xyzzzzz_1, \
                                         tg_xyyyz_xzzzzzz_0, tg_xyyyz_xzzzzzz_1, tg_xyyyz_yyyyyyy_0, tg_xyyyz_yyyyyyy_1, \
                                         tg_xyyyz_yyyyyyz_0, tg_xyyyz_yyyyyyz_1, tg_xyyyz_yyyyyzz_0, tg_xyyyz_yyyyyzz_1, \
                                         tg_xyyyz_yyyyzzz_0, tg_xyyyz_yyyyzzz_1, tg_xyyyz_yyyzzzz_0, tg_xyyyz_yyyzzzz_1, \
                                         tg_xyyyz_yyzzzzz_0, tg_xyyyz_yyzzzzz_1, tg_xyyyz_yzzzzzz_0, tg_xyyyz_yzzzzzz_1, \
                                         tg_xyyyz_zzzzzzz_0, tg_xyyyz_zzzzzzz_1, tg_xyyzz_xxxxxxx_0, tg_xyyzz_xxxxxxx_1, \
                                         tg_xyyzz_xxxxxxy_0, tg_xyyzz_xxxxxxy_1, tg_xyyzz_xxxxxxz_0, tg_xyyzz_xxxxxxz_1, \
                                         tg_xyyzz_xxxxxyy_0, tg_xyyzz_xxxxxyy_1, tg_xyyzz_xxxxxyz_0, tg_xyyzz_xxxxxyz_1, \
                                         tg_xyyzz_xxxxxzz_0, tg_xyyzz_xxxxxzz_1, tg_xyyzz_xxxxyyy_0, tg_xyyzz_xxxxyyy_1, \
                                         tg_xyyzz_xxxxyyz_0, tg_xyyzz_xxxxyyz_1, tg_xyyzz_xxxxyzz_0, tg_xyyzz_xxxxyzz_1, \
                                         tg_xyyzz_xxxxzzz_0, tg_xyyzz_xxxxzzz_1, tg_xyyzz_xxxyyyy_0, tg_xyyzz_xxxyyyy_1, \
                                         tg_xyyzz_xxxyyyz_0, tg_xyyzz_xxxyyyz_1, tg_xyyzz_xxxyyzz_0, tg_xyyzz_xxxyyzz_1, \
                                         tg_xyyzz_xxxyzzz_0, tg_xyyzz_xxxyzzz_1, tg_xyyzz_xxxzzzz_0, tg_xyyzz_xxxzzzz_1, \
                                         tg_xyyzz_xxyyyyy_0, tg_xyyzz_xxyyyyy_1, tg_xyyzz_xxyyyyz_0, tg_xyyzz_xxyyyyz_1, \
                                         tg_xyyzz_xxyyyzz_0, tg_xyyzz_xxyyyzz_1, tg_xyyzz_xxyyzzz_0, tg_xyyzz_xxyyzzz_1, \
                                         tg_xyyzz_xxyzzzz_0, tg_xyyzz_xxyzzzz_1, tg_xyyzz_xxzzzzz_0, tg_xyyzz_xxzzzzz_1, \
                                         tg_xyyzz_xyyyyyy_0, tg_xyyzz_xyyyyyy_1, tg_xyyzz_xyyyyyz_0, tg_xyyzz_xyyyyyz_1, \
                                         tg_xyyzz_xyyyyzz_0, tg_xyyzz_xyyyyzz_1, tg_xyyzz_xyyyzzz_0, tg_xyyzz_xyyyzzz_1, \
                                         tg_xyyzz_xyyzzzz_0, tg_xyyzz_xyyzzzz_1, tg_xyyzz_xyzzzzz_0, tg_xyyzz_xyzzzzz_1, \
                                         tg_xyyzz_xzzzzzz_0, tg_xyyzz_xzzzzzz_1, tg_xyyzz_yyyyyyy_0, tg_xyyzz_yyyyyyy_1, \
                                         tg_xyyzz_yyyyyyz_0, tg_xyyzz_yyyyyyz_1, tg_xyyzz_yyyyyzz_0, tg_xyyzz_yyyyyzz_1, \
                                         tg_xyyzz_yyyyzzz_0, tg_xyyzz_yyyyzzz_1, tg_xyyzz_yyyzzzz_0, tg_xyyzz_yyyzzzz_1, \
                                         tg_xyyzz_yyzzzzz_0, tg_xyyzz_yyzzzzz_1, tg_xyyzz_yzzzzzz_0, tg_xyyzz_yzzzzzz_1, \
                                         tg_xyyzz_zzzzzzz_0, tg_xyyzz_zzzzzzz_1, tg_xyzzz_xxxxxxx_0, tg_xyzzz_xxxxxxx_1, \
                                         tg_xyzzz_xxxxxxy_0, tg_xyzzz_xxxxxxy_1, tg_xyzzz_xxxxxxz_0, tg_xyzzz_xxxxxxz_1, \
                                         tg_xyzzz_xxxxxyy_0, tg_xyzzz_xxxxxyy_1, tg_xyzzz_xxxxxyz_0, tg_xyzzz_xxxxxyz_1, \
                                         tg_xyzzz_xxxxxzz_0, tg_xyzzz_xxxxxzz_1, tg_xyzzz_xxxxyyy_0, tg_xyzzz_xxxxyyy_1, \
                                         tg_xyzzz_xxxxyyz_0, tg_xyzzz_xxxxyyz_1, tg_xyzzz_xxxxyzz_0, tg_xyzzz_xxxxyzz_1, \
                                         tg_xyzzz_xxxxzzz_0, tg_xyzzz_xxxxzzz_1, tg_xyzzz_xxxyyyy_0, tg_xyzzz_xxxyyyy_1, \
                                         tg_xyzzz_xxxyyyz_0, tg_xyzzz_xxxyyyz_1, tg_xyzzz_xxxyyzz_0, tg_xyzzz_xxxyyzz_1, \
                                         tg_xyzzz_xxxyzzz_0, tg_xyzzz_xxxyzzz_1, tg_xyzzz_xxxzzzz_0, tg_xyzzz_xxxzzzz_1, \
                                         tg_xyzzz_xxyyyyy_0, tg_xyzzz_xxyyyyy_1, tg_xyzzz_xxyyyyz_0, tg_xyzzz_xxyyyyz_1, \
                                         tg_xyzzz_xxyyyzz_0, tg_xyzzz_xxyyyzz_1, tg_xyzzz_xxyyzzz_0, tg_xyzzz_xxyyzzz_1, \
                                         tg_xyzzz_xxyzzzz_0, tg_xyzzz_xxyzzzz_1, tg_xyzzz_xxzzzzz_0, tg_xyzzz_xxzzzzz_1, \
                                         tg_xyzzz_xyyyyyy_0, tg_xyzzz_xyyyyyy_1, tg_xyzzz_xyyyyyz_0, tg_xyzzz_xyyyyyz_1, \
                                         tg_xyzzz_xyyyyzz_0, tg_xyzzz_xyyyyzz_1, tg_xyzzz_xyyyzzz_0, tg_xyzzz_xyyyzzz_1, \
                                         tg_xyzzz_xyyzzzz_0, tg_xyzzz_xyyzzzz_1, tg_xyzzz_xyzzzzz_0, tg_xyzzz_xyzzzzz_1, \
                                         tg_xyzzz_xzzzzzz_0, tg_xyzzz_xzzzzzz_1, tg_xyzzz_yyyyyyy_0, tg_xyzzz_yyyyyyy_1, \
                                         tg_xyzzz_yyyyyyz_0, tg_xyzzz_yyyyyyz_1, tg_xyzzz_yyyyyzz_0, tg_xyzzz_yyyyyzz_1, \
                                         tg_xyzzz_yyyyzzz_0, tg_xyzzz_yyyyzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyyyz_xxxxxyz_0[j] = pb_x * tg_xxyyyz_xxxxxyz_0[j] + fr * tg_xxyyyz_xxxxxyz_1[j] + fl1_fx * (tg_xyyyz_xxxxxyz_0[j] - tg_xyyyz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyz_xxxxyz_1[j];

                    tg_xxxyyyz_xxxxxzz_0[j] = pb_x * tg_xxyyyz_xxxxxzz_0[j] + fr * tg_xxyyyz_xxxxxzz_1[j] + fl1_fx * (tg_xyyyz_xxxxxzz_0[j] - tg_xyyyz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyz_xxxxzz_1[j];

                    tg_xxxyyyz_xxxxyyy_0[j] = pb_x * tg_xxyyyz_xxxxyyy_0[j] + fr * tg_xxyyyz_xxxxyyy_1[j] + fl1_fx * (tg_xyyyz_xxxxyyy_0[j] - tg_xyyyz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyz_xxxyyy_1[j];

                    tg_xxxyyyz_xxxxyyz_0[j] = pb_x * tg_xxyyyz_xxxxyyz_0[j] + fr * tg_xxyyyz_xxxxyyz_1[j] + fl1_fx * (tg_xyyyz_xxxxyyz_0[j] - tg_xyyyz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyz_xxxyyz_1[j];

                    tg_xxxyyyz_xxxxyzz_0[j] = pb_x * tg_xxyyyz_xxxxyzz_0[j] + fr * tg_xxyyyz_xxxxyzz_1[j] + fl1_fx * (tg_xyyyz_xxxxyzz_0[j] - tg_xyyyz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyz_xxxyzz_1[j];

                    tg_xxxyyyz_xxxxzzz_0[j] = pb_x * tg_xxyyyz_xxxxzzz_0[j] + fr * tg_xxyyyz_xxxxzzz_1[j] + fl1_fx * (tg_xyyyz_xxxxzzz_0[j] - tg_xyyyz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyz_xxxzzz_1[j];

                    tg_xxxyyyz_xxxyyyy_0[j] = pb_x * tg_xxyyyz_xxxyyyy_0[j] + fr * tg_xxyyyz_xxxyyyy_1[j] + fl1_fx * (tg_xyyyz_xxxyyyy_0[j] - tg_xyyyz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyz_xxyyyy_1[j];

                    tg_xxxyyyz_xxxyyyz_0[j] = pb_x * tg_xxyyyz_xxxyyyz_0[j] + fr * tg_xxyyyz_xxxyyyz_1[j] + fl1_fx * (tg_xyyyz_xxxyyyz_0[j] - tg_xyyyz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyz_xxyyyz_1[j];

                    tg_xxxyyyz_xxxyyzz_0[j] = pb_x * tg_xxyyyz_xxxyyzz_0[j] + fr * tg_xxyyyz_xxxyyzz_1[j] + fl1_fx * (tg_xyyyz_xxxyyzz_0[j] - tg_xyyyz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyz_xxyyzz_1[j];

                    tg_xxxyyyz_xxxyzzz_0[j] = pb_x * tg_xxyyyz_xxxyzzz_0[j] + fr * tg_xxyyyz_xxxyzzz_1[j] + fl1_fx * (tg_xyyyz_xxxyzzz_0[j] - tg_xyyyz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyz_xxyzzz_1[j];

                    tg_xxxyyyz_xxxzzzz_0[j] = pb_x * tg_xxyyyz_xxxzzzz_0[j] + fr * tg_xxyyyz_xxxzzzz_1[j] + fl1_fx * (tg_xyyyz_xxxzzzz_0[j] - tg_xyyyz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyz_xxzzzz_1[j];

                    tg_xxxyyyz_xxyyyyy_0[j] = pb_x * tg_xxyyyz_xxyyyyy_0[j] + fr * tg_xxyyyz_xxyyyyy_1[j] + fl1_fx * (tg_xyyyz_xxyyyyy_0[j] - tg_xyyyz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xyyyyy_1[j];

                    tg_xxxyyyz_xxyyyyz_0[j] = pb_x * tg_xxyyyz_xxyyyyz_0[j] + fr * tg_xxyyyz_xxyyyyz_1[j] + fl1_fx * (tg_xyyyz_xxyyyyz_0[j] - tg_xyyyz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xyyyyz_1[j];

                    tg_xxxyyyz_xxyyyzz_0[j] = pb_x * tg_xxyyyz_xxyyyzz_0[j] + fr * tg_xxyyyz_xxyyyzz_1[j] + fl1_fx * (tg_xyyyz_xxyyyzz_0[j] - tg_xyyyz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xyyyzz_1[j];

                    tg_xxxyyyz_xxyyzzz_0[j] = pb_x * tg_xxyyyz_xxyyzzz_0[j] + fr * tg_xxyyyz_xxyyzzz_1[j] + fl1_fx * (tg_xyyyz_xxyyzzz_0[j] - tg_xyyyz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xyyzzz_1[j];

                    tg_xxxyyyz_xxyzzzz_0[j] = pb_x * tg_xxyyyz_xxyzzzz_0[j] + fr * tg_xxyyyz_xxyzzzz_1[j] + fl1_fx * (tg_xyyyz_xxyzzzz_0[j] - tg_xyyyz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xyzzzz_1[j];

                    tg_xxxyyyz_xxzzzzz_0[j] = pb_x * tg_xxyyyz_xxzzzzz_0[j] + fr * tg_xxyyyz_xxzzzzz_1[j] + fl1_fx * (tg_xyyyz_xxzzzzz_0[j] - tg_xyyyz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyz_xzzzzz_1[j];

                    tg_xxxyyyz_xyyyyyy_0[j] = pb_x * tg_xxyyyz_xyyyyyy_0[j] + fr * tg_xxyyyz_xyyyyyy_1[j] + fl1_fx * (tg_xyyyz_xyyyyyy_0[j] - tg_xyyyz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yyyyyy_1[j];

                    tg_xxxyyyz_xyyyyyz_0[j] = pb_x * tg_xxyyyz_xyyyyyz_0[j] + fr * tg_xxyyyz_xyyyyyz_1[j] + fl1_fx * (tg_xyyyz_xyyyyyz_0[j] - tg_xyyyz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yyyyyz_1[j];

                    tg_xxxyyyz_xyyyyzz_0[j] = pb_x * tg_xxyyyz_xyyyyzz_0[j] + fr * tg_xxyyyz_xyyyyzz_1[j] + fl1_fx * (tg_xyyyz_xyyyyzz_0[j] - tg_xyyyz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yyyyzz_1[j];

                    tg_xxxyyyz_xyyyzzz_0[j] = pb_x * tg_xxyyyz_xyyyzzz_0[j] + fr * tg_xxyyyz_xyyyzzz_1[j] + fl1_fx * (tg_xyyyz_xyyyzzz_0[j] - tg_xyyyz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yyyzzz_1[j];

                    tg_xxxyyyz_xyyzzzz_0[j] = pb_x * tg_xxyyyz_xyyzzzz_0[j] + fr * tg_xxyyyz_xyyzzzz_1[j] + fl1_fx * (tg_xyyyz_xyyzzzz_0[j] - tg_xyyyz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yyzzzz_1[j];

                    tg_xxxyyyz_xyzzzzz_0[j] = pb_x * tg_xxyyyz_xyzzzzz_0[j] + fr * tg_xxyyyz_xyzzzzz_1[j] + fl1_fx * (tg_xyyyz_xyzzzzz_0[j] - tg_xyyyz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_yzzzzz_1[j];

                    tg_xxxyyyz_xzzzzzz_0[j] = pb_x * tg_xxyyyz_xzzzzzz_0[j] + fr * tg_xxyyyz_xzzzzzz_1[j] + fl1_fx * (tg_xyyyz_xzzzzzz_0[j] - tg_xyyyz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyz_zzzzzz_1[j];

                    tg_xxxyyyz_yyyyyyy_0[j] = pb_x * tg_xxyyyz_yyyyyyy_0[j] + fr * tg_xxyyyz_yyyyyyy_1[j] + fl1_fx * (tg_xyyyz_yyyyyyy_0[j] - tg_xyyyz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxyyyz_yyyyyyz_0[j] = pb_x * tg_xxyyyz_yyyyyyz_0[j] + fr * tg_xxyyyz_yyyyyyz_1[j] + fl1_fx * (tg_xyyyz_yyyyyyz_0[j] - tg_xyyyz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxyyyz_yyyyyzz_0[j] = pb_x * tg_xxyyyz_yyyyyzz_0[j] + fr * tg_xxyyyz_yyyyyzz_1[j] + fl1_fx * (tg_xyyyz_yyyyyzz_0[j] - tg_xyyyz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxyyyz_yyyyzzz_0[j] = pb_x * tg_xxyyyz_yyyyzzz_0[j] + fr * tg_xxyyyz_yyyyzzz_1[j] + fl1_fx * (tg_xyyyz_yyyyzzz_0[j] - tg_xyyyz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxyyyz_yyyzzzz_0[j] = pb_x * tg_xxyyyz_yyyzzzz_0[j] + fr * tg_xxyyyz_yyyzzzz_1[j] + fl1_fx * (tg_xyyyz_yyyzzzz_0[j] - tg_xyyyz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxyyyz_yyzzzzz_0[j] = pb_x * tg_xxyyyz_yyzzzzz_0[j] + fr * tg_xxyyyz_yyzzzzz_1[j] + fl1_fx * (tg_xyyyz_yyzzzzz_0[j] - tg_xyyyz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyz_yzzzzzz_0[j] = pb_x * tg_xxyyyz_yzzzzzz_0[j] + fr * tg_xxyyyz_yzzzzzz_1[j] + fl1_fx * (tg_xyyyz_yzzzzzz_0[j] - tg_xyyyz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyz_zzzzzzz_0[j] = pb_x * tg_xxyyyz_zzzzzzz_0[j] + fr * tg_xxyyyz_zzzzzzz_1[j] + fl1_fx * (tg_xyyyz_zzzzzzz_0[j] - tg_xyyyz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyzz_xxxxxxx_0[j] = pb_x * tg_xxyyzz_xxxxxxx_0[j] + fr * tg_xxyyzz_xxxxxxx_1[j] + fl1_fx * (tg_xyyzz_xxxxxxx_0[j] - tg_xyyzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyyzz_xxxxxx_1[j];

                    tg_xxxyyzz_xxxxxxy_0[j] = pb_x * tg_xxyyzz_xxxxxxy_0[j] + fr * tg_xxyyzz_xxxxxxy_1[j] + fl1_fx * (tg_xyyzz_xxxxxxy_0[j] - tg_xyyzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyzz_xxxxxy_1[j];

                    tg_xxxyyzz_xxxxxxz_0[j] = pb_x * tg_xxyyzz_xxxxxxz_0[j] + fr * tg_xxyyzz_xxxxxxz_1[j] + fl1_fx * (tg_xyyzz_xxxxxxz_0[j] - tg_xyyzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyzz_xxxxxz_1[j];

                    tg_xxxyyzz_xxxxxyy_0[j] = pb_x * tg_xxyyzz_xxxxxyy_0[j] + fr * tg_xxyyzz_xxxxxyy_1[j] + fl1_fx * (tg_xyyzz_xxxxxyy_0[j] - tg_xyyzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyzz_xxxxyy_1[j];

                    tg_xxxyyzz_xxxxxyz_0[j] = pb_x * tg_xxyyzz_xxxxxyz_0[j] + fr * tg_xxyyzz_xxxxxyz_1[j] + fl1_fx * (tg_xyyzz_xxxxxyz_0[j] - tg_xyyzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyzz_xxxxyz_1[j];

                    tg_xxxyyzz_xxxxxzz_0[j] = pb_x * tg_xxyyzz_xxxxxzz_0[j] + fr * tg_xxyyzz_xxxxxzz_1[j] + fl1_fx * (tg_xyyzz_xxxxxzz_0[j] - tg_xyyzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyzz_xxxxzz_1[j];

                    tg_xxxyyzz_xxxxyyy_0[j] = pb_x * tg_xxyyzz_xxxxyyy_0[j] + fr * tg_xxyyzz_xxxxyyy_1[j] + fl1_fx * (tg_xyyzz_xxxxyyy_0[j] - tg_xyyzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzz_xxxyyy_1[j];

                    tg_xxxyyzz_xxxxyyz_0[j] = pb_x * tg_xxyyzz_xxxxyyz_0[j] + fr * tg_xxyyzz_xxxxyyz_1[j] + fl1_fx * (tg_xyyzz_xxxxyyz_0[j] - tg_xyyzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzz_xxxyyz_1[j];

                    tg_xxxyyzz_xxxxyzz_0[j] = pb_x * tg_xxyyzz_xxxxyzz_0[j] + fr * tg_xxyyzz_xxxxyzz_1[j] + fl1_fx * (tg_xyyzz_xxxxyzz_0[j] - tg_xyyzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzz_xxxyzz_1[j];

                    tg_xxxyyzz_xxxxzzz_0[j] = pb_x * tg_xxyyzz_xxxxzzz_0[j] + fr * tg_xxyyzz_xxxxzzz_1[j] + fl1_fx * (tg_xyyzz_xxxxzzz_0[j] - tg_xyyzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzz_xxxzzz_1[j];

                    tg_xxxyyzz_xxxyyyy_0[j] = pb_x * tg_xxyyzz_xxxyyyy_0[j] + fr * tg_xxyyzz_xxxyyyy_1[j] + fl1_fx * (tg_xyyzz_xxxyyyy_0[j] - tg_xyyzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzz_xxyyyy_1[j];

                    tg_xxxyyzz_xxxyyyz_0[j] = pb_x * tg_xxyyzz_xxxyyyz_0[j] + fr * tg_xxyyzz_xxxyyyz_1[j] + fl1_fx * (tg_xyyzz_xxxyyyz_0[j] - tg_xyyzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzz_xxyyyz_1[j];

                    tg_xxxyyzz_xxxyyzz_0[j] = pb_x * tg_xxyyzz_xxxyyzz_0[j] + fr * tg_xxyyzz_xxxyyzz_1[j] + fl1_fx * (tg_xyyzz_xxxyyzz_0[j] - tg_xyyzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzz_xxyyzz_1[j];

                    tg_xxxyyzz_xxxyzzz_0[j] = pb_x * tg_xxyyzz_xxxyzzz_0[j] + fr * tg_xxyyzz_xxxyzzz_1[j] + fl1_fx * (tg_xyyzz_xxxyzzz_0[j] - tg_xyyzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzz_xxyzzz_1[j];

                    tg_xxxyyzz_xxxzzzz_0[j] = pb_x * tg_xxyyzz_xxxzzzz_0[j] + fr * tg_xxyyzz_xxxzzzz_1[j] + fl1_fx * (tg_xyyzz_xxxzzzz_0[j] - tg_xyyzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzz_xxzzzz_1[j];

                    tg_xxxyyzz_xxyyyyy_0[j] = pb_x * tg_xxyyzz_xxyyyyy_0[j] + fr * tg_xxyyzz_xxyyyyy_1[j] + fl1_fx * (tg_xyyzz_xxyyyyy_0[j] - tg_xyyzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xyyyyy_1[j];

                    tg_xxxyyzz_xxyyyyz_0[j] = pb_x * tg_xxyyzz_xxyyyyz_0[j] + fr * tg_xxyyzz_xxyyyyz_1[j] + fl1_fx * (tg_xyyzz_xxyyyyz_0[j] - tg_xyyzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xyyyyz_1[j];

                    tg_xxxyyzz_xxyyyzz_0[j] = pb_x * tg_xxyyzz_xxyyyzz_0[j] + fr * tg_xxyyzz_xxyyyzz_1[j] + fl1_fx * (tg_xyyzz_xxyyyzz_0[j] - tg_xyyzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xyyyzz_1[j];

                    tg_xxxyyzz_xxyyzzz_0[j] = pb_x * tg_xxyyzz_xxyyzzz_0[j] + fr * tg_xxyyzz_xxyyzzz_1[j] + fl1_fx * (tg_xyyzz_xxyyzzz_0[j] - tg_xyyzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xyyzzz_1[j];

                    tg_xxxyyzz_xxyzzzz_0[j] = pb_x * tg_xxyyzz_xxyzzzz_0[j] + fr * tg_xxyyzz_xxyzzzz_1[j] + fl1_fx * (tg_xyyzz_xxyzzzz_0[j] - tg_xyyzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xyzzzz_1[j];

                    tg_xxxyyzz_xxzzzzz_0[j] = pb_x * tg_xxyyzz_xxzzzzz_0[j] + fr * tg_xxyyzz_xxzzzzz_1[j] + fl1_fx * (tg_xyyzz_xxzzzzz_0[j] - tg_xyyzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzz_xzzzzz_1[j];

                    tg_xxxyyzz_xyyyyyy_0[j] = pb_x * tg_xxyyzz_xyyyyyy_0[j] + fr * tg_xxyyzz_xyyyyyy_1[j] + fl1_fx * (tg_xyyzz_xyyyyyy_0[j] - tg_xyyzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yyyyyy_1[j];

                    tg_xxxyyzz_xyyyyyz_0[j] = pb_x * tg_xxyyzz_xyyyyyz_0[j] + fr * tg_xxyyzz_xyyyyyz_1[j] + fl1_fx * (tg_xyyzz_xyyyyyz_0[j] - tg_xyyzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yyyyyz_1[j];

                    tg_xxxyyzz_xyyyyzz_0[j] = pb_x * tg_xxyyzz_xyyyyzz_0[j] + fr * tg_xxyyzz_xyyyyzz_1[j] + fl1_fx * (tg_xyyzz_xyyyyzz_0[j] - tg_xyyzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yyyyzz_1[j];

                    tg_xxxyyzz_xyyyzzz_0[j] = pb_x * tg_xxyyzz_xyyyzzz_0[j] + fr * tg_xxyyzz_xyyyzzz_1[j] + fl1_fx * (tg_xyyzz_xyyyzzz_0[j] - tg_xyyzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yyyzzz_1[j];

                    tg_xxxyyzz_xyyzzzz_0[j] = pb_x * tg_xxyyzz_xyyzzzz_0[j] + fr * tg_xxyyzz_xyyzzzz_1[j] + fl1_fx * (tg_xyyzz_xyyzzzz_0[j] - tg_xyyzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yyzzzz_1[j];

                    tg_xxxyyzz_xyzzzzz_0[j] = pb_x * tg_xxyyzz_xyzzzzz_0[j] + fr * tg_xxyyzz_xyzzzzz_1[j] + fl1_fx * (tg_xyyzz_xyzzzzz_0[j] - tg_xyyzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_yzzzzz_1[j];

                    tg_xxxyyzz_xzzzzzz_0[j] = pb_x * tg_xxyyzz_xzzzzzz_0[j] + fr * tg_xxyyzz_xzzzzzz_1[j] + fl1_fx * (tg_xyyzz_xzzzzzz_0[j] - tg_xyyzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzz_zzzzzz_1[j];

                    tg_xxxyyzz_yyyyyyy_0[j] = pb_x * tg_xxyyzz_yyyyyyy_0[j] + fr * tg_xxyyzz_yyyyyyy_1[j] + fl1_fx * (tg_xyyzz_yyyyyyy_0[j] - tg_xyyzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxyyzz_yyyyyyz_0[j] = pb_x * tg_xxyyzz_yyyyyyz_0[j] + fr * tg_xxyyzz_yyyyyyz_1[j] + fl1_fx * (tg_xyyzz_yyyyyyz_0[j] - tg_xyyzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxyyzz_yyyyyzz_0[j] = pb_x * tg_xxyyzz_yyyyyzz_0[j] + fr * tg_xxyyzz_yyyyyzz_1[j] + fl1_fx * (tg_xyyzz_yyyyyzz_0[j] - tg_xyyzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxyyzz_yyyyzzz_0[j] = pb_x * tg_xxyyzz_yyyyzzz_0[j] + fr * tg_xxyyzz_yyyyzzz_1[j] + fl1_fx * (tg_xyyzz_yyyyzzz_0[j] - tg_xyyzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxyyzz_yyyzzzz_0[j] = pb_x * tg_xxyyzz_yyyzzzz_0[j] + fr * tg_xxyyzz_yyyzzzz_1[j] + fl1_fx * (tg_xyyzz_yyyzzzz_0[j] - tg_xyyzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxyyzz_yyzzzzz_0[j] = pb_x * tg_xxyyzz_yyzzzzz_0[j] + fr * tg_xxyyzz_yyzzzzz_1[j] + fl1_fx * (tg_xyyzz_yyzzzzz_0[j] - tg_xyyzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxyyzz_yzzzzzz_0[j] = pb_x * tg_xxyyzz_yzzzzzz_0[j] + fr * tg_xxyyzz_yzzzzzz_1[j] + fl1_fx * (tg_xyyzz_yzzzzzz_0[j] - tg_xyyzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxyyzz_zzzzzzz_0[j] = pb_x * tg_xxyyzz_zzzzzzz_0[j] + fr * tg_xxyyzz_zzzzzzz_1[j] + fl1_fx * (tg_xyyzz_zzzzzzz_0[j] - tg_xyyzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxyzzz_xxxxxxx_0[j] = pb_x * tg_xxyzzz_xxxxxxx_0[j] + fr * tg_xxyzzz_xxxxxxx_1[j] + fl1_fx * (tg_xyzzz_xxxxxxx_0[j] - tg_xyzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxyzzz_xxxxxx_1[j];

                    tg_xxxyzzz_xxxxxxy_0[j] = pb_x * tg_xxyzzz_xxxxxxy_0[j] + fr * tg_xxyzzz_xxxxxxy_1[j] + fl1_fx * (tg_xyzzz_xxxxxxy_0[j] - tg_xyzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzzz_xxxxxy_1[j];

                    tg_xxxyzzz_xxxxxxz_0[j] = pb_x * tg_xxyzzz_xxxxxxz_0[j] + fr * tg_xxyzzz_xxxxxxz_1[j] + fl1_fx * (tg_xyzzz_xxxxxxz_0[j] - tg_xyzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzzz_xxxxxz_1[j];

                    tg_xxxyzzz_xxxxxyy_0[j] = pb_x * tg_xxyzzz_xxxxxyy_0[j] + fr * tg_xxyzzz_xxxxxyy_1[j] + fl1_fx * (tg_xyzzz_xxxxxyy_0[j] - tg_xyzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzzz_xxxxyy_1[j];

                    tg_xxxyzzz_xxxxxyz_0[j] = pb_x * tg_xxyzzz_xxxxxyz_0[j] + fr * tg_xxyzzz_xxxxxyz_1[j] + fl1_fx * (tg_xyzzz_xxxxxyz_0[j] - tg_xyzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzzz_xxxxyz_1[j];

                    tg_xxxyzzz_xxxxxzz_0[j] = pb_x * tg_xxyzzz_xxxxxzz_0[j] + fr * tg_xxyzzz_xxxxxzz_1[j] + fl1_fx * (tg_xyzzz_xxxxxzz_0[j] - tg_xyzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzzz_xxxxzz_1[j];

                    tg_xxxyzzz_xxxxyyy_0[j] = pb_x * tg_xxyzzz_xxxxyyy_0[j] + fr * tg_xxyzzz_xxxxyyy_1[j] + fl1_fx * (tg_xyzzz_xxxxyyy_0[j] - tg_xyzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzz_xxxyyy_1[j];

                    tg_xxxyzzz_xxxxyyz_0[j] = pb_x * tg_xxyzzz_xxxxyyz_0[j] + fr * tg_xxyzzz_xxxxyyz_1[j] + fl1_fx * (tg_xyzzz_xxxxyyz_0[j] - tg_xyzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzz_xxxyyz_1[j];

                    tg_xxxyzzz_xxxxyzz_0[j] = pb_x * tg_xxyzzz_xxxxyzz_0[j] + fr * tg_xxyzzz_xxxxyzz_1[j] + fl1_fx * (tg_xyzzz_xxxxyzz_0[j] - tg_xyzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzz_xxxyzz_1[j];

                    tg_xxxyzzz_xxxxzzz_0[j] = pb_x * tg_xxyzzz_xxxxzzz_0[j] + fr * tg_xxyzzz_xxxxzzz_1[j] + fl1_fx * (tg_xyzzz_xxxxzzz_0[j] - tg_xyzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzz_xxxzzz_1[j];

                    tg_xxxyzzz_xxxyyyy_0[j] = pb_x * tg_xxyzzz_xxxyyyy_0[j] + fr * tg_xxyzzz_xxxyyyy_1[j] + fl1_fx * (tg_xyzzz_xxxyyyy_0[j] - tg_xyzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzz_xxyyyy_1[j];

                    tg_xxxyzzz_xxxyyyz_0[j] = pb_x * tg_xxyzzz_xxxyyyz_0[j] + fr * tg_xxyzzz_xxxyyyz_1[j] + fl1_fx * (tg_xyzzz_xxxyyyz_0[j] - tg_xyzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzz_xxyyyz_1[j];

                    tg_xxxyzzz_xxxyyzz_0[j] = pb_x * tg_xxyzzz_xxxyyzz_0[j] + fr * tg_xxyzzz_xxxyyzz_1[j] + fl1_fx * (tg_xyzzz_xxxyyzz_0[j] - tg_xyzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzz_xxyyzz_1[j];

                    tg_xxxyzzz_xxxyzzz_0[j] = pb_x * tg_xxyzzz_xxxyzzz_0[j] + fr * tg_xxyzzz_xxxyzzz_1[j] + fl1_fx * (tg_xyzzz_xxxyzzz_0[j] - tg_xyzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzz_xxyzzz_1[j];

                    tg_xxxyzzz_xxxzzzz_0[j] = pb_x * tg_xxyzzz_xxxzzzz_0[j] + fr * tg_xxyzzz_xxxzzzz_1[j] + fl1_fx * (tg_xyzzz_xxxzzzz_0[j] - tg_xyzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzz_xxzzzz_1[j];

                    tg_xxxyzzz_xxyyyyy_0[j] = pb_x * tg_xxyzzz_xxyyyyy_0[j] + fr * tg_xxyzzz_xxyyyyy_1[j] + fl1_fx * (tg_xyzzz_xxyyyyy_0[j] - tg_xyzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xyyyyy_1[j];

                    tg_xxxyzzz_xxyyyyz_0[j] = pb_x * tg_xxyzzz_xxyyyyz_0[j] + fr * tg_xxyzzz_xxyyyyz_1[j] + fl1_fx * (tg_xyzzz_xxyyyyz_0[j] - tg_xyzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xyyyyz_1[j];

                    tg_xxxyzzz_xxyyyzz_0[j] = pb_x * tg_xxyzzz_xxyyyzz_0[j] + fr * tg_xxyzzz_xxyyyzz_1[j] + fl1_fx * (tg_xyzzz_xxyyyzz_0[j] - tg_xyzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xyyyzz_1[j];

                    tg_xxxyzzz_xxyyzzz_0[j] = pb_x * tg_xxyzzz_xxyyzzz_0[j] + fr * tg_xxyzzz_xxyyzzz_1[j] + fl1_fx * (tg_xyzzz_xxyyzzz_0[j] - tg_xyzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xyyzzz_1[j];

                    tg_xxxyzzz_xxyzzzz_0[j] = pb_x * tg_xxyzzz_xxyzzzz_0[j] + fr * tg_xxyzzz_xxyzzzz_1[j] + fl1_fx * (tg_xyzzz_xxyzzzz_0[j] - tg_xyzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xyzzzz_1[j];

                    tg_xxxyzzz_xxzzzzz_0[j] = pb_x * tg_xxyzzz_xxzzzzz_0[j] + fr * tg_xxyzzz_xxzzzzz_1[j] + fl1_fx * (tg_xyzzz_xxzzzzz_0[j] - tg_xyzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzz_xzzzzz_1[j];

                    tg_xxxyzzz_xyyyyyy_0[j] = pb_x * tg_xxyzzz_xyyyyyy_0[j] + fr * tg_xxyzzz_xyyyyyy_1[j] + fl1_fx * (tg_xyzzz_xyyyyyy_0[j] - tg_xyzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yyyyyy_1[j];

                    tg_xxxyzzz_xyyyyyz_0[j] = pb_x * tg_xxyzzz_xyyyyyz_0[j] + fr * tg_xxyzzz_xyyyyyz_1[j] + fl1_fx * (tg_xyzzz_xyyyyyz_0[j] - tg_xyzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yyyyyz_1[j];

                    tg_xxxyzzz_xyyyyzz_0[j] = pb_x * tg_xxyzzz_xyyyyzz_0[j] + fr * tg_xxyzzz_xyyyyzz_1[j] + fl1_fx * (tg_xyzzz_xyyyyzz_0[j] - tg_xyzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yyyyzz_1[j];

                    tg_xxxyzzz_xyyyzzz_0[j] = pb_x * tg_xxyzzz_xyyyzzz_0[j] + fr * tg_xxyzzz_xyyyzzz_1[j] + fl1_fx * (tg_xyzzz_xyyyzzz_0[j] - tg_xyzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yyyzzz_1[j];

                    tg_xxxyzzz_xyyzzzz_0[j] = pb_x * tg_xxyzzz_xyyzzzz_0[j] + fr * tg_xxyzzz_xyyzzzz_1[j] + fl1_fx * (tg_xyzzz_xyyzzzz_0[j] - tg_xyzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yyzzzz_1[j];

                    tg_xxxyzzz_xyzzzzz_0[j] = pb_x * tg_xxyzzz_xyzzzzz_0[j] + fr * tg_xxyzzz_xyzzzzz_1[j] + fl1_fx * (tg_xyzzz_xyzzzzz_0[j] - tg_xyzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_yzzzzz_1[j];

                    tg_xxxyzzz_xzzzzzz_0[j] = pb_x * tg_xxyzzz_xzzzzzz_0[j] + fr * tg_xxyzzz_xzzzzzz_1[j] + fl1_fx * (tg_xyzzz_xzzzzzz_0[j] - tg_xyzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzz_zzzzzz_1[j];

                    tg_xxxyzzz_yyyyyyy_0[j] = pb_x * tg_xxyzzz_yyyyyyy_0[j] + fr * tg_xxyzzz_yyyyyyy_1[j] + fl1_fx * (tg_xyzzz_yyyyyyy_0[j] - tg_xyzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxyzzz_yyyyyyz_0[j] = pb_x * tg_xxyzzz_yyyyyyz_0[j] + fr * tg_xxyzzz_yyyyyyz_1[j] + fl1_fx * (tg_xyzzz_yyyyyyz_0[j] - tg_xyzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxyzzz_yyyyyzz_0[j] = pb_x * tg_xxyzzz_yyyyyzz_0[j] + fr * tg_xxyzzz_yyyyyzz_1[j] + fl1_fx * (tg_xyzzz_yyyyyzz_0[j] - tg_xyzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxyzzz_yyyyzzz_0[j] = pb_x * tg_xxyzzz_yyyyzzz_0[j] + fr * tg_xxyzzz_yyyyzzz_1[j] + fl1_fx * (tg_xyzzz_yyyyzzz_0[j] - tg_xyzzz_yyyyzzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_500_600(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (500,600)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 500); 

                auto tg_xxyzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 501); 

                auto tg_xxyzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 502); 

                auto tg_xxyzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 503); 

                auto tg_xxzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 504); 

                auto tg_xxzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 505); 

                auto tg_xxzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 506); 

                auto tg_xxzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 507); 

                auto tg_xxzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 508); 

                auto tg_xxzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 509); 

                auto tg_xxzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 510); 

                auto tg_xxzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 511); 

                auto tg_xxzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 512); 

                auto tg_xxzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 513); 

                auto tg_xxzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 514); 

                auto tg_xxzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 515); 

                auto tg_xxzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 516); 

                auto tg_xxzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 517); 

                auto tg_xxzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 518); 

                auto tg_xxzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 519); 

                auto tg_xxzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 520); 

                auto tg_xxzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 521); 

                auto tg_xxzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 522); 

                auto tg_xxzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 523); 

                auto tg_xxzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 524); 

                auto tg_xxzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 525); 

                auto tg_xxzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 526); 

                auto tg_xxzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 527); 

                auto tg_xxzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 528); 

                auto tg_xxzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 529); 

                auto tg_xxzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 530); 

                auto tg_xxzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 531); 

                auto tg_xxzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 532); 

                auto tg_xxzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 533); 

                auto tg_xxzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 534); 

                auto tg_xxzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 535); 

                auto tg_xxzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 536); 

                auto tg_xxzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 537); 

                auto tg_xxzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 538); 

                auto tg_xxzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 539); 

                auto tg_xyyyyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 540); 

                auto tg_xyyyyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 541); 

                auto tg_xyyyyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 542); 

                auto tg_xyyyyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 543); 

                auto tg_xyyyyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 544); 

                auto tg_xyyyyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 545); 

                auto tg_xyyyyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 546); 

                auto tg_xyyyyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 547); 

                auto tg_xyyyyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 548); 

                auto tg_xyyyyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 549); 

                auto tg_xyyyyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 550); 

                auto tg_xyyyyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 551); 

                auto tg_xyyyyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 552); 

                auto tg_xyyyyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 553); 

                auto tg_xyyyyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 554); 

                auto tg_xyyyyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 555); 

                auto tg_xyyyyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 556); 

                auto tg_xyyyyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 557); 

                auto tg_xyyyyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 558); 

                auto tg_xyyyyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 559); 

                auto tg_xyyyyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 560); 

                auto tg_xyyyyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 561); 

                auto tg_xyyyyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 562); 

                auto tg_xyyyyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 563); 

                auto tg_xyyyyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 564); 

                auto tg_xyyyyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 565); 

                auto tg_xyyyyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 566); 

                auto tg_xyyyyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 567); 

                auto tg_xyyyyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 568); 

                auto tg_xyyyyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 569); 

                auto tg_xyyyyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 570); 

                auto tg_xyyyyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 571); 

                auto tg_xyyyyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 572); 

                auto tg_xyyyyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 573); 

                auto tg_xyyyyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 574); 

                auto tg_xyyyyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 575); 

                auto tg_xyyyyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 576); 

                auto tg_xyyyyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 577); 

                auto tg_xyyyyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 578); 

                auto tg_xyyyyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 579); 

                auto tg_xyyyyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 580); 

                auto tg_xyyyyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 581); 

                auto tg_xyyyyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 582); 

                auto tg_xyyyyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 583); 

                auto tg_xyyyyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 584); 

                auto tg_xyyyyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 585); 

                auto tg_xyyyyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 586); 

                auto tg_xyyyyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 587); 

                auto tg_xyyyyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 588); 

                auto tg_xyyyyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 589); 

                auto tg_xyyyyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 590); 

                auto tg_xyyyyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 591); 

                auto tg_xyyyyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 592); 

                auto tg_xyyyyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 593); 

                auto tg_xyyyyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 594); 

                auto tg_xyyyyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 595); 

                auto tg_xyyyyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 596); 

                auto tg_xyyyyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 597); 

                auto tg_xyyyyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 598); 

                auto tg_xyyyyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 599); 

                auto tg_xxyzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 500); 

                auto tg_xxyzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 501); 

                auto tg_xxyzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 502); 

                auto tg_xxyzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 503); 

                auto tg_xxzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 504); 

                auto tg_xxzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 505); 

                auto tg_xxzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 506); 

                auto tg_xxzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 507); 

                auto tg_xxzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 508); 

                auto tg_xxzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 509); 

                auto tg_xxzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 510); 

                auto tg_xxzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 511); 

                auto tg_xxzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 512); 

                auto tg_xxzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 513); 

                auto tg_xxzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 514); 

                auto tg_xxzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 515); 

                auto tg_xxzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 516); 

                auto tg_xxzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 517); 

                auto tg_xxzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 518); 

                auto tg_xxzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 519); 

                auto tg_xxzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 520); 

                auto tg_xxzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 521); 

                auto tg_xxzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 522); 

                auto tg_xxzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 523); 

                auto tg_xxzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 524); 

                auto tg_xxzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 525); 

                auto tg_xxzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 526); 

                auto tg_xxzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 527); 

                auto tg_xxzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 528); 

                auto tg_xxzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 529); 

                auto tg_xxzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 530); 

                auto tg_xxzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 531); 

                auto tg_xxzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 532); 

                auto tg_xxzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 533); 

                auto tg_xxzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 534); 

                auto tg_xxzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 535); 

                auto tg_xxzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 536); 

                auto tg_xxzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 537); 

                auto tg_xxzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 538); 

                auto tg_xxzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 539); 

                auto tg_xyyyyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 540); 

                auto tg_xyyyyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 541); 

                auto tg_xyyyyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 542); 

                auto tg_xyyyyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 543); 

                auto tg_xyyyyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 544); 

                auto tg_xyyyyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 545); 

                auto tg_xyyyyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 546); 

                auto tg_xyyyyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 547); 

                auto tg_xyyyyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 548); 

                auto tg_xyyyyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 549); 

                auto tg_xyyyyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 550); 

                auto tg_xyyyyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 551); 

                auto tg_xyyyyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 552); 

                auto tg_xyyyyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 553); 

                auto tg_xyyyyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 554); 

                auto tg_xyyyyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 555); 

                auto tg_xyyyyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 556); 

                auto tg_xyyyyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 557); 

                auto tg_xyyyyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 558); 

                auto tg_xyyyyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 559); 

                auto tg_xyyyyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 560); 

                auto tg_xyyyyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 561); 

                auto tg_xyyyyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 562); 

                auto tg_xyyyyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 563); 

                auto tg_xyyyyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 564); 

                auto tg_xyyyyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 565); 

                auto tg_xyyyyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 566); 

                auto tg_xyyyyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 567); 

                auto tg_xyyyyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 568); 

                auto tg_xyyyyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 569); 

                auto tg_xyyyyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 570); 

                auto tg_xyyyyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 571); 

                auto tg_xyyyyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 572); 

                auto tg_xyyyyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 573); 

                auto tg_xyyyyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 574); 

                auto tg_xyyyyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 575); 

                auto tg_xyyyyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 576); 

                auto tg_xyyyyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 577); 

                auto tg_xyyyyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 578); 

                auto tg_xyyyyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 579); 

                auto tg_xyyyyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 580); 

                auto tg_xyyyyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 581); 

                auto tg_xyyyyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 582); 

                auto tg_xyyyyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 583); 

                auto tg_xyyyyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 584); 

                auto tg_xyyyyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 585); 

                auto tg_xyyyyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 586); 

                auto tg_xyyyyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 587); 

                auto tg_xyyyyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 588); 

                auto tg_xyyyyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 589); 

                auto tg_xyyyyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 590); 

                auto tg_xyyyyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 591); 

                auto tg_xyyyyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 592); 

                auto tg_xyyyyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 593); 

                auto tg_xyyyyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 594); 

                auto tg_xyyyyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 595); 

                auto tg_xyyyyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 596); 

                auto tg_xyyyyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 597); 

                auto tg_xyyyyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 598); 

                auto tg_xyyyyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 599); 

                auto tg_xyzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 500); 

                auto tg_xyzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 501); 

                auto tg_xyzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 502); 

                auto tg_xyzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 503); 

                auto tg_xzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 504); 

                auto tg_xzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 505); 

                auto tg_xzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 506); 

                auto tg_xzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 507); 

                auto tg_xzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 508); 

                auto tg_xzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 509); 

                auto tg_xzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 510); 

                auto tg_xzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 511); 

                auto tg_xzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 512); 

                auto tg_xzzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 513); 

                auto tg_xzzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 514); 

                auto tg_xzzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 515); 

                auto tg_xzzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 516); 

                auto tg_xzzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 517); 

                auto tg_xzzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 518); 

                auto tg_xzzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 519); 

                auto tg_xzzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 520); 

                auto tg_xzzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 521); 

                auto tg_xzzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 522); 

                auto tg_xzzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 523); 

                auto tg_xzzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 524); 

                auto tg_xzzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 525); 

                auto tg_xzzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 526); 

                auto tg_xzzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 527); 

                auto tg_xzzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 528); 

                auto tg_xzzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 529); 

                auto tg_xzzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 530); 

                auto tg_xzzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 531); 

                auto tg_xzzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 532); 

                auto tg_xzzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 533); 

                auto tg_xzzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 534); 

                auto tg_xzzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 535); 

                auto tg_xzzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 536); 

                auto tg_xzzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 537); 

                auto tg_xzzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 538); 

                auto tg_xzzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 539); 

                auto tg_yyyyy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 543); 

                auto tg_yyyyy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 558); 

                auto tg_yyyyy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 599); 

                auto tg_xyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 500); 

                auto tg_xyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 501); 

                auto tg_xyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 502); 

                auto tg_xyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 503); 

                auto tg_xzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 504); 

                auto tg_xzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 505); 

                auto tg_xzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 506); 

                auto tg_xzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 507); 

                auto tg_xzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 508); 

                auto tg_xzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 509); 

                auto tg_xzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 510); 

                auto tg_xzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 511); 

                auto tg_xzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 512); 

                auto tg_xzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 513); 

                auto tg_xzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 514); 

                auto tg_xzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 515); 

                auto tg_xzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 516); 

                auto tg_xzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 517); 

                auto tg_xzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 518); 

                auto tg_xzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 519); 

                auto tg_xzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 520); 

                auto tg_xzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 521); 

                auto tg_xzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 522); 

                auto tg_xzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 523); 

                auto tg_xzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 524); 

                auto tg_xzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 525); 

                auto tg_xzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 526); 

                auto tg_xzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 527); 

                auto tg_xzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 528); 

                auto tg_xzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 529); 

                auto tg_xzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 530); 

                auto tg_xzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 531); 

                auto tg_xzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 532); 

                auto tg_xzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 533); 

                auto tg_xzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 534); 

                auto tg_xzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 535); 

                auto tg_xzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 536); 

                auto tg_xzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 537); 

                auto tg_xzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 538); 

                auto tg_xzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 539); 

                auto tg_yyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 543); 

                auto tg_yyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 558); 

                auto tg_yyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 599); 

                auto tg_xxzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 392); 

                auto tg_xxzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 393); 

                auto tg_xxzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 394); 

                auto tg_xxzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 395); 

                auto tg_xxzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 396); 

                auto tg_xxzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 397); 

                auto tg_xxzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 398); 

                auto tg_xxzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 399); 

                auto tg_xxzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 400); 

                auto tg_xxzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 401); 

                auto tg_xxzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 402); 

                auto tg_xxzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 403); 

                auto tg_xxzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 404); 

                auto tg_xxzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 405); 

                auto tg_xxzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 406); 

                auto tg_xxzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 407); 

                auto tg_xxzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 408); 

                auto tg_xxzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 409); 

                auto tg_xxzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 410); 

                auto tg_xxzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 411); 

                auto tg_xxzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 412); 

                auto tg_xxzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 413); 

                auto tg_xxzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 414); 

                auto tg_xxzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 415); 

                auto tg_xxzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 416); 

                auto tg_xxzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 417); 

                auto tg_xxzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 418); 

                auto tg_xxzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 419); 

                auto tg_xyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 420); 

                auto tg_xyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 421); 

                auto tg_xyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 422); 

                auto tg_xyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 423); 

                auto tg_xyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 424); 

                auto tg_xyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 425); 

                auto tg_xyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 426); 

                auto tg_xyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 427); 

                auto tg_xyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 428); 

                auto tg_xyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 429); 

                auto tg_xyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 430); 

                auto tg_xyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 431); 

                auto tg_xyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 432); 

                auto tg_xyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 433); 

                auto tg_xyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 434); 

                auto tg_xyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 435); 

                auto tg_xyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 436); 

                auto tg_xyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 437); 

                auto tg_xyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 438); 

                auto tg_xyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 439); 

                auto tg_xyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 440); 

                auto tg_xyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 441); 

                auto tg_xyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 442); 

                auto tg_xyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 443); 

                auto tg_xyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 444); 

                auto tg_xyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 445); 

                auto tg_xyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 446); 

                auto tg_xyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 447); 

                auto tg_xyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 448); 

                auto tg_xyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 449); 

                auto tg_xyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 450); 

                auto tg_xyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 451); 

                auto tg_xyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 452); 

                auto tg_xyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 453); 

                auto tg_xyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 454); 

                auto tg_xyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 455); 

                auto tg_xyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 456); 

                auto tg_xyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 457); 

                auto tg_xyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 458); 

                auto tg_xyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 459); 

                auto tg_xyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 460); 

                auto tg_xyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 461); 

                auto tg_xyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 462); 

                auto tg_xyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 463); 

                auto tg_xyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 464); 

                auto tg_xyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 465); 

                auto tg_xyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 466); 

                auto tg_xyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 467); 

                auto tg_xyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 468); 

                auto tg_xyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 469); 

                auto tg_xyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 470); 

                auto tg_xyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 471); 

                // set up pointers to integrals

                auto tg_xxxyzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 500); 

                auto tg_xxxyzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 501); 

                auto tg_xxxyzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 502); 

                auto tg_xxxyzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 503); 

                auto tg_xxxzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 504); 

                auto tg_xxxzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 505); 

                auto tg_xxxzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 506); 

                auto tg_xxxzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 507); 

                auto tg_xxxzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 508); 

                auto tg_xxxzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 509); 

                auto tg_xxxzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 510); 

                auto tg_xxxzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 511); 

                auto tg_xxxzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 512); 

                auto tg_xxxzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 513); 

                auto tg_xxxzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 514); 

                auto tg_xxxzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 515); 

                auto tg_xxxzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 516); 

                auto tg_xxxzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 517); 

                auto tg_xxxzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 518); 

                auto tg_xxxzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 519); 

                auto tg_xxxzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 520); 

                auto tg_xxxzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 521); 

                auto tg_xxxzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 522); 

                auto tg_xxxzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 523); 

                auto tg_xxxzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 524); 

                auto tg_xxxzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 525); 

                auto tg_xxxzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 526); 

                auto tg_xxxzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 527); 

                auto tg_xxxzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 528); 

                auto tg_xxxzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 529); 

                auto tg_xxxzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 530); 

                auto tg_xxxzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 531); 

                auto tg_xxxzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 532); 

                auto tg_xxxzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 533); 

                auto tg_xxxzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 534); 

                auto tg_xxxzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 535); 

                auto tg_xxxzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 536); 

                auto tg_xxxzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 537); 

                auto tg_xxxzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 538); 

                auto tg_xxxzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 539); 

                auto tg_xxyyyyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 540); 

                auto tg_xxyyyyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 541); 

                auto tg_xxyyyyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 542); 

                auto tg_xxyyyyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 543); 

                auto tg_xxyyyyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 544); 

                auto tg_xxyyyyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 545); 

                auto tg_xxyyyyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 546); 

                auto tg_xxyyyyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 547); 

                auto tg_xxyyyyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 548); 

                auto tg_xxyyyyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 549); 

                auto tg_xxyyyyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 550); 

                auto tg_xxyyyyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 551); 

                auto tg_xxyyyyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 552); 

                auto tg_xxyyyyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 553); 

                auto tg_xxyyyyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 554); 

                auto tg_xxyyyyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 555); 

                auto tg_xxyyyyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 556); 

                auto tg_xxyyyyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 557); 

                auto tg_xxyyyyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 558); 

                auto tg_xxyyyyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 559); 

                auto tg_xxyyyyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 560); 

                auto tg_xxyyyyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 561); 

                auto tg_xxyyyyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 562); 

                auto tg_xxyyyyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 563); 

                auto tg_xxyyyyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 564); 

                auto tg_xxyyyyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 565); 

                auto tg_xxyyyyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 566); 

                auto tg_xxyyyyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 567); 

                auto tg_xxyyyyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 568); 

                auto tg_xxyyyyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 569); 

                auto tg_xxyyyyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 570); 

                auto tg_xxyyyyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 571); 

                auto tg_xxyyyyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 572); 

                auto tg_xxyyyyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 573); 

                auto tg_xxyyyyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 574); 

                auto tg_xxyyyyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 575); 

                auto tg_xxyyyyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 576); 

                auto tg_xxyyyyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 577); 

                auto tg_xxyyyyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 578); 

                auto tg_xxyyyyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 579); 

                auto tg_xxyyyyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 580); 

                auto tg_xxyyyyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 581); 

                auto tg_xxyyyyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 582); 

                auto tg_xxyyyyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 583); 

                auto tg_xxyyyyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 584); 

                auto tg_xxyyyyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 585); 

                auto tg_xxyyyyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 586); 

                auto tg_xxyyyyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 587); 

                auto tg_xxyyyyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 588); 

                auto tg_xxyyyyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 589); 

                auto tg_xxyyyyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 590); 

                auto tg_xxyyyyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 591); 

                auto tg_xxyyyyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 592); 

                auto tg_xxyyyyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 593); 

                auto tg_xxyyyyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 594); 

                auto tg_xxyyyyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 595); 

                auto tg_xxyyyyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 596); 

                auto tg_xxyyyyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 597); 

                auto tg_xxyyyyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 598); 

                auto tg_xxyyyyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 599); 

                // Batch of Integrals (500,600)

                #pragma omp simd aligned(fxn, fza, tg_xxxyzzz_yyyzzzz_0, tg_xxxyzzz_yyzzzzz_0, \
                                         tg_xxxyzzz_yzzzzzz_0, tg_xxxyzzz_zzzzzzz_0, tg_xxxzzzz_xxxxxxx_0, tg_xxxzzzz_xxxxxxy_0, \
                                         tg_xxxzzzz_xxxxxxz_0, tg_xxxzzzz_xxxxxyy_0, tg_xxxzzzz_xxxxxyz_0, tg_xxxzzzz_xxxxxzz_0, \
                                         tg_xxxzzzz_xxxxyyy_0, tg_xxxzzzz_xxxxyyz_0, tg_xxxzzzz_xxxxyzz_0, tg_xxxzzzz_xxxxzzz_0, \
                                         tg_xxxzzzz_xxxyyyy_0, tg_xxxzzzz_xxxyyyz_0, tg_xxxzzzz_xxxyyzz_0, tg_xxxzzzz_xxxyzzz_0, \
                                         tg_xxxzzzz_xxxzzzz_0, tg_xxxzzzz_xxyyyyy_0, tg_xxxzzzz_xxyyyyz_0, tg_xxxzzzz_xxyyyzz_0, \
                                         tg_xxxzzzz_xxyyzzz_0, tg_xxxzzzz_xxyzzzz_0, tg_xxxzzzz_xxzzzzz_0, tg_xxxzzzz_xyyyyyy_0, \
                                         tg_xxxzzzz_xyyyyyz_0, tg_xxxzzzz_xyyyyzz_0, tg_xxxzzzz_xyyyzzz_0, tg_xxxzzzz_xyyzzzz_0, \
                                         tg_xxxzzzz_xyzzzzz_0, tg_xxxzzzz_xzzzzzz_0, tg_xxxzzzz_yyyyyyy_0, tg_xxxzzzz_yyyyyyz_0, \
                                         tg_xxxzzzz_yyyyyzz_0, tg_xxxzzzz_yyyyzzz_0, tg_xxxzzzz_yyyzzzz_0, tg_xxxzzzz_yyzzzzz_0, \
                                         tg_xxxzzzz_yzzzzzz_0, tg_xxxzzzz_zzzzzzz_0, tg_xxyyyyy_xxxxxxx_0, tg_xxyyyyy_xxxxxxy_0, \
                                         tg_xxyyyyy_xxxxxxz_0, tg_xxyyyyy_xxxxxyy_0, tg_xxyyyyy_xxxxxyz_0, tg_xxyyyyy_xxxxxzz_0, \
                                         tg_xxyyyyy_xxxxyyy_0, tg_xxyyyyy_xxxxyyz_0, tg_xxyyyyy_xxxxyzz_0, tg_xxyyyyy_xxxxzzz_0, \
                                         tg_xxyyyyy_xxxyyyy_0, tg_xxyyyyy_xxxyyyz_0, tg_xxyyyyy_xxxyyzz_0, tg_xxyyyyy_xxxyzzz_0, \
                                         tg_xxyyyyy_xxxzzzz_0, tg_xxyyyyy_xxyyyyy_0, tg_xxyyyyy_xxyyyyz_0, tg_xxyyyyy_xxyyyzz_0, \
                                         tg_xxyyyyy_xxyyzzz_0, tg_xxyyyyy_xxyzzzz_0, tg_xxyyyyy_xxzzzzz_0, tg_xxyyyyy_xyyyyyy_0, \
                                         tg_xxyyyyy_xyyyyyz_0, tg_xxyyyyy_xyyyyzz_0, tg_xxyyyyy_xyyyzzz_0, tg_xxyyyyy_xyyzzzz_0, \
                                         tg_xxyyyyy_xyzzzzz_0, tg_xxyyyyy_xzzzzzz_0, tg_xxyyyyy_yyyyyyy_0, tg_xxyyyyy_yyyyyyz_0, \
                                         tg_xxyyyyy_yyyyyzz_0, tg_xxyyyyy_yyyyzzz_0, tg_xxyyyyy_yyyzzzz_0, tg_xxyyyyy_yyzzzzz_0, \
                                         tg_xxyyyyy_yzzzzzz_0, tg_xxyyyyy_zzzzzzz_0, tg_xxyyyyz_xxxxxxx_0, tg_xxyyyyz_xxxxxxy_0, \
                                         tg_xxyyyyz_xxxxxxz_0, tg_xxyyyyz_xxxxxyy_0, tg_xxyyyyz_xxxxxyz_0, tg_xxyyyyz_xxxxxzz_0, \
                                         tg_xxyyyyz_xxxxyyy_0, tg_xxyyyyz_xxxxyyz_0, tg_xxyyyyz_xxxxyzz_0, tg_xxyyyyz_xxxxzzz_0, \
                                         tg_xxyyyyz_xxxyyyy_0, tg_xxyyyyz_xxxyyyz_0, tg_xxyyyyz_xxxyyzz_0, tg_xxyyyyz_xxxyzzz_0, \
                                         tg_xxyyyyz_xxxzzzz_0, tg_xxyyyyz_xxyyyyy_0, tg_xxyyyyz_xxyyyyz_0, tg_xxyyyyz_xxyyyzz_0, \
                                         tg_xxyyyyz_xxyyzzz_0, tg_xxyyyyz_xxyzzzz_0, tg_xxyyyyz_xxzzzzz_0, tg_xxyyyyz_xyyyyyy_0, \
                                         tg_xxyyyyz_xyyyyyz_0, tg_xxyyyyz_xyyyyzz_0, tg_xxyzzz_yyyzzzz_0, tg_xxyzzz_yyyzzzz_1, \
                                         tg_xxyzzz_yyzzzzz_0, tg_xxyzzz_yyzzzzz_1, tg_xxyzzz_yzzzzzz_0, tg_xxyzzz_yzzzzzz_1, \
                                         tg_xxyzzz_zzzzzzz_0, tg_xxyzzz_zzzzzzz_1, tg_xxzzzz_xxxxxx_1, tg_xxzzzz_xxxxxxx_0, \
                                         tg_xxzzzz_xxxxxxx_1, tg_xxzzzz_xxxxxxy_0, tg_xxzzzz_xxxxxxy_1, tg_xxzzzz_xxxxxxz_0, \
                                         tg_xxzzzz_xxxxxxz_1, tg_xxzzzz_xxxxxy_1, tg_xxzzzz_xxxxxyy_0, tg_xxzzzz_xxxxxyy_1, \
                                         tg_xxzzzz_xxxxxyz_0, tg_xxzzzz_xxxxxyz_1, tg_xxzzzz_xxxxxz_1, tg_xxzzzz_xxxxxzz_0, \
                                         tg_xxzzzz_xxxxxzz_1, tg_xxzzzz_xxxxyy_1, tg_xxzzzz_xxxxyyy_0, tg_xxzzzz_xxxxyyy_1, \
                                         tg_xxzzzz_xxxxyyz_0, tg_xxzzzz_xxxxyyz_1, tg_xxzzzz_xxxxyz_1, tg_xxzzzz_xxxxyzz_0, \
                                         tg_xxzzzz_xxxxyzz_1, tg_xxzzzz_xxxxzz_1, tg_xxzzzz_xxxxzzz_0, tg_xxzzzz_xxxxzzz_1, \
                                         tg_xxzzzz_xxxyyy_1, tg_xxzzzz_xxxyyyy_0, tg_xxzzzz_xxxyyyy_1, tg_xxzzzz_xxxyyyz_0, \
                                         tg_xxzzzz_xxxyyyz_1, tg_xxzzzz_xxxyyz_1, tg_xxzzzz_xxxyyzz_0, tg_xxzzzz_xxxyyzz_1, \
                                         tg_xxzzzz_xxxyzz_1, tg_xxzzzz_xxxyzzz_0, tg_xxzzzz_xxxyzzz_1, tg_xxzzzz_xxxzzz_1, \
                                         tg_xxzzzz_xxxzzzz_0, tg_xxzzzz_xxxzzzz_1, tg_xxzzzz_xxyyyy_1, tg_xxzzzz_xxyyyyy_0, \
                                         tg_xxzzzz_xxyyyyy_1, tg_xxzzzz_xxyyyyz_0, tg_xxzzzz_xxyyyyz_1, tg_xxzzzz_xxyyyz_1, \
                                         tg_xxzzzz_xxyyyzz_0, tg_xxzzzz_xxyyyzz_1, tg_xxzzzz_xxyyzz_1, tg_xxzzzz_xxyyzzz_0, \
                                         tg_xxzzzz_xxyyzzz_1, tg_xxzzzz_xxyzzz_1, tg_xxzzzz_xxyzzzz_0, tg_xxzzzz_xxyzzzz_1, \
                                         tg_xxzzzz_xxzzzz_1, tg_xxzzzz_xxzzzzz_0, tg_xxzzzz_xxzzzzz_1, tg_xxzzzz_xyyyyy_1, \
                                         tg_xxzzzz_xyyyyyy_0, tg_xxzzzz_xyyyyyy_1, tg_xxzzzz_xyyyyyz_0, tg_xxzzzz_xyyyyyz_1, \
                                         tg_xxzzzz_xyyyyz_1, tg_xxzzzz_xyyyyzz_0, tg_xxzzzz_xyyyyzz_1, tg_xxzzzz_xyyyzz_1, \
                                         tg_xxzzzz_xyyyzzz_0, tg_xxzzzz_xyyyzzz_1, tg_xxzzzz_xyyzzz_1, tg_xxzzzz_xyyzzzz_0, \
                                         tg_xxzzzz_xyyzzzz_1, tg_xxzzzz_xyzzzz_1, tg_xxzzzz_xyzzzzz_0, tg_xxzzzz_xyzzzzz_1, \
                                         tg_xxzzzz_xzzzzz_1, tg_xxzzzz_xzzzzzz_0, tg_xxzzzz_xzzzzzz_1, tg_xxzzzz_yyyyyy_1, \
                                         tg_xxzzzz_yyyyyyy_0, tg_xxzzzz_yyyyyyy_1, tg_xxzzzz_yyyyyyz_0, tg_xxzzzz_yyyyyyz_1, \
                                         tg_xxzzzz_yyyyyz_1, tg_xxzzzz_yyyyyzz_0, tg_xxzzzz_yyyyyzz_1, tg_xxzzzz_yyyyzz_1, \
                                         tg_xxzzzz_yyyyzzz_0, tg_xxzzzz_yyyyzzz_1, tg_xxzzzz_yyyzzz_1, tg_xxzzzz_yyyzzzz_0, \
                                         tg_xxzzzz_yyyzzzz_1, tg_xxzzzz_yyzzzz_1, tg_xxzzzz_yyzzzzz_0, tg_xxzzzz_yyzzzzz_1, \
                                         tg_xxzzzz_yzzzzz_1, tg_xxzzzz_yzzzzzz_0, tg_xxzzzz_yzzzzzz_1, tg_xxzzzz_zzzzzz_1, \
                                         tg_xxzzzz_zzzzzzz_0, tg_xxzzzz_zzzzzzz_1, tg_xyyyyy_xxxxxx_1, tg_xyyyyy_xxxxxxx_0, \
                                         tg_xyyyyy_xxxxxxx_1, tg_xyyyyy_xxxxxxy_0, tg_xyyyyy_xxxxxxy_1, tg_xyyyyy_xxxxxxz_0, \
                                         tg_xyyyyy_xxxxxxz_1, tg_xyyyyy_xxxxxy_1, tg_xyyyyy_xxxxxyy_0, tg_xyyyyy_xxxxxyy_1, \
                                         tg_xyyyyy_xxxxxyz_0, tg_xyyyyy_xxxxxyz_1, tg_xyyyyy_xxxxxz_1, tg_xyyyyy_xxxxxzz_0, \
                                         tg_xyyyyy_xxxxxzz_1, tg_xyyyyy_xxxxyy_1, tg_xyyyyy_xxxxyyy_0, tg_xyyyyy_xxxxyyy_1, \
                                         tg_xyyyyy_xxxxyyz_0, tg_xyyyyy_xxxxyyz_1, tg_xyyyyy_xxxxyz_1, tg_xyyyyy_xxxxyzz_0, \
                                         tg_xyyyyy_xxxxyzz_1, tg_xyyyyy_xxxxzz_1, tg_xyyyyy_xxxxzzz_0, tg_xyyyyy_xxxxzzz_1, \
                                         tg_xyyyyy_xxxyyy_1, tg_xyyyyy_xxxyyyy_0, tg_xyyyyy_xxxyyyy_1, tg_xyyyyy_xxxyyyz_0, \
                                         tg_xyyyyy_xxxyyyz_1, tg_xyyyyy_xxxyyz_1, tg_xyyyyy_xxxyyzz_0, tg_xyyyyy_xxxyyzz_1, \
                                         tg_xyyyyy_xxxyzz_1, tg_xyyyyy_xxxyzzz_0, tg_xyyyyy_xxxyzzz_1, tg_xyyyyy_xxxzzz_1, \
                                         tg_xyyyyy_xxxzzzz_0, tg_xyyyyy_xxxzzzz_1, tg_xyyyyy_xxyyyy_1, tg_xyyyyy_xxyyyyy_0, \
                                         tg_xyyyyy_xxyyyyy_1, tg_xyyyyy_xxyyyyz_0, tg_xyyyyy_xxyyyyz_1, tg_xyyyyy_xxyyyz_1, \
                                         tg_xyyyyy_xxyyyzz_0, tg_xyyyyy_xxyyyzz_1, tg_xyyyyy_xxyyzz_1, tg_xyyyyy_xxyyzzz_0, \
                                         tg_xyyyyy_xxyyzzz_1, tg_xyyyyy_xxyzzz_1, tg_xyyyyy_xxyzzzz_0, tg_xyyyyy_xxyzzzz_1, \
                                         tg_xyyyyy_xxzzzz_1, tg_xyyyyy_xxzzzzz_0, tg_xyyyyy_xxzzzzz_1, tg_xyyyyy_xyyyyy_1, \
                                         tg_xyyyyy_xyyyyyy_0, tg_xyyyyy_xyyyyyy_1, tg_xyyyyy_xyyyyyz_0, tg_xyyyyy_xyyyyyz_1, \
                                         tg_xyyyyy_xyyyyz_1, tg_xyyyyy_xyyyyzz_0, tg_xyyyyy_xyyyyzz_1, tg_xyyyyy_xyyyzz_1, \
                                         tg_xyyyyy_xyyyzzz_0, tg_xyyyyy_xyyyzzz_1, tg_xyyyyy_xyyzzz_1, tg_xyyyyy_xyyzzzz_0, \
                                         tg_xyyyyy_xyyzzzz_1, tg_xyyyyy_xyzzzz_1, tg_xyyyyy_xyzzzzz_0, tg_xyyyyy_xyzzzzz_1, \
                                         tg_xyyyyy_xzzzzz_1, tg_xyyyyy_xzzzzzz_0, tg_xyyyyy_xzzzzzz_1, tg_xyyyyy_yyyyyy_1, \
                                         tg_xyyyyy_yyyyyyy_0, tg_xyyyyy_yyyyyyy_1, tg_xyyyyy_yyyyyyz_0, tg_xyyyyy_yyyyyyz_1, \
                                         tg_xyyyyy_yyyyyz_1, tg_xyyyyy_yyyyyzz_0, tg_xyyyyy_yyyyyzz_1, tg_xyyyyy_yyyyzz_1, \
                                         tg_xyyyyy_yyyyzzz_0, tg_xyyyyy_yyyyzzz_1, tg_xyyyyy_yyyzzz_1, tg_xyyyyy_yyyzzzz_0, \
                                         tg_xyyyyy_yyyzzzz_1, tg_xyyyyy_yyzzzz_1, tg_xyyyyy_yyzzzzz_0, tg_xyyyyy_yyzzzzz_1, \
                                         tg_xyyyyy_yzzzzz_1, tg_xyyyyy_yzzzzzz_0, tg_xyyyyy_yzzzzzz_1, tg_xyyyyy_zzzzzz_1, \
                                         tg_xyyyyy_zzzzzzz_0, tg_xyyyyy_zzzzzzz_1, tg_xyyyyz_xxxxxx_1, tg_xyyyyz_xxxxxxx_0, \
                                         tg_xyyyyz_xxxxxxx_1, tg_xyyyyz_xxxxxxy_0, tg_xyyyyz_xxxxxxy_1, tg_xyyyyz_xxxxxxz_0, \
                                         tg_xyyyyz_xxxxxxz_1, tg_xyyyyz_xxxxxy_1, tg_xyyyyz_xxxxxyy_0, tg_xyyyyz_xxxxxyy_1, \
                                         tg_xyyyyz_xxxxxyz_0, tg_xyyyyz_xxxxxyz_1, tg_xyyyyz_xxxxxz_1, tg_xyyyyz_xxxxxzz_0, \
                                         tg_xyyyyz_xxxxxzz_1, tg_xyyyyz_xxxxyy_1, tg_xyyyyz_xxxxyyy_0, tg_xyyyyz_xxxxyyy_1, \
                                         tg_xyyyyz_xxxxyyz_0, tg_xyyyyz_xxxxyyz_1, tg_xyyyyz_xxxxyz_1, tg_xyyyyz_xxxxyzz_0, \
                                         tg_xyyyyz_xxxxyzz_1, tg_xyyyyz_xxxxzz_1, tg_xyyyyz_xxxxzzz_0, tg_xyyyyz_xxxxzzz_1, \
                                         tg_xyyyyz_xxxyyy_1, tg_xyyyyz_xxxyyyy_0, tg_xyyyyz_xxxyyyy_1, tg_xyyyyz_xxxyyyz_0, \
                                         tg_xyyyyz_xxxyyyz_1, tg_xyyyyz_xxxyyz_1, tg_xyyyyz_xxxyyzz_0, tg_xyyyyz_xxxyyzz_1, \
                                         tg_xyyyyz_xxxyzz_1, tg_xyyyyz_xxxyzzz_0, tg_xyyyyz_xxxyzzz_1, tg_xyyyyz_xxxzzz_1, \
                                         tg_xyyyyz_xxxzzzz_0, tg_xyyyyz_xxxzzzz_1, tg_xyyyyz_xxyyyy_1, tg_xyyyyz_xxyyyyy_0, \
                                         tg_xyyyyz_xxyyyyy_1, tg_xyyyyz_xxyyyyz_0, tg_xyyyyz_xxyyyyz_1, tg_xyyyyz_xxyyyz_1, \
                                         tg_xyyyyz_xxyyyzz_0, tg_xyyyyz_xxyyyzz_1, tg_xyyyyz_xxyyzz_1, tg_xyyyyz_xxyyzzz_0, \
                                         tg_xyyyyz_xxyyzzz_1, tg_xyyyyz_xxyzzz_1, tg_xyyyyz_xxyzzzz_0, tg_xyyyyz_xxyzzzz_1, \
                                         tg_xyyyyz_xxzzzz_1, tg_xyyyyz_xxzzzzz_0, tg_xyyyyz_xxzzzzz_1, tg_xyyyyz_xyyyyy_1, \
                                         tg_xyyyyz_xyyyyyy_0, tg_xyyyyz_xyyyyyy_1, tg_xyyyyz_xyyyyyz_0, tg_xyyyyz_xyyyyyz_1, \
                                         tg_xyyyyz_xyyyyz_1, tg_xyyyyz_xyyyyzz_0, tg_xyyyyz_xyyyyzz_1, tg_xyyyyz_xyyyzz_1, \
                                         tg_xyyyyz_xyyzzz_1, tg_xyyyyz_xyzzzz_1, tg_xyyyyz_xzzzzz_1, tg_xyyyyz_yyyyyy_1, \
                                         tg_xyyyyz_yyyyyz_1, tg_xyyyyz_yyyyzz_1, tg_xyzzz_yyyzzzz_0, tg_xyzzz_yyyzzzz_1, \
                                         tg_xyzzz_yyzzzzz_0, tg_xyzzz_yyzzzzz_1, tg_xyzzz_yzzzzzz_0, tg_xyzzz_yzzzzzz_1, \
                                         tg_xyzzz_zzzzzzz_0, tg_xyzzz_zzzzzzz_1, tg_xzzzz_xxxxxxx_0, tg_xzzzz_xxxxxxx_1, \
                                         tg_xzzzz_xxxxxxy_0, tg_xzzzz_xxxxxxy_1, tg_xzzzz_xxxxxxz_0, tg_xzzzz_xxxxxxz_1, \
                                         tg_xzzzz_xxxxxyy_0, tg_xzzzz_xxxxxyy_1, tg_xzzzz_xxxxxyz_0, tg_xzzzz_xxxxxyz_1, \
                                         tg_xzzzz_xxxxxzz_0, tg_xzzzz_xxxxxzz_1, tg_xzzzz_xxxxyyy_0, tg_xzzzz_xxxxyyy_1, \
                                         tg_xzzzz_xxxxyyz_0, tg_xzzzz_xxxxyyz_1, tg_xzzzz_xxxxyzz_0, tg_xzzzz_xxxxyzz_1, \
                                         tg_xzzzz_xxxxzzz_0, tg_xzzzz_xxxxzzz_1, tg_xzzzz_xxxyyyy_0, tg_xzzzz_xxxyyyy_1, \
                                         tg_xzzzz_xxxyyyz_0, tg_xzzzz_xxxyyyz_1, tg_xzzzz_xxxyyzz_0, tg_xzzzz_xxxyyzz_1, \
                                         tg_xzzzz_xxxyzzz_0, tg_xzzzz_xxxyzzz_1, tg_xzzzz_xxxzzzz_0, tg_xzzzz_xxxzzzz_1, \
                                         tg_xzzzz_xxyyyyy_0, tg_xzzzz_xxyyyyy_1, tg_xzzzz_xxyyyyz_0, tg_xzzzz_xxyyyyz_1, \
                                         tg_xzzzz_xxyyyzz_0, tg_xzzzz_xxyyyzz_1, tg_xzzzz_xxyyzzz_0, tg_xzzzz_xxyyzzz_1, \
                                         tg_xzzzz_xxyzzzz_0, tg_xzzzz_xxyzzzz_1, tg_xzzzz_xxzzzzz_0, tg_xzzzz_xxzzzzz_1, \
                                         tg_xzzzz_xyyyyyy_0, tg_xzzzz_xyyyyyy_1, tg_xzzzz_xyyyyyz_0, tg_xzzzz_xyyyyyz_1, \
                                         tg_xzzzz_xyyyyzz_0, tg_xzzzz_xyyyyzz_1, tg_xzzzz_xyyyzzz_0, tg_xzzzz_xyyyzzz_1, \
                                         tg_xzzzz_xyyzzzz_0, tg_xzzzz_xyyzzzz_1, tg_xzzzz_xyzzzzz_0, tg_xzzzz_xyzzzzz_1, \
                                         tg_xzzzz_xzzzzzz_0, tg_xzzzz_xzzzzzz_1, tg_xzzzz_yyyyyyy_0, tg_xzzzz_yyyyyyy_1, \
                                         tg_xzzzz_yyyyyyz_0, tg_xzzzz_yyyyyyz_1, tg_xzzzz_yyyyyzz_0, tg_xzzzz_yyyyyzz_1, \
                                         tg_xzzzz_yyyyzzz_0, tg_xzzzz_yyyyzzz_1, tg_xzzzz_yyyzzzz_0, tg_xzzzz_yyyzzzz_1, \
                                         tg_xzzzz_yyzzzzz_0, tg_xzzzz_yyzzzzz_1, tg_xzzzz_yzzzzzz_0, tg_xzzzz_yzzzzzz_1, \
                                         tg_xzzzz_zzzzzzz_0, tg_xzzzz_zzzzzzz_1, tg_yyyyy_xxxxxxx_0, tg_yyyyy_xxxxxxx_1, \
                                         tg_yyyyy_xxxxxxy_0, tg_yyyyy_xxxxxxy_1, tg_yyyyy_xxxxxxz_0, tg_yyyyy_xxxxxxz_1, \
                                         tg_yyyyy_xxxxxyy_0, tg_yyyyy_xxxxxyy_1, tg_yyyyy_xxxxxyz_0, tg_yyyyy_xxxxxyz_1, \
                                         tg_yyyyy_xxxxxzz_0, tg_yyyyy_xxxxxzz_1, tg_yyyyy_xxxxyyy_0, tg_yyyyy_xxxxyyy_1, \
                                         tg_yyyyy_xxxxyyz_0, tg_yyyyy_xxxxyyz_1, tg_yyyyy_xxxxyzz_0, tg_yyyyy_xxxxyzz_1, \
                                         tg_yyyyy_xxxxzzz_0, tg_yyyyy_xxxxzzz_1, tg_yyyyy_xxxyyyy_0, tg_yyyyy_xxxyyyy_1, \
                                         tg_yyyyy_xxxyyyz_0, tg_yyyyy_xxxyyyz_1, tg_yyyyy_xxxyyzz_0, tg_yyyyy_xxxyyzz_1, \
                                         tg_yyyyy_xxxyzzz_0, tg_yyyyy_xxxyzzz_1, tg_yyyyy_xxxzzzz_0, tg_yyyyy_xxxzzzz_1, \
                                         tg_yyyyy_xxyyyyy_0, tg_yyyyy_xxyyyyy_1, tg_yyyyy_xxyyyyz_0, tg_yyyyy_xxyyyyz_1, \
                                         tg_yyyyy_xxyyyzz_0, tg_yyyyy_xxyyyzz_1, tg_yyyyy_xxyyzzz_0, tg_yyyyy_xxyyzzz_1, \
                                         tg_yyyyy_xxyzzzz_0, tg_yyyyy_xxyzzzz_1, tg_yyyyy_xxzzzzz_0, tg_yyyyy_xxzzzzz_1, \
                                         tg_yyyyy_xyyyyyy_0, tg_yyyyy_xyyyyyy_1, tg_yyyyy_xyyyyyz_0, tg_yyyyy_xyyyyyz_1, \
                                         tg_yyyyy_xyyyyzz_0, tg_yyyyy_xyyyyzz_1, tg_yyyyy_xyyyzzz_0, tg_yyyyy_xyyyzzz_1, \
                                         tg_yyyyy_xyyzzzz_0, tg_yyyyy_xyyzzzz_1, tg_yyyyy_xyzzzzz_0, tg_yyyyy_xyzzzzz_1, \
                                         tg_yyyyy_xzzzzzz_0, tg_yyyyy_xzzzzzz_1, tg_yyyyy_yyyyyyy_0, tg_yyyyy_yyyyyyy_1, \
                                         tg_yyyyy_yyyyyyz_0, tg_yyyyy_yyyyyyz_1, tg_yyyyy_yyyyyzz_0, tg_yyyyy_yyyyyzz_1, \
                                         tg_yyyyy_yyyyzzz_0, tg_yyyyy_yyyyzzz_1, tg_yyyyy_yyyzzzz_0, tg_yyyyy_yyyzzzz_1, \
                                         tg_yyyyy_yyzzzzz_0, tg_yyyyy_yyzzzzz_1, tg_yyyyy_yzzzzzz_0, tg_yyyyy_yzzzzzz_1, \
                                         tg_yyyyy_zzzzzzz_0, tg_yyyyy_zzzzzzz_1, tg_yyyyz_xxxxxxx_0, tg_yyyyz_xxxxxxx_1, \
                                         tg_yyyyz_xxxxxxy_0, tg_yyyyz_xxxxxxy_1, tg_yyyyz_xxxxxxz_0, tg_yyyyz_xxxxxxz_1, \
                                         tg_yyyyz_xxxxxyy_0, tg_yyyyz_xxxxxyy_1, tg_yyyyz_xxxxxyz_0, tg_yyyyz_xxxxxyz_1, \
                                         tg_yyyyz_xxxxxzz_0, tg_yyyyz_xxxxxzz_1, tg_yyyyz_xxxxyyy_0, tg_yyyyz_xxxxyyy_1, \
                                         tg_yyyyz_xxxxyyz_0, tg_yyyyz_xxxxyyz_1, tg_yyyyz_xxxxyzz_0, tg_yyyyz_xxxxyzz_1, \
                                         tg_yyyyz_xxxxzzz_0, tg_yyyyz_xxxxzzz_1, tg_yyyyz_xxxyyyy_0, tg_yyyyz_xxxyyyy_1, \
                                         tg_yyyyz_xxxyyyz_0, tg_yyyyz_xxxyyyz_1, tg_yyyyz_xxxyyzz_0, tg_yyyyz_xxxyyzz_1, \
                                         tg_yyyyz_xxxyzzz_0, tg_yyyyz_xxxyzzz_1, tg_yyyyz_xxxzzzz_0, tg_yyyyz_xxxzzzz_1, \
                                         tg_yyyyz_xxyyyyy_0, tg_yyyyz_xxyyyyy_1, tg_yyyyz_xxyyyyz_0, tg_yyyyz_xxyyyyz_1, \
                                         tg_yyyyz_xxyyyzz_0, tg_yyyyz_xxyyyzz_1, tg_yyyyz_xxyyzzz_0, tg_yyyyz_xxyyzzz_1, \
                                         tg_yyyyz_xxyzzzz_0, tg_yyyyz_xxyzzzz_1, tg_yyyyz_xxzzzzz_0, tg_yyyyz_xxzzzzz_1, \
                                         tg_yyyyz_xyyyyyy_0, tg_yyyyz_xyyyyyy_1, tg_yyyyz_xyyyyyz_0, tg_yyyyz_xyyyyyz_1, \
                                         tg_yyyyz_xyyyyzz_0, tg_yyyyz_xyyyyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyzzz_yyyzzzz_0[j] = pb_x * tg_xxyzzz_yyyzzzz_0[j] + fr * tg_xxyzzz_yyyzzzz_1[j] + fl1_fx * (tg_xyzzz_yyyzzzz_0[j] - tg_xyzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxyzzz_yyzzzzz_0[j] = pb_x * tg_xxyzzz_yyzzzzz_0[j] + fr * tg_xxyzzz_yyzzzzz_1[j] + fl1_fx * (tg_xyzzz_yyzzzzz_0[j] - tg_xyzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxyzzz_yzzzzzz_0[j] = pb_x * tg_xxyzzz_yzzzzzz_0[j] + fr * tg_xxyzzz_yzzzzzz_1[j] + fl1_fx * (tg_xyzzz_yzzzzzz_0[j] - tg_xyzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxyzzz_zzzzzzz_0[j] = pb_x * tg_xxyzzz_zzzzzzz_0[j] + fr * tg_xxyzzz_zzzzzzz_1[j] + fl1_fx * (tg_xyzzz_zzzzzzz_0[j] - tg_xyzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxxzzzz_xxxxxxx_0[j] = pb_x * tg_xxzzzz_xxxxxxx_0[j] + fr * tg_xxzzzz_xxxxxxx_1[j] + fl1_fx * (tg_xzzzz_xxxxxxx_0[j] - tg_xzzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xxzzzz_xxxxxx_1[j];

                    tg_xxxzzzz_xxxxxxy_0[j] = pb_x * tg_xxzzzz_xxxxxxy_0[j] + fr * tg_xxzzzz_xxxxxxy_1[j] + fl1_fx * (tg_xzzzz_xxxxxxy_0[j] - tg_xzzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzzz_xxxxxy_1[j];

                    tg_xxxzzzz_xxxxxxz_0[j] = pb_x * tg_xxzzzz_xxxxxxz_0[j] + fr * tg_xxzzzz_xxxxxxz_1[j] + fl1_fx * (tg_xzzzz_xxxxxxz_0[j] - tg_xzzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzzz_xxxxxz_1[j];

                    tg_xxxzzzz_xxxxxyy_0[j] = pb_x * tg_xxzzzz_xxxxxyy_0[j] + fr * tg_xxzzzz_xxxxxyy_1[j] + fl1_fx * (tg_xzzzz_xxxxxyy_0[j] - tg_xzzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzzz_xxxxyy_1[j];

                    tg_xxxzzzz_xxxxxyz_0[j] = pb_x * tg_xxzzzz_xxxxxyz_0[j] + fr * tg_xxzzzz_xxxxxyz_1[j] + fl1_fx * (tg_xzzzz_xxxxxyz_0[j] - tg_xzzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzzz_xxxxyz_1[j];

                    tg_xxxzzzz_xxxxxzz_0[j] = pb_x * tg_xxzzzz_xxxxxzz_0[j] + fr * tg_xxzzzz_xxxxxzz_1[j] + fl1_fx * (tg_xzzzz_xxxxxzz_0[j] - tg_xzzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzzz_xxxxzz_1[j];

                    tg_xxxzzzz_xxxxyyy_0[j] = pb_x * tg_xxzzzz_xxxxyyy_0[j] + fr * tg_xxzzzz_xxxxyyy_1[j] + fl1_fx * (tg_xzzzz_xxxxyyy_0[j] - tg_xzzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzz_xxxyyy_1[j];

                    tg_xxxzzzz_xxxxyyz_0[j] = pb_x * tg_xxzzzz_xxxxyyz_0[j] + fr * tg_xxzzzz_xxxxyyz_1[j] + fl1_fx * (tg_xzzzz_xxxxyyz_0[j] - tg_xzzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzz_xxxyyz_1[j];

                    tg_xxxzzzz_xxxxyzz_0[j] = pb_x * tg_xxzzzz_xxxxyzz_0[j] + fr * tg_xxzzzz_xxxxyzz_1[j] + fl1_fx * (tg_xzzzz_xxxxyzz_0[j] - tg_xzzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzz_xxxyzz_1[j];

                    tg_xxxzzzz_xxxxzzz_0[j] = pb_x * tg_xxzzzz_xxxxzzz_0[j] + fr * tg_xxzzzz_xxxxzzz_1[j] + fl1_fx * (tg_xzzzz_xxxxzzz_0[j] - tg_xzzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzz_xxxzzz_1[j];

                    tg_xxxzzzz_xxxyyyy_0[j] = pb_x * tg_xxzzzz_xxxyyyy_0[j] + fr * tg_xxzzzz_xxxyyyy_1[j] + fl1_fx * (tg_xzzzz_xxxyyyy_0[j] - tg_xzzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzz_xxyyyy_1[j];

                    tg_xxxzzzz_xxxyyyz_0[j] = pb_x * tg_xxzzzz_xxxyyyz_0[j] + fr * tg_xxzzzz_xxxyyyz_1[j] + fl1_fx * (tg_xzzzz_xxxyyyz_0[j] - tg_xzzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzz_xxyyyz_1[j];

                    tg_xxxzzzz_xxxyyzz_0[j] = pb_x * tg_xxzzzz_xxxyyzz_0[j] + fr * tg_xxzzzz_xxxyyzz_1[j] + fl1_fx * (tg_xzzzz_xxxyyzz_0[j] - tg_xzzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzz_xxyyzz_1[j];

                    tg_xxxzzzz_xxxyzzz_0[j] = pb_x * tg_xxzzzz_xxxyzzz_0[j] + fr * tg_xxzzzz_xxxyzzz_1[j] + fl1_fx * (tg_xzzzz_xxxyzzz_0[j] - tg_xzzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzz_xxyzzz_1[j];

                    tg_xxxzzzz_xxxzzzz_0[j] = pb_x * tg_xxzzzz_xxxzzzz_0[j] + fr * tg_xxzzzz_xxxzzzz_1[j] + fl1_fx * (tg_xzzzz_xxxzzzz_0[j] - tg_xzzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzz_xxzzzz_1[j];

                    tg_xxxzzzz_xxyyyyy_0[j] = pb_x * tg_xxzzzz_xxyyyyy_0[j] + fr * tg_xxzzzz_xxyyyyy_1[j] + fl1_fx * (tg_xzzzz_xxyyyyy_0[j] - tg_xzzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xyyyyy_1[j];

                    tg_xxxzzzz_xxyyyyz_0[j] = pb_x * tg_xxzzzz_xxyyyyz_0[j] + fr * tg_xxzzzz_xxyyyyz_1[j] + fl1_fx * (tg_xzzzz_xxyyyyz_0[j] - tg_xzzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xyyyyz_1[j];

                    tg_xxxzzzz_xxyyyzz_0[j] = pb_x * tg_xxzzzz_xxyyyzz_0[j] + fr * tg_xxzzzz_xxyyyzz_1[j] + fl1_fx * (tg_xzzzz_xxyyyzz_0[j] - tg_xzzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xyyyzz_1[j];

                    tg_xxxzzzz_xxyyzzz_0[j] = pb_x * tg_xxzzzz_xxyyzzz_0[j] + fr * tg_xxzzzz_xxyyzzz_1[j] + fl1_fx * (tg_xzzzz_xxyyzzz_0[j] - tg_xzzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xyyzzz_1[j];

                    tg_xxxzzzz_xxyzzzz_0[j] = pb_x * tg_xxzzzz_xxyzzzz_0[j] + fr * tg_xxzzzz_xxyzzzz_1[j] + fl1_fx * (tg_xzzzz_xxyzzzz_0[j] - tg_xzzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xyzzzz_1[j];

                    tg_xxxzzzz_xxzzzzz_0[j] = pb_x * tg_xxzzzz_xxzzzzz_0[j] + fr * tg_xxzzzz_xxzzzzz_1[j] + fl1_fx * (tg_xzzzz_xxzzzzz_0[j] - tg_xzzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzz_xzzzzz_1[j];

                    tg_xxxzzzz_xyyyyyy_0[j] = pb_x * tg_xxzzzz_xyyyyyy_0[j] + fr * tg_xxzzzz_xyyyyyy_1[j] + fl1_fx * (tg_xzzzz_xyyyyyy_0[j] - tg_xzzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yyyyyy_1[j];

                    tg_xxxzzzz_xyyyyyz_0[j] = pb_x * tg_xxzzzz_xyyyyyz_0[j] + fr * tg_xxzzzz_xyyyyyz_1[j] + fl1_fx * (tg_xzzzz_xyyyyyz_0[j] - tg_xzzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yyyyyz_1[j];

                    tg_xxxzzzz_xyyyyzz_0[j] = pb_x * tg_xxzzzz_xyyyyzz_0[j] + fr * tg_xxzzzz_xyyyyzz_1[j] + fl1_fx * (tg_xzzzz_xyyyyzz_0[j] - tg_xzzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yyyyzz_1[j];

                    tg_xxxzzzz_xyyyzzz_0[j] = pb_x * tg_xxzzzz_xyyyzzz_0[j] + fr * tg_xxzzzz_xyyyzzz_1[j] + fl1_fx * (tg_xzzzz_xyyyzzz_0[j] - tg_xzzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yyyzzz_1[j];

                    tg_xxxzzzz_xyyzzzz_0[j] = pb_x * tg_xxzzzz_xyyzzzz_0[j] + fr * tg_xxzzzz_xyyzzzz_1[j] + fl1_fx * (tg_xzzzz_xyyzzzz_0[j] - tg_xzzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yyzzzz_1[j];

                    tg_xxxzzzz_xyzzzzz_0[j] = pb_x * tg_xxzzzz_xyzzzzz_0[j] + fr * tg_xxzzzz_xyzzzzz_1[j] + fl1_fx * (tg_xzzzz_xyzzzzz_0[j] - tg_xzzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_yzzzzz_1[j];

                    tg_xxxzzzz_xzzzzzz_0[j] = pb_x * tg_xxzzzz_xzzzzzz_0[j] + fr * tg_xxzzzz_xzzzzzz_1[j] + fl1_fx * (tg_xzzzz_xzzzzzz_0[j] - tg_xzzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzz_zzzzzz_1[j];

                    tg_xxxzzzz_yyyyyyy_0[j] = pb_x * tg_xxzzzz_yyyyyyy_0[j] + fr * tg_xxzzzz_yyyyyyy_1[j] + fl1_fx * (tg_xzzzz_yyyyyyy_0[j] - tg_xzzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxxzzzz_yyyyyyz_0[j] = pb_x * tg_xxzzzz_yyyyyyz_0[j] + fr * tg_xxzzzz_yyyyyyz_1[j] + fl1_fx * (tg_xzzzz_yyyyyyz_0[j] - tg_xzzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxxzzzz_yyyyyzz_0[j] = pb_x * tg_xxzzzz_yyyyyzz_0[j] + fr * tg_xxzzzz_yyyyyzz_1[j] + fl1_fx * (tg_xzzzz_yyyyyzz_0[j] - tg_xzzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxxzzzz_yyyyzzz_0[j] = pb_x * tg_xxzzzz_yyyyzzz_0[j] + fr * tg_xxzzzz_yyyyzzz_1[j] + fl1_fx * (tg_xzzzz_yyyyzzz_0[j] - tg_xzzzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxxzzzz_yyyzzzz_0[j] = pb_x * tg_xxzzzz_yyyzzzz_0[j] + fr * tg_xxzzzz_yyyzzzz_1[j] + fl1_fx * (tg_xzzzz_yyyzzzz_0[j] - tg_xzzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxxzzzz_yyzzzzz_0[j] = pb_x * tg_xxzzzz_yyzzzzz_0[j] + fr * tg_xxzzzz_yyzzzzz_1[j] + fl1_fx * (tg_xzzzz_yyzzzzz_0[j] - tg_xzzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxxzzzz_yzzzzzz_0[j] = pb_x * tg_xxzzzz_yzzzzzz_0[j] + fr * tg_xxzzzz_yzzzzzz_1[j] + fl1_fx * (tg_xzzzz_yzzzzzz_0[j] - tg_xzzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxxzzzz_zzzzzzz_0[j] = pb_x * tg_xxzzzz_zzzzzzz_0[j] + fr * tg_xxzzzz_zzzzzzz_1[j] + fl1_fx * (tg_xzzzz_zzzzzzz_0[j] - tg_xzzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyy_xxxxxxx_0[j] = pb_x * tg_xyyyyy_xxxxxxx_0[j] + fr * tg_xyyyyy_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxxx_0[j] - tg_yyyyy_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyyy_xxxxxx_1[j];

                    tg_xxyyyyy_xxxxxxy_0[j] = pb_x * tg_xyyyyy_xxxxxxy_0[j] + fr * tg_xyyyyy_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxxy_0[j] - tg_yyyyy_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyy_xxxxxy_1[j];

                    tg_xxyyyyy_xxxxxxz_0[j] = pb_x * tg_xyyyyy_xxxxxxz_0[j] + fr * tg_xyyyyy_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxxz_0[j] - tg_yyyyy_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyy_xxxxxz_1[j];

                    tg_xxyyyyy_xxxxxyy_0[j] = pb_x * tg_xyyyyy_xxxxxyy_0[j] + fr * tg_xyyyyy_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxyy_0[j] - tg_yyyyy_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyy_xxxxyy_1[j];

                    tg_xxyyyyy_xxxxxyz_0[j] = pb_x * tg_xyyyyy_xxxxxyz_0[j] + fr * tg_xyyyyy_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxyz_0[j] - tg_yyyyy_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyy_xxxxyz_1[j];

                    tg_xxyyyyy_xxxxxzz_0[j] = pb_x * tg_xyyyyy_xxxxxzz_0[j] + fr * tg_xyyyyy_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxxzz_0[j] - tg_yyyyy_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyy_xxxxzz_1[j];

                    tg_xxyyyyy_xxxxyyy_0[j] = pb_x * tg_xyyyyy_xxxxyyy_0[j] + fr * tg_xyyyyy_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxyyy_0[j] - tg_yyyyy_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyy_xxxyyy_1[j];

                    tg_xxyyyyy_xxxxyyz_0[j] = pb_x * tg_xyyyyy_xxxxyyz_0[j] + fr * tg_xyyyyy_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxyyz_0[j] - tg_yyyyy_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyy_xxxyyz_1[j];

                    tg_xxyyyyy_xxxxyzz_0[j] = pb_x * tg_xyyyyy_xxxxyzz_0[j] + fr * tg_xyyyyy_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxyzz_0[j] - tg_yyyyy_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyy_xxxyzz_1[j];

                    tg_xxyyyyy_xxxxzzz_0[j] = pb_x * tg_xyyyyy_xxxxzzz_0[j] + fr * tg_xyyyyy_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxxzzz_0[j] - tg_yyyyy_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyy_xxxzzz_1[j];

                    tg_xxyyyyy_xxxyyyy_0[j] = pb_x * tg_xyyyyy_xxxyyyy_0[j] + fr * tg_xyyyyy_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxyyyy_0[j] - tg_yyyyy_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyy_xxyyyy_1[j];

                    tg_xxyyyyy_xxxyyyz_0[j] = pb_x * tg_xyyyyy_xxxyyyz_0[j] + fr * tg_xyyyyy_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxyyyz_0[j] - tg_yyyyy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyy_xxyyyz_1[j];

                    tg_xxyyyyy_xxxyyzz_0[j] = pb_x * tg_xyyyyy_xxxyyzz_0[j] + fr * tg_xyyyyy_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxyyzz_0[j] - tg_yyyyy_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyy_xxyyzz_1[j];

                    tg_xxyyyyy_xxxyzzz_0[j] = pb_x * tg_xyyyyy_xxxyzzz_0[j] + fr * tg_xyyyyy_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxyzzz_0[j] - tg_yyyyy_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyy_xxyzzz_1[j];

                    tg_xxyyyyy_xxxzzzz_0[j] = pb_x * tg_xyyyyy_xxxzzzz_0[j] + fr * tg_xyyyyy_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxxzzzz_0[j] - tg_yyyyy_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyy_xxzzzz_1[j];

                    tg_xxyyyyy_xxyyyyy_0[j] = pb_x * tg_xyyyyy_xxyyyyy_0[j] + fr * tg_xyyyyy_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxyyyyy_0[j] - tg_yyyyy_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xyyyyy_1[j];

                    tg_xxyyyyy_xxyyyyz_0[j] = pb_x * tg_xyyyyy_xxyyyyz_0[j] + fr * tg_xyyyyy_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxyyyyz_0[j] - tg_yyyyy_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xyyyyz_1[j];

                    tg_xxyyyyy_xxyyyzz_0[j] = pb_x * tg_xyyyyy_xxyyyzz_0[j] + fr * tg_xyyyyy_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxyyyzz_0[j] - tg_yyyyy_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xyyyzz_1[j];

                    tg_xxyyyyy_xxyyzzz_0[j] = pb_x * tg_xyyyyy_xxyyzzz_0[j] + fr * tg_xyyyyy_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxyyzzz_0[j] - tg_yyyyy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xyyzzz_1[j];

                    tg_xxyyyyy_xxyzzzz_0[j] = pb_x * tg_xyyyyy_xxyzzzz_0[j] + fr * tg_xyyyyy_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxyzzzz_0[j] - tg_yyyyy_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xyzzzz_1[j];

                    tg_xxyyyyy_xxzzzzz_0[j] = pb_x * tg_xyyyyy_xxzzzzz_0[j] + fr * tg_xyyyyy_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xxzzzzz_0[j] - tg_yyyyy_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyy_xzzzzz_1[j];

                    tg_xxyyyyy_xyyyyyy_0[j] = pb_x * tg_xyyyyy_xyyyyyy_0[j] + fr * tg_xyyyyy_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyyyyyy_0[j] - tg_yyyyy_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yyyyyy_1[j];

                    tg_xxyyyyy_xyyyyyz_0[j] = pb_x * tg_xyyyyy_xyyyyyz_0[j] + fr * tg_xyyyyy_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyyyyyz_0[j] - tg_yyyyy_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yyyyyz_1[j];

                    tg_xxyyyyy_xyyyyzz_0[j] = pb_x * tg_xyyyyy_xyyyyzz_0[j] + fr * tg_xyyyyy_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyyyyzz_0[j] - tg_yyyyy_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yyyyzz_1[j];

                    tg_xxyyyyy_xyyyzzz_0[j] = pb_x * tg_xyyyyy_xyyyzzz_0[j] + fr * tg_xyyyyy_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyyyzzz_0[j] - tg_yyyyy_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yyyzzz_1[j];

                    tg_xxyyyyy_xyyzzzz_0[j] = pb_x * tg_xyyyyy_xyyzzzz_0[j] + fr * tg_xyyyyy_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyyzzzz_0[j] - tg_yyyyy_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yyzzzz_1[j];

                    tg_xxyyyyy_xyzzzzz_0[j] = pb_x * tg_xyyyyy_xyzzzzz_0[j] + fr * tg_xyyyyy_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xyzzzzz_0[j] - tg_yyyyy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_yzzzzz_1[j];

                    tg_xxyyyyy_xzzzzzz_0[j] = pb_x * tg_xyyyyy_xzzzzzz_0[j] + fr * tg_xyyyyy_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_xzzzzzz_0[j] - tg_yyyyy_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyy_zzzzzz_1[j];

                    tg_xxyyyyy_yyyyyyy_0[j] = pb_x * tg_xyyyyy_yyyyyyy_0[j] + fr * tg_xyyyyy_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyyyyyy_0[j] - tg_yyyyy_yyyyyyy_1[j] * fl1_fza);

                    tg_xxyyyyy_yyyyyyz_0[j] = pb_x * tg_xyyyyy_yyyyyyz_0[j] + fr * tg_xyyyyy_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyyyyyz_0[j] - tg_yyyyy_yyyyyyz_1[j] * fl1_fza);

                    tg_xxyyyyy_yyyyyzz_0[j] = pb_x * tg_xyyyyy_yyyyyzz_0[j] + fr * tg_xyyyyy_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyyyyzz_0[j] - tg_yyyyy_yyyyyzz_1[j] * fl1_fza);

                    tg_xxyyyyy_yyyyzzz_0[j] = pb_x * tg_xyyyyy_yyyyzzz_0[j] + fr * tg_xyyyyy_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyyyzzz_0[j] - tg_yyyyy_yyyyzzz_1[j] * fl1_fza);

                    tg_xxyyyyy_yyyzzzz_0[j] = pb_x * tg_xyyyyy_yyyzzzz_0[j] + fr * tg_xyyyyy_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyyzzzz_0[j] - tg_yyyyy_yyyzzzz_1[j] * fl1_fza);

                    tg_xxyyyyy_yyzzzzz_0[j] = pb_x * tg_xyyyyy_yyzzzzz_0[j] + fr * tg_xyyyyy_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yyzzzzz_0[j] - tg_yyyyy_yyzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyy_yzzzzzz_0[j] = pb_x * tg_xyyyyy_yzzzzzz_0[j] + fr * tg_xyyyyy_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_yzzzzzz_0[j] - tg_yyyyy_yzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyy_zzzzzzz_0[j] = pb_x * tg_xyyyyy_zzzzzzz_0[j] + fr * tg_xyyyyy_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyy_zzzzzzz_0[j] - tg_yyyyy_zzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyz_xxxxxxx_0[j] = pb_x * tg_xyyyyz_xxxxxxx_0[j] + fr * tg_xyyyyz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxxx_0[j] - tg_yyyyz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyyz_xxxxxx_1[j];

                    tg_xxyyyyz_xxxxxxy_0[j] = pb_x * tg_xyyyyz_xxxxxxy_0[j] + fr * tg_xyyyyz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxxy_0[j] - tg_yyyyz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyz_xxxxxy_1[j];

                    tg_xxyyyyz_xxxxxxz_0[j] = pb_x * tg_xyyyyz_xxxxxxz_0[j] + fr * tg_xyyyyz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxxz_0[j] - tg_yyyyz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyz_xxxxxz_1[j];

                    tg_xxyyyyz_xxxxxyy_0[j] = pb_x * tg_xyyyyz_xxxxxyy_0[j] + fr * tg_xyyyyz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxyy_0[j] - tg_yyyyz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyz_xxxxyy_1[j];

                    tg_xxyyyyz_xxxxxyz_0[j] = pb_x * tg_xyyyyz_xxxxxyz_0[j] + fr * tg_xyyyyz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxyz_0[j] - tg_yyyyz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyz_xxxxyz_1[j];

                    tg_xxyyyyz_xxxxxzz_0[j] = pb_x * tg_xyyyyz_xxxxxzz_0[j] + fr * tg_xyyyyz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxxzz_0[j] - tg_yyyyz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyz_xxxxzz_1[j];

                    tg_xxyyyyz_xxxxyyy_0[j] = pb_x * tg_xyyyyz_xxxxyyy_0[j] + fr * tg_xyyyyz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxyyy_0[j] - tg_yyyyz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyz_xxxyyy_1[j];

                    tg_xxyyyyz_xxxxyyz_0[j] = pb_x * tg_xyyyyz_xxxxyyz_0[j] + fr * tg_xyyyyz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxyyz_0[j] - tg_yyyyz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyz_xxxyyz_1[j];

                    tg_xxyyyyz_xxxxyzz_0[j] = pb_x * tg_xyyyyz_xxxxyzz_0[j] + fr * tg_xyyyyz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxyzz_0[j] - tg_yyyyz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyz_xxxyzz_1[j];

                    tg_xxyyyyz_xxxxzzz_0[j] = pb_x * tg_xyyyyz_xxxxzzz_0[j] + fr * tg_xyyyyz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxxzzz_0[j] - tg_yyyyz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyz_xxxzzz_1[j];

                    tg_xxyyyyz_xxxyyyy_0[j] = pb_x * tg_xyyyyz_xxxyyyy_0[j] + fr * tg_xyyyyz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxyyyy_0[j] - tg_yyyyz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyz_xxyyyy_1[j];

                    tg_xxyyyyz_xxxyyyz_0[j] = pb_x * tg_xyyyyz_xxxyyyz_0[j] + fr * tg_xyyyyz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxyyyz_0[j] - tg_yyyyz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyz_xxyyyz_1[j];

                    tg_xxyyyyz_xxxyyzz_0[j] = pb_x * tg_xyyyyz_xxxyyzz_0[j] + fr * tg_xyyyyz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxyyzz_0[j] - tg_yyyyz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyz_xxyyzz_1[j];

                    tg_xxyyyyz_xxxyzzz_0[j] = pb_x * tg_xyyyyz_xxxyzzz_0[j] + fr * tg_xyyyyz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxyzzz_0[j] - tg_yyyyz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyz_xxyzzz_1[j];

                    tg_xxyyyyz_xxxzzzz_0[j] = pb_x * tg_xyyyyz_xxxzzzz_0[j] + fr * tg_xyyyyz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxxzzzz_0[j] - tg_yyyyz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyz_xxzzzz_1[j];

                    tg_xxyyyyz_xxyyyyy_0[j] = pb_x * tg_xyyyyz_xxyyyyy_0[j] + fr * tg_xyyyyz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxyyyyy_0[j] - tg_yyyyz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xyyyyy_1[j];

                    tg_xxyyyyz_xxyyyyz_0[j] = pb_x * tg_xyyyyz_xxyyyyz_0[j] + fr * tg_xyyyyz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxyyyyz_0[j] - tg_yyyyz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xyyyyz_1[j];

                    tg_xxyyyyz_xxyyyzz_0[j] = pb_x * tg_xyyyyz_xxyyyzz_0[j] + fr * tg_xyyyyz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxyyyzz_0[j] - tg_yyyyz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xyyyzz_1[j];

                    tg_xxyyyyz_xxyyzzz_0[j] = pb_x * tg_xyyyyz_xxyyzzz_0[j] + fr * tg_xyyyyz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxyyzzz_0[j] - tg_yyyyz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xyyzzz_1[j];

                    tg_xxyyyyz_xxyzzzz_0[j] = pb_x * tg_xyyyyz_xxyzzzz_0[j] + fr * tg_xyyyyz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxyzzzz_0[j] - tg_yyyyz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xyzzzz_1[j];

                    tg_xxyyyyz_xxzzzzz_0[j] = pb_x * tg_xyyyyz_xxzzzzz_0[j] + fr * tg_xyyyyz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xxzzzzz_0[j] - tg_yyyyz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyz_xzzzzz_1[j];

                    tg_xxyyyyz_xyyyyyy_0[j] = pb_x * tg_xyyyyz_xyyyyyy_0[j] + fr * tg_xyyyyz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyyyyyy_0[j] - tg_yyyyz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yyyyyy_1[j];

                    tg_xxyyyyz_xyyyyyz_0[j] = pb_x * tg_xyyyyz_xyyyyyz_0[j] + fr * tg_xyyyyz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyyyyyz_0[j] - tg_yyyyz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yyyyyz_1[j];

                    tg_xxyyyyz_xyyyyzz_0[j] = pb_x * tg_xyyyyz_xyyyyzz_0[j] + fr * tg_xyyyyz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyyyyzz_0[j] - tg_yyyyz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yyyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_600_700(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (600,700)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xyyyyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 600); 

                auto tg_xyyyyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 601); 

                auto tg_xyyyyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 602); 

                auto tg_xyyyyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 603); 

                auto tg_xyyyyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 604); 

                auto tg_xyyyyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 605); 

                auto tg_xyyyyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 606); 

                auto tg_xyyyyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 607); 

                auto tg_xyyyyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 608); 

                auto tg_xyyyyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 609); 

                auto tg_xyyyyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 610); 

                auto tg_xyyyyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 611); 

                auto tg_xyyyzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 612); 

                auto tg_xyyyzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 613); 

                auto tg_xyyyzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 614); 

                auto tg_xyyyzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 615); 

                auto tg_xyyyzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 616); 

                auto tg_xyyyzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 617); 

                auto tg_xyyyzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 618); 

                auto tg_xyyyzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 619); 

                auto tg_xyyyzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 620); 

                auto tg_xyyyzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 621); 

                auto tg_xyyyzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 622); 

                auto tg_xyyyzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 623); 

                auto tg_xyyyzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 624); 

                auto tg_xyyyzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 625); 

                auto tg_xyyyzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 626); 

                auto tg_xyyyzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 627); 

                auto tg_xyyyzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 628); 

                auto tg_xyyyzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 629); 

                auto tg_xyyyzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 630); 

                auto tg_xyyyzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 631); 

                auto tg_xyyyzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 632); 

                auto tg_xyyyzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 633); 

                auto tg_xyyyzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 634); 

                auto tg_xyyyzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 635); 

                auto tg_xyyyzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 636); 

                auto tg_xyyyzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 637); 

                auto tg_xyyyzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 638); 

                auto tg_xyyyzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 639); 

                auto tg_xyyyzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 640); 

                auto tg_xyyyzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 641); 

                auto tg_xyyyzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 642); 

                auto tg_xyyyzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 643); 

                auto tg_xyyyzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 644); 

                auto tg_xyyyzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 645); 

                auto tg_xyyyzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 646); 

                auto tg_xyyyzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 647); 

                auto tg_xyyzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 648); 

                auto tg_xyyzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 649); 

                auto tg_xyyzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 650); 

                auto tg_xyyzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 651); 

                auto tg_xyyzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 652); 

                auto tg_xyyzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 653); 

                auto tg_xyyzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 654); 

                auto tg_xyyzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 655); 

                auto tg_xyyzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 656); 

                auto tg_xyyzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 657); 

                auto tg_xyyzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 658); 

                auto tg_xyyzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 659); 

                auto tg_xyyzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 660); 

                auto tg_xyyzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 661); 

                auto tg_xyyzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 662); 

                auto tg_xyyzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 663); 

                auto tg_xyyzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 664); 

                auto tg_xyyzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 665); 

                auto tg_xyyzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 666); 

                auto tg_xyyzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 667); 

                auto tg_xyyzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 668); 

                auto tg_xyyzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 669); 

                auto tg_xyyzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 670); 

                auto tg_xyyzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 671); 

                auto tg_xyyzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 672); 

                auto tg_xyyzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 673); 

                auto tg_xyyzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 674); 

                auto tg_xyyzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 675); 

                auto tg_xyyzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 676); 

                auto tg_xyyzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 677); 

                auto tg_xyyzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 678); 

                auto tg_xyyzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 679); 

                auto tg_xyyzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 680); 

                auto tg_xyyzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 681); 

                auto tg_xyyzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 682); 

                auto tg_xyyzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 683); 

                auto tg_xyzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 684); 

                auto tg_xyzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 685); 

                auto tg_xyzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 686); 

                auto tg_xyzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 687); 

                auto tg_xyzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 688); 

                auto tg_xyzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 689); 

                auto tg_xyzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 690); 

                auto tg_xyzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 691); 

                auto tg_xyzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 692); 

                auto tg_xyzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 693); 

                auto tg_xyzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 694); 

                auto tg_xyzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 695); 

                auto tg_xyzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 696); 

                auto tg_xyzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 697); 

                auto tg_xyzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 698); 

                auto tg_xyzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 699); 

                auto tg_xyyyyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 600); 

                auto tg_xyyyyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 601); 

                auto tg_xyyyyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 602); 

                auto tg_xyyyyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 603); 

                auto tg_xyyyyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 604); 

                auto tg_xyyyyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 605); 

                auto tg_xyyyyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 606); 

                auto tg_xyyyyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 607); 

                auto tg_xyyyyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 608); 

                auto tg_xyyyyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 609); 

                auto tg_xyyyyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 610); 

                auto tg_xyyyyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 611); 

                auto tg_xyyyzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 612); 

                auto tg_xyyyzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 613); 

                auto tg_xyyyzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 614); 

                auto tg_xyyyzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 615); 

                auto tg_xyyyzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 616); 

                auto tg_xyyyzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 617); 

                auto tg_xyyyzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 618); 

                auto tg_xyyyzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 619); 

                auto tg_xyyyzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 620); 

                auto tg_xyyyzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 621); 

                auto tg_xyyyzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 622); 

                auto tg_xyyyzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 623); 

                auto tg_xyyyzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 624); 

                auto tg_xyyyzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 625); 

                auto tg_xyyyzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 626); 

                auto tg_xyyyzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 627); 

                auto tg_xyyyzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 628); 

                auto tg_xyyyzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 629); 

                auto tg_xyyyzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 630); 

                auto tg_xyyyzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 631); 

                auto tg_xyyyzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 632); 

                auto tg_xyyyzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 633); 

                auto tg_xyyyzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 634); 

                auto tg_xyyyzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 635); 

                auto tg_xyyyzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 636); 

                auto tg_xyyyzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 637); 

                auto tg_xyyyzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 638); 

                auto tg_xyyyzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 639); 

                auto tg_xyyyzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 640); 

                auto tg_xyyyzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 641); 

                auto tg_xyyyzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 642); 

                auto tg_xyyyzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 643); 

                auto tg_xyyyzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 644); 

                auto tg_xyyyzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 645); 

                auto tg_xyyyzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 646); 

                auto tg_xyyyzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 647); 

                auto tg_xyyzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 648); 

                auto tg_xyyzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 649); 

                auto tg_xyyzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 650); 

                auto tg_xyyzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 651); 

                auto tg_xyyzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 652); 

                auto tg_xyyzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 653); 

                auto tg_xyyzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 654); 

                auto tg_xyyzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 655); 

                auto tg_xyyzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 656); 

                auto tg_xyyzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 657); 

                auto tg_xyyzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 658); 

                auto tg_xyyzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 659); 

                auto tg_xyyzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 660); 

                auto tg_xyyzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 661); 

                auto tg_xyyzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 662); 

                auto tg_xyyzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 663); 

                auto tg_xyyzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 664); 

                auto tg_xyyzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 665); 

                auto tg_xyyzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 666); 

                auto tg_xyyzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 667); 

                auto tg_xyyzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 668); 

                auto tg_xyyzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 669); 

                auto tg_xyyzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 670); 

                auto tg_xyyzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 671); 

                auto tg_xyyzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 672); 

                auto tg_xyyzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 673); 

                auto tg_xyyzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 674); 

                auto tg_xyyzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 675); 

                auto tg_xyyzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 676); 

                auto tg_xyyzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 677); 

                auto tg_xyyzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 678); 

                auto tg_xyyzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 679); 

                auto tg_xyyzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 680); 

                auto tg_xyyzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 681); 

                auto tg_xyyzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 682); 

                auto tg_xyyzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 683); 

                auto tg_xyzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 684); 

                auto tg_xyzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 685); 

                auto tg_xyzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 686); 

                auto tg_xyzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 687); 

                auto tg_xyzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 688); 

                auto tg_xyzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 689); 

                auto tg_xyzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 690); 

                auto tg_xyzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 691); 

                auto tg_xyzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 692); 

                auto tg_xyzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 693); 

                auto tg_xyzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 694); 

                auto tg_xyzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 695); 

                auto tg_xyzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 696); 

                auto tg_xyzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 697); 

                auto tg_xyzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 698); 

                auto tg_xyzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 699); 

                auto tg_yyyyz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 622); 

                auto tg_yyyzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 629); 

                auto tg_yyyzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 636); 

                auto tg_yyyzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 699); 

                auto tg_yyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 622); 

                auto tg_yyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 629); 

                auto tg_yyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 636); 

                auto tg_yyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 699); 

                auto tg_xyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 472); 

                auto tg_xyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 473); 

                auto tg_xyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 474); 

                auto tg_xyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 475); 

                auto tg_xyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 476); 

                auto tg_xyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 477); 

                auto tg_xyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 478); 

                auto tg_xyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 479); 

                auto tg_xyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 480); 

                auto tg_xyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 481); 

                auto tg_xyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 482); 

                auto tg_xyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 483); 

                auto tg_xyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 484); 

                auto tg_xyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 485); 

                auto tg_xyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 486); 

                auto tg_xyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 487); 

                auto tg_xyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 488); 

                auto tg_xyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 489); 

                auto tg_xyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 490); 

                auto tg_xyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 491); 

                auto tg_xyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 492); 

                auto tg_xyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 493); 

                auto tg_xyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 494); 

                auto tg_xyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 495); 

                auto tg_xyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 496); 

                auto tg_xyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 497); 

                auto tg_xyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 498); 

                auto tg_xyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 499); 

                auto tg_xyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 500); 

                auto tg_xyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 501); 

                auto tg_xyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 502); 

                auto tg_xyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 503); 

                auto tg_xyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 504); 

                auto tg_xyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 505); 

                auto tg_xyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 506); 

                auto tg_xyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 507); 

                auto tg_xyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 508); 

                auto tg_xyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 509); 

                auto tg_xyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 510); 

                auto tg_xyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 511); 

                auto tg_xyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 512); 

                auto tg_xyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 513); 

                auto tg_xyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 514); 

                auto tg_xyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 515); 

                auto tg_xyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 516); 

                auto tg_xyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 517); 

                auto tg_xyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 518); 

                auto tg_xyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 519); 

                auto tg_xyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 520); 

                auto tg_xyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 521); 

                auto tg_xyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 522); 

                auto tg_xyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 523); 

                auto tg_xyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 524); 

                auto tg_xyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 525); 

                auto tg_xyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 526); 

                auto tg_xyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 527); 

                auto tg_xyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 528); 

                auto tg_xyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 529); 

                auto tg_xyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 530); 

                auto tg_xyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 531); 

                auto tg_xyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 532); 

                auto tg_xyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 533); 

                auto tg_xyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 534); 

                auto tg_xyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 535); 

                auto tg_xyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 536); 

                auto tg_xyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 537); 

                auto tg_xyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 538); 

                auto tg_xyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 539); 

                auto tg_xyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 540); 

                auto tg_xyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 541); 

                auto tg_xyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 542); 

                auto tg_xyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 543); 

                auto tg_xyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 544); 

                auto tg_xyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 545); 

                auto tg_xyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 546); 

                auto tg_xyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 547); 

                // set up pointers to integrals

                auto tg_xxyyyyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 600); 

                auto tg_xxyyyyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 601); 

                auto tg_xxyyyyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 602); 

                auto tg_xxyyyyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 603); 

                auto tg_xxyyyyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 604); 

                auto tg_xxyyyyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 605); 

                auto tg_xxyyyyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 606); 

                auto tg_xxyyyyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 607); 

                auto tg_xxyyyyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 608); 

                auto tg_xxyyyyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 609); 

                auto tg_xxyyyyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 610); 

                auto tg_xxyyyyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 611); 

                auto tg_xxyyyzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 612); 

                auto tg_xxyyyzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 613); 

                auto tg_xxyyyzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 614); 

                auto tg_xxyyyzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 615); 

                auto tg_xxyyyzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 616); 

                auto tg_xxyyyzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 617); 

                auto tg_xxyyyzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 618); 

                auto tg_xxyyyzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 619); 

                auto tg_xxyyyzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 620); 

                auto tg_xxyyyzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 621); 

                auto tg_xxyyyzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 622); 

                auto tg_xxyyyzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 623); 

                auto tg_xxyyyzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 624); 

                auto tg_xxyyyzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 625); 

                auto tg_xxyyyzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 626); 

                auto tg_xxyyyzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 627); 

                auto tg_xxyyyzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 628); 

                auto tg_xxyyyzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 629); 

                auto tg_xxyyyzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 630); 

                auto tg_xxyyyzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 631); 

                auto tg_xxyyyzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 632); 

                auto tg_xxyyyzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 633); 

                auto tg_xxyyyzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 634); 

                auto tg_xxyyyzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 635); 

                auto tg_xxyyyzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 636); 

                auto tg_xxyyyzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 637); 

                auto tg_xxyyyzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 638); 

                auto tg_xxyyyzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 639); 

                auto tg_xxyyyzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 640); 

                auto tg_xxyyyzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 641); 

                auto tg_xxyyyzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 642); 

                auto tg_xxyyyzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 643); 

                auto tg_xxyyyzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 644); 

                auto tg_xxyyyzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 645); 

                auto tg_xxyyyzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 646); 

                auto tg_xxyyyzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 647); 

                auto tg_xxyyzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 648); 

                auto tg_xxyyzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 649); 

                auto tg_xxyyzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 650); 

                auto tg_xxyyzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 651); 

                auto tg_xxyyzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 652); 

                auto tg_xxyyzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 653); 

                auto tg_xxyyzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 654); 

                auto tg_xxyyzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 655); 

                auto tg_xxyyzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 656); 

                auto tg_xxyyzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 657); 

                auto tg_xxyyzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 658); 

                auto tg_xxyyzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 659); 

                auto tg_xxyyzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 660); 

                auto tg_xxyyzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 661); 

                auto tg_xxyyzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 662); 

                auto tg_xxyyzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 663); 

                auto tg_xxyyzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 664); 

                auto tg_xxyyzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 665); 

                auto tg_xxyyzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 666); 

                auto tg_xxyyzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 667); 

                auto tg_xxyyzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 668); 

                auto tg_xxyyzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 669); 

                auto tg_xxyyzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 670); 

                auto tg_xxyyzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 671); 

                auto tg_xxyyzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 672); 

                auto tg_xxyyzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 673); 

                auto tg_xxyyzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 674); 

                auto tg_xxyyzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 675); 

                auto tg_xxyyzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 676); 

                auto tg_xxyyzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 677); 

                auto tg_xxyyzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 678); 

                auto tg_xxyyzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 679); 

                auto tg_xxyyzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 680); 

                auto tg_xxyyzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 681); 

                auto tg_xxyyzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 682); 

                auto tg_xxyyzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 683); 

                auto tg_xxyzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 684); 

                auto tg_xxyzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 685); 

                auto tg_xxyzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 686); 

                auto tg_xxyzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 687); 

                auto tg_xxyzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 688); 

                auto tg_xxyzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 689); 

                auto tg_xxyzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 690); 

                auto tg_xxyzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 691); 

                auto tg_xxyzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 692); 

                auto tg_xxyzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 693); 

                auto tg_xxyzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 694); 

                auto tg_xxyzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 695); 

                auto tg_xxyzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 696); 

                auto tg_xxyzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 697); 

                auto tg_xxyzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 698); 

                auto tg_xxyzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 699); 

                // Batch of Integrals (600,700)

                #pragma omp simd aligned(fxn, fza, tg_xxyyyyz_xyyyzzz_0, tg_xxyyyyz_xyyzzzz_0, \
                                         tg_xxyyyyz_xyzzzzz_0, tg_xxyyyyz_xzzzzzz_0, tg_xxyyyyz_yyyyyyy_0, tg_xxyyyyz_yyyyyyz_0, \
                                         tg_xxyyyyz_yyyyyzz_0, tg_xxyyyyz_yyyyzzz_0, tg_xxyyyyz_yyyzzzz_0, tg_xxyyyyz_yyzzzzz_0, \
                                         tg_xxyyyyz_yzzzzzz_0, tg_xxyyyyz_zzzzzzz_0, tg_xxyyyzz_xxxxxxx_0, tg_xxyyyzz_xxxxxxy_0, \
                                         tg_xxyyyzz_xxxxxxz_0, tg_xxyyyzz_xxxxxyy_0, tg_xxyyyzz_xxxxxyz_0, tg_xxyyyzz_xxxxxzz_0, \
                                         tg_xxyyyzz_xxxxyyy_0, tg_xxyyyzz_xxxxyyz_0, tg_xxyyyzz_xxxxyzz_0, tg_xxyyyzz_xxxxzzz_0, \
                                         tg_xxyyyzz_xxxyyyy_0, tg_xxyyyzz_xxxyyyz_0, tg_xxyyyzz_xxxyyzz_0, tg_xxyyyzz_xxxyzzz_0, \
                                         tg_xxyyyzz_xxxzzzz_0, tg_xxyyyzz_xxyyyyy_0, tg_xxyyyzz_xxyyyyz_0, tg_xxyyyzz_xxyyyzz_0, \
                                         tg_xxyyyzz_xxyyzzz_0, tg_xxyyyzz_xxyzzzz_0, tg_xxyyyzz_xxzzzzz_0, tg_xxyyyzz_xyyyyyy_0, \
                                         tg_xxyyyzz_xyyyyyz_0, tg_xxyyyzz_xyyyyzz_0, tg_xxyyyzz_xyyyzzz_0, tg_xxyyyzz_xyyzzzz_0, \
                                         tg_xxyyyzz_xyzzzzz_0, tg_xxyyyzz_xzzzzzz_0, tg_xxyyyzz_yyyyyyy_0, tg_xxyyyzz_yyyyyyz_0, \
                                         tg_xxyyyzz_yyyyyzz_0, tg_xxyyyzz_yyyyzzz_0, tg_xxyyyzz_yyyzzzz_0, tg_xxyyyzz_yyzzzzz_0, \
                                         tg_xxyyyzz_yzzzzzz_0, tg_xxyyyzz_zzzzzzz_0, tg_xxyyzzz_xxxxxxx_0, tg_xxyyzzz_xxxxxxy_0, \
                                         tg_xxyyzzz_xxxxxxz_0, tg_xxyyzzz_xxxxxyy_0, tg_xxyyzzz_xxxxxyz_0, tg_xxyyzzz_xxxxxzz_0, \
                                         tg_xxyyzzz_xxxxyyy_0, tg_xxyyzzz_xxxxyyz_0, tg_xxyyzzz_xxxxyzz_0, tg_xxyyzzz_xxxxzzz_0, \
                                         tg_xxyyzzz_xxxyyyy_0, tg_xxyyzzz_xxxyyyz_0, tg_xxyyzzz_xxxyyzz_0, tg_xxyyzzz_xxxyzzz_0, \
                                         tg_xxyyzzz_xxxzzzz_0, tg_xxyyzzz_xxyyyyy_0, tg_xxyyzzz_xxyyyyz_0, tg_xxyyzzz_xxyyyzz_0, \
                                         tg_xxyyzzz_xxyyzzz_0, tg_xxyyzzz_xxyzzzz_0, tg_xxyyzzz_xxzzzzz_0, tg_xxyyzzz_xyyyyyy_0, \
                                         tg_xxyyzzz_xyyyyyz_0, tg_xxyyzzz_xyyyyzz_0, tg_xxyyzzz_xyyyzzz_0, tg_xxyyzzz_xyyzzzz_0, \
                                         tg_xxyyzzz_xyzzzzz_0, tg_xxyyzzz_xzzzzzz_0, tg_xxyyzzz_yyyyyyy_0, tg_xxyyzzz_yyyyyyz_0, \
                                         tg_xxyyzzz_yyyyyzz_0, tg_xxyyzzz_yyyyzzz_0, tg_xxyyzzz_yyyzzzz_0, tg_xxyyzzz_yyzzzzz_0, \
                                         tg_xxyyzzz_yzzzzzz_0, tg_xxyyzzz_zzzzzzz_0, tg_xxyzzzz_xxxxxxx_0, tg_xxyzzzz_xxxxxxy_0, \
                                         tg_xxyzzzz_xxxxxxz_0, tg_xxyzzzz_xxxxxyy_0, tg_xxyzzzz_xxxxxyz_0, tg_xxyzzzz_xxxxxzz_0, \
                                         tg_xxyzzzz_xxxxyyy_0, tg_xxyzzzz_xxxxyyz_0, tg_xxyzzzz_xxxxyzz_0, tg_xxyzzzz_xxxxzzz_0, \
                                         tg_xxyzzzz_xxxyyyy_0, tg_xxyzzzz_xxxyyyz_0, tg_xxyzzzz_xxxyyzz_0, tg_xxyzzzz_xxxyzzz_0, \
                                         tg_xxyzzzz_xxxzzzz_0, tg_xxyzzzz_xxyyyyy_0, tg_xyyyyz_xyyyzzz_0, tg_xyyyyz_xyyyzzz_1, \
                                         tg_xyyyyz_xyyzzzz_0, tg_xyyyyz_xyyzzzz_1, tg_xyyyyz_xyzzzzz_0, tg_xyyyyz_xyzzzzz_1, \
                                         tg_xyyyyz_xzzzzzz_0, tg_xyyyyz_xzzzzzz_1, tg_xyyyyz_yyyyyyy_0, tg_xyyyyz_yyyyyyy_1, \
                                         tg_xyyyyz_yyyyyyz_0, tg_xyyyyz_yyyyyyz_1, tg_xyyyyz_yyyyyzz_0, tg_xyyyyz_yyyyyzz_1, \
                                         tg_xyyyyz_yyyyzzz_0, tg_xyyyyz_yyyyzzz_1, tg_xyyyyz_yyyzzz_1, tg_xyyyyz_yyyzzzz_0, \
                                         tg_xyyyyz_yyyzzzz_1, tg_xyyyyz_yyzzzz_1, tg_xyyyyz_yyzzzzz_0, tg_xyyyyz_yyzzzzz_1, \
                                         tg_xyyyyz_yzzzzz_1, tg_xyyyyz_yzzzzzz_0, tg_xyyyyz_yzzzzzz_1, tg_xyyyyz_zzzzzz_1, \
                                         tg_xyyyyz_zzzzzzz_0, tg_xyyyyz_zzzzzzz_1, tg_xyyyzz_xxxxxx_1, tg_xyyyzz_xxxxxxx_0, \
                                         tg_xyyyzz_xxxxxxx_1, tg_xyyyzz_xxxxxxy_0, tg_xyyyzz_xxxxxxy_1, tg_xyyyzz_xxxxxxz_0, \
                                         tg_xyyyzz_xxxxxxz_1, tg_xyyyzz_xxxxxy_1, tg_xyyyzz_xxxxxyy_0, tg_xyyyzz_xxxxxyy_1, \
                                         tg_xyyyzz_xxxxxyz_0, tg_xyyyzz_xxxxxyz_1, tg_xyyyzz_xxxxxz_1, tg_xyyyzz_xxxxxzz_0, \
                                         tg_xyyyzz_xxxxxzz_1, tg_xyyyzz_xxxxyy_1, tg_xyyyzz_xxxxyyy_0, tg_xyyyzz_xxxxyyy_1, \
                                         tg_xyyyzz_xxxxyyz_0, tg_xyyyzz_xxxxyyz_1, tg_xyyyzz_xxxxyz_1, tg_xyyyzz_xxxxyzz_0, \
                                         tg_xyyyzz_xxxxyzz_1, tg_xyyyzz_xxxxzz_1, tg_xyyyzz_xxxxzzz_0, tg_xyyyzz_xxxxzzz_1, \
                                         tg_xyyyzz_xxxyyy_1, tg_xyyyzz_xxxyyyy_0, tg_xyyyzz_xxxyyyy_1, tg_xyyyzz_xxxyyyz_0, \
                                         tg_xyyyzz_xxxyyyz_1, tg_xyyyzz_xxxyyz_1, tg_xyyyzz_xxxyyzz_0, tg_xyyyzz_xxxyyzz_1, \
                                         tg_xyyyzz_xxxyzz_1, tg_xyyyzz_xxxyzzz_0, tg_xyyyzz_xxxyzzz_1, tg_xyyyzz_xxxzzz_1, \
                                         tg_xyyyzz_xxxzzzz_0, tg_xyyyzz_xxxzzzz_1, tg_xyyyzz_xxyyyy_1, tg_xyyyzz_xxyyyyy_0, \
                                         tg_xyyyzz_xxyyyyy_1, tg_xyyyzz_xxyyyyz_0, tg_xyyyzz_xxyyyyz_1, tg_xyyyzz_xxyyyz_1, \
                                         tg_xyyyzz_xxyyyzz_0, tg_xyyyzz_xxyyyzz_1, tg_xyyyzz_xxyyzz_1, tg_xyyyzz_xxyyzzz_0, \
                                         tg_xyyyzz_xxyyzzz_1, tg_xyyyzz_xxyzzz_1, tg_xyyyzz_xxyzzzz_0, tg_xyyyzz_xxyzzzz_1, \
                                         tg_xyyyzz_xxzzzz_1, tg_xyyyzz_xxzzzzz_0, tg_xyyyzz_xxzzzzz_1, tg_xyyyzz_xyyyyy_1, \
                                         tg_xyyyzz_xyyyyyy_0, tg_xyyyzz_xyyyyyy_1, tg_xyyyzz_xyyyyyz_0, tg_xyyyzz_xyyyyyz_1, \
                                         tg_xyyyzz_xyyyyz_1, tg_xyyyzz_xyyyyzz_0, tg_xyyyzz_xyyyyzz_1, tg_xyyyzz_xyyyzz_1, \
                                         tg_xyyyzz_xyyyzzz_0, tg_xyyyzz_xyyyzzz_1, tg_xyyyzz_xyyzzz_1, tg_xyyyzz_xyyzzzz_0, \
                                         tg_xyyyzz_xyyzzzz_1, tg_xyyyzz_xyzzzz_1, tg_xyyyzz_xyzzzzz_0, tg_xyyyzz_xyzzzzz_1, \
                                         tg_xyyyzz_xzzzzz_1, tg_xyyyzz_xzzzzzz_0, tg_xyyyzz_xzzzzzz_1, tg_xyyyzz_yyyyyy_1, \
                                         tg_xyyyzz_yyyyyyy_0, tg_xyyyzz_yyyyyyy_1, tg_xyyyzz_yyyyyyz_0, tg_xyyyzz_yyyyyyz_1, \
                                         tg_xyyyzz_yyyyyz_1, tg_xyyyzz_yyyyyzz_0, tg_xyyyzz_yyyyyzz_1, tg_xyyyzz_yyyyzz_1, \
                                         tg_xyyyzz_yyyyzzz_0, tg_xyyyzz_yyyyzzz_1, tg_xyyyzz_yyyzzz_1, tg_xyyyzz_yyyzzzz_0, \
                                         tg_xyyyzz_yyyzzzz_1, tg_xyyyzz_yyzzzz_1, tg_xyyyzz_yyzzzzz_0, tg_xyyyzz_yyzzzzz_1, \
                                         tg_xyyyzz_yzzzzz_1, tg_xyyyzz_yzzzzzz_0, tg_xyyyzz_yzzzzzz_1, tg_xyyyzz_zzzzzz_1, \
                                         tg_xyyyzz_zzzzzzz_0, tg_xyyyzz_zzzzzzz_1, tg_xyyzzz_xxxxxx_1, tg_xyyzzz_xxxxxxx_0, \
                                         tg_xyyzzz_xxxxxxx_1, tg_xyyzzz_xxxxxxy_0, tg_xyyzzz_xxxxxxy_1, tg_xyyzzz_xxxxxxz_0, \
                                         tg_xyyzzz_xxxxxxz_1, tg_xyyzzz_xxxxxy_1, tg_xyyzzz_xxxxxyy_0, tg_xyyzzz_xxxxxyy_1, \
                                         tg_xyyzzz_xxxxxyz_0, tg_xyyzzz_xxxxxyz_1, tg_xyyzzz_xxxxxz_1, tg_xyyzzz_xxxxxzz_0, \
                                         tg_xyyzzz_xxxxxzz_1, tg_xyyzzz_xxxxyy_1, tg_xyyzzz_xxxxyyy_0, tg_xyyzzz_xxxxyyy_1, \
                                         tg_xyyzzz_xxxxyyz_0, tg_xyyzzz_xxxxyyz_1, tg_xyyzzz_xxxxyz_1, tg_xyyzzz_xxxxyzz_0, \
                                         tg_xyyzzz_xxxxyzz_1, tg_xyyzzz_xxxxzz_1, tg_xyyzzz_xxxxzzz_0, tg_xyyzzz_xxxxzzz_1, \
                                         tg_xyyzzz_xxxyyy_1, tg_xyyzzz_xxxyyyy_0, tg_xyyzzz_xxxyyyy_1, tg_xyyzzz_xxxyyyz_0, \
                                         tg_xyyzzz_xxxyyyz_1, tg_xyyzzz_xxxyyz_1, tg_xyyzzz_xxxyyzz_0, tg_xyyzzz_xxxyyzz_1, \
                                         tg_xyyzzz_xxxyzz_1, tg_xyyzzz_xxxyzzz_0, tg_xyyzzz_xxxyzzz_1, tg_xyyzzz_xxxzzz_1, \
                                         tg_xyyzzz_xxxzzzz_0, tg_xyyzzz_xxxzzzz_1, tg_xyyzzz_xxyyyy_1, tg_xyyzzz_xxyyyyy_0, \
                                         tg_xyyzzz_xxyyyyy_1, tg_xyyzzz_xxyyyyz_0, tg_xyyzzz_xxyyyyz_1, tg_xyyzzz_xxyyyz_1, \
                                         tg_xyyzzz_xxyyyzz_0, tg_xyyzzz_xxyyyzz_1, tg_xyyzzz_xxyyzz_1, tg_xyyzzz_xxyyzzz_0, \
                                         tg_xyyzzz_xxyyzzz_1, tg_xyyzzz_xxyzzz_1, tg_xyyzzz_xxyzzzz_0, tg_xyyzzz_xxyzzzz_1, \
                                         tg_xyyzzz_xxzzzz_1, tg_xyyzzz_xxzzzzz_0, tg_xyyzzz_xxzzzzz_1, tg_xyyzzz_xyyyyy_1, \
                                         tg_xyyzzz_xyyyyyy_0, tg_xyyzzz_xyyyyyy_1, tg_xyyzzz_xyyyyyz_0, tg_xyyzzz_xyyyyyz_1, \
                                         tg_xyyzzz_xyyyyz_1, tg_xyyzzz_xyyyyzz_0, tg_xyyzzz_xyyyyzz_1, tg_xyyzzz_xyyyzz_1, \
                                         tg_xyyzzz_xyyyzzz_0, tg_xyyzzz_xyyyzzz_1, tg_xyyzzz_xyyzzz_1, tg_xyyzzz_xyyzzzz_0, \
                                         tg_xyyzzz_xyyzzzz_1, tg_xyyzzz_xyzzzz_1, tg_xyyzzz_xyzzzzz_0, tg_xyyzzz_xyzzzzz_1, \
                                         tg_xyyzzz_xzzzzz_1, tg_xyyzzz_xzzzzzz_0, tg_xyyzzz_xzzzzzz_1, tg_xyyzzz_yyyyyy_1, \
                                         tg_xyyzzz_yyyyyyy_0, tg_xyyzzz_yyyyyyy_1, tg_xyyzzz_yyyyyyz_0, tg_xyyzzz_yyyyyyz_1, \
                                         tg_xyyzzz_yyyyyz_1, tg_xyyzzz_yyyyyzz_0, tg_xyyzzz_yyyyyzz_1, tg_xyyzzz_yyyyzz_1, \
                                         tg_xyyzzz_yyyyzzz_0, tg_xyyzzz_yyyyzzz_1, tg_xyyzzz_yyyzzz_1, tg_xyyzzz_yyyzzzz_0, \
                                         tg_xyyzzz_yyyzzzz_1, tg_xyyzzz_yyzzzz_1, tg_xyyzzz_yyzzzzz_0, tg_xyyzzz_yyzzzzz_1, \
                                         tg_xyyzzz_yzzzzz_1, tg_xyyzzz_yzzzzzz_0, tg_xyyzzz_yzzzzzz_1, tg_xyyzzz_zzzzzz_1, \
                                         tg_xyyzzz_zzzzzzz_0, tg_xyyzzz_zzzzzzz_1, tg_xyzzzz_xxxxxx_1, tg_xyzzzz_xxxxxxx_0, \
                                         tg_xyzzzz_xxxxxxx_1, tg_xyzzzz_xxxxxxy_0, tg_xyzzzz_xxxxxxy_1, tg_xyzzzz_xxxxxxz_0, \
                                         tg_xyzzzz_xxxxxxz_1, tg_xyzzzz_xxxxxy_1, tg_xyzzzz_xxxxxyy_0, tg_xyzzzz_xxxxxyy_1, \
                                         tg_xyzzzz_xxxxxyz_0, tg_xyzzzz_xxxxxyz_1, tg_xyzzzz_xxxxxz_1, tg_xyzzzz_xxxxxzz_0, \
                                         tg_xyzzzz_xxxxxzz_1, tg_xyzzzz_xxxxyy_1, tg_xyzzzz_xxxxyyy_0, tg_xyzzzz_xxxxyyy_1, \
                                         tg_xyzzzz_xxxxyyz_0, tg_xyzzzz_xxxxyyz_1, tg_xyzzzz_xxxxyz_1, tg_xyzzzz_xxxxyzz_0, \
                                         tg_xyzzzz_xxxxyzz_1, tg_xyzzzz_xxxxzz_1, tg_xyzzzz_xxxxzzz_0, tg_xyzzzz_xxxxzzz_1, \
                                         tg_xyzzzz_xxxyyy_1, tg_xyzzzz_xxxyyyy_0, tg_xyzzzz_xxxyyyy_1, tg_xyzzzz_xxxyyyz_0, \
                                         tg_xyzzzz_xxxyyyz_1, tg_xyzzzz_xxxyyz_1, tg_xyzzzz_xxxyyzz_0, tg_xyzzzz_xxxyyzz_1, \
                                         tg_xyzzzz_xxxyzz_1, tg_xyzzzz_xxxyzzz_0, tg_xyzzzz_xxxyzzz_1, tg_xyzzzz_xxxzzz_1, \
                                         tg_xyzzzz_xxxzzzz_0, tg_xyzzzz_xxxzzzz_1, tg_xyzzzz_xxyyyy_1, tg_xyzzzz_xxyyyyy_0, \
                                         tg_xyzzzz_xxyyyyy_1, tg_xyzzzz_xxyyyz_1, tg_xyzzzz_xxyyzz_1, tg_xyzzzz_xxyzzz_1, \
                                         tg_xyzzzz_xxzzzz_1, tg_xyzzzz_xyyyyy_1, tg_yyyyz_xyyyzzz_0, tg_yyyyz_xyyyzzz_1, \
                                         tg_yyyyz_xyyzzzz_0, tg_yyyyz_xyyzzzz_1, tg_yyyyz_xyzzzzz_0, tg_yyyyz_xyzzzzz_1, \
                                         tg_yyyyz_xzzzzzz_0, tg_yyyyz_xzzzzzz_1, tg_yyyyz_yyyyyyy_0, tg_yyyyz_yyyyyyy_1, \
                                         tg_yyyyz_yyyyyyz_0, tg_yyyyz_yyyyyyz_1, tg_yyyyz_yyyyyzz_0, tg_yyyyz_yyyyyzz_1, \
                                         tg_yyyyz_yyyyzzz_0, tg_yyyyz_yyyyzzz_1, tg_yyyyz_yyyzzzz_0, tg_yyyyz_yyyzzzz_1, \
                                         tg_yyyyz_yyzzzzz_0, tg_yyyyz_yyzzzzz_1, tg_yyyyz_yzzzzzz_0, tg_yyyyz_yzzzzzz_1, \
                                         tg_yyyyz_zzzzzzz_0, tg_yyyyz_zzzzzzz_1, tg_yyyzz_xxxxxxx_0, tg_yyyzz_xxxxxxx_1, \
                                         tg_yyyzz_xxxxxxy_0, tg_yyyzz_xxxxxxy_1, tg_yyyzz_xxxxxxz_0, tg_yyyzz_xxxxxxz_1, \
                                         tg_yyyzz_xxxxxyy_0, tg_yyyzz_xxxxxyy_1, tg_yyyzz_xxxxxyz_0, tg_yyyzz_xxxxxyz_1, \
                                         tg_yyyzz_xxxxxzz_0, tg_yyyzz_xxxxxzz_1, tg_yyyzz_xxxxyyy_0, tg_yyyzz_xxxxyyy_1, \
                                         tg_yyyzz_xxxxyyz_0, tg_yyyzz_xxxxyyz_1, tg_yyyzz_xxxxyzz_0, tg_yyyzz_xxxxyzz_1, \
                                         tg_yyyzz_xxxxzzz_0, tg_yyyzz_xxxxzzz_1, tg_yyyzz_xxxyyyy_0, tg_yyyzz_xxxyyyy_1, \
                                         tg_yyyzz_xxxyyyz_0, tg_yyyzz_xxxyyyz_1, tg_yyyzz_xxxyyzz_0, tg_yyyzz_xxxyyzz_1, \
                                         tg_yyyzz_xxxyzzz_0, tg_yyyzz_xxxyzzz_1, tg_yyyzz_xxxzzzz_0, tg_yyyzz_xxxzzzz_1, \
                                         tg_yyyzz_xxyyyyy_0, tg_yyyzz_xxyyyyy_1, tg_yyyzz_xxyyyyz_0, tg_yyyzz_xxyyyyz_1, \
                                         tg_yyyzz_xxyyyzz_0, tg_yyyzz_xxyyyzz_1, tg_yyyzz_xxyyzzz_0, tg_yyyzz_xxyyzzz_1, \
                                         tg_yyyzz_xxyzzzz_0, tg_yyyzz_xxyzzzz_1, tg_yyyzz_xxzzzzz_0, tg_yyyzz_xxzzzzz_1, \
                                         tg_yyyzz_xyyyyyy_0, tg_yyyzz_xyyyyyy_1, tg_yyyzz_xyyyyyz_0, tg_yyyzz_xyyyyyz_1, \
                                         tg_yyyzz_xyyyyzz_0, tg_yyyzz_xyyyyzz_1, tg_yyyzz_xyyyzzz_0, tg_yyyzz_xyyyzzz_1, \
                                         tg_yyyzz_xyyzzzz_0, tg_yyyzz_xyyzzzz_1, tg_yyyzz_xyzzzzz_0, tg_yyyzz_xyzzzzz_1, \
                                         tg_yyyzz_xzzzzzz_0, tg_yyyzz_xzzzzzz_1, tg_yyyzz_yyyyyyy_0, tg_yyyzz_yyyyyyy_1, \
                                         tg_yyyzz_yyyyyyz_0, tg_yyyzz_yyyyyyz_1, tg_yyyzz_yyyyyzz_0, tg_yyyzz_yyyyyzz_1, \
                                         tg_yyyzz_yyyyzzz_0, tg_yyyzz_yyyyzzz_1, tg_yyyzz_yyyzzzz_0, tg_yyyzz_yyyzzzz_1, \
                                         tg_yyyzz_yyzzzzz_0, tg_yyyzz_yyzzzzz_1, tg_yyyzz_yzzzzzz_0, tg_yyyzz_yzzzzzz_1, \
                                         tg_yyyzz_zzzzzzz_0, tg_yyyzz_zzzzzzz_1, tg_yyzzz_xxxxxxx_0, tg_yyzzz_xxxxxxx_1, \
                                         tg_yyzzz_xxxxxxy_0, tg_yyzzz_xxxxxxy_1, tg_yyzzz_xxxxxxz_0, tg_yyzzz_xxxxxxz_1, \
                                         tg_yyzzz_xxxxxyy_0, tg_yyzzz_xxxxxyy_1, tg_yyzzz_xxxxxyz_0, tg_yyzzz_xxxxxyz_1, \
                                         tg_yyzzz_xxxxxzz_0, tg_yyzzz_xxxxxzz_1, tg_yyzzz_xxxxyyy_0, tg_yyzzz_xxxxyyy_1, \
                                         tg_yyzzz_xxxxyyz_0, tg_yyzzz_xxxxyyz_1, tg_yyzzz_xxxxyzz_0, tg_yyzzz_xxxxyzz_1, \
                                         tg_yyzzz_xxxxzzz_0, tg_yyzzz_xxxxzzz_1, tg_yyzzz_xxxyyyy_0, tg_yyzzz_xxxyyyy_1, \
                                         tg_yyzzz_xxxyyyz_0, tg_yyzzz_xxxyyyz_1, tg_yyzzz_xxxyyzz_0, tg_yyzzz_xxxyyzz_1, \
                                         tg_yyzzz_xxxyzzz_0, tg_yyzzz_xxxyzzz_1, tg_yyzzz_xxxzzzz_0, tg_yyzzz_xxxzzzz_1, \
                                         tg_yyzzz_xxyyyyy_0, tg_yyzzz_xxyyyyy_1, tg_yyzzz_xxyyyyz_0, tg_yyzzz_xxyyyyz_1, \
                                         tg_yyzzz_xxyyyzz_0, tg_yyzzz_xxyyyzz_1, tg_yyzzz_xxyyzzz_0, tg_yyzzz_xxyyzzz_1, \
                                         tg_yyzzz_xxyzzzz_0, tg_yyzzz_xxyzzzz_1, tg_yyzzz_xxzzzzz_0, tg_yyzzz_xxzzzzz_1, \
                                         tg_yyzzz_xyyyyyy_0, tg_yyzzz_xyyyyyy_1, tg_yyzzz_xyyyyyz_0, tg_yyzzz_xyyyyyz_1, \
                                         tg_yyzzz_xyyyyzz_0, tg_yyzzz_xyyyyzz_1, tg_yyzzz_xyyyzzz_0, tg_yyzzz_xyyyzzz_1, \
                                         tg_yyzzz_xyyzzzz_0, tg_yyzzz_xyyzzzz_1, tg_yyzzz_xyzzzzz_0, tg_yyzzz_xyzzzzz_1, \
                                         tg_yyzzz_xzzzzzz_0, tg_yyzzz_xzzzzzz_1, tg_yyzzz_yyyyyyy_0, tg_yyzzz_yyyyyyy_1, \
                                         tg_yyzzz_yyyyyyz_0, tg_yyzzz_yyyyyyz_1, tg_yyzzz_yyyyyzz_0, tg_yyzzz_yyyyyzz_1, \
                                         tg_yyzzz_yyyyzzz_0, tg_yyzzz_yyyyzzz_1, tg_yyzzz_yyyzzzz_0, tg_yyzzz_yyyzzzz_1, \
                                         tg_yyzzz_yyzzzzz_0, tg_yyzzz_yyzzzzz_1, tg_yyzzz_yzzzzzz_0, tg_yyzzz_yzzzzzz_1, \
                                         tg_yyzzz_zzzzzzz_0, tg_yyzzz_zzzzzzz_1, tg_yzzzz_xxxxxxx_0, tg_yzzzz_xxxxxxx_1, \
                                         tg_yzzzz_xxxxxxy_0, tg_yzzzz_xxxxxxy_1, tg_yzzzz_xxxxxxz_0, tg_yzzzz_xxxxxxz_1, \
                                         tg_yzzzz_xxxxxyy_0, tg_yzzzz_xxxxxyy_1, tg_yzzzz_xxxxxyz_0, tg_yzzzz_xxxxxyz_1, \
                                         tg_yzzzz_xxxxxzz_0, tg_yzzzz_xxxxxzz_1, tg_yzzzz_xxxxyyy_0, tg_yzzzz_xxxxyyy_1, \
                                         tg_yzzzz_xxxxyyz_0, tg_yzzzz_xxxxyyz_1, tg_yzzzz_xxxxyzz_0, tg_yzzzz_xxxxyzz_1, \
                                         tg_yzzzz_xxxxzzz_0, tg_yzzzz_xxxxzzz_1, tg_yzzzz_xxxyyyy_0, tg_yzzzz_xxxyyyy_1, \
                                         tg_yzzzz_xxxyyyz_0, tg_yzzzz_xxxyyyz_1, tg_yzzzz_xxxyyzz_0, tg_yzzzz_xxxyyzz_1, \
                                         tg_yzzzz_xxxyzzz_0, tg_yzzzz_xxxyzzz_1, tg_yzzzz_xxxzzzz_0, tg_yzzzz_xxxzzzz_1, \
                                         tg_yzzzz_xxyyyyy_0, tg_yzzzz_xxyyyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxyyyyz_xyyyzzz_0[j] = pb_x * tg_xyyyyz_xyyyzzz_0[j] + fr * tg_xyyyyz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyyyzzz_0[j] - tg_yyyyz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yyyzzz_1[j];

                    tg_xxyyyyz_xyyzzzz_0[j] = pb_x * tg_xyyyyz_xyyzzzz_0[j] + fr * tg_xyyyyz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyyzzzz_0[j] - tg_yyyyz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yyzzzz_1[j];

                    tg_xxyyyyz_xyzzzzz_0[j] = pb_x * tg_xyyyyz_xyzzzzz_0[j] + fr * tg_xyyyyz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xyzzzzz_0[j] - tg_yyyyz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_yzzzzz_1[j];

                    tg_xxyyyyz_xzzzzzz_0[j] = pb_x * tg_xyyyyz_xzzzzzz_0[j] + fr * tg_xyyyyz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_xzzzzzz_0[j] - tg_yyyyz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyz_zzzzzz_1[j];

                    tg_xxyyyyz_yyyyyyy_0[j] = pb_x * tg_xyyyyz_yyyyyyy_0[j] + fr * tg_xyyyyz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyyyyyy_0[j] - tg_yyyyz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxyyyyz_yyyyyyz_0[j] = pb_x * tg_xyyyyz_yyyyyyz_0[j] + fr * tg_xyyyyz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyyyyyz_0[j] - tg_yyyyz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxyyyyz_yyyyyzz_0[j] = pb_x * tg_xyyyyz_yyyyyzz_0[j] + fr * tg_xyyyyz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyyyyzz_0[j] - tg_yyyyz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxyyyyz_yyyyzzz_0[j] = pb_x * tg_xyyyyz_yyyyzzz_0[j] + fr * tg_xyyyyz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyyyzzz_0[j] - tg_yyyyz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxyyyyz_yyyzzzz_0[j] = pb_x * tg_xyyyyz_yyyzzzz_0[j] + fr * tg_xyyyyz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyyzzzz_0[j] - tg_yyyyz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxyyyyz_yyzzzzz_0[j] = pb_x * tg_xyyyyz_yyzzzzz_0[j] + fr * tg_xyyyyz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yyzzzzz_0[j] - tg_yyyyz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyz_yzzzzzz_0[j] = pb_x * tg_xyyyyz_yzzzzzz_0[j] + fr * tg_xyyyyz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_yzzzzzz_0[j] - tg_yyyyz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyz_zzzzzzz_0[j] = pb_x * tg_xyyyyz_zzzzzzz_0[j] + fr * tg_xyyyyz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyz_zzzzzzz_0[j] - tg_yyyyz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyzz_xxxxxxx_0[j] = pb_x * tg_xyyyzz_xxxxxxx_0[j] + fr * tg_xyyyzz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxxx_0[j] - tg_yyyzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyyzz_xxxxxx_1[j];

                    tg_xxyyyzz_xxxxxxy_0[j] = pb_x * tg_xyyyzz_xxxxxxy_0[j] + fr * tg_xyyyzz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxxy_0[j] - tg_yyyzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyzz_xxxxxy_1[j];

                    tg_xxyyyzz_xxxxxxz_0[j] = pb_x * tg_xyyyzz_xxxxxxz_0[j] + fr * tg_xyyyzz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxxz_0[j] - tg_yyyzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyzz_xxxxxz_1[j];

                    tg_xxyyyzz_xxxxxyy_0[j] = pb_x * tg_xyyyzz_xxxxxyy_0[j] + fr * tg_xyyyzz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxyy_0[j] - tg_yyyzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyzz_xxxxyy_1[j];

                    tg_xxyyyzz_xxxxxyz_0[j] = pb_x * tg_xyyyzz_xxxxxyz_0[j] + fr * tg_xyyyzz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxyz_0[j] - tg_yyyzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyzz_xxxxyz_1[j];

                    tg_xxyyyzz_xxxxxzz_0[j] = pb_x * tg_xyyyzz_xxxxxzz_0[j] + fr * tg_xyyyzz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxxzz_0[j] - tg_yyyzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyzz_xxxxzz_1[j];

                    tg_xxyyyzz_xxxxyyy_0[j] = pb_x * tg_xyyyzz_xxxxyyy_0[j] + fr * tg_xyyyzz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxyyy_0[j] - tg_yyyzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzz_xxxyyy_1[j];

                    tg_xxyyyzz_xxxxyyz_0[j] = pb_x * tg_xyyyzz_xxxxyyz_0[j] + fr * tg_xyyyzz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxyyz_0[j] - tg_yyyzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzz_xxxyyz_1[j];

                    tg_xxyyyzz_xxxxyzz_0[j] = pb_x * tg_xyyyzz_xxxxyzz_0[j] + fr * tg_xyyyzz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxyzz_0[j] - tg_yyyzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzz_xxxyzz_1[j];

                    tg_xxyyyzz_xxxxzzz_0[j] = pb_x * tg_xyyyzz_xxxxzzz_0[j] + fr * tg_xyyyzz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxxzzz_0[j] - tg_yyyzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzz_xxxzzz_1[j];

                    tg_xxyyyzz_xxxyyyy_0[j] = pb_x * tg_xyyyzz_xxxyyyy_0[j] + fr * tg_xyyyzz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxyyyy_0[j] - tg_yyyzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzz_xxyyyy_1[j];

                    tg_xxyyyzz_xxxyyyz_0[j] = pb_x * tg_xyyyzz_xxxyyyz_0[j] + fr * tg_xyyyzz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxyyyz_0[j] - tg_yyyzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzz_xxyyyz_1[j];

                    tg_xxyyyzz_xxxyyzz_0[j] = pb_x * tg_xyyyzz_xxxyyzz_0[j] + fr * tg_xyyyzz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxyyzz_0[j] - tg_yyyzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzz_xxyyzz_1[j];

                    tg_xxyyyzz_xxxyzzz_0[j] = pb_x * tg_xyyyzz_xxxyzzz_0[j] + fr * tg_xyyyzz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxyzzz_0[j] - tg_yyyzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzz_xxyzzz_1[j];

                    tg_xxyyyzz_xxxzzzz_0[j] = pb_x * tg_xyyyzz_xxxzzzz_0[j] + fr * tg_xyyyzz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxxzzzz_0[j] - tg_yyyzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzz_xxzzzz_1[j];

                    tg_xxyyyzz_xxyyyyy_0[j] = pb_x * tg_xyyyzz_xxyyyyy_0[j] + fr * tg_xyyyzz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxyyyyy_0[j] - tg_yyyzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xyyyyy_1[j];

                    tg_xxyyyzz_xxyyyyz_0[j] = pb_x * tg_xyyyzz_xxyyyyz_0[j] + fr * tg_xyyyzz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxyyyyz_0[j] - tg_yyyzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xyyyyz_1[j];

                    tg_xxyyyzz_xxyyyzz_0[j] = pb_x * tg_xyyyzz_xxyyyzz_0[j] + fr * tg_xyyyzz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxyyyzz_0[j] - tg_yyyzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xyyyzz_1[j];

                    tg_xxyyyzz_xxyyzzz_0[j] = pb_x * tg_xyyyzz_xxyyzzz_0[j] + fr * tg_xyyyzz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxyyzzz_0[j] - tg_yyyzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xyyzzz_1[j];

                    tg_xxyyyzz_xxyzzzz_0[j] = pb_x * tg_xyyyzz_xxyzzzz_0[j] + fr * tg_xyyyzz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxyzzzz_0[j] - tg_yyyzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xyzzzz_1[j];

                    tg_xxyyyzz_xxzzzzz_0[j] = pb_x * tg_xyyyzz_xxzzzzz_0[j] + fr * tg_xyyyzz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xxzzzzz_0[j] - tg_yyyzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzz_xzzzzz_1[j];

                    tg_xxyyyzz_xyyyyyy_0[j] = pb_x * tg_xyyyzz_xyyyyyy_0[j] + fr * tg_xyyyzz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyyyyyy_0[j] - tg_yyyzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yyyyyy_1[j];

                    tg_xxyyyzz_xyyyyyz_0[j] = pb_x * tg_xyyyzz_xyyyyyz_0[j] + fr * tg_xyyyzz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyyyyyz_0[j] - tg_yyyzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yyyyyz_1[j];

                    tg_xxyyyzz_xyyyyzz_0[j] = pb_x * tg_xyyyzz_xyyyyzz_0[j] + fr * tg_xyyyzz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyyyyzz_0[j] - tg_yyyzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yyyyzz_1[j];

                    tg_xxyyyzz_xyyyzzz_0[j] = pb_x * tg_xyyyzz_xyyyzzz_0[j] + fr * tg_xyyyzz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyyyzzz_0[j] - tg_yyyzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yyyzzz_1[j];

                    tg_xxyyyzz_xyyzzzz_0[j] = pb_x * tg_xyyyzz_xyyzzzz_0[j] + fr * tg_xyyyzz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyyzzzz_0[j] - tg_yyyzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yyzzzz_1[j];

                    tg_xxyyyzz_xyzzzzz_0[j] = pb_x * tg_xyyyzz_xyzzzzz_0[j] + fr * tg_xyyyzz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xyzzzzz_0[j] - tg_yyyzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_yzzzzz_1[j];

                    tg_xxyyyzz_xzzzzzz_0[j] = pb_x * tg_xyyyzz_xzzzzzz_0[j] + fr * tg_xyyyzz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_xzzzzzz_0[j] - tg_yyyzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzz_zzzzzz_1[j];

                    tg_xxyyyzz_yyyyyyy_0[j] = pb_x * tg_xyyyzz_yyyyyyy_0[j] + fr * tg_xyyyzz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyyyyyy_0[j] - tg_yyyzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxyyyzz_yyyyyyz_0[j] = pb_x * tg_xyyyzz_yyyyyyz_0[j] + fr * tg_xyyyzz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyyyyyz_0[j] - tg_yyyzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxyyyzz_yyyyyzz_0[j] = pb_x * tg_xyyyzz_yyyyyzz_0[j] + fr * tg_xyyyzz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyyyyzz_0[j] - tg_yyyzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxyyyzz_yyyyzzz_0[j] = pb_x * tg_xyyyzz_yyyyzzz_0[j] + fr * tg_xyyyzz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyyyzzz_0[j] - tg_yyyzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxyyyzz_yyyzzzz_0[j] = pb_x * tg_xyyyzz_yyyzzzz_0[j] + fr * tg_xyyyzz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyyzzzz_0[j] - tg_yyyzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxyyyzz_yyzzzzz_0[j] = pb_x * tg_xyyyzz_yyzzzzz_0[j] + fr * tg_xyyyzz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yyzzzzz_0[j] - tg_yyyzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxyyyzz_yzzzzzz_0[j] = pb_x * tg_xyyyzz_yzzzzzz_0[j] + fr * tg_xyyyzz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_yzzzzzz_0[j] - tg_yyyzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxyyyzz_zzzzzzz_0[j] = pb_x * tg_xyyyzz_zzzzzzz_0[j] + fr * tg_xyyyzz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzz_zzzzzzz_0[j] - tg_yyyzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxyyzzz_xxxxxxx_0[j] = pb_x * tg_xyyzzz_xxxxxxx_0[j] + fr * tg_xyyzzz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxxx_0[j] - tg_yyzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyyzzz_xxxxxx_1[j];

                    tg_xxyyzzz_xxxxxxy_0[j] = pb_x * tg_xyyzzz_xxxxxxy_0[j] + fr * tg_xyyzzz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxxy_0[j] - tg_yyzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzzz_xxxxxy_1[j];

                    tg_xxyyzzz_xxxxxxz_0[j] = pb_x * tg_xyyzzz_xxxxxxz_0[j] + fr * tg_xyyzzz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxxz_0[j] - tg_yyzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzzz_xxxxxz_1[j];

                    tg_xxyyzzz_xxxxxyy_0[j] = pb_x * tg_xyyzzz_xxxxxyy_0[j] + fr * tg_xyyzzz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxyy_0[j] - tg_yyzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzzz_xxxxyy_1[j];

                    tg_xxyyzzz_xxxxxyz_0[j] = pb_x * tg_xyyzzz_xxxxxyz_0[j] + fr * tg_xyyzzz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxyz_0[j] - tg_yyzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzzz_xxxxyz_1[j];

                    tg_xxyyzzz_xxxxxzz_0[j] = pb_x * tg_xyyzzz_xxxxxzz_0[j] + fr * tg_xyyzzz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxxzz_0[j] - tg_yyzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzzz_xxxxzz_1[j];

                    tg_xxyyzzz_xxxxyyy_0[j] = pb_x * tg_xyyzzz_xxxxyyy_0[j] + fr * tg_xyyzzz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxyyy_0[j] - tg_yyzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzz_xxxyyy_1[j];

                    tg_xxyyzzz_xxxxyyz_0[j] = pb_x * tg_xyyzzz_xxxxyyz_0[j] + fr * tg_xyyzzz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxyyz_0[j] - tg_yyzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzz_xxxyyz_1[j];

                    tg_xxyyzzz_xxxxyzz_0[j] = pb_x * tg_xyyzzz_xxxxyzz_0[j] + fr * tg_xyyzzz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxyzz_0[j] - tg_yyzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzz_xxxyzz_1[j];

                    tg_xxyyzzz_xxxxzzz_0[j] = pb_x * tg_xyyzzz_xxxxzzz_0[j] + fr * tg_xyyzzz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxxzzz_0[j] - tg_yyzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzz_xxxzzz_1[j];

                    tg_xxyyzzz_xxxyyyy_0[j] = pb_x * tg_xyyzzz_xxxyyyy_0[j] + fr * tg_xyyzzz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxyyyy_0[j] - tg_yyzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzz_xxyyyy_1[j];

                    tg_xxyyzzz_xxxyyyz_0[j] = pb_x * tg_xyyzzz_xxxyyyz_0[j] + fr * tg_xyyzzz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxyyyz_0[j] - tg_yyzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzz_xxyyyz_1[j];

                    tg_xxyyzzz_xxxyyzz_0[j] = pb_x * tg_xyyzzz_xxxyyzz_0[j] + fr * tg_xyyzzz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxyyzz_0[j] - tg_yyzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzz_xxyyzz_1[j];

                    tg_xxyyzzz_xxxyzzz_0[j] = pb_x * tg_xyyzzz_xxxyzzz_0[j] + fr * tg_xyyzzz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxyzzz_0[j] - tg_yyzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzz_xxyzzz_1[j];

                    tg_xxyyzzz_xxxzzzz_0[j] = pb_x * tg_xyyzzz_xxxzzzz_0[j] + fr * tg_xyyzzz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxxzzzz_0[j] - tg_yyzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzz_xxzzzz_1[j];

                    tg_xxyyzzz_xxyyyyy_0[j] = pb_x * tg_xyyzzz_xxyyyyy_0[j] + fr * tg_xyyzzz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxyyyyy_0[j] - tg_yyzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xyyyyy_1[j];

                    tg_xxyyzzz_xxyyyyz_0[j] = pb_x * tg_xyyzzz_xxyyyyz_0[j] + fr * tg_xyyzzz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxyyyyz_0[j] - tg_yyzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xyyyyz_1[j];

                    tg_xxyyzzz_xxyyyzz_0[j] = pb_x * tg_xyyzzz_xxyyyzz_0[j] + fr * tg_xyyzzz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxyyyzz_0[j] - tg_yyzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xyyyzz_1[j];

                    tg_xxyyzzz_xxyyzzz_0[j] = pb_x * tg_xyyzzz_xxyyzzz_0[j] + fr * tg_xyyzzz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxyyzzz_0[j] - tg_yyzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xyyzzz_1[j];

                    tg_xxyyzzz_xxyzzzz_0[j] = pb_x * tg_xyyzzz_xxyzzzz_0[j] + fr * tg_xyyzzz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxyzzzz_0[j] - tg_yyzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xyzzzz_1[j];

                    tg_xxyyzzz_xxzzzzz_0[j] = pb_x * tg_xyyzzz_xxzzzzz_0[j] + fr * tg_xyyzzz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xxzzzzz_0[j] - tg_yyzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzz_xzzzzz_1[j];

                    tg_xxyyzzz_xyyyyyy_0[j] = pb_x * tg_xyyzzz_xyyyyyy_0[j] + fr * tg_xyyzzz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyyyyyy_0[j] - tg_yyzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yyyyyy_1[j];

                    tg_xxyyzzz_xyyyyyz_0[j] = pb_x * tg_xyyzzz_xyyyyyz_0[j] + fr * tg_xyyzzz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyyyyyz_0[j] - tg_yyzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yyyyyz_1[j];

                    tg_xxyyzzz_xyyyyzz_0[j] = pb_x * tg_xyyzzz_xyyyyzz_0[j] + fr * tg_xyyzzz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyyyyzz_0[j] - tg_yyzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yyyyzz_1[j];

                    tg_xxyyzzz_xyyyzzz_0[j] = pb_x * tg_xyyzzz_xyyyzzz_0[j] + fr * tg_xyyzzz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyyyzzz_0[j] - tg_yyzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yyyzzz_1[j];

                    tg_xxyyzzz_xyyzzzz_0[j] = pb_x * tg_xyyzzz_xyyzzzz_0[j] + fr * tg_xyyzzz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyyzzzz_0[j] - tg_yyzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yyzzzz_1[j];

                    tg_xxyyzzz_xyzzzzz_0[j] = pb_x * tg_xyyzzz_xyzzzzz_0[j] + fr * tg_xyyzzz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xyzzzzz_0[j] - tg_yyzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_yzzzzz_1[j];

                    tg_xxyyzzz_xzzzzzz_0[j] = pb_x * tg_xyyzzz_xzzzzzz_0[j] + fr * tg_xyyzzz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_xzzzzzz_0[j] - tg_yyzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzz_zzzzzz_1[j];

                    tg_xxyyzzz_yyyyyyy_0[j] = pb_x * tg_xyyzzz_yyyyyyy_0[j] + fr * tg_xyyzzz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyyyyyy_0[j] - tg_yyzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxyyzzz_yyyyyyz_0[j] = pb_x * tg_xyyzzz_yyyyyyz_0[j] + fr * tg_xyyzzz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyyyyyz_0[j] - tg_yyzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxyyzzz_yyyyyzz_0[j] = pb_x * tg_xyyzzz_yyyyyzz_0[j] + fr * tg_xyyzzz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyyyyzz_0[j] - tg_yyzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxyyzzz_yyyyzzz_0[j] = pb_x * tg_xyyzzz_yyyyzzz_0[j] + fr * tg_xyyzzz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyyyzzz_0[j] - tg_yyzzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxyyzzz_yyyzzzz_0[j] = pb_x * tg_xyyzzz_yyyzzzz_0[j] + fr * tg_xyyzzz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyyzzzz_0[j] - tg_yyzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxyyzzz_yyzzzzz_0[j] = pb_x * tg_xyyzzz_yyzzzzz_0[j] + fr * tg_xyyzzz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yyzzzzz_0[j] - tg_yyzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxyyzzz_yzzzzzz_0[j] = pb_x * tg_xyyzzz_yzzzzzz_0[j] + fr * tg_xyyzzz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_yzzzzzz_0[j] - tg_yyzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxyyzzz_zzzzzzz_0[j] = pb_x * tg_xyyzzz_zzzzzzz_0[j] + fr * tg_xyyzzz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzz_zzzzzzz_0[j] - tg_yyzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxyzzzz_xxxxxxx_0[j] = pb_x * tg_xyzzzz_xxxxxxx_0[j] + fr * tg_xyzzzz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxxx_0[j] - tg_yzzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xyzzzz_xxxxxx_1[j];

                    tg_xxyzzzz_xxxxxxy_0[j] = pb_x * tg_xyzzzz_xxxxxxy_0[j] + fr * tg_xyzzzz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxxy_0[j] - tg_yzzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzzz_xxxxxy_1[j];

                    tg_xxyzzzz_xxxxxxz_0[j] = pb_x * tg_xyzzzz_xxxxxxz_0[j] + fr * tg_xyzzzz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxxz_0[j] - tg_yzzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzzz_xxxxxz_1[j];

                    tg_xxyzzzz_xxxxxyy_0[j] = pb_x * tg_xyzzzz_xxxxxyy_0[j] + fr * tg_xyzzzz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxyy_0[j] - tg_yzzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzzz_xxxxyy_1[j];

                    tg_xxyzzzz_xxxxxyz_0[j] = pb_x * tg_xyzzzz_xxxxxyz_0[j] + fr * tg_xyzzzz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxyz_0[j] - tg_yzzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzzz_xxxxyz_1[j];

                    tg_xxyzzzz_xxxxxzz_0[j] = pb_x * tg_xyzzzz_xxxxxzz_0[j] + fr * tg_xyzzzz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxxzz_0[j] - tg_yzzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzzz_xxxxzz_1[j];

                    tg_xxyzzzz_xxxxyyy_0[j] = pb_x * tg_xyzzzz_xxxxyyy_0[j] + fr * tg_xyzzzz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxyyy_0[j] - tg_yzzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzz_xxxyyy_1[j];

                    tg_xxyzzzz_xxxxyyz_0[j] = pb_x * tg_xyzzzz_xxxxyyz_0[j] + fr * tg_xyzzzz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxyyz_0[j] - tg_yzzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzz_xxxyyz_1[j];

                    tg_xxyzzzz_xxxxyzz_0[j] = pb_x * tg_xyzzzz_xxxxyzz_0[j] + fr * tg_xyzzzz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxyzz_0[j] - tg_yzzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzz_xxxyzz_1[j];

                    tg_xxyzzzz_xxxxzzz_0[j] = pb_x * tg_xyzzzz_xxxxzzz_0[j] + fr * tg_xyzzzz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxxzzz_0[j] - tg_yzzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzz_xxxzzz_1[j];

                    tg_xxyzzzz_xxxyyyy_0[j] = pb_x * tg_xyzzzz_xxxyyyy_0[j] + fr * tg_xyzzzz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxyyyy_0[j] - tg_yzzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzz_xxyyyy_1[j];

                    tg_xxyzzzz_xxxyyyz_0[j] = pb_x * tg_xyzzzz_xxxyyyz_0[j] + fr * tg_xyzzzz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxyyyz_0[j] - tg_yzzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzz_xxyyyz_1[j];

                    tg_xxyzzzz_xxxyyzz_0[j] = pb_x * tg_xyzzzz_xxxyyzz_0[j] + fr * tg_xyzzzz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxyyzz_0[j] - tg_yzzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzz_xxyyzz_1[j];

                    tg_xxyzzzz_xxxyzzz_0[j] = pb_x * tg_xyzzzz_xxxyzzz_0[j] + fr * tg_xyzzzz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxyzzz_0[j] - tg_yzzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzz_xxyzzz_1[j];

                    tg_xxyzzzz_xxxzzzz_0[j] = pb_x * tg_xyzzzz_xxxzzzz_0[j] + fr * tg_xyzzzz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxxzzzz_0[j] - tg_yzzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzz_xxzzzz_1[j];

                    tg_xxyzzzz_xxyyyyy_0[j] = pb_x * tg_xyzzzz_xxyyyyy_0[j] + fr * tg_xyzzzz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxyyyyy_0[j] - tg_yzzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xyyyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_700_800(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (700,800)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xyzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 700); 

                auto tg_xyzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 701); 

                auto tg_xyzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 702); 

                auto tg_xyzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 703); 

                auto tg_xyzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 704); 

                auto tg_xyzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 705); 

                auto tg_xyzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 706); 

                auto tg_xyzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 707); 

                auto tg_xyzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 708); 

                auto tg_xyzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 709); 

                auto tg_xyzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 710); 

                auto tg_xyzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 711); 

                auto tg_xyzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 712); 

                auto tg_xyzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 713); 

                auto tg_xyzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 714); 

                auto tg_xyzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 715); 

                auto tg_xyzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 716); 

                auto tg_xyzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 717); 

                auto tg_xyzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 718); 

                auto tg_xyzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 719); 

                auto tg_xzzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 720); 

                auto tg_xzzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 721); 

                auto tg_xzzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 722); 

                auto tg_xzzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 723); 

                auto tg_xzzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 724); 

                auto tg_xzzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 725); 

                auto tg_xzzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 726); 

                auto tg_xzzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 727); 

                auto tg_xzzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 728); 

                auto tg_xzzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 729); 

                auto tg_xzzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 730); 

                auto tg_xzzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 731); 

                auto tg_xzzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 732); 

                auto tg_xzzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 733); 

                auto tg_xzzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 734); 

                auto tg_xzzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 735); 

                auto tg_xzzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 736); 

                auto tg_xzzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 737); 

                auto tg_xzzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 738); 

                auto tg_xzzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 739); 

                auto tg_xzzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 740); 

                auto tg_xzzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 741); 

                auto tg_xzzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 742); 

                auto tg_xzzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 743); 

                auto tg_xzzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 744); 

                auto tg_xzzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 745); 

                auto tg_xzzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 746); 

                auto tg_xzzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 747); 

                auto tg_xzzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 748); 

                auto tg_xzzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 749); 

                auto tg_xzzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 750); 

                auto tg_xzzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 751); 

                auto tg_xzzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 752); 

                auto tg_xzzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 753); 

                auto tg_xzzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 754); 

                auto tg_xzzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 755); 

                auto tg_yyyyyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 756); 

                auto tg_yyyyyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 757); 

                auto tg_yyyyyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 758); 

                auto tg_yyyyyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 759); 

                auto tg_yyyyyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 760); 

                auto tg_yyyyyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 761); 

                auto tg_yyyyyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 762); 

                auto tg_yyyyyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 763); 

                auto tg_yyyyyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 764); 

                auto tg_yyyyyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 765); 

                auto tg_yyyyyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 766); 

                auto tg_yyyyyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 767); 

                auto tg_yyyyyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 768); 

                auto tg_yyyyyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 769); 

                auto tg_yyyyyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 770); 

                auto tg_yyyyyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 771); 

                auto tg_yyyyyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 772); 

                auto tg_yyyyyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 773); 

                auto tg_yyyyyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 774); 

                auto tg_yyyyyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 775); 

                auto tg_yyyyyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 776); 

                auto tg_yyyyyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 777); 

                auto tg_yyyyyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 778); 

                auto tg_yyyyyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 779); 

                auto tg_yyyyyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 780); 

                auto tg_yyyyyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 781); 

                auto tg_yyyyyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 782); 

                auto tg_yyyyyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 783); 

                auto tg_yyyyyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 784); 

                auto tg_yyyyyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 785); 

                auto tg_yyyyyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 786); 

                auto tg_yyyyyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 787); 

                auto tg_yyyyyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 788); 

                auto tg_yyyyyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 789); 

                auto tg_yyyyyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 790); 

                auto tg_yyyyyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 791); 

                auto tg_yyyyyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 792); 

                auto tg_yyyyyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 793); 

                auto tg_yyyyyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 794); 

                auto tg_yyyyyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 795); 

                auto tg_yyyyyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 796); 

                auto tg_yyyyyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 797); 

                auto tg_yyyyyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 798); 

                auto tg_yyyyyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 799); 

                auto tg_xyzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 700); 

                auto tg_xyzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 701); 

                auto tg_xyzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 702); 

                auto tg_xyzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 703); 

                auto tg_xyzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 704); 

                auto tg_xyzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 705); 

                auto tg_xyzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 706); 

                auto tg_xyzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 707); 

                auto tg_xyzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 708); 

                auto tg_xyzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 709); 

                auto tg_xyzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 710); 

                auto tg_xyzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 711); 

                auto tg_xyzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 712); 

                auto tg_xyzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 713); 

                auto tg_xyzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 714); 

                auto tg_xyzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 715); 

                auto tg_xyzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 716); 

                auto tg_xyzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 717); 

                auto tg_xyzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 718); 

                auto tg_xyzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 719); 

                auto tg_xzzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 720); 

                auto tg_xzzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 721); 

                auto tg_xzzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 722); 

                auto tg_xzzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 723); 

                auto tg_xzzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 724); 

                auto tg_xzzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 725); 

                auto tg_xzzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 726); 

                auto tg_xzzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 727); 

                auto tg_xzzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 728); 

                auto tg_xzzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 729); 

                auto tg_xzzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 730); 

                auto tg_xzzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 731); 

                auto tg_xzzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 732); 

                auto tg_xzzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 733); 

                auto tg_xzzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 734); 

                auto tg_xzzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 735); 

                auto tg_xzzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 736); 

                auto tg_xzzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 737); 

                auto tg_xzzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 738); 

                auto tg_xzzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 739); 

                auto tg_xzzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 740); 

                auto tg_xzzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 741); 

                auto tg_xzzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 742); 

                auto tg_xzzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 743); 

                auto tg_xzzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 744); 

                auto tg_xzzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 745); 

                auto tg_xzzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 746); 

                auto tg_xzzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 747); 

                auto tg_xzzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 748); 

                auto tg_xzzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 749); 

                auto tg_xzzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 750); 

                auto tg_xzzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 751); 

                auto tg_xzzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 752); 

                auto tg_xzzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 753); 

                auto tg_xzzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 754); 

                auto tg_xzzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 755); 

                auto tg_yyyyyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 756); 

                auto tg_yyyyyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 757); 

                auto tg_yyyyyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 758); 

                auto tg_yyyyyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 759); 

                auto tg_yyyyyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 760); 

                auto tg_yyyyyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 761); 

                auto tg_yyyyyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 762); 

                auto tg_yyyyyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 763); 

                auto tg_yyyyyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 764); 

                auto tg_yyyyyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 765); 

                auto tg_yyyyyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 766); 

                auto tg_yyyyyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 767); 

                auto tg_yyyyyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 768); 

                auto tg_yyyyyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 769); 

                auto tg_yyyyyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 770); 

                auto tg_yyyyyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 771); 

                auto tg_yyyyyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 772); 

                auto tg_yyyyyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 773); 

                auto tg_yyyyyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 774); 

                auto tg_yyyyyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 775); 

                auto tg_yyyyyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 776); 

                auto tg_yyyyyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 777); 

                auto tg_yyyyyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 778); 

                auto tg_yyyyyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 779); 

                auto tg_yyyyyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 780); 

                auto tg_yyyyyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 781); 

                auto tg_yyyyyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 782); 

                auto tg_yyyyyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 783); 

                auto tg_yyyyyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 784); 

                auto tg_yyyyyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 785); 

                auto tg_yyyyyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 786); 

                auto tg_yyyyyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 787); 

                auto tg_yyyyyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 788); 

                auto tg_yyyyyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 789); 

                auto tg_yyyyyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 790); 

                auto tg_yyyyyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 791); 

                auto tg_yyyyyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 792); 

                auto tg_yyyyyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 793); 

                auto tg_yyyyyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 794); 

                auto tg_yyyyyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 795); 

                auto tg_yyyyyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 796); 

                auto tg_yyyyyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 797); 

                auto tg_yyyyyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 798); 

                auto tg_yyyyyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 799); 

                auto tg_yzzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 701); 

                auto tg_yzzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 714); 

                auto tg_yzzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 755); 

                auto tg_yzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 701); 

                auto tg_yzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 714); 

                auto tg_yzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 755); 

                auto tg_xyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 548); 

                auto tg_xyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 549); 

                auto tg_xyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 550); 

                auto tg_xyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 551); 

                auto tg_xyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 552); 

                auto tg_xyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 553); 

                auto tg_xyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 554); 

                auto tg_xyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 555); 

                auto tg_xyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 556); 

                auto tg_xyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 557); 

                auto tg_xyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 558); 

                auto tg_xyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 559); 

                auto tg_xzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 560); 

                auto tg_xzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 561); 

                auto tg_xzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 562); 

                auto tg_xzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 563); 

                auto tg_xzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 564); 

                auto tg_xzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 565); 

                auto tg_xzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 566); 

                auto tg_xzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 567); 

                auto tg_xzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 568); 

                auto tg_xzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 569); 

                auto tg_xzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 570); 

                auto tg_xzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 571); 

                auto tg_xzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 572); 

                auto tg_xzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 573); 

                auto tg_xzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 574); 

                auto tg_xzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 575); 

                auto tg_xzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 576); 

                auto tg_xzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 577); 

                auto tg_xzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 578); 

                auto tg_xzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 579); 

                auto tg_xzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 580); 

                auto tg_xzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 581); 

                auto tg_xzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 582); 

                auto tg_xzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 583); 

                auto tg_xzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 584); 

                auto tg_xzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 585); 

                auto tg_xzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 586); 

                auto tg_xzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 587); 

                auto tg_yyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 623); 

                // set up pointers to integrals

                auto tg_xxyzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 700); 

                auto tg_xxyzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 701); 

                auto tg_xxyzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 702); 

                auto tg_xxyzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 703); 

                auto tg_xxyzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 704); 

                auto tg_xxyzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 705); 

                auto tg_xxyzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 706); 

                auto tg_xxyzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 707); 

                auto tg_xxyzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 708); 

                auto tg_xxyzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 709); 

                auto tg_xxyzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 710); 

                auto tg_xxyzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 711); 

                auto tg_xxyzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 712); 

                auto tg_xxyzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 713); 

                auto tg_xxyzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 714); 

                auto tg_xxyzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 715); 

                auto tg_xxyzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 716); 

                auto tg_xxyzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 717); 

                auto tg_xxyzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 718); 

                auto tg_xxyzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 719); 

                auto tg_xxzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 720); 

                auto tg_xxzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 721); 

                auto tg_xxzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 722); 

                auto tg_xxzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 723); 

                auto tg_xxzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 724); 

                auto tg_xxzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 725); 

                auto tg_xxzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 726); 

                auto tg_xxzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 727); 

                auto tg_xxzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 728); 

                auto tg_xxzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 729); 

                auto tg_xxzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 730); 

                auto tg_xxzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 731); 

                auto tg_xxzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 732); 

                auto tg_xxzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 733); 

                auto tg_xxzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 734); 

                auto tg_xxzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 735); 

                auto tg_xxzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 736); 

                auto tg_xxzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 737); 

                auto tg_xxzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 738); 

                auto tg_xxzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 739); 

                auto tg_xxzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 740); 

                auto tg_xxzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 741); 

                auto tg_xxzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 742); 

                auto tg_xxzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 743); 

                auto tg_xxzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 744); 

                auto tg_xxzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 745); 

                auto tg_xxzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 746); 

                auto tg_xxzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 747); 

                auto tg_xxzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 748); 

                auto tg_xxzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 749); 

                auto tg_xxzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 750); 

                auto tg_xxzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 751); 

                auto tg_xxzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 752); 

                auto tg_xxzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 753); 

                auto tg_xxzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 754); 

                auto tg_xxzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 755); 

                auto tg_xyyyyyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 756); 

                auto tg_xyyyyyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 757); 

                auto tg_xyyyyyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 758); 

                auto tg_xyyyyyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 759); 

                auto tg_xyyyyyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 760); 

                auto tg_xyyyyyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 761); 

                auto tg_xyyyyyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 762); 

                auto tg_xyyyyyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 763); 

                auto tg_xyyyyyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 764); 

                auto tg_xyyyyyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 765); 

                auto tg_xyyyyyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 766); 

                auto tg_xyyyyyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 767); 

                auto tg_xyyyyyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 768); 

                auto tg_xyyyyyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 769); 

                auto tg_xyyyyyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 770); 

                auto tg_xyyyyyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 771); 

                auto tg_xyyyyyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 772); 

                auto tg_xyyyyyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 773); 

                auto tg_xyyyyyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 774); 

                auto tg_xyyyyyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 775); 

                auto tg_xyyyyyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 776); 

                auto tg_xyyyyyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 777); 

                auto tg_xyyyyyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 778); 

                auto tg_xyyyyyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 779); 

                auto tg_xyyyyyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 780); 

                auto tg_xyyyyyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 781); 

                auto tg_xyyyyyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 782); 

                auto tg_xyyyyyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 783); 

                auto tg_xyyyyyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 784); 

                auto tg_xyyyyyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 785); 

                auto tg_xyyyyyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 786); 

                auto tg_xyyyyyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 787); 

                auto tg_xyyyyyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 788); 

                auto tg_xyyyyyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 789); 

                auto tg_xyyyyyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 790); 

                auto tg_xyyyyyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 791); 

                auto tg_xyyyyyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 792); 

                auto tg_xyyyyyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 793); 

                auto tg_xyyyyyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 794); 

                auto tg_xyyyyyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 795); 

                auto tg_xyyyyyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 796); 

                auto tg_xyyyyyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 797); 

                auto tg_xyyyyyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 798); 

                auto tg_xyyyyyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 799); 

                // Batch of Integrals (700,800)

                #pragma omp simd aligned(fxn, fza, tg_xxyzzzz_xxyyyyz_0, tg_xxyzzzz_xxyyyzz_0, \
                                         tg_xxyzzzz_xxyyzzz_0, tg_xxyzzzz_xxyzzzz_0, tg_xxyzzzz_xxzzzzz_0, tg_xxyzzzz_xyyyyyy_0, \
                                         tg_xxyzzzz_xyyyyyz_0, tg_xxyzzzz_xyyyyzz_0, tg_xxyzzzz_xyyyzzz_0, tg_xxyzzzz_xyyzzzz_0, \
                                         tg_xxyzzzz_xyzzzzz_0, tg_xxyzzzz_xzzzzzz_0, tg_xxyzzzz_yyyyyyy_0, tg_xxyzzzz_yyyyyyz_0, \
                                         tg_xxyzzzz_yyyyyzz_0, tg_xxyzzzz_yyyyzzz_0, tg_xxyzzzz_yyyzzzz_0, tg_xxyzzzz_yyzzzzz_0, \
                                         tg_xxyzzzz_yzzzzzz_0, tg_xxyzzzz_zzzzzzz_0, tg_xxzzzzz_xxxxxxx_0, tg_xxzzzzz_xxxxxxy_0, \
                                         tg_xxzzzzz_xxxxxxz_0, tg_xxzzzzz_xxxxxyy_0, tg_xxzzzzz_xxxxxyz_0, tg_xxzzzzz_xxxxxzz_0, \
                                         tg_xxzzzzz_xxxxyyy_0, tg_xxzzzzz_xxxxyyz_0, tg_xxzzzzz_xxxxyzz_0, tg_xxzzzzz_xxxxzzz_0, \
                                         tg_xxzzzzz_xxxyyyy_0, tg_xxzzzzz_xxxyyyz_0, tg_xxzzzzz_xxxyyzz_0, tg_xxzzzzz_xxxyzzz_0, \
                                         tg_xxzzzzz_xxxzzzz_0, tg_xxzzzzz_xxyyyyy_0, tg_xxzzzzz_xxyyyyz_0, tg_xxzzzzz_xxyyyzz_0, \
                                         tg_xxzzzzz_xxyyzzz_0, tg_xxzzzzz_xxyzzzz_0, tg_xxzzzzz_xxzzzzz_0, tg_xxzzzzz_xyyyyyy_0, \
                                         tg_xxzzzzz_xyyyyyz_0, tg_xxzzzzz_xyyyyzz_0, tg_xxzzzzz_xyyyzzz_0, tg_xxzzzzz_xyyzzzz_0, \
                                         tg_xxzzzzz_xyzzzzz_0, tg_xxzzzzz_xzzzzzz_0, tg_xxzzzzz_yyyyyyy_0, tg_xxzzzzz_yyyyyyz_0, \
                                         tg_xxzzzzz_yyyyyzz_0, tg_xxzzzzz_yyyyzzz_0, tg_xxzzzzz_yyyzzzz_0, tg_xxzzzzz_yyzzzzz_0, \
                                         tg_xxzzzzz_yzzzzzz_0, tg_xxzzzzz_zzzzzzz_0, tg_xyyyyyy_xxxxxxx_0, tg_xyyyyyy_xxxxxxy_0, \
                                         tg_xyyyyyy_xxxxxxz_0, tg_xyyyyyy_xxxxxyy_0, tg_xyyyyyy_xxxxxyz_0, tg_xyyyyyy_xxxxxzz_0, \
                                         tg_xyyyyyy_xxxxyyy_0, tg_xyyyyyy_xxxxyyz_0, tg_xyyyyyy_xxxxyzz_0, tg_xyyyyyy_xxxxzzz_0, \
                                         tg_xyyyyyy_xxxyyyy_0, tg_xyyyyyy_xxxyyyz_0, tg_xyyyyyy_xxxyyzz_0, tg_xyyyyyy_xxxyzzz_0, \
                                         tg_xyyyyyy_xxxzzzz_0, tg_xyyyyyy_xxyyyyy_0, tg_xyyyyyy_xxyyyyz_0, tg_xyyyyyy_xxyyyzz_0, \
                                         tg_xyyyyyy_xxyyzzz_0, tg_xyyyyyy_xxyzzzz_0, tg_xyyyyyy_xxzzzzz_0, tg_xyyyyyy_xyyyyyy_0, \
                                         tg_xyyyyyy_xyyyyyz_0, tg_xyyyyyy_xyyyyzz_0, tg_xyyyyyy_xyyyzzz_0, tg_xyyyyyy_xyyzzzz_0, \
                                         tg_xyyyyyy_xyzzzzz_0, tg_xyyyyyy_xzzzzzz_0, tg_xyyyyyy_yyyyyyy_0, tg_xyyyyyy_yyyyyyz_0, \
                                         tg_xyyyyyy_yyyyyzz_0, tg_xyyyyyy_yyyyzzz_0, tg_xyyyyyy_yyyzzzz_0, tg_xyyyyyy_yyzzzzz_0, \
                                         tg_xyyyyyy_yzzzzzz_0, tg_xyyyyyy_zzzzzzz_0, tg_xyyyyyz_xxxxxxx_0, tg_xyyyyyz_xxxxxxy_0, \
                                         tg_xyyyyyz_xxxxxxz_0, tg_xyyyyyz_xxxxxyy_0, tg_xyyyyyz_xxxxxyz_0, tg_xyyyyyz_xxxxxzz_0, \
                                         tg_xyyyyyz_xxxxyyy_0, tg_xyyyyyz_xxxxyyz_0, tg_xyzzzz_xxyyyyz_0, tg_xyzzzz_xxyyyyz_1, \
                                         tg_xyzzzz_xxyyyzz_0, tg_xyzzzz_xxyyyzz_1, tg_xyzzzz_xxyyzzz_0, tg_xyzzzz_xxyyzzz_1, \
                                         tg_xyzzzz_xxyzzzz_0, tg_xyzzzz_xxyzzzz_1, tg_xyzzzz_xxzzzzz_0, tg_xyzzzz_xxzzzzz_1, \
                                         tg_xyzzzz_xyyyyyy_0, tg_xyzzzz_xyyyyyy_1, tg_xyzzzz_xyyyyyz_0, tg_xyzzzz_xyyyyyz_1, \
                                         tg_xyzzzz_xyyyyz_1, tg_xyzzzz_xyyyyzz_0, tg_xyzzzz_xyyyyzz_1, tg_xyzzzz_xyyyzz_1, \
                                         tg_xyzzzz_xyyyzzz_0, tg_xyzzzz_xyyyzzz_1, tg_xyzzzz_xyyzzz_1, tg_xyzzzz_xyyzzzz_0, \
                                         tg_xyzzzz_xyyzzzz_1, tg_xyzzzz_xyzzzz_1, tg_xyzzzz_xyzzzzz_0, tg_xyzzzz_xyzzzzz_1, \
                                         tg_xyzzzz_xzzzzz_1, tg_xyzzzz_xzzzzzz_0, tg_xyzzzz_xzzzzzz_1, tg_xyzzzz_yyyyyy_1, \
                                         tg_xyzzzz_yyyyyyy_0, tg_xyzzzz_yyyyyyy_1, tg_xyzzzz_yyyyyyz_0, tg_xyzzzz_yyyyyyz_1, \
                                         tg_xyzzzz_yyyyyz_1, tg_xyzzzz_yyyyyzz_0, tg_xyzzzz_yyyyyzz_1, tg_xyzzzz_yyyyzz_1, \
                                         tg_xyzzzz_yyyyzzz_0, tg_xyzzzz_yyyyzzz_1, tg_xyzzzz_yyyzzz_1, tg_xyzzzz_yyyzzzz_0, \
                                         tg_xyzzzz_yyyzzzz_1, tg_xyzzzz_yyzzzz_1, tg_xyzzzz_yyzzzzz_0, tg_xyzzzz_yyzzzzz_1, \
                                         tg_xyzzzz_yzzzzz_1, tg_xyzzzz_yzzzzzz_0, tg_xyzzzz_yzzzzzz_1, tg_xyzzzz_zzzzzz_1, \
                                         tg_xyzzzz_zzzzzzz_0, tg_xyzzzz_zzzzzzz_1, tg_xzzzzz_xxxxxx_1, tg_xzzzzz_xxxxxxx_0, \
                                         tg_xzzzzz_xxxxxxx_1, tg_xzzzzz_xxxxxxy_0, tg_xzzzzz_xxxxxxy_1, tg_xzzzzz_xxxxxxz_0, \
                                         tg_xzzzzz_xxxxxxz_1, tg_xzzzzz_xxxxxy_1, tg_xzzzzz_xxxxxyy_0, tg_xzzzzz_xxxxxyy_1, \
                                         tg_xzzzzz_xxxxxyz_0, tg_xzzzzz_xxxxxyz_1, tg_xzzzzz_xxxxxz_1, tg_xzzzzz_xxxxxzz_0, \
                                         tg_xzzzzz_xxxxxzz_1, tg_xzzzzz_xxxxyy_1, tg_xzzzzz_xxxxyyy_0, tg_xzzzzz_xxxxyyy_1, \
                                         tg_xzzzzz_xxxxyyz_0, tg_xzzzzz_xxxxyyz_1, tg_xzzzzz_xxxxyz_1, tg_xzzzzz_xxxxyzz_0, \
                                         tg_xzzzzz_xxxxyzz_1, tg_xzzzzz_xxxxzz_1, tg_xzzzzz_xxxxzzz_0, tg_xzzzzz_xxxxzzz_1, \
                                         tg_xzzzzz_xxxyyy_1, tg_xzzzzz_xxxyyyy_0, tg_xzzzzz_xxxyyyy_1, tg_xzzzzz_xxxyyyz_0, \
                                         tg_xzzzzz_xxxyyyz_1, tg_xzzzzz_xxxyyz_1, tg_xzzzzz_xxxyyzz_0, tg_xzzzzz_xxxyyzz_1, \
                                         tg_xzzzzz_xxxyzz_1, tg_xzzzzz_xxxyzzz_0, tg_xzzzzz_xxxyzzz_1, tg_xzzzzz_xxxzzz_1, \
                                         tg_xzzzzz_xxxzzzz_0, tg_xzzzzz_xxxzzzz_1, tg_xzzzzz_xxyyyy_1, tg_xzzzzz_xxyyyyy_0, \
                                         tg_xzzzzz_xxyyyyy_1, tg_xzzzzz_xxyyyyz_0, tg_xzzzzz_xxyyyyz_1, tg_xzzzzz_xxyyyz_1, \
                                         tg_xzzzzz_xxyyyzz_0, tg_xzzzzz_xxyyyzz_1, tg_xzzzzz_xxyyzz_1, tg_xzzzzz_xxyyzzz_0, \
                                         tg_xzzzzz_xxyyzzz_1, tg_xzzzzz_xxyzzz_1, tg_xzzzzz_xxyzzzz_0, tg_xzzzzz_xxyzzzz_1, \
                                         tg_xzzzzz_xxzzzz_1, tg_xzzzzz_xxzzzzz_0, tg_xzzzzz_xxzzzzz_1, tg_xzzzzz_xyyyyy_1, \
                                         tg_xzzzzz_xyyyyyy_0, tg_xzzzzz_xyyyyyy_1, tg_xzzzzz_xyyyyyz_0, tg_xzzzzz_xyyyyyz_1, \
                                         tg_xzzzzz_xyyyyz_1, tg_xzzzzz_xyyyyzz_0, tg_xzzzzz_xyyyyzz_1, tg_xzzzzz_xyyyzz_1, \
                                         tg_xzzzzz_xyyyzzz_0, tg_xzzzzz_xyyyzzz_1, tg_xzzzzz_xyyzzz_1, tg_xzzzzz_xyyzzzz_0, \
                                         tg_xzzzzz_xyyzzzz_1, tg_xzzzzz_xyzzzz_1, tg_xzzzzz_xyzzzzz_0, tg_xzzzzz_xyzzzzz_1, \
                                         tg_xzzzzz_xzzzzz_1, tg_xzzzzz_xzzzzzz_0, tg_xzzzzz_xzzzzzz_1, tg_xzzzzz_yyyyyy_1, \
                                         tg_xzzzzz_yyyyyyy_0, tg_xzzzzz_yyyyyyy_1, tg_xzzzzz_yyyyyyz_0, tg_xzzzzz_yyyyyyz_1, \
                                         tg_xzzzzz_yyyyyz_1, tg_xzzzzz_yyyyyzz_0, tg_xzzzzz_yyyyyzz_1, tg_xzzzzz_yyyyzz_1, \
                                         tg_xzzzzz_yyyyzzz_0, tg_xzzzzz_yyyyzzz_1, tg_xzzzzz_yyyzzz_1, tg_xzzzzz_yyyzzzz_0, \
                                         tg_xzzzzz_yyyzzzz_1, tg_xzzzzz_yyzzzz_1, tg_xzzzzz_yyzzzzz_0, tg_xzzzzz_yyzzzzz_1, \
                                         tg_xzzzzz_yzzzzz_1, tg_xzzzzz_yzzzzzz_0, tg_xzzzzz_yzzzzzz_1, tg_xzzzzz_zzzzzz_1, \
                                         tg_xzzzzz_zzzzzzz_0, tg_xzzzzz_zzzzzzz_1, tg_yyyyyy_xxxxxx_1, tg_yyyyyy_xxxxxxx_0, \
                                         tg_yyyyyy_xxxxxxx_1, tg_yyyyyy_xxxxxxy_0, tg_yyyyyy_xxxxxxy_1, tg_yyyyyy_xxxxxxz_0, \
                                         tg_yyyyyy_xxxxxxz_1, tg_yyyyyy_xxxxxy_1, tg_yyyyyy_xxxxxyy_0, tg_yyyyyy_xxxxxyy_1, \
                                         tg_yyyyyy_xxxxxyz_0, tg_yyyyyy_xxxxxyz_1, tg_yyyyyy_xxxxxz_1, tg_yyyyyy_xxxxxzz_0, \
                                         tg_yyyyyy_xxxxxzz_1, tg_yyyyyy_xxxxyy_1, tg_yyyyyy_xxxxyyy_0, tg_yyyyyy_xxxxyyy_1, \
                                         tg_yyyyyy_xxxxyyz_0, tg_yyyyyy_xxxxyyz_1, tg_yyyyyy_xxxxyz_1, tg_yyyyyy_xxxxyzz_0, \
                                         tg_yyyyyy_xxxxyzz_1, tg_yyyyyy_xxxxzz_1, tg_yyyyyy_xxxxzzz_0, tg_yyyyyy_xxxxzzz_1, \
                                         tg_yyyyyy_xxxyyy_1, tg_yyyyyy_xxxyyyy_0, tg_yyyyyy_xxxyyyy_1, tg_yyyyyy_xxxyyyz_0, \
                                         tg_yyyyyy_xxxyyyz_1, tg_yyyyyy_xxxyyz_1, tg_yyyyyy_xxxyyzz_0, tg_yyyyyy_xxxyyzz_1, \
                                         tg_yyyyyy_xxxyzz_1, tg_yyyyyy_xxxyzzz_0, tg_yyyyyy_xxxyzzz_1, tg_yyyyyy_xxxzzz_1, \
                                         tg_yyyyyy_xxxzzzz_0, tg_yyyyyy_xxxzzzz_1, tg_yyyyyy_xxyyyy_1, tg_yyyyyy_xxyyyyy_0, \
                                         tg_yyyyyy_xxyyyyy_1, tg_yyyyyy_xxyyyyz_0, tg_yyyyyy_xxyyyyz_1, tg_yyyyyy_xxyyyz_1, \
                                         tg_yyyyyy_xxyyyzz_0, tg_yyyyyy_xxyyyzz_1, tg_yyyyyy_xxyyzz_1, tg_yyyyyy_xxyyzzz_0, \
                                         tg_yyyyyy_xxyyzzz_1, tg_yyyyyy_xxyzzz_1, tg_yyyyyy_xxyzzzz_0, tg_yyyyyy_xxyzzzz_1, \
                                         tg_yyyyyy_xxzzzz_1, tg_yyyyyy_xxzzzzz_0, tg_yyyyyy_xxzzzzz_1, tg_yyyyyy_xyyyyy_1, \
                                         tg_yyyyyy_xyyyyyy_0, tg_yyyyyy_xyyyyyy_1, tg_yyyyyy_xyyyyyz_0, tg_yyyyyy_xyyyyyz_1, \
                                         tg_yyyyyy_xyyyyz_1, tg_yyyyyy_xyyyyzz_0, tg_yyyyyy_xyyyyzz_1, tg_yyyyyy_xyyyzz_1, \
                                         tg_yyyyyy_xyyyzzz_0, tg_yyyyyy_xyyyzzz_1, tg_yyyyyy_xyyzzz_1, tg_yyyyyy_xyyzzzz_0, \
                                         tg_yyyyyy_xyyzzzz_1, tg_yyyyyy_xyzzzz_1, tg_yyyyyy_xyzzzzz_0, tg_yyyyyy_xyzzzzz_1, \
                                         tg_yyyyyy_xzzzzz_1, tg_yyyyyy_xzzzzzz_0, tg_yyyyyy_xzzzzzz_1, tg_yyyyyy_yyyyyy_1, \
                                         tg_yyyyyy_yyyyyyy_0, tg_yyyyyy_yyyyyyy_1, tg_yyyyyy_yyyyyyz_0, tg_yyyyyy_yyyyyyz_1, \
                                         tg_yyyyyy_yyyyyz_1, tg_yyyyyy_yyyyyzz_0, tg_yyyyyy_yyyyyzz_1, tg_yyyyyy_yyyyzz_1, \
                                         tg_yyyyyy_yyyyzzz_0, tg_yyyyyy_yyyyzzz_1, tg_yyyyyy_yyyzzz_1, tg_yyyyyy_yyyzzzz_0, \
                                         tg_yyyyyy_yyyzzzz_1, tg_yyyyyy_yyzzzz_1, tg_yyyyyy_yyzzzzz_0, tg_yyyyyy_yyzzzzz_1, \
                                         tg_yyyyyy_yzzzzz_1, tg_yyyyyy_yzzzzzz_0, tg_yyyyyy_yzzzzzz_1, tg_yyyyyy_zzzzzz_1, \
                                         tg_yyyyyy_zzzzzzz_0, tg_yyyyyy_zzzzzzz_1, tg_yyyyyz_xxxxxx_1, tg_yyyyyz_xxxxxxx_0, \
                                         tg_yyyyyz_xxxxxxx_1, tg_yyyyyz_xxxxxxy_0, tg_yyyyyz_xxxxxxy_1, tg_yyyyyz_xxxxxxz_0, \
                                         tg_yyyyyz_xxxxxxz_1, tg_yyyyyz_xxxxxy_1, tg_yyyyyz_xxxxxyy_0, tg_yyyyyz_xxxxxyy_1, \
                                         tg_yyyyyz_xxxxxyz_0, tg_yyyyyz_xxxxxyz_1, tg_yyyyyz_xxxxxz_1, tg_yyyyyz_xxxxxzz_0, \
                                         tg_yyyyyz_xxxxxzz_1, tg_yyyyyz_xxxxyy_1, tg_yyyyyz_xxxxyyy_0, tg_yyyyyz_xxxxyyy_1, \
                                         tg_yyyyyz_xxxxyyz_0, tg_yyyyyz_xxxxyyz_1, tg_yyyyyz_xxxxyz_1, tg_yyyyyz_xxxxzz_1, \
                                         tg_yyyyyz_xxxyyy_1, tg_yyyyyz_xxxyyz_1, tg_yzzzz_xxyyyyz_0, tg_yzzzz_xxyyyyz_1, \
                                         tg_yzzzz_xxyyyzz_0, tg_yzzzz_xxyyyzz_1, tg_yzzzz_xxyyzzz_0, tg_yzzzz_xxyyzzz_1, \
                                         tg_yzzzz_xxyzzzz_0, tg_yzzzz_xxyzzzz_1, tg_yzzzz_xxzzzzz_0, tg_yzzzz_xxzzzzz_1, \
                                         tg_yzzzz_xyyyyyy_0, tg_yzzzz_xyyyyyy_1, tg_yzzzz_xyyyyyz_0, tg_yzzzz_xyyyyyz_1, \
                                         tg_yzzzz_xyyyyzz_0, tg_yzzzz_xyyyyzz_1, tg_yzzzz_xyyyzzz_0, tg_yzzzz_xyyyzzz_1, \
                                         tg_yzzzz_xyyzzzz_0, tg_yzzzz_xyyzzzz_1, tg_yzzzz_xyzzzzz_0, tg_yzzzz_xyzzzzz_1, \
                                         tg_yzzzz_xzzzzzz_0, tg_yzzzz_xzzzzzz_1, tg_yzzzz_yyyyyyy_0, tg_yzzzz_yyyyyyy_1, \
                                         tg_yzzzz_yyyyyyz_0, tg_yzzzz_yyyyyyz_1, tg_yzzzz_yyyyyzz_0, tg_yzzzz_yyyyyzz_1, \
                                         tg_yzzzz_yyyyzzz_0, tg_yzzzz_yyyyzzz_1, tg_yzzzz_yyyzzzz_0, tg_yzzzz_yyyzzzz_1, \
                                         tg_yzzzz_yyzzzzz_0, tg_yzzzz_yyzzzzz_1, tg_yzzzz_yzzzzzz_0, tg_yzzzz_yzzzzzz_1, \
                                         tg_yzzzz_zzzzzzz_0, tg_yzzzz_zzzzzzz_1, tg_zzzzz_xxxxxxx_0, tg_zzzzz_xxxxxxx_1, \
                                         tg_zzzzz_xxxxxxy_0, tg_zzzzz_xxxxxxy_1, tg_zzzzz_xxxxxxz_0, tg_zzzzz_xxxxxxz_1, \
                                         tg_zzzzz_xxxxxyy_0, tg_zzzzz_xxxxxyy_1, tg_zzzzz_xxxxxyz_0, tg_zzzzz_xxxxxyz_1, \
                                         tg_zzzzz_xxxxxzz_0, tg_zzzzz_xxxxxzz_1, tg_zzzzz_xxxxyyy_0, tg_zzzzz_xxxxyyy_1, \
                                         tg_zzzzz_xxxxyyz_0, tg_zzzzz_xxxxyyz_1, tg_zzzzz_xxxxyzz_0, tg_zzzzz_xxxxyzz_1, \
                                         tg_zzzzz_xxxxzzz_0, tg_zzzzz_xxxxzzz_1, tg_zzzzz_xxxyyyy_0, tg_zzzzz_xxxyyyy_1, \
                                         tg_zzzzz_xxxyyyz_0, tg_zzzzz_xxxyyyz_1, tg_zzzzz_xxxyyzz_0, tg_zzzzz_xxxyyzz_1, \
                                         tg_zzzzz_xxxyzzz_0, tg_zzzzz_xxxyzzz_1, tg_zzzzz_xxxzzzz_0, tg_zzzzz_xxxzzzz_1, \
                                         tg_zzzzz_xxyyyyy_0, tg_zzzzz_xxyyyyy_1, tg_zzzzz_xxyyyyz_0, tg_zzzzz_xxyyyyz_1, \
                                         tg_zzzzz_xxyyyzz_0, tg_zzzzz_xxyyyzz_1, tg_zzzzz_xxyyzzz_0, tg_zzzzz_xxyyzzz_1, \
                                         tg_zzzzz_xxyzzzz_0, tg_zzzzz_xxyzzzz_1, tg_zzzzz_xxzzzzz_0, tg_zzzzz_xxzzzzz_1, \
                                         tg_zzzzz_xyyyyyy_0, tg_zzzzz_xyyyyyy_1, tg_zzzzz_xyyyyyz_0, tg_zzzzz_xyyyyyz_1, \
                                         tg_zzzzz_xyyyyzz_0, tg_zzzzz_xyyyyzz_1, tg_zzzzz_xyyyzzz_0, tg_zzzzz_xyyyzzz_1, \
                                         tg_zzzzz_xyyzzzz_0, tg_zzzzz_xyyzzzz_1, tg_zzzzz_xyzzzzz_0, tg_zzzzz_xyzzzzz_1, \
                                         tg_zzzzz_xzzzzzz_0, tg_zzzzz_xzzzzzz_1, tg_zzzzz_yyyyyyy_0, tg_zzzzz_yyyyyyy_1, \
                                         tg_zzzzz_yyyyyyz_0, tg_zzzzz_yyyyyyz_1, tg_zzzzz_yyyyyzz_0, tg_zzzzz_yyyyyzz_1, \
                                         tg_zzzzz_yyyyzzz_0, tg_zzzzz_yyyyzzz_1, tg_zzzzz_yyyzzzz_0, tg_zzzzz_yyyzzzz_1, \
                                         tg_zzzzz_yyzzzzz_0, tg_zzzzz_yyzzzzz_1, tg_zzzzz_yzzzzzz_0, tg_zzzzz_yzzzzzz_1, \
                                         tg_zzzzz_zzzzzzz_0, tg_zzzzz_zzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxyzzzz_xxyyyyz_0[j] = pb_x * tg_xyzzzz_xxyyyyz_0[j] + fr * tg_xyzzzz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxyyyyz_0[j] - tg_yzzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xyyyyz_1[j];

                    tg_xxyzzzz_xxyyyzz_0[j] = pb_x * tg_xyzzzz_xxyyyzz_0[j] + fr * tg_xyzzzz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxyyyzz_0[j] - tg_yzzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xyyyzz_1[j];

                    tg_xxyzzzz_xxyyzzz_0[j] = pb_x * tg_xyzzzz_xxyyzzz_0[j] + fr * tg_xyzzzz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxyyzzz_0[j] - tg_yzzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xyyzzz_1[j];

                    tg_xxyzzzz_xxyzzzz_0[j] = pb_x * tg_xyzzzz_xxyzzzz_0[j] + fr * tg_xyzzzz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxyzzzz_0[j] - tg_yzzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xyzzzz_1[j];

                    tg_xxyzzzz_xxzzzzz_0[j] = pb_x * tg_xyzzzz_xxzzzzz_0[j] + fr * tg_xyzzzz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xxzzzzz_0[j] - tg_yzzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzz_xzzzzz_1[j];

                    tg_xxyzzzz_xyyyyyy_0[j] = pb_x * tg_xyzzzz_xyyyyyy_0[j] + fr * tg_xyzzzz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyyyyyy_0[j] - tg_yzzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yyyyyy_1[j];

                    tg_xxyzzzz_xyyyyyz_0[j] = pb_x * tg_xyzzzz_xyyyyyz_0[j] + fr * tg_xyzzzz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyyyyyz_0[j] - tg_yzzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yyyyyz_1[j];

                    tg_xxyzzzz_xyyyyzz_0[j] = pb_x * tg_xyzzzz_xyyyyzz_0[j] + fr * tg_xyzzzz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyyyyzz_0[j] - tg_yzzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yyyyzz_1[j];

                    tg_xxyzzzz_xyyyzzz_0[j] = pb_x * tg_xyzzzz_xyyyzzz_0[j] + fr * tg_xyzzzz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyyyzzz_0[j] - tg_yzzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yyyzzz_1[j];

                    tg_xxyzzzz_xyyzzzz_0[j] = pb_x * tg_xyzzzz_xyyzzzz_0[j] + fr * tg_xyzzzz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyyzzzz_0[j] - tg_yzzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yyzzzz_1[j];

                    tg_xxyzzzz_xyzzzzz_0[j] = pb_x * tg_xyzzzz_xyzzzzz_0[j] + fr * tg_xyzzzz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xyzzzzz_0[j] - tg_yzzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_yzzzzz_1[j];

                    tg_xxyzzzz_xzzzzzz_0[j] = pb_x * tg_xyzzzz_xzzzzzz_0[j] + fr * tg_xyzzzz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_xzzzzzz_0[j] - tg_yzzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzz_zzzzzz_1[j];

                    tg_xxyzzzz_yyyyyyy_0[j] = pb_x * tg_xyzzzz_yyyyyyy_0[j] + fr * tg_xyzzzz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyyyyyy_0[j] - tg_yzzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxyzzzz_yyyyyyz_0[j] = pb_x * tg_xyzzzz_yyyyyyz_0[j] + fr * tg_xyzzzz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyyyyyz_0[j] - tg_yzzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxyzzzz_yyyyyzz_0[j] = pb_x * tg_xyzzzz_yyyyyzz_0[j] + fr * tg_xyzzzz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyyyyzz_0[j] - tg_yzzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxyzzzz_yyyyzzz_0[j] = pb_x * tg_xyzzzz_yyyyzzz_0[j] + fr * tg_xyzzzz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyyyzzz_0[j] - tg_yzzzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxyzzzz_yyyzzzz_0[j] = pb_x * tg_xyzzzz_yyyzzzz_0[j] + fr * tg_xyzzzz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyyzzzz_0[j] - tg_yzzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxyzzzz_yyzzzzz_0[j] = pb_x * tg_xyzzzz_yyzzzzz_0[j] + fr * tg_xyzzzz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yyzzzzz_0[j] - tg_yzzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxyzzzz_yzzzzzz_0[j] = pb_x * tg_xyzzzz_yzzzzzz_0[j] + fr * tg_xyzzzz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_yzzzzzz_0[j] - tg_yzzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxyzzzz_zzzzzzz_0[j] = pb_x * tg_xyzzzz_zzzzzzz_0[j] + fr * tg_xyzzzz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzz_zzzzzzz_0[j] - tg_yzzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xxzzzzz_xxxxxxx_0[j] = pb_x * tg_xzzzzz_xxxxxxx_0[j] + fr * tg_xzzzzz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxx_0[j] - tg_zzzzz_xxxxxxx_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_xzzzzz_xxxxxx_1[j];

                    tg_xxzzzzz_xxxxxxy_0[j] = pb_x * tg_xzzzzz_xxxxxxy_0[j] + fr * tg_xzzzzz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxy_0[j] - tg_zzzzz_xxxxxxy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzzz_xxxxxy_1[j];

                    tg_xxzzzzz_xxxxxxz_0[j] = pb_x * tg_xzzzzz_xxxxxxz_0[j] + fr * tg_xzzzzz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxz_0[j] - tg_zzzzz_xxxxxxz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzzz_xxxxxz_1[j];

                    tg_xxzzzzz_xxxxxyy_0[j] = pb_x * tg_xzzzzz_xxxxxyy_0[j] + fr * tg_xzzzzz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxyy_0[j] - tg_zzzzz_xxxxxyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzzz_xxxxyy_1[j];

                    tg_xxzzzzz_xxxxxyz_0[j] = pb_x * tg_xzzzzz_xxxxxyz_0[j] + fr * tg_xzzzzz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxyz_0[j] - tg_zzzzz_xxxxxyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzzz_xxxxyz_1[j];

                    tg_xxzzzzz_xxxxxzz_0[j] = pb_x * tg_xzzzzz_xxxxxzz_0[j] + fr * tg_xzzzzz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxzz_0[j] - tg_zzzzz_xxxxxzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzzz_xxxxzz_1[j];

                    tg_xxzzzzz_xxxxyyy_0[j] = pb_x * tg_xzzzzz_xxxxyyy_0[j] + fr * tg_xzzzzz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyyy_0[j] - tg_zzzzz_xxxxyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzz_xxxyyy_1[j];

                    tg_xxzzzzz_xxxxyyz_0[j] = pb_x * tg_xzzzzz_xxxxyyz_0[j] + fr * tg_xzzzzz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyyz_0[j] - tg_zzzzz_xxxxyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzz_xxxyyz_1[j];

                    tg_xxzzzzz_xxxxyzz_0[j] = pb_x * tg_xzzzzz_xxxxyzz_0[j] + fr * tg_xzzzzz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyzz_0[j] - tg_zzzzz_xxxxyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzz_xxxyzz_1[j];

                    tg_xxzzzzz_xxxxzzz_0[j] = pb_x * tg_xzzzzz_xxxxzzz_0[j] + fr * tg_xzzzzz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxzzz_0[j] - tg_zzzzz_xxxxzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzz_xxxzzz_1[j];

                    tg_xxzzzzz_xxxyyyy_0[j] = pb_x * tg_xzzzzz_xxxyyyy_0[j] + fr * tg_xzzzzz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyyy_0[j] - tg_zzzzz_xxxyyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzz_xxyyyy_1[j];

                    tg_xxzzzzz_xxxyyyz_0[j] = pb_x * tg_xzzzzz_xxxyyyz_0[j] + fr * tg_xzzzzz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyyz_0[j] - tg_zzzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzz_xxyyyz_1[j];

                    tg_xxzzzzz_xxxyyzz_0[j] = pb_x * tg_xzzzzz_xxxyyzz_0[j] + fr * tg_xzzzzz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyzz_0[j] - tg_zzzzz_xxxyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzz_xxyyzz_1[j];

                    tg_xxzzzzz_xxxyzzz_0[j] = pb_x * tg_xzzzzz_xxxyzzz_0[j] + fr * tg_xzzzzz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyzzz_0[j] - tg_zzzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzz_xxyzzz_1[j];

                    tg_xxzzzzz_xxxzzzz_0[j] = pb_x * tg_xzzzzz_xxxzzzz_0[j] + fr * tg_xzzzzz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxzzzz_0[j] - tg_zzzzz_xxxzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzz_xxzzzz_1[j];

                    tg_xxzzzzz_xxyyyyy_0[j] = pb_x * tg_xzzzzz_xxyyyyy_0[j] + fr * tg_xzzzzz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyyy_0[j] - tg_zzzzz_xxyyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xyyyyy_1[j];

                    tg_xxzzzzz_xxyyyyz_0[j] = pb_x * tg_xzzzzz_xxyyyyz_0[j] + fr * tg_xzzzzz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyyz_0[j] - tg_zzzzz_xxyyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xyyyyz_1[j];

                    tg_xxzzzzz_xxyyyzz_0[j] = pb_x * tg_xzzzzz_xxyyyzz_0[j] + fr * tg_xzzzzz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyzz_0[j] - tg_zzzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xyyyzz_1[j];

                    tg_xxzzzzz_xxyyzzz_0[j] = pb_x * tg_xzzzzz_xxyyzzz_0[j] + fr * tg_xzzzzz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyzzz_0[j] - tg_zzzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xyyzzz_1[j];

                    tg_xxzzzzz_xxyzzzz_0[j] = pb_x * tg_xzzzzz_xxyzzzz_0[j] + fr * tg_xzzzzz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyzzzz_0[j] - tg_zzzzz_xxyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xyzzzz_1[j];

                    tg_xxzzzzz_xxzzzzz_0[j] = pb_x * tg_xzzzzz_xxzzzzz_0[j] + fr * tg_xzzzzz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxzzzzz_0[j] - tg_zzzzz_xxzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzz_xzzzzz_1[j];

                    tg_xxzzzzz_xyyyyyy_0[j] = pb_x * tg_xzzzzz_xyyyyyy_0[j] + fr * tg_xzzzzz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyyy_0[j] - tg_zzzzz_xyyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yyyyyy_1[j];

                    tg_xxzzzzz_xyyyyyz_0[j] = pb_x * tg_xzzzzz_xyyyyyz_0[j] + fr * tg_xzzzzz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyyz_0[j] - tg_zzzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yyyyyz_1[j];

                    tg_xxzzzzz_xyyyyzz_0[j] = pb_x * tg_xzzzzz_xyyyyzz_0[j] + fr * tg_xzzzzz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyzz_0[j] - tg_zzzzz_xyyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yyyyzz_1[j];

                    tg_xxzzzzz_xyyyzzz_0[j] = pb_x * tg_xzzzzz_xyyyzzz_0[j] + fr * tg_xzzzzz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyzzz_0[j] - tg_zzzzz_xyyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yyyzzz_1[j];

                    tg_xxzzzzz_xyyzzzz_0[j] = pb_x * tg_xzzzzz_xyyzzzz_0[j] + fr * tg_xzzzzz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyzzzz_0[j] - tg_zzzzz_xyyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yyzzzz_1[j];

                    tg_xxzzzzz_xyzzzzz_0[j] = pb_x * tg_xzzzzz_xyzzzzz_0[j] + fr * tg_xzzzzz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyzzzzz_0[j] - tg_zzzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_yzzzzz_1[j];

                    tg_xxzzzzz_xzzzzzz_0[j] = pb_x * tg_xzzzzz_xzzzzzz_0[j] + fr * tg_xzzzzz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xzzzzzz_0[j] - tg_zzzzz_xzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzz_zzzzzz_1[j];

                    tg_xxzzzzz_yyyyyyy_0[j] = pb_x * tg_xzzzzz_yyyyyyy_0[j] + fr * tg_xzzzzz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyyy_0[j] - tg_zzzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_xxzzzzz_yyyyyyz_0[j] = pb_x * tg_xzzzzz_yyyyyyz_0[j] + fr * tg_xzzzzz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyyz_0[j] - tg_zzzzz_yyyyyyz_1[j] * fl1_fza);

                    tg_xxzzzzz_yyyyyzz_0[j] = pb_x * tg_xzzzzz_yyyyyzz_0[j] + fr * tg_xzzzzz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyzz_0[j] - tg_zzzzz_yyyyyzz_1[j] * fl1_fza);

                    tg_xxzzzzz_yyyyzzz_0[j] = pb_x * tg_xzzzzz_yyyyzzz_0[j] + fr * tg_xzzzzz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyzzz_0[j] - tg_zzzzz_yyyyzzz_1[j] * fl1_fza);

                    tg_xxzzzzz_yyyzzzz_0[j] = pb_x * tg_xzzzzz_yyyzzzz_0[j] + fr * tg_xzzzzz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyzzzz_0[j] - tg_zzzzz_yyyzzzz_1[j] * fl1_fza);

                    tg_xxzzzzz_yyzzzzz_0[j] = pb_x * tg_xzzzzz_yyzzzzz_0[j] + fr * tg_xzzzzz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyzzzzz_0[j] - tg_zzzzz_yyzzzzz_1[j] * fl1_fza);

                    tg_xxzzzzz_yzzzzzz_0[j] = pb_x * tg_xzzzzz_yzzzzzz_0[j] + fr * tg_xzzzzz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yzzzzzz_0[j] - tg_zzzzz_yzzzzzz_1[j] * fl1_fza);

                    tg_xxzzzzz_zzzzzzz_0[j] = pb_x * tg_xzzzzz_zzzzzzz_0[j] + fr * tg_xzzzzz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_zzzzzzz_0[j] - tg_zzzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_xyyyyyy_xxxxxxx_0[j] = pb_x * tg_yyyyyy_xxxxxxx_0[j] + fr * tg_yyyyyy_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yyyyyy_xxxxxx_1[j];

                    tg_xyyyyyy_xxxxxxy_0[j] = pb_x * tg_yyyyyy_xxxxxxy_0[j] + fr * tg_yyyyyy_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yyyyyy_xxxxxy_1[j];

                    tg_xyyyyyy_xxxxxxz_0[j] = pb_x * tg_yyyyyy_xxxxxxz_0[j] + fr * tg_yyyyyy_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yyyyyy_xxxxxz_1[j];

                    tg_xyyyyyy_xxxxxyy_0[j] = pb_x * tg_yyyyyy_xxxxxyy_0[j] + fr * tg_yyyyyy_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yyyyyy_xxxxyy_1[j];

                    tg_xyyyyyy_xxxxxyz_0[j] = pb_x * tg_yyyyyy_xxxxxyz_0[j] + fr * tg_yyyyyy_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yyyyyy_xxxxyz_1[j];

                    tg_xyyyyyy_xxxxxzz_0[j] = pb_x * tg_yyyyyy_xxxxxzz_0[j] + fr * tg_yyyyyy_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yyyyyy_xxxxzz_1[j];

                    tg_xyyyyyy_xxxxyyy_0[j] = pb_x * tg_yyyyyy_xxxxyyy_0[j] + fr * tg_yyyyyy_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yyyyyy_xxxyyy_1[j];

                    tg_xyyyyyy_xxxxyyz_0[j] = pb_x * tg_yyyyyy_xxxxyyz_0[j] + fr * tg_yyyyyy_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yyyyyy_xxxyyz_1[j];

                    tg_xyyyyyy_xxxxyzz_0[j] = pb_x * tg_yyyyyy_xxxxyzz_0[j] + fr * tg_yyyyyy_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyy_xxxyzz_1[j];

                    tg_xyyyyyy_xxxxzzz_0[j] = pb_x * tg_yyyyyy_xxxxzzz_0[j] + fr * tg_yyyyyy_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyy_xxxzzz_1[j];

                    tg_xyyyyyy_xxxyyyy_0[j] = pb_x * tg_yyyyyy_xxxyyyy_0[j] + fr * tg_yyyyyy_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyyy_xxyyyy_1[j];

                    tg_xyyyyyy_xxxyyyz_0[j] = pb_x * tg_yyyyyy_xxxyyyz_0[j] + fr * tg_yyyyyy_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyyy_xxyyyz_1[j];

                    tg_xyyyyyy_xxxyyzz_0[j] = pb_x * tg_yyyyyy_xxxyyzz_0[j] + fr * tg_yyyyyy_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyy_xxyyzz_1[j];

                    tg_xyyyyyy_xxxyzzz_0[j] = pb_x * tg_yyyyyy_xxxyzzz_0[j] + fr * tg_yyyyyy_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyy_xxyzzz_1[j];

                    tg_xyyyyyy_xxxzzzz_0[j] = pb_x * tg_yyyyyy_xxxzzzz_0[j] + fr * tg_yyyyyy_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyy_xxzzzz_1[j];

                    tg_xyyyyyy_xxyyyyy_0[j] = pb_x * tg_yyyyyy_xxyyyyy_0[j] + fr * tg_yyyyyy_xxyyyyy_1[j] + fl1_fxn * tg_yyyyyy_xyyyyy_1[j];

                    tg_xyyyyyy_xxyyyyz_0[j] = pb_x * tg_yyyyyy_xxyyyyz_0[j] + fr * tg_yyyyyy_xxyyyyz_1[j] + fl1_fxn * tg_yyyyyy_xyyyyz_1[j];

                    tg_xyyyyyy_xxyyyzz_0[j] = pb_x * tg_yyyyyy_xxyyyzz_0[j] + fr * tg_yyyyyy_xxyyyzz_1[j] + fl1_fxn * tg_yyyyyy_xyyyzz_1[j];

                    tg_xyyyyyy_xxyyzzz_0[j] = pb_x * tg_yyyyyy_xxyyzzz_0[j] + fr * tg_yyyyyy_xxyyzzz_1[j] + fl1_fxn * tg_yyyyyy_xyyzzz_1[j];

                    tg_xyyyyyy_xxyzzzz_0[j] = pb_x * tg_yyyyyy_xxyzzzz_0[j] + fr * tg_yyyyyy_xxyzzzz_1[j] + fl1_fxn * tg_yyyyyy_xyzzzz_1[j];

                    tg_xyyyyyy_xxzzzzz_0[j] = pb_x * tg_yyyyyy_xxzzzzz_0[j] + fr * tg_yyyyyy_xxzzzzz_1[j] + fl1_fxn * tg_yyyyyy_xzzzzz_1[j];

                    tg_xyyyyyy_xyyyyyy_0[j] = pb_x * tg_yyyyyy_xyyyyyy_0[j] + fr * tg_yyyyyy_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yyyyyy_1[j];

                    tg_xyyyyyy_xyyyyyz_0[j] = pb_x * tg_yyyyyy_xyyyyyz_0[j] + fr * tg_yyyyyy_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yyyyyz_1[j];

                    tg_xyyyyyy_xyyyyzz_0[j] = pb_x * tg_yyyyyy_xyyyyzz_0[j] + fr * tg_yyyyyy_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yyyyzz_1[j];

                    tg_xyyyyyy_xyyyzzz_0[j] = pb_x * tg_yyyyyy_xyyyzzz_0[j] + fr * tg_yyyyyy_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yyyzzz_1[j];

                    tg_xyyyyyy_xyyzzzz_0[j] = pb_x * tg_yyyyyy_xyyzzzz_0[j] + fr * tg_yyyyyy_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yyzzzz_1[j];

                    tg_xyyyyyy_xyzzzzz_0[j] = pb_x * tg_yyyyyy_xyzzzzz_0[j] + fr * tg_yyyyyy_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_yzzzzz_1[j];

                    tg_xyyyyyy_xzzzzzz_0[j] = pb_x * tg_yyyyyy_xzzzzzz_0[j] + fr * tg_yyyyyy_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyy_zzzzzz_1[j];

                    tg_xyyyyyy_yyyyyyy_0[j] = pb_x * tg_yyyyyy_yyyyyyy_0[j] + fr * tg_yyyyyy_yyyyyyy_1[j];

                    tg_xyyyyyy_yyyyyyz_0[j] = pb_x * tg_yyyyyy_yyyyyyz_0[j] + fr * tg_yyyyyy_yyyyyyz_1[j];

                    tg_xyyyyyy_yyyyyzz_0[j] = pb_x * tg_yyyyyy_yyyyyzz_0[j] + fr * tg_yyyyyy_yyyyyzz_1[j];

                    tg_xyyyyyy_yyyyzzz_0[j] = pb_x * tg_yyyyyy_yyyyzzz_0[j] + fr * tg_yyyyyy_yyyyzzz_1[j];

                    tg_xyyyyyy_yyyzzzz_0[j] = pb_x * tg_yyyyyy_yyyzzzz_0[j] + fr * tg_yyyyyy_yyyzzzz_1[j];

                    tg_xyyyyyy_yyzzzzz_0[j] = pb_x * tg_yyyyyy_yyzzzzz_0[j] + fr * tg_yyyyyy_yyzzzzz_1[j];

                    tg_xyyyyyy_yzzzzzz_0[j] = pb_x * tg_yyyyyy_yzzzzzz_0[j] + fr * tg_yyyyyy_yzzzzzz_1[j];

                    tg_xyyyyyy_zzzzzzz_0[j] = pb_x * tg_yyyyyy_zzzzzzz_0[j] + fr * tg_yyyyyy_zzzzzzz_1[j];

                    tg_xyyyyyz_xxxxxxx_0[j] = pb_x * tg_yyyyyz_xxxxxxx_0[j] + fr * tg_yyyyyz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yyyyyz_xxxxxx_1[j];

                    tg_xyyyyyz_xxxxxxy_0[j] = pb_x * tg_yyyyyz_xxxxxxy_0[j] + fr * tg_yyyyyz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yyyyyz_xxxxxy_1[j];

                    tg_xyyyyyz_xxxxxxz_0[j] = pb_x * tg_yyyyyz_xxxxxxz_0[j] + fr * tg_yyyyyz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yyyyyz_xxxxxz_1[j];

                    tg_xyyyyyz_xxxxxyy_0[j] = pb_x * tg_yyyyyz_xxxxxyy_0[j] + fr * tg_yyyyyz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yyyyyz_xxxxyy_1[j];

                    tg_xyyyyyz_xxxxxyz_0[j] = pb_x * tg_yyyyyz_xxxxxyz_0[j] + fr * tg_yyyyyz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yyyyyz_xxxxyz_1[j];

                    tg_xyyyyyz_xxxxxzz_0[j] = pb_x * tg_yyyyyz_xxxxxzz_0[j] + fr * tg_yyyyyz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yyyyyz_xxxxzz_1[j];

                    tg_xyyyyyz_xxxxyyy_0[j] = pb_x * tg_yyyyyz_xxxxyyy_0[j] + fr * tg_yyyyyz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yyyyyz_xxxyyy_1[j];

                    tg_xyyyyyz_xxxxyyz_0[j] = pb_x * tg_yyyyyz_xxxxyyz_0[j] + fr * tg_yyyyyz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yyyyyz_xxxyyz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_800_900(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (800,900)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_yyyyyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 800); 

                auto tg_yyyyyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 801); 

                auto tg_yyyyyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 802); 

                auto tg_yyyyyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 803); 

                auto tg_yyyyyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 804); 

                auto tg_yyyyyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 805); 

                auto tg_yyyyyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 806); 

                auto tg_yyyyyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 807); 

                auto tg_yyyyyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 808); 

                auto tg_yyyyyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 809); 

                auto tg_yyyyyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 810); 

                auto tg_yyyyyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 811); 

                auto tg_yyyyyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 812); 

                auto tg_yyyyyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 813); 

                auto tg_yyyyyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 814); 

                auto tg_yyyyyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 815); 

                auto tg_yyyyyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 816); 

                auto tg_yyyyyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 817); 

                auto tg_yyyyyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 818); 

                auto tg_yyyyyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 819); 

                auto tg_yyyyyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 820); 

                auto tg_yyyyyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 821); 

                auto tg_yyyyyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 822); 

                auto tg_yyyyyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 823); 

                auto tg_yyyyyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 824); 

                auto tg_yyyyyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 825); 

                auto tg_yyyyyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 826); 

                auto tg_yyyyyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 827); 

                auto tg_yyyyzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 828); 

                auto tg_yyyyzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 829); 

                auto tg_yyyyzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 830); 

                auto tg_yyyyzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 831); 

                auto tg_yyyyzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 832); 

                auto tg_yyyyzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 833); 

                auto tg_yyyyzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 834); 

                auto tg_yyyyzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 835); 

                auto tg_yyyyzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 836); 

                auto tg_yyyyzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 837); 

                auto tg_yyyyzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 838); 

                auto tg_yyyyzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 839); 

                auto tg_yyyyzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 840); 

                auto tg_yyyyzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 841); 

                auto tg_yyyyzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 842); 

                auto tg_yyyyzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 843); 

                auto tg_yyyyzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 844); 

                auto tg_yyyyzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 845); 

                auto tg_yyyyzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 846); 

                auto tg_yyyyzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 847); 

                auto tg_yyyyzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 848); 

                auto tg_yyyyzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 849); 

                auto tg_yyyyzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 850); 

                auto tg_yyyyzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 851); 

                auto tg_yyyyzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 852); 

                auto tg_yyyyzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 853); 

                auto tg_yyyyzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 854); 

                auto tg_yyyyzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 855); 

                auto tg_yyyyzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 856); 

                auto tg_yyyyzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 857); 

                auto tg_yyyyzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 858); 

                auto tg_yyyyzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 859); 

                auto tg_yyyyzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 860); 

                auto tg_yyyyzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 861); 

                auto tg_yyyyzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 862); 

                auto tg_yyyyzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 863); 

                auto tg_yyyzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 864); 

                auto tg_yyyzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 865); 

                auto tg_yyyzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 866); 

                auto tg_yyyzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 867); 

                auto tg_yyyzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 868); 

                auto tg_yyyzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 869); 

                auto tg_yyyzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 870); 

                auto tg_yyyzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 871); 

                auto tg_yyyzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 872); 

                auto tg_yyyzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 873); 

                auto tg_yyyzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 874); 

                auto tg_yyyzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 875); 

                auto tg_yyyzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 876); 

                auto tg_yyyzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 877); 

                auto tg_yyyzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 878); 

                auto tg_yyyzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 879); 

                auto tg_yyyzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 880); 

                auto tg_yyyzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 881); 

                auto tg_yyyzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 882); 

                auto tg_yyyzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 883); 

                auto tg_yyyzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 884); 

                auto tg_yyyzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 885); 

                auto tg_yyyzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 886); 

                auto tg_yyyzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 887); 

                auto tg_yyyzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 888); 

                auto tg_yyyzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 889); 

                auto tg_yyyzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 890); 

                auto tg_yyyzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 891); 

                auto tg_yyyzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 892); 

                auto tg_yyyzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 893); 

                auto tg_yyyzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 894); 

                auto tg_yyyzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 895); 

                auto tg_yyyzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 896); 

                auto tg_yyyzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 897); 

                auto tg_yyyzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 898); 

                auto tg_yyyzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 899); 

                auto tg_yyyyyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 800); 

                auto tg_yyyyyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 801); 

                auto tg_yyyyyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 802); 

                auto tg_yyyyyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 803); 

                auto tg_yyyyyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 804); 

                auto tg_yyyyyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 805); 

                auto tg_yyyyyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 806); 

                auto tg_yyyyyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 807); 

                auto tg_yyyyyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 808); 

                auto tg_yyyyyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 809); 

                auto tg_yyyyyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 810); 

                auto tg_yyyyyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 811); 

                auto tg_yyyyyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 812); 

                auto tg_yyyyyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 813); 

                auto tg_yyyyyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 814); 

                auto tg_yyyyyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 815); 

                auto tg_yyyyyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 816); 

                auto tg_yyyyyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 817); 

                auto tg_yyyyyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 818); 

                auto tg_yyyyyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 819); 

                auto tg_yyyyyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 820); 

                auto tg_yyyyyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 821); 

                auto tg_yyyyyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 822); 

                auto tg_yyyyyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 823); 

                auto tg_yyyyyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 824); 

                auto tg_yyyyyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 825); 

                auto tg_yyyyyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 826); 

                auto tg_yyyyyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 827); 

                auto tg_yyyyzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 828); 

                auto tg_yyyyzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 829); 

                auto tg_yyyyzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 830); 

                auto tg_yyyyzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 831); 

                auto tg_yyyyzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 832); 

                auto tg_yyyyzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 833); 

                auto tg_yyyyzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 834); 

                auto tg_yyyyzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 835); 

                auto tg_yyyyzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 836); 

                auto tg_yyyyzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 837); 

                auto tg_yyyyzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 838); 

                auto tg_yyyyzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 839); 

                auto tg_yyyyzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 840); 

                auto tg_yyyyzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 841); 

                auto tg_yyyyzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 842); 

                auto tg_yyyyzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 843); 

                auto tg_yyyyzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 844); 

                auto tg_yyyyzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 845); 

                auto tg_yyyyzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 846); 

                auto tg_yyyyzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 847); 

                auto tg_yyyyzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 848); 

                auto tg_yyyyzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 849); 

                auto tg_yyyyzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 850); 

                auto tg_yyyyzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 851); 

                auto tg_yyyyzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 852); 

                auto tg_yyyyzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 853); 

                auto tg_yyyyzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 854); 

                auto tg_yyyyzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 855); 

                auto tg_yyyyzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 856); 

                auto tg_yyyyzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 857); 

                auto tg_yyyyzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 858); 

                auto tg_yyyyzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 859); 

                auto tg_yyyyzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 860); 

                auto tg_yyyyzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 861); 

                auto tg_yyyyzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 862); 

                auto tg_yyyyzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 863); 

                auto tg_yyyzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 864); 

                auto tg_yyyzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 865); 

                auto tg_yyyzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 866); 

                auto tg_yyyzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 867); 

                auto tg_yyyzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 868); 

                auto tg_yyyzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 869); 

                auto tg_yyyzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 870); 

                auto tg_yyyzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 871); 

                auto tg_yyyzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 872); 

                auto tg_yyyzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 873); 

                auto tg_yyyzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 874); 

                auto tg_yyyzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 875); 

                auto tg_yyyzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 876); 

                auto tg_yyyzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 877); 

                auto tg_yyyzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 878); 

                auto tg_yyyzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 879); 

                auto tg_yyyzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 880); 

                auto tg_yyyzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 881); 

                auto tg_yyyzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 882); 

                auto tg_yyyzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 883); 

                auto tg_yyyzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 884); 

                auto tg_yyyzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 885); 

                auto tg_yyyzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 886); 

                auto tg_yyyzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 887); 

                auto tg_yyyzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 888); 

                auto tg_yyyzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 889); 

                auto tg_yyyzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 890); 

                auto tg_yyyzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 891); 

                auto tg_yyyzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 892); 

                auto tg_yyyzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 893); 

                auto tg_yyyzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 894); 

                auto tg_yyyzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 895); 

                auto tg_yyyzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 896); 

                auto tg_yyyzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 897); 

                auto tg_yyyzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 898); 

                auto tg_yyyzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 899); 

                auto tg_yyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 646); 

                auto tg_yyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 656); 

                auto tg_yyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 678); 

                auto tg_yyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 699); 

                // set up pointers to integrals

                auto tg_xyyyyyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 800); 

                auto tg_xyyyyyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 801); 

                auto tg_xyyyyyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 802); 

                auto tg_xyyyyyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 803); 

                auto tg_xyyyyyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 804); 

                auto tg_xyyyyyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 805); 

                auto tg_xyyyyyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 806); 

                auto tg_xyyyyyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 807); 

                auto tg_xyyyyyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 808); 

                auto tg_xyyyyyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 809); 

                auto tg_xyyyyyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 810); 

                auto tg_xyyyyyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 811); 

                auto tg_xyyyyyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 812); 

                auto tg_xyyyyyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 813); 

                auto tg_xyyyyyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 814); 

                auto tg_xyyyyyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 815); 

                auto tg_xyyyyyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 816); 

                auto tg_xyyyyyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 817); 

                auto tg_xyyyyyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 818); 

                auto tg_xyyyyyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 819); 

                auto tg_xyyyyyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 820); 

                auto tg_xyyyyyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 821); 

                auto tg_xyyyyyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 822); 

                auto tg_xyyyyyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 823); 

                auto tg_xyyyyyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 824); 

                auto tg_xyyyyyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 825); 

                auto tg_xyyyyyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 826); 

                auto tg_xyyyyyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 827); 

                auto tg_xyyyyzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 828); 

                auto tg_xyyyyzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 829); 

                auto tg_xyyyyzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 830); 

                auto tg_xyyyyzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 831); 

                auto tg_xyyyyzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 832); 

                auto tg_xyyyyzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 833); 

                auto tg_xyyyyzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 834); 

                auto tg_xyyyyzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 835); 

                auto tg_xyyyyzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 836); 

                auto tg_xyyyyzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 837); 

                auto tg_xyyyyzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 838); 

                auto tg_xyyyyzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 839); 

                auto tg_xyyyyzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 840); 

                auto tg_xyyyyzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 841); 

                auto tg_xyyyyzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 842); 

                auto tg_xyyyyzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 843); 

                auto tg_xyyyyzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 844); 

                auto tg_xyyyyzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 845); 

                auto tg_xyyyyzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 846); 

                auto tg_xyyyyzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 847); 

                auto tg_xyyyyzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 848); 

                auto tg_xyyyyzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 849); 

                auto tg_xyyyyzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 850); 

                auto tg_xyyyyzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 851); 

                auto tg_xyyyyzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 852); 

                auto tg_xyyyyzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 853); 

                auto tg_xyyyyzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 854); 

                auto tg_xyyyyzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 855); 

                auto tg_xyyyyzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 856); 

                auto tg_xyyyyzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 857); 

                auto tg_xyyyyzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 858); 

                auto tg_xyyyyzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 859); 

                auto tg_xyyyyzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 860); 

                auto tg_xyyyyzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 861); 

                auto tg_xyyyyzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 862); 

                auto tg_xyyyyzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 863); 

                auto tg_xyyyzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 864); 

                auto tg_xyyyzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 865); 

                auto tg_xyyyzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 866); 

                auto tg_xyyyzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 867); 

                auto tg_xyyyzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 868); 

                auto tg_xyyyzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 869); 

                auto tg_xyyyzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 870); 

                auto tg_xyyyzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 871); 

                auto tg_xyyyzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 872); 

                auto tg_xyyyzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 873); 

                auto tg_xyyyzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 874); 

                auto tg_xyyyzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 875); 

                auto tg_xyyyzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 876); 

                auto tg_xyyyzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 877); 

                auto tg_xyyyzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 878); 

                auto tg_xyyyzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 879); 

                auto tg_xyyyzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 880); 

                auto tg_xyyyzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 881); 

                auto tg_xyyyzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 882); 

                auto tg_xyyyzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 883); 

                auto tg_xyyyzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 884); 

                auto tg_xyyyzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 885); 

                auto tg_xyyyzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 886); 

                auto tg_xyyyzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 887); 

                auto tg_xyyyzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 888); 

                auto tg_xyyyzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 889); 

                auto tg_xyyyzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 890); 

                auto tg_xyyyzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 891); 

                auto tg_xyyyzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 892); 

                auto tg_xyyyzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 893); 

                auto tg_xyyyzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 894); 

                auto tg_xyyyzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 895); 

                auto tg_xyyyzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 896); 

                auto tg_xyyyzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 897); 

                auto tg_xyyyzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 898); 

                auto tg_xyyyzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 899); 

                // Batch of Integrals (800,900)

                #pragma omp simd aligned(fxn, tg_xyyyyyz_xxxxyzz_0, tg_xyyyyyz_xxxxzzz_0, \
                                         tg_xyyyyyz_xxxyyyy_0, tg_xyyyyyz_xxxyyyz_0, tg_xyyyyyz_xxxyyzz_0, tg_xyyyyyz_xxxyzzz_0, \
                                         tg_xyyyyyz_xxxzzzz_0, tg_xyyyyyz_xxyyyyy_0, tg_xyyyyyz_xxyyyyz_0, tg_xyyyyyz_xxyyyzz_0, \
                                         tg_xyyyyyz_xxyyzzz_0, tg_xyyyyyz_xxyzzzz_0, tg_xyyyyyz_xxzzzzz_0, tg_xyyyyyz_xyyyyyy_0, \
                                         tg_xyyyyyz_xyyyyyz_0, tg_xyyyyyz_xyyyyzz_0, tg_xyyyyyz_xyyyzzz_0, tg_xyyyyyz_xyyzzzz_0, \
                                         tg_xyyyyyz_xyzzzzz_0, tg_xyyyyyz_xzzzzzz_0, tg_xyyyyyz_yyyyyyy_0, tg_xyyyyyz_yyyyyyz_0, \
                                         tg_xyyyyyz_yyyyyzz_0, tg_xyyyyyz_yyyyzzz_0, tg_xyyyyyz_yyyzzzz_0, tg_xyyyyyz_yyzzzzz_0, \
                                         tg_xyyyyyz_yzzzzzz_0, tg_xyyyyyz_zzzzzzz_0, tg_xyyyyzz_xxxxxxx_0, tg_xyyyyzz_xxxxxxy_0, \
                                         tg_xyyyyzz_xxxxxxz_0, tg_xyyyyzz_xxxxxyy_0, tg_xyyyyzz_xxxxxyz_0, tg_xyyyyzz_xxxxxzz_0, \
                                         tg_xyyyyzz_xxxxyyy_0, tg_xyyyyzz_xxxxyyz_0, tg_xyyyyzz_xxxxyzz_0, tg_xyyyyzz_xxxxzzz_0, \
                                         tg_xyyyyzz_xxxyyyy_0, tg_xyyyyzz_xxxyyyz_0, tg_xyyyyzz_xxxyyzz_0, tg_xyyyyzz_xxxyzzz_0, \
                                         tg_xyyyyzz_xxxzzzz_0, tg_xyyyyzz_xxyyyyy_0, tg_xyyyyzz_xxyyyyz_0, tg_xyyyyzz_xxyyyzz_0, \
                                         tg_xyyyyzz_xxyyzzz_0, tg_xyyyyzz_xxyzzzz_0, tg_xyyyyzz_xxzzzzz_0, tg_xyyyyzz_xyyyyyy_0, \
                                         tg_xyyyyzz_xyyyyyz_0, tg_xyyyyzz_xyyyyzz_0, tg_xyyyyzz_xyyyzzz_0, tg_xyyyyzz_xyyzzzz_0, \
                                         tg_xyyyyzz_xyzzzzz_0, tg_xyyyyzz_xzzzzzz_0, tg_xyyyyzz_yyyyyyy_0, tg_xyyyyzz_yyyyyyz_0, \
                                         tg_xyyyyzz_yyyyyzz_0, tg_xyyyyzz_yyyyzzz_0, tg_xyyyyzz_yyyzzzz_0, tg_xyyyyzz_yyzzzzz_0, \
                                         tg_xyyyyzz_yzzzzzz_0, tg_xyyyyzz_zzzzzzz_0, tg_xyyyzzz_xxxxxxx_0, tg_xyyyzzz_xxxxxxy_0, \
                                         tg_xyyyzzz_xxxxxxz_0, tg_xyyyzzz_xxxxxyy_0, tg_xyyyzzz_xxxxxyz_0, tg_xyyyzzz_xxxxxzz_0, \
                                         tg_xyyyzzz_xxxxyyy_0, tg_xyyyzzz_xxxxyyz_0, tg_xyyyzzz_xxxxyzz_0, tg_xyyyzzz_xxxxzzz_0, \
                                         tg_xyyyzzz_xxxyyyy_0, tg_xyyyzzz_xxxyyyz_0, tg_xyyyzzz_xxxyyzz_0, tg_xyyyzzz_xxxyzzz_0, \
                                         tg_xyyyzzz_xxxzzzz_0, tg_xyyyzzz_xxyyyyy_0, tg_xyyyzzz_xxyyyyz_0, tg_xyyyzzz_xxyyyzz_0, \
                                         tg_xyyyzzz_xxyyzzz_0, tg_xyyyzzz_xxyzzzz_0, tg_xyyyzzz_xxzzzzz_0, tg_xyyyzzz_xyyyyyy_0, \
                                         tg_xyyyzzz_xyyyyyz_0, tg_xyyyzzz_xyyyyzz_0, tg_xyyyzzz_xyyyzzz_0, tg_xyyyzzz_xyyzzzz_0, \
                                         tg_xyyyzzz_xyzzzzz_0, tg_xyyyzzz_xzzzzzz_0, tg_xyyyzzz_yyyyyyy_0, tg_xyyyzzz_yyyyyyz_0, \
                                         tg_xyyyzzz_yyyyyzz_0, tg_xyyyzzz_yyyyzzz_0, tg_xyyyzzz_yyyzzzz_0, tg_xyyyzzz_yyzzzzz_0, \
                                         tg_xyyyzzz_yzzzzzz_0, tg_xyyyzzz_zzzzzzz_0, tg_yyyyyz_xxxxyzz_0, tg_yyyyyz_xxxxyzz_1, \
                                         tg_yyyyyz_xxxxzzz_0, tg_yyyyyz_xxxxzzz_1, tg_yyyyyz_xxxyyyy_0, tg_yyyyyz_xxxyyyy_1, \
                                         tg_yyyyyz_xxxyyyz_0, tg_yyyyyz_xxxyyyz_1, tg_yyyyyz_xxxyyzz_0, tg_yyyyyz_xxxyyzz_1, \
                                         tg_yyyyyz_xxxyzz_1, tg_yyyyyz_xxxyzzz_0, tg_yyyyyz_xxxyzzz_1, tg_yyyyyz_xxxzzz_1, \
                                         tg_yyyyyz_xxxzzzz_0, tg_yyyyyz_xxxzzzz_1, tg_yyyyyz_xxyyyy_1, tg_yyyyyz_xxyyyyy_0, \
                                         tg_yyyyyz_xxyyyyy_1, tg_yyyyyz_xxyyyyz_0, tg_yyyyyz_xxyyyyz_1, tg_yyyyyz_xxyyyz_1, \
                                         tg_yyyyyz_xxyyyzz_0, tg_yyyyyz_xxyyyzz_1, tg_yyyyyz_xxyyzz_1, tg_yyyyyz_xxyyzzz_0, \
                                         tg_yyyyyz_xxyyzzz_1, tg_yyyyyz_xxyzzz_1, tg_yyyyyz_xxyzzzz_0, tg_yyyyyz_xxyzzzz_1, \
                                         tg_yyyyyz_xxzzzz_1, tg_yyyyyz_xxzzzzz_0, tg_yyyyyz_xxzzzzz_1, tg_yyyyyz_xyyyyy_1, \
                                         tg_yyyyyz_xyyyyyy_0, tg_yyyyyz_xyyyyyy_1, tg_yyyyyz_xyyyyyz_0, tg_yyyyyz_xyyyyyz_1, \
                                         tg_yyyyyz_xyyyyz_1, tg_yyyyyz_xyyyyzz_0, tg_yyyyyz_xyyyyzz_1, tg_yyyyyz_xyyyzz_1, \
                                         tg_yyyyyz_xyyyzzz_0, tg_yyyyyz_xyyyzzz_1, tg_yyyyyz_xyyzzz_1, tg_yyyyyz_xyyzzzz_0, \
                                         tg_yyyyyz_xyyzzzz_1, tg_yyyyyz_xyzzzz_1, tg_yyyyyz_xyzzzzz_0, tg_yyyyyz_xyzzzzz_1, \
                                         tg_yyyyyz_xzzzzz_1, tg_yyyyyz_xzzzzzz_0, tg_yyyyyz_xzzzzzz_1, tg_yyyyyz_yyyyyy_1, \
                                         tg_yyyyyz_yyyyyyy_0, tg_yyyyyz_yyyyyyy_1, tg_yyyyyz_yyyyyyz_0, tg_yyyyyz_yyyyyyz_1, \
                                         tg_yyyyyz_yyyyyz_1, tg_yyyyyz_yyyyyzz_0, tg_yyyyyz_yyyyyzz_1, tg_yyyyyz_yyyyzz_1, \
                                         tg_yyyyyz_yyyyzzz_0, tg_yyyyyz_yyyyzzz_1, tg_yyyyyz_yyyzzz_1, tg_yyyyyz_yyyzzzz_0, \
                                         tg_yyyyyz_yyyzzzz_1, tg_yyyyyz_yyzzzz_1, tg_yyyyyz_yyzzzzz_0, tg_yyyyyz_yyzzzzz_1, \
                                         tg_yyyyyz_yzzzzz_1, tg_yyyyyz_yzzzzzz_0, tg_yyyyyz_yzzzzzz_1, tg_yyyyyz_zzzzzz_1, \
                                         tg_yyyyyz_zzzzzzz_0, tg_yyyyyz_zzzzzzz_1, tg_yyyyzz_xxxxxx_1, tg_yyyyzz_xxxxxxx_0, \
                                         tg_yyyyzz_xxxxxxx_1, tg_yyyyzz_xxxxxxy_0, tg_yyyyzz_xxxxxxy_1, tg_yyyyzz_xxxxxxz_0, \
                                         tg_yyyyzz_xxxxxxz_1, tg_yyyyzz_xxxxxy_1, tg_yyyyzz_xxxxxyy_0, tg_yyyyzz_xxxxxyy_1, \
                                         tg_yyyyzz_xxxxxyz_0, tg_yyyyzz_xxxxxyz_1, tg_yyyyzz_xxxxxz_1, tg_yyyyzz_xxxxxzz_0, \
                                         tg_yyyyzz_xxxxxzz_1, tg_yyyyzz_xxxxyy_1, tg_yyyyzz_xxxxyyy_0, tg_yyyyzz_xxxxyyy_1, \
                                         tg_yyyyzz_xxxxyyz_0, tg_yyyyzz_xxxxyyz_1, tg_yyyyzz_xxxxyz_1, tg_yyyyzz_xxxxyzz_0, \
                                         tg_yyyyzz_xxxxyzz_1, tg_yyyyzz_xxxxzz_1, tg_yyyyzz_xxxxzzz_0, tg_yyyyzz_xxxxzzz_1, \
                                         tg_yyyyzz_xxxyyy_1, tg_yyyyzz_xxxyyyy_0, tg_yyyyzz_xxxyyyy_1, tg_yyyyzz_xxxyyyz_0, \
                                         tg_yyyyzz_xxxyyyz_1, tg_yyyyzz_xxxyyz_1, tg_yyyyzz_xxxyyzz_0, tg_yyyyzz_xxxyyzz_1, \
                                         tg_yyyyzz_xxxyzz_1, tg_yyyyzz_xxxyzzz_0, tg_yyyyzz_xxxyzzz_1, tg_yyyyzz_xxxzzz_1, \
                                         tg_yyyyzz_xxxzzzz_0, tg_yyyyzz_xxxzzzz_1, tg_yyyyzz_xxyyyy_1, tg_yyyyzz_xxyyyyy_0, \
                                         tg_yyyyzz_xxyyyyy_1, tg_yyyyzz_xxyyyyz_0, tg_yyyyzz_xxyyyyz_1, tg_yyyyzz_xxyyyz_1, \
                                         tg_yyyyzz_xxyyyzz_0, tg_yyyyzz_xxyyyzz_1, tg_yyyyzz_xxyyzz_1, tg_yyyyzz_xxyyzzz_0, \
                                         tg_yyyyzz_xxyyzzz_1, tg_yyyyzz_xxyzzz_1, tg_yyyyzz_xxyzzzz_0, tg_yyyyzz_xxyzzzz_1, \
                                         tg_yyyyzz_xxzzzz_1, tg_yyyyzz_xxzzzzz_0, tg_yyyyzz_xxzzzzz_1, tg_yyyyzz_xyyyyy_1, \
                                         tg_yyyyzz_xyyyyyy_0, tg_yyyyzz_xyyyyyy_1, tg_yyyyzz_xyyyyyz_0, tg_yyyyzz_xyyyyyz_1, \
                                         tg_yyyyzz_xyyyyz_1, tg_yyyyzz_xyyyyzz_0, tg_yyyyzz_xyyyyzz_1, tg_yyyyzz_xyyyzz_1, \
                                         tg_yyyyzz_xyyyzzz_0, tg_yyyyzz_xyyyzzz_1, tg_yyyyzz_xyyzzz_1, tg_yyyyzz_xyyzzzz_0, \
                                         tg_yyyyzz_xyyzzzz_1, tg_yyyyzz_xyzzzz_1, tg_yyyyzz_xyzzzzz_0, tg_yyyyzz_xyzzzzz_1, \
                                         tg_yyyyzz_xzzzzz_1, tg_yyyyzz_xzzzzzz_0, tg_yyyyzz_xzzzzzz_1, tg_yyyyzz_yyyyyy_1, \
                                         tg_yyyyzz_yyyyyyy_0, tg_yyyyzz_yyyyyyy_1, tg_yyyyzz_yyyyyyz_0, tg_yyyyzz_yyyyyyz_1, \
                                         tg_yyyyzz_yyyyyz_1, tg_yyyyzz_yyyyyzz_0, tg_yyyyzz_yyyyyzz_1, tg_yyyyzz_yyyyzz_1, \
                                         tg_yyyyzz_yyyyzzz_0, tg_yyyyzz_yyyyzzz_1, tg_yyyyzz_yyyzzz_1, tg_yyyyzz_yyyzzzz_0, \
                                         tg_yyyyzz_yyyzzzz_1, tg_yyyyzz_yyzzzz_1, tg_yyyyzz_yyzzzzz_0, tg_yyyyzz_yyzzzzz_1, \
                                         tg_yyyyzz_yzzzzz_1, tg_yyyyzz_yzzzzzz_0, tg_yyyyzz_yzzzzzz_1, tg_yyyyzz_zzzzzz_1, \
                                         tg_yyyyzz_zzzzzzz_0, tg_yyyyzz_zzzzzzz_1, tg_yyyzzz_xxxxxx_1, tg_yyyzzz_xxxxxxx_0, \
                                         tg_yyyzzz_xxxxxxx_1, tg_yyyzzz_xxxxxxy_0, tg_yyyzzz_xxxxxxy_1, tg_yyyzzz_xxxxxxz_0, \
                                         tg_yyyzzz_xxxxxxz_1, tg_yyyzzz_xxxxxy_1, tg_yyyzzz_xxxxxyy_0, tg_yyyzzz_xxxxxyy_1, \
                                         tg_yyyzzz_xxxxxyz_0, tg_yyyzzz_xxxxxyz_1, tg_yyyzzz_xxxxxz_1, tg_yyyzzz_xxxxxzz_0, \
                                         tg_yyyzzz_xxxxxzz_1, tg_yyyzzz_xxxxyy_1, tg_yyyzzz_xxxxyyy_0, tg_yyyzzz_xxxxyyy_1, \
                                         tg_yyyzzz_xxxxyyz_0, tg_yyyzzz_xxxxyyz_1, tg_yyyzzz_xxxxyz_1, tg_yyyzzz_xxxxyzz_0, \
                                         tg_yyyzzz_xxxxyzz_1, tg_yyyzzz_xxxxzz_1, tg_yyyzzz_xxxxzzz_0, tg_yyyzzz_xxxxzzz_1, \
                                         tg_yyyzzz_xxxyyy_1, tg_yyyzzz_xxxyyyy_0, tg_yyyzzz_xxxyyyy_1, tg_yyyzzz_xxxyyyz_0, \
                                         tg_yyyzzz_xxxyyyz_1, tg_yyyzzz_xxxyyz_1, tg_yyyzzz_xxxyyzz_0, tg_yyyzzz_xxxyyzz_1, \
                                         tg_yyyzzz_xxxyzz_1, tg_yyyzzz_xxxyzzz_0, tg_yyyzzz_xxxyzzz_1, tg_yyyzzz_xxxzzz_1, \
                                         tg_yyyzzz_xxxzzzz_0, tg_yyyzzz_xxxzzzz_1, tg_yyyzzz_xxyyyy_1, tg_yyyzzz_xxyyyyy_0, \
                                         tg_yyyzzz_xxyyyyy_1, tg_yyyzzz_xxyyyyz_0, tg_yyyzzz_xxyyyyz_1, tg_yyyzzz_xxyyyz_1, \
                                         tg_yyyzzz_xxyyyzz_0, tg_yyyzzz_xxyyyzz_1, tg_yyyzzz_xxyyzz_1, tg_yyyzzz_xxyyzzz_0, \
                                         tg_yyyzzz_xxyyzzz_1, tg_yyyzzz_xxyzzz_1, tg_yyyzzz_xxyzzzz_0, tg_yyyzzz_xxyzzzz_1, \
                                         tg_yyyzzz_xxzzzz_1, tg_yyyzzz_xxzzzzz_0, tg_yyyzzz_xxzzzzz_1, tg_yyyzzz_xyyyyy_1, \
                                         tg_yyyzzz_xyyyyyy_0, tg_yyyzzz_xyyyyyy_1, tg_yyyzzz_xyyyyyz_0, tg_yyyzzz_xyyyyyz_1, \
                                         tg_yyyzzz_xyyyyz_1, tg_yyyzzz_xyyyyzz_0, tg_yyyzzz_xyyyyzz_1, tg_yyyzzz_xyyyzz_1, \
                                         tg_yyyzzz_xyyyzzz_0, tg_yyyzzz_xyyyzzz_1, tg_yyyzzz_xyyzzz_1, tg_yyyzzz_xyyzzzz_0, \
                                         tg_yyyzzz_xyyzzzz_1, tg_yyyzzz_xyzzzz_1, tg_yyyzzz_xyzzzzz_0, tg_yyyzzz_xyzzzzz_1, \
                                         tg_yyyzzz_xzzzzz_1, tg_yyyzzz_xzzzzzz_0, tg_yyyzzz_xzzzzzz_1, tg_yyyzzz_yyyyyy_1, \
                                         tg_yyyzzz_yyyyyyy_0, tg_yyyzzz_yyyyyyy_1, tg_yyyzzz_yyyyyyz_0, tg_yyyzzz_yyyyyyz_1, \
                                         tg_yyyzzz_yyyyyz_1, tg_yyyzzz_yyyyyzz_0, tg_yyyzzz_yyyyyzz_1, tg_yyyzzz_yyyyzz_1, \
                                         tg_yyyzzz_yyyyzzz_0, tg_yyyzzz_yyyyzzz_1, tg_yyyzzz_yyyzzz_1, tg_yyyzzz_yyyzzzz_0, \
                                         tg_yyyzzz_yyyzzzz_1, tg_yyyzzz_yyzzzz_1, tg_yyyzzz_yyzzzzz_0, tg_yyyzzz_yyzzzzz_1, \
                                         tg_yyyzzz_yzzzzz_1, tg_yyyzzz_yzzzzzz_0, tg_yyyzzz_yzzzzzz_1, tg_yyyzzz_zzzzzz_1, \
                                         tg_yyyzzz_zzzzzzz_0, tg_yyyzzz_zzzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fxn = fxn[j];

                    double fr = wp_x[j]; 

                    tg_xyyyyyz_xxxxyzz_0[j] = pb_x * tg_yyyyyz_xxxxyzz_0[j] + fr * tg_yyyyyz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyz_xxxyzz_1[j];

                    tg_xyyyyyz_xxxxzzz_0[j] = pb_x * tg_yyyyyz_xxxxzzz_0[j] + fr * tg_yyyyyz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyz_xxxzzz_1[j];

                    tg_xyyyyyz_xxxyyyy_0[j] = pb_x * tg_yyyyyz_xxxyyyy_0[j] + fr * tg_yyyyyz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyyz_xxyyyy_1[j];

                    tg_xyyyyyz_xxxyyyz_0[j] = pb_x * tg_yyyyyz_xxxyyyz_0[j] + fr * tg_yyyyyz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyyz_xxyyyz_1[j];

                    tg_xyyyyyz_xxxyyzz_0[j] = pb_x * tg_yyyyyz_xxxyyzz_0[j] + fr * tg_yyyyyz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyz_xxyyzz_1[j];

                    tg_xyyyyyz_xxxyzzz_0[j] = pb_x * tg_yyyyyz_xxxyzzz_0[j] + fr * tg_yyyyyz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyz_xxyzzz_1[j];

                    tg_xyyyyyz_xxxzzzz_0[j] = pb_x * tg_yyyyyz_xxxzzzz_0[j] + fr * tg_yyyyyz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyz_xxzzzz_1[j];

                    tg_xyyyyyz_xxyyyyy_0[j] = pb_x * tg_yyyyyz_xxyyyyy_0[j] + fr * tg_yyyyyz_xxyyyyy_1[j] + fl1_fxn * tg_yyyyyz_xyyyyy_1[j];

                    tg_xyyyyyz_xxyyyyz_0[j] = pb_x * tg_yyyyyz_xxyyyyz_0[j] + fr * tg_yyyyyz_xxyyyyz_1[j] + fl1_fxn * tg_yyyyyz_xyyyyz_1[j];

                    tg_xyyyyyz_xxyyyzz_0[j] = pb_x * tg_yyyyyz_xxyyyzz_0[j] + fr * tg_yyyyyz_xxyyyzz_1[j] + fl1_fxn * tg_yyyyyz_xyyyzz_1[j];

                    tg_xyyyyyz_xxyyzzz_0[j] = pb_x * tg_yyyyyz_xxyyzzz_0[j] + fr * tg_yyyyyz_xxyyzzz_1[j] + fl1_fxn * tg_yyyyyz_xyyzzz_1[j];

                    tg_xyyyyyz_xxyzzzz_0[j] = pb_x * tg_yyyyyz_xxyzzzz_0[j] + fr * tg_yyyyyz_xxyzzzz_1[j] + fl1_fxn * tg_yyyyyz_xyzzzz_1[j];

                    tg_xyyyyyz_xxzzzzz_0[j] = pb_x * tg_yyyyyz_xxzzzzz_0[j] + fr * tg_yyyyyz_xxzzzzz_1[j] + fl1_fxn * tg_yyyyyz_xzzzzz_1[j];

                    tg_xyyyyyz_xyyyyyy_0[j] = pb_x * tg_yyyyyz_xyyyyyy_0[j] + fr * tg_yyyyyz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yyyyyy_1[j];

                    tg_xyyyyyz_xyyyyyz_0[j] = pb_x * tg_yyyyyz_xyyyyyz_0[j] + fr * tg_yyyyyz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yyyyyz_1[j];

                    tg_xyyyyyz_xyyyyzz_0[j] = pb_x * tg_yyyyyz_xyyyyzz_0[j] + fr * tg_yyyyyz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yyyyzz_1[j];

                    tg_xyyyyyz_xyyyzzz_0[j] = pb_x * tg_yyyyyz_xyyyzzz_0[j] + fr * tg_yyyyyz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yyyzzz_1[j];

                    tg_xyyyyyz_xyyzzzz_0[j] = pb_x * tg_yyyyyz_xyyzzzz_0[j] + fr * tg_yyyyyz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yyzzzz_1[j];

                    tg_xyyyyyz_xyzzzzz_0[j] = pb_x * tg_yyyyyz_xyzzzzz_0[j] + fr * tg_yyyyyz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_yzzzzz_1[j];

                    tg_xyyyyyz_xzzzzzz_0[j] = pb_x * tg_yyyyyz_xzzzzzz_0[j] + fr * tg_yyyyyz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyz_zzzzzz_1[j];

                    tg_xyyyyyz_yyyyyyy_0[j] = pb_x * tg_yyyyyz_yyyyyyy_0[j] + fr * tg_yyyyyz_yyyyyyy_1[j];

                    tg_xyyyyyz_yyyyyyz_0[j] = pb_x * tg_yyyyyz_yyyyyyz_0[j] + fr * tg_yyyyyz_yyyyyyz_1[j];

                    tg_xyyyyyz_yyyyyzz_0[j] = pb_x * tg_yyyyyz_yyyyyzz_0[j] + fr * tg_yyyyyz_yyyyyzz_1[j];

                    tg_xyyyyyz_yyyyzzz_0[j] = pb_x * tg_yyyyyz_yyyyzzz_0[j] + fr * tg_yyyyyz_yyyyzzz_1[j];

                    tg_xyyyyyz_yyyzzzz_0[j] = pb_x * tg_yyyyyz_yyyzzzz_0[j] + fr * tg_yyyyyz_yyyzzzz_1[j];

                    tg_xyyyyyz_yyzzzzz_0[j] = pb_x * tg_yyyyyz_yyzzzzz_0[j] + fr * tg_yyyyyz_yyzzzzz_1[j];

                    tg_xyyyyyz_yzzzzzz_0[j] = pb_x * tg_yyyyyz_yzzzzzz_0[j] + fr * tg_yyyyyz_yzzzzzz_1[j];

                    tg_xyyyyyz_zzzzzzz_0[j] = pb_x * tg_yyyyyz_zzzzzzz_0[j] + fr * tg_yyyyyz_zzzzzzz_1[j];

                    tg_xyyyyzz_xxxxxxx_0[j] = pb_x * tg_yyyyzz_xxxxxxx_0[j] + fr * tg_yyyyzz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yyyyzz_xxxxxx_1[j];

                    tg_xyyyyzz_xxxxxxy_0[j] = pb_x * tg_yyyyzz_xxxxxxy_0[j] + fr * tg_yyyyzz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yyyyzz_xxxxxy_1[j];

                    tg_xyyyyzz_xxxxxxz_0[j] = pb_x * tg_yyyyzz_xxxxxxz_0[j] + fr * tg_yyyyzz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yyyyzz_xxxxxz_1[j];

                    tg_xyyyyzz_xxxxxyy_0[j] = pb_x * tg_yyyyzz_xxxxxyy_0[j] + fr * tg_yyyyzz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yyyyzz_xxxxyy_1[j];

                    tg_xyyyyzz_xxxxxyz_0[j] = pb_x * tg_yyyyzz_xxxxxyz_0[j] + fr * tg_yyyyzz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yyyyzz_xxxxyz_1[j];

                    tg_xyyyyzz_xxxxxzz_0[j] = pb_x * tg_yyyyzz_xxxxxzz_0[j] + fr * tg_yyyyzz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yyyyzz_xxxxzz_1[j];

                    tg_xyyyyzz_xxxxyyy_0[j] = pb_x * tg_yyyyzz_xxxxyyy_0[j] + fr * tg_yyyyzz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yyyyzz_xxxyyy_1[j];

                    tg_xyyyyzz_xxxxyyz_0[j] = pb_x * tg_yyyyzz_xxxxyyz_0[j] + fr * tg_yyyyzz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yyyyzz_xxxyyz_1[j];

                    tg_xyyyyzz_xxxxyzz_0[j] = pb_x * tg_yyyyzz_xxxxyzz_0[j] + fr * tg_yyyyzz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yyyyzz_xxxyzz_1[j];

                    tg_xyyyyzz_xxxxzzz_0[j] = pb_x * tg_yyyyzz_xxxxzzz_0[j] + fr * tg_yyyyzz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yyyyzz_xxxzzz_1[j];

                    tg_xyyyyzz_xxxyyyy_0[j] = pb_x * tg_yyyyzz_xxxyyyy_0[j] + fr * tg_yyyyzz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyzz_xxyyyy_1[j];

                    tg_xyyyyzz_xxxyyyz_0[j] = pb_x * tg_yyyyzz_xxxyyyz_0[j] + fr * tg_yyyyzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyzz_xxyyyz_1[j];

                    tg_xyyyyzz_xxxyyzz_0[j] = pb_x * tg_yyyyzz_xxxyyzz_0[j] + fr * tg_yyyyzz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyzz_xxyyzz_1[j];

                    tg_xyyyyzz_xxxyzzz_0[j] = pb_x * tg_yyyyzz_xxxyzzz_0[j] + fr * tg_yyyyzz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyzz_xxyzzz_1[j];

                    tg_xyyyyzz_xxxzzzz_0[j] = pb_x * tg_yyyyzz_xxxzzzz_0[j] + fr * tg_yyyyzz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyzz_xxzzzz_1[j];

                    tg_xyyyyzz_xxyyyyy_0[j] = pb_x * tg_yyyyzz_xxyyyyy_0[j] + fr * tg_yyyyzz_xxyyyyy_1[j] + fl1_fxn * tg_yyyyzz_xyyyyy_1[j];

                    tg_xyyyyzz_xxyyyyz_0[j] = pb_x * tg_yyyyzz_xxyyyyz_0[j] + fr * tg_yyyyzz_xxyyyyz_1[j] + fl1_fxn * tg_yyyyzz_xyyyyz_1[j];

                    tg_xyyyyzz_xxyyyzz_0[j] = pb_x * tg_yyyyzz_xxyyyzz_0[j] + fr * tg_yyyyzz_xxyyyzz_1[j] + fl1_fxn * tg_yyyyzz_xyyyzz_1[j];

                    tg_xyyyyzz_xxyyzzz_0[j] = pb_x * tg_yyyyzz_xxyyzzz_0[j] + fr * tg_yyyyzz_xxyyzzz_1[j] + fl1_fxn * tg_yyyyzz_xyyzzz_1[j];

                    tg_xyyyyzz_xxyzzzz_0[j] = pb_x * tg_yyyyzz_xxyzzzz_0[j] + fr * tg_yyyyzz_xxyzzzz_1[j] + fl1_fxn * tg_yyyyzz_xyzzzz_1[j];

                    tg_xyyyyzz_xxzzzzz_0[j] = pb_x * tg_yyyyzz_xxzzzzz_0[j] + fr * tg_yyyyzz_xxzzzzz_1[j] + fl1_fxn * tg_yyyyzz_xzzzzz_1[j];

                    tg_xyyyyzz_xyyyyyy_0[j] = pb_x * tg_yyyyzz_xyyyyyy_0[j] + fr * tg_yyyyzz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yyyyyy_1[j];

                    tg_xyyyyzz_xyyyyyz_0[j] = pb_x * tg_yyyyzz_xyyyyyz_0[j] + fr * tg_yyyyzz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yyyyyz_1[j];

                    tg_xyyyyzz_xyyyyzz_0[j] = pb_x * tg_yyyyzz_xyyyyzz_0[j] + fr * tg_yyyyzz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yyyyzz_1[j];

                    tg_xyyyyzz_xyyyzzz_0[j] = pb_x * tg_yyyyzz_xyyyzzz_0[j] + fr * tg_yyyyzz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yyyzzz_1[j];

                    tg_xyyyyzz_xyyzzzz_0[j] = pb_x * tg_yyyyzz_xyyzzzz_0[j] + fr * tg_yyyyzz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yyzzzz_1[j];

                    tg_xyyyyzz_xyzzzzz_0[j] = pb_x * tg_yyyyzz_xyzzzzz_0[j] + fr * tg_yyyyzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_yzzzzz_1[j];

                    tg_xyyyyzz_xzzzzzz_0[j] = pb_x * tg_yyyyzz_xzzzzzz_0[j] + fr * tg_yyyyzz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzz_zzzzzz_1[j];

                    tg_xyyyyzz_yyyyyyy_0[j] = pb_x * tg_yyyyzz_yyyyyyy_0[j] + fr * tg_yyyyzz_yyyyyyy_1[j];

                    tg_xyyyyzz_yyyyyyz_0[j] = pb_x * tg_yyyyzz_yyyyyyz_0[j] + fr * tg_yyyyzz_yyyyyyz_1[j];

                    tg_xyyyyzz_yyyyyzz_0[j] = pb_x * tg_yyyyzz_yyyyyzz_0[j] + fr * tg_yyyyzz_yyyyyzz_1[j];

                    tg_xyyyyzz_yyyyzzz_0[j] = pb_x * tg_yyyyzz_yyyyzzz_0[j] + fr * tg_yyyyzz_yyyyzzz_1[j];

                    tg_xyyyyzz_yyyzzzz_0[j] = pb_x * tg_yyyyzz_yyyzzzz_0[j] + fr * tg_yyyyzz_yyyzzzz_1[j];

                    tg_xyyyyzz_yyzzzzz_0[j] = pb_x * tg_yyyyzz_yyzzzzz_0[j] + fr * tg_yyyyzz_yyzzzzz_1[j];

                    tg_xyyyyzz_yzzzzzz_0[j] = pb_x * tg_yyyyzz_yzzzzzz_0[j] + fr * tg_yyyyzz_yzzzzzz_1[j];

                    tg_xyyyyzz_zzzzzzz_0[j] = pb_x * tg_yyyyzz_zzzzzzz_0[j] + fr * tg_yyyyzz_zzzzzzz_1[j];

                    tg_xyyyzzz_xxxxxxx_0[j] = pb_x * tg_yyyzzz_xxxxxxx_0[j] + fr * tg_yyyzzz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yyyzzz_xxxxxx_1[j];

                    tg_xyyyzzz_xxxxxxy_0[j] = pb_x * tg_yyyzzz_xxxxxxy_0[j] + fr * tg_yyyzzz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yyyzzz_xxxxxy_1[j];

                    tg_xyyyzzz_xxxxxxz_0[j] = pb_x * tg_yyyzzz_xxxxxxz_0[j] + fr * tg_yyyzzz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yyyzzz_xxxxxz_1[j];

                    tg_xyyyzzz_xxxxxyy_0[j] = pb_x * tg_yyyzzz_xxxxxyy_0[j] + fr * tg_yyyzzz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yyyzzz_xxxxyy_1[j];

                    tg_xyyyzzz_xxxxxyz_0[j] = pb_x * tg_yyyzzz_xxxxxyz_0[j] + fr * tg_yyyzzz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yyyzzz_xxxxyz_1[j];

                    tg_xyyyzzz_xxxxxzz_0[j] = pb_x * tg_yyyzzz_xxxxxzz_0[j] + fr * tg_yyyzzz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yyyzzz_xxxxzz_1[j];

                    tg_xyyyzzz_xxxxyyy_0[j] = pb_x * tg_yyyzzz_xxxxyyy_0[j] + fr * tg_yyyzzz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yyyzzz_xxxyyy_1[j];

                    tg_xyyyzzz_xxxxyyz_0[j] = pb_x * tg_yyyzzz_xxxxyyz_0[j] + fr * tg_yyyzzz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yyyzzz_xxxyyz_1[j];

                    tg_xyyyzzz_xxxxyzz_0[j] = pb_x * tg_yyyzzz_xxxxyzz_0[j] + fr * tg_yyyzzz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yyyzzz_xxxyzz_1[j];

                    tg_xyyyzzz_xxxxzzz_0[j] = pb_x * tg_yyyzzz_xxxxzzz_0[j] + fr * tg_yyyzzz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yyyzzz_xxxzzz_1[j];

                    tg_xyyyzzz_xxxyyyy_0[j] = pb_x * tg_yyyzzz_xxxyyyy_0[j] + fr * tg_yyyzzz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yyyzzz_xxyyyy_1[j];

                    tg_xyyyzzz_xxxyyyz_0[j] = pb_x * tg_yyyzzz_xxxyyyz_0[j] + fr * tg_yyyzzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yyyzzz_xxyyyz_1[j];

                    tg_xyyyzzz_xxxyyzz_0[j] = pb_x * tg_yyyzzz_xxxyyzz_0[j] + fr * tg_yyyzzz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yyyzzz_xxyyzz_1[j];

                    tg_xyyyzzz_xxxyzzz_0[j] = pb_x * tg_yyyzzz_xxxyzzz_0[j] + fr * tg_yyyzzz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzzz_xxyzzz_1[j];

                    tg_xyyyzzz_xxxzzzz_0[j] = pb_x * tg_yyyzzz_xxxzzzz_0[j] + fr * tg_yyyzzz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzzz_xxzzzz_1[j];

                    tg_xyyyzzz_xxyyyyy_0[j] = pb_x * tg_yyyzzz_xxyyyyy_0[j] + fr * tg_yyyzzz_xxyyyyy_1[j] + fl1_fxn * tg_yyyzzz_xyyyyy_1[j];

                    tg_xyyyzzz_xxyyyyz_0[j] = pb_x * tg_yyyzzz_xxyyyyz_0[j] + fr * tg_yyyzzz_xxyyyyz_1[j] + fl1_fxn * tg_yyyzzz_xyyyyz_1[j];

                    tg_xyyyzzz_xxyyyzz_0[j] = pb_x * tg_yyyzzz_xxyyyzz_0[j] + fr * tg_yyyzzz_xxyyyzz_1[j] + fl1_fxn * tg_yyyzzz_xyyyzz_1[j];

                    tg_xyyyzzz_xxyyzzz_0[j] = pb_x * tg_yyyzzz_xxyyzzz_0[j] + fr * tg_yyyzzz_xxyyzzz_1[j] + fl1_fxn * tg_yyyzzz_xyyzzz_1[j];

                    tg_xyyyzzz_xxyzzzz_0[j] = pb_x * tg_yyyzzz_xxyzzzz_0[j] + fr * tg_yyyzzz_xxyzzzz_1[j] + fl1_fxn * tg_yyyzzz_xyzzzz_1[j];

                    tg_xyyyzzz_xxzzzzz_0[j] = pb_x * tg_yyyzzz_xxzzzzz_0[j] + fr * tg_yyyzzz_xxzzzzz_1[j] + fl1_fxn * tg_yyyzzz_xzzzzz_1[j];

                    tg_xyyyzzz_xyyyyyy_0[j] = pb_x * tg_yyyzzz_xyyyyyy_0[j] + fr * tg_yyyzzz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yyyyyy_1[j];

                    tg_xyyyzzz_xyyyyyz_0[j] = pb_x * tg_yyyzzz_xyyyyyz_0[j] + fr * tg_yyyzzz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yyyyyz_1[j];

                    tg_xyyyzzz_xyyyyzz_0[j] = pb_x * tg_yyyzzz_xyyyyzz_0[j] + fr * tg_yyyzzz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yyyyzz_1[j];

                    tg_xyyyzzz_xyyyzzz_0[j] = pb_x * tg_yyyzzz_xyyyzzz_0[j] + fr * tg_yyyzzz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yyyzzz_1[j];

                    tg_xyyyzzz_xyyzzzz_0[j] = pb_x * tg_yyyzzz_xyyzzzz_0[j] + fr * tg_yyyzzz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yyzzzz_1[j];

                    tg_xyyyzzz_xyzzzzz_0[j] = pb_x * tg_yyyzzz_xyzzzzz_0[j] + fr * tg_yyyzzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_yzzzzz_1[j];

                    tg_xyyyzzz_xzzzzzz_0[j] = pb_x * tg_yyyzzz_xzzzzzz_0[j] + fr * tg_yyyzzz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzz_zzzzzz_1[j];

                    tg_xyyyzzz_yyyyyyy_0[j] = pb_x * tg_yyyzzz_yyyyyyy_0[j] + fr * tg_yyyzzz_yyyyyyy_1[j];

                    tg_xyyyzzz_yyyyyyz_0[j] = pb_x * tg_yyyzzz_yyyyyyz_0[j] + fr * tg_yyyzzz_yyyyyyz_1[j];

                    tg_xyyyzzz_yyyyyzz_0[j] = pb_x * tg_yyyzzz_yyyyyzz_0[j] + fr * tg_yyyzzz_yyyyyzz_1[j];

                    tg_xyyyzzz_yyyyzzz_0[j] = pb_x * tg_yyyzzz_yyyyzzz_0[j] + fr * tg_yyyzzz_yyyyzzz_1[j];

                    tg_xyyyzzz_yyyzzzz_0[j] = pb_x * tg_yyyzzz_yyyzzzz_0[j] + fr * tg_yyyzzz_yyyzzzz_1[j];

                    tg_xyyyzzz_yyzzzzz_0[j] = pb_x * tg_yyyzzz_yyzzzzz_0[j] + fr * tg_yyyzzz_yyzzzzz_1[j];

                    tg_xyyyzzz_yzzzzzz_0[j] = pb_x * tg_yyyzzz_yzzzzzz_0[j] + fr * tg_yyyzzz_yzzzzzz_1[j];

                    tg_xyyyzzz_zzzzzzz_0[j] = pb_x * tg_yyyzzz_zzzzzzz_0[j] + fr * tg_yyyzzz_zzzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_900_999(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (900,999)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_yyzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 900); 

                auto tg_yyzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 901); 

                auto tg_yyzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 902); 

                auto tg_yyzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 903); 

                auto tg_yyzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 904); 

                auto tg_yyzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 905); 

                auto tg_yyzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 906); 

                auto tg_yyzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 907); 

                auto tg_yyzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 908); 

                auto tg_yyzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 909); 

                auto tg_yyzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 910); 

                auto tg_yyzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 911); 

                auto tg_yyzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 912); 

                auto tg_yyzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 913); 

                auto tg_yyzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 914); 

                auto tg_yyzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 915); 

                auto tg_yyzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 916); 

                auto tg_yyzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 917); 

                auto tg_yyzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 918); 

                auto tg_yyzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 919); 

                auto tg_yyzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 920); 

                auto tg_yyzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 921); 

                auto tg_yyzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 922); 

                auto tg_yyzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 923); 

                auto tg_yyzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 924); 

                auto tg_yyzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 925); 

                auto tg_yyzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 926); 

                auto tg_yyzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 927); 

                auto tg_yyzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 928); 

                auto tg_yyzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 929); 

                auto tg_yyzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 930); 

                auto tg_yyzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 931); 

                auto tg_yyzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 932); 

                auto tg_yyzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 933); 

                auto tg_yyzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 934); 

                auto tg_yyzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 935); 

                auto tg_yzzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 936); 

                auto tg_yzzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 937); 

                auto tg_yzzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 938); 

                auto tg_yzzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 939); 

                auto tg_yzzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 940); 

                auto tg_yzzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 941); 

                auto tg_yzzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 942); 

                auto tg_yzzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 943); 

                auto tg_yzzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 944); 

                auto tg_yzzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 945); 

                auto tg_yzzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 946); 

                auto tg_yzzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 947); 

                auto tg_yzzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 948); 

                auto tg_yzzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 949); 

                auto tg_yzzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 950); 

                auto tg_yzzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 951); 

                auto tg_yzzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 952); 

                auto tg_yzzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 953); 

                auto tg_yzzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 954); 

                auto tg_yzzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 955); 

                auto tg_yzzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 956); 

                auto tg_yzzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 957); 

                auto tg_yzzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 958); 

                auto tg_yzzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 959); 

                auto tg_yzzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 960); 

                auto tg_yzzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 961); 

                auto tg_yzzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 962); 

                auto tg_yzzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 963); 

                auto tg_yzzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 964); 

                auto tg_yzzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 965); 

                auto tg_yzzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 966); 

                auto tg_yzzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 967); 

                auto tg_yzzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 968); 

                auto tg_yzzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 969); 

                auto tg_yzzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 970); 

                auto tg_yzzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 971); 

                auto tg_zzzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 972); 

                auto tg_zzzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 973); 

                auto tg_zzzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 974); 

                auto tg_zzzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 975); 

                auto tg_zzzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 976); 

                auto tg_zzzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 977); 

                auto tg_zzzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 978); 

                auto tg_zzzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 979); 

                auto tg_zzzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 980); 

                auto tg_zzzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 981); 

                auto tg_zzzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 982); 

                auto tg_zzzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 983); 

                auto tg_zzzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 984); 

                auto tg_zzzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 985); 

                auto tg_zzzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 986); 

                auto tg_zzzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 987); 

                auto tg_zzzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 988); 

                auto tg_zzzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 989); 

                auto tg_zzzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 990); 

                auto tg_zzzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 991); 

                auto tg_zzzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 992); 

                auto tg_zzzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 993); 

                auto tg_zzzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 994); 

                auto tg_zzzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 995); 

                auto tg_zzzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 996); 

                auto tg_zzzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 997); 

                auto tg_zzzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 998); 

                auto tg_yyzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 900); 

                auto tg_yyzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 901); 

                auto tg_yyzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 902); 

                auto tg_yyzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 903); 

                auto tg_yyzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 904); 

                auto tg_yyzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 905); 

                auto tg_yyzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 906); 

                auto tg_yyzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 907); 

                auto tg_yyzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 908); 

                auto tg_yyzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 909); 

                auto tg_yyzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 910); 

                auto tg_yyzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 911); 

                auto tg_yyzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 912); 

                auto tg_yyzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 913); 

                auto tg_yyzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 914); 

                auto tg_yyzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 915); 

                auto tg_yyzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 916); 

                auto tg_yyzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 917); 

                auto tg_yyzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 918); 

                auto tg_yyzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 919); 

                auto tg_yyzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 920); 

                auto tg_yyzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 921); 

                auto tg_yyzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 922); 

                auto tg_yyzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 923); 

                auto tg_yyzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 924); 

                auto tg_yyzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 925); 

                auto tg_yyzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 926); 

                auto tg_yyzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 927); 

                auto tg_yyzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 928); 

                auto tg_yyzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 929); 

                auto tg_yyzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 930); 

                auto tg_yyzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 931); 

                auto tg_yyzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 932); 

                auto tg_yyzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 933); 

                auto tg_yyzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 934); 

                auto tg_yyzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 935); 

                auto tg_yzzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 936); 

                auto tg_yzzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 937); 

                auto tg_yzzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 938); 

                auto tg_yzzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 939); 

                auto tg_yzzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 940); 

                auto tg_yzzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 941); 

                auto tg_yzzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 942); 

                auto tg_yzzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 943); 

                auto tg_yzzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 944); 

                auto tg_yzzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 945); 

                auto tg_yzzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 946); 

                auto tg_yzzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 947); 

                auto tg_yzzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 948); 

                auto tg_yzzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 949); 

                auto tg_yzzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 950); 

                auto tg_yzzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 951); 

                auto tg_yzzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 952); 

                auto tg_yzzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 953); 

                auto tg_yzzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 954); 

                auto tg_yzzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 955); 

                auto tg_yzzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 956); 

                auto tg_yzzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 957); 

                auto tg_yzzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 958); 

                auto tg_yzzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 959); 

                auto tg_yzzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 960); 

                auto tg_yzzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 961); 

                auto tg_yzzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 962); 

                auto tg_yzzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 963); 

                auto tg_yzzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 964); 

                auto tg_yzzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 965); 

                auto tg_yzzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 966); 

                auto tg_yzzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 967); 

                auto tg_yzzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 968); 

                auto tg_yzzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 969); 

                auto tg_yzzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 970); 

                auto tg_yzzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 971); 

                auto tg_zzzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 972); 

                auto tg_zzzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 973); 

                auto tg_zzzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 974); 

                auto tg_zzzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 975); 

                auto tg_zzzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 976); 

                auto tg_zzzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 977); 

                auto tg_zzzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 978); 

                auto tg_zzzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 979); 

                auto tg_zzzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 980); 

                auto tg_zzzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 981); 

                auto tg_zzzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 982); 

                auto tg_zzzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 983); 

                auto tg_zzzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 984); 

                auto tg_zzzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 985); 

                auto tg_zzzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 986); 

                auto tg_zzzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 987); 

                auto tg_zzzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 988); 

                auto tg_zzzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 989); 

                auto tg_zzzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 990); 

                auto tg_zzzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 991); 

                auto tg_zzzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 992); 

                auto tg_zzzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 993); 

                auto tg_zzzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 994); 

                auto tg_zzzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 995); 

                auto tg_zzzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 996); 

                auto tg_zzzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 997); 

                auto tg_zzzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 998); 

                auto tg_yyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 733); 

                auto tg_yzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 743); 

                auto tg_yzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 775); 

                auto tg_zzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 782); 

                // set up pointers to integrals

                auto tg_xyyzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 900); 

                auto tg_xyyzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 901); 

                auto tg_xyyzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 902); 

                auto tg_xyyzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 903); 

                auto tg_xyyzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 904); 

                auto tg_xyyzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 905); 

                auto tg_xyyzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 906); 

                auto tg_xyyzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 907); 

                auto tg_xyyzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 908); 

                auto tg_xyyzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 909); 

                auto tg_xyyzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 910); 

                auto tg_xyyzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 911); 

                auto tg_xyyzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 912); 

                auto tg_xyyzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 913); 

                auto tg_xyyzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 914); 

                auto tg_xyyzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 915); 

                auto tg_xyyzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 916); 

                auto tg_xyyzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 917); 

                auto tg_xyyzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 918); 

                auto tg_xyyzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 919); 

                auto tg_xyyzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 920); 

                auto tg_xyyzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 921); 

                auto tg_xyyzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 922); 

                auto tg_xyyzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 923); 

                auto tg_xyyzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 924); 

                auto tg_xyyzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 925); 

                auto tg_xyyzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 926); 

                auto tg_xyyzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 927); 

                auto tg_xyyzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 928); 

                auto tg_xyyzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 929); 

                auto tg_xyyzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 930); 

                auto tg_xyyzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 931); 

                auto tg_xyyzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 932); 

                auto tg_xyyzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 933); 

                auto tg_xyyzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 934); 

                auto tg_xyyzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 935); 

                auto tg_xyzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 936); 

                auto tg_xyzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 937); 

                auto tg_xyzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 938); 

                auto tg_xyzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 939); 

                auto tg_xyzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 940); 

                auto tg_xyzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 941); 

                auto tg_xyzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 942); 

                auto tg_xyzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 943); 

                auto tg_xyzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 944); 

                auto tg_xyzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 945); 

                auto tg_xyzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 946); 

                auto tg_xyzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 947); 

                auto tg_xyzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 948); 

                auto tg_xyzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 949); 

                auto tg_xyzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 950); 

                auto tg_xyzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 951); 

                auto tg_xyzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 952); 

                auto tg_xyzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 953); 

                auto tg_xyzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 954); 

                auto tg_xyzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 955); 

                auto tg_xyzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 956); 

                auto tg_xyzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 957); 

                auto tg_xyzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 958); 

                auto tg_xyzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 959); 

                auto tg_xyzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 960); 

                auto tg_xyzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 961); 

                auto tg_xyzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 962); 

                auto tg_xyzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 963); 

                auto tg_xyzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 964); 

                auto tg_xyzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 965); 

                auto tg_xyzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 966); 

                auto tg_xyzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 967); 

                auto tg_xyzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 968); 

                auto tg_xyzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 969); 

                auto tg_xyzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 970); 

                auto tg_xyzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 971); 

                auto tg_xzzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 972); 

                auto tg_xzzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 973); 

                auto tg_xzzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 974); 

                auto tg_xzzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 975); 

                auto tg_xzzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 976); 

                auto tg_xzzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 977); 

                auto tg_xzzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 978); 

                auto tg_xzzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 979); 

                auto tg_xzzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 980); 

                auto tg_xzzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 981); 

                auto tg_xzzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 982); 

                auto tg_xzzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 983); 

                auto tg_xzzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 984); 

                auto tg_xzzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 985); 

                auto tg_xzzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 986); 

                auto tg_xzzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 987); 

                auto tg_xzzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 988); 

                auto tg_xzzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 989); 

                auto tg_xzzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 990); 

                auto tg_xzzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 991); 

                auto tg_xzzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 992); 

                auto tg_xzzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 993); 

                auto tg_xzzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 994); 

                auto tg_xzzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 995); 

                auto tg_xzzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 996); 

                auto tg_xzzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 997); 

                auto tg_xzzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 998); 

                // Batch of Integrals (900,999)

                #pragma omp simd aligned(fxn, tg_xyyzzzz_xxxxxxx_0, tg_xyyzzzz_xxxxxxy_0, \
                                         tg_xyyzzzz_xxxxxxz_0, tg_xyyzzzz_xxxxxyy_0, tg_xyyzzzz_xxxxxyz_0, tg_xyyzzzz_xxxxxzz_0, \
                                         tg_xyyzzzz_xxxxyyy_0, tg_xyyzzzz_xxxxyyz_0, tg_xyyzzzz_xxxxyzz_0, tg_xyyzzzz_xxxxzzz_0, \
                                         tg_xyyzzzz_xxxyyyy_0, tg_xyyzzzz_xxxyyyz_0, tg_xyyzzzz_xxxyyzz_0, tg_xyyzzzz_xxxyzzz_0, \
                                         tg_xyyzzzz_xxxzzzz_0, tg_xyyzzzz_xxyyyyy_0, tg_xyyzzzz_xxyyyyz_0, tg_xyyzzzz_xxyyyzz_0, \
                                         tg_xyyzzzz_xxyyzzz_0, tg_xyyzzzz_xxyzzzz_0, tg_xyyzzzz_xxzzzzz_0, tg_xyyzzzz_xyyyyyy_0, \
                                         tg_xyyzzzz_xyyyyyz_0, tg_xyyzzzz_xyyyyzz_0, tg_xyyzzzz_xyyyzzz_0, tg_xyyzzzz_xyyzzzz_0, \
                                         tg_xyyzzzz_xyzzzzz_0, tg_xyyzzzz_xzzzzzz_0, tg_xyyzzzz_yyyyyyy_0, tg_xyyzzzz_yyyyyyz_0, \
                                         tg_xyyzzzz_yyyyyzz_0, tg_xyyzzzz_yyyyzzz_0, tg_xyyzzzz_yyyzzzz_0, tg_xyyzzzz_yyzzzzz_0, \
                                         tg_xyyzzzz_yzzzzzz_0, tg_xyyzzzz_zzzzzzz_0, tg_xyzzzzz_xxxxxxx_0, tg_xyzzzzz_xxxxxxy_0, \
                                         tg_xyzzzzz_xxxxxxz_0, tg_xyzzzzz_xxxxxyy_0, tg_xyzzzzz_xxxxxyz_0, tg_xyzzzzz_xxxxxzz_0, \
                                         tg_xyzzzzz_xxxxyyy_0, tg_xyzzzzz_xxxxyyz_0, tg_xyzzzzz_xxxxyzz_0, tg_xyzzzzz_xxxxzzz_0, \
                                         tg_xyzzzzz_xxxyyyy_0, tg_xyzzzzz_xxxyyyz_0, tg_xyzzzzz_xxxyyzz_0, tg_xyzzzzz_xxxyzzz_0, \
                                         tg_xyzzzzz_xxxzzzz_0, tg_xyzzzzz_xxyyyyy_0, tg_xyzzzzz_xxyyyyz_0, tg_xyzzzzz_xxyyyzz_0, \
                                         tg_xyzzzzz_xxyyzzz_0, tg_xyzzzzz_xxyzzzz_0, tg_xyzzzzz_xxzzzzz_0, tg_xyzzzzz_xyyyyyy_0, \
                                         tg_xyzzzzz_xyyyyyz_0, tg_xyzzzzz_xyyyyzz_0, tg_xyzzzzz_xyyyzzz_0, tg_xyzzzzz_xyyzzzz_0, \
                                         tg_xyzzzzz_xyzzzzz_0, tg_xyzzzzz_xzzzzzz_0, tg_xyzzzzz_yyyyyyy_0, tg_xyzzzzz_yyyyyyz_0, \
                                         tg_xyzzzzz_yyyyyzz_0, tg_xyzzzzz_yyyyzzz_0, tg_xyzzzzz_yyyzzzz_0, tg_xyzzzzz_yyzzzzz_0, \
                                         tg_xyzzzzz_yzzzzzz_0, tg_xyzzzzz_zzzzzzz_0, tg_xzzzzzz_xxxxxxx_0, tg_xzzzzzz_xxxxxxy_0, \
                                         tg_xzzzzzz_xxxxxxz_0, tg_xzzzzzz_xxxxxyy_0, tg_xzzzzzz_xxxxxyz_0, tg_xzzzzzz_xxxxxzz_0, \
                                         tg_xzzzzzz_xxxxyyy_0, tg_xzzzzzz_xxxxyyz_0, tg_xzzzzzz_xxxxyzz_0, tg_xzzzzzz_xxxxzzz_0, \
                                         tg_xzzzzzz_xxxyyyy_0, tg_xzzzzzz_xxxyyyz_0, tg_xzzzzzz_xxxyyzz_0, tg_xzzzzzz_xxxyzzz_0, \
                                         tg_xzzzzzz_xxxzzzz_0, tg_xzzzzzz_xxyyyyy_0, tg_xzzzzzz_xxyyyyz_0, tg_xzzzzzz_xxyyyzz_0, \
                                         tg_xzzzzzz_xxyyzzz_0, tg_xzzzzzz_xxyzzzz_0, tg_xzzzzzz_xxzzzzz_0, tg_xzzzzzz_xyyyyyy_0, \
                                         tg_xzzzzzz_xyyyyyz_0, tg_xzzzzzz_xyyyyzz_0, tg_xzzzzzz_xyyyzzz_0, tg_xzzzzzz_xyyzzzz_0, \
                                         tg_xzzzzzz_xyzzzzz_0, tg_yyzzzz_xxxxxx_1, tg_yyzzzz_xxxxxxx_0, tg_yyzzzz_xxxxxxx_1, \
                                         tg_yyzzzz_xxxxxxy_0, tg_yyzzzz_xxxxxxy_1, tg_yyzzzz_xxxxxxz_0, tg_yyzzzz_xxxxxxz_1, \
                                         tg_yyzzzz_xxxxxy_1, tg_yyzzzz_xxxxxyy_0, tg_yyzzzz_xxxxxyy_1, tg_yyzzzz_xxxxxyz_0, \
                                         tg_yyzzzz_xxxxxyz_1, tg_yyzzzz_xxxxxz_1, tg_yyzzzz_xxxxxzz_0, tg_yyzzzz_xxxxxzz_1, \
                                         tg_yyzzzz_xxxxyy_1, tg_yyzzzz_xxxxyyy_0, tg_yyzzzz_xxxxyyy_1, tg_yyzzzz_xxxxyyz_0, \
                                         tg_yyzzzz_xxxxyyz_1, tg_yyzzzz_xxxxyz_1, tg_yyzzzz_xxxxyzz_0, tg_yyzzzz_xxxxyzz_1, \
                                         tg_yyzzzz_xxxxzz_1, tg_yyzzzz_xxxxzzz_0, tg_yyzzzz_xxxxzzz_1, tg_yyzzzz_xxxyyy_1, \
                                         tg_yyzzzz_xxxyyyy_0, tg_yyzzzz_xxxyyyy_1, tg_yyzzzz_xxxyyyz_0, tg_yyzzzz_xxxyyyz_1, \
                                         tg_yyzzzz_xxxyyz_1, tg_yyzzzz_xxxyyzz_0, tg_yyzzzz_xxxyyzz_1, tg_yyzzzz_xxxyzz_1, \
                                         tg_yyzzzz_xxxyzzz_0, tg_yyzzzz_xxxyzzz_1, tg_yyzzzz_xxxzzz_1, tg_yyzzzz_xxxzzzz_0, \
                                         tg_yyzzzz_xxxzzzz_1, tg_yyzzzz_xxyyyy_1, tg_yyzzzz_xxyyyyy_0, tg_yyzzzz_xxyyyyy_1, \
                                         tg_yyzzzz_xxyyyyz_0, tg_yyzzzz_xxyyyyz_1, tg_yyzzzz_xxyyyz_1, tg_yyzzzz_xxyyyzz_0, \
                                         tg_yyzzzz_xxyyyzz_1, tg_yyzzzz_xxyyzz_1, tg_yyzzzz_xxyyzzz_0, tg_yyzzzz_xxyyzzz_1, \
                                         tg_yyzzzz_xxyzzz_1, tg_yyzzzz_xxyzzzz_0, tg_yyzzzz_xxyzzzz_1, tg_yyzzzz_xxzzzz_1, \
                                         tg_yyzzzz_xxzzzzz_0, tg_yyzzzz_xxzzzzz_1, tg_yyzzzz_xyyyyy_1, tg_yyzzzz_xyyyyyy_0, \
                                         tg_yyzzzz_xyyyyyy_1, tg_yyzzzz_xyyyyyz_0, tg_yyzzzz_xyyyyyz_1, tg_yyzzzz_xyyyyz_1, \
                                         tg_yyzzzz_xyyyyzz_0, tg_yyzzzz_xyyyyzz_1, tg_yyzzzz_xyyyzz_1, tg_yyzzzz_xyyyzzz_0, \
                                         tg_yyzzzz_xyyyzzz_1, tg_yyzzzz_xyyzzz_1, tg_yyzzzz_xyyzzzz_0, tg_yyzzzz_xyyzzzz_1, \
                                         tg_yyzzzz_xyzzzz_1, tg_yyzzzz_xyzzzzz_0, tg_yyzzzz_xyzzzzz_1, tg_yyzzzz_xzzzzz_1, \
                                         tg_yyzzzz_xzzzzzz_0, tg_yyzzzz_xzzzzzz_1, tg_yyzzzz_yyyyyy_1, tg_yyzzzz_yyyyyyy_0, \
                                         tg_yyzzzz_yyyyyyy_1, tg_yyzzzz_yyyyyyz_0, tg_yyzzzz_yyyyyyz_1, tg_yyzzzz_yyyyyz_1, \
                                         tg_yyzzzz_yyyyyzz_0, tg_yyzzzz_yyyyyzz_1, tg_yyzzzz_yyyyzz_1, tg_yyzzzz_yyyyzzz_0, \
                                         tg_yyzzzz_yyyyzzz_1, tg_yyzzzz_yyyzzz_1, tg_yyzzzz_yyyzzzz_0, tg_yyzzzz_yyyzzzz_1, \
                                         tg_yyzzzz_yyzzzz_1, tg_yyzzzz_yyzzzzz_0, tg_yyzzzz_yyzzzzz_1, tg_yyzzzz_yzzzzz_1, \
                                         tg_yyzzzz_yzzzzzz_0, tg_yyzzzz_yzzzzzz_1, tg_yyzzzz_zzzzzz_1, tg_yyzzzz_zzzzzzz_0, \
                                         tg_yyzzzz_zzzzzzz_1, tg_yzzzzz_xxxxxx_1, tg_yzzzzz_xxxxxxx_0, tg_yzzzzz_xxxxxxx_1, \
                                         tg_yzzzzz_xxxxxxy_0, tg_yzzzzz_xxxxxxy_1, tg_yzzzzz_xxxxxxz_0, tg_yzzzzz_xxxxxxz_1, \
                                         tg_yzzzzz_xxxxxy_1, tg_yzzzzz_xxxxxyy_0, tg_yzzzzz_xxxxxyy_1, tg_yzzzzz_xxxxxyz_0, \
                                         tg_yzzzzz_xxxxxyz_1, tg_yzzzzz_xxxxxz_1, tg_yzzzzz_xxxxxzz_0, tg_yzzzzz_xxxxxzz_1, \
                                         tg_yzzzzz_xxxxyy_1, tg_yzzzzz_xxxxyyy_0, tg_yzzzzz_xxxxyyy_1, tg_yzzzzz_xxxxyyz_0, \
                                         tg_yzzzzz_xxxxyyz_1, tg_yzzzzz_xxxxyz_1, tg_yzzzzz_xxxxyzz_0, tg_yzzzzz_xxxxyzz_1, \
                                         tg_yzzzzz_xxxxzz_1, tg_yzzzzz_xxxxzzz_0, tg_yzzzzz_xxxxzzz_1, tg_yzzzzz_xxxyyy_1, \
                                         tg_yzzzzz_xxxyyyy_0, tg_yzzzzz_xxxyyyy_1, tg_yzzzzz_xxxyyyz_0, tg_yzzzzz_xxxyyyz_1, \
                                         tg_yzzzzz_xxxyyz_1, tg_yzzzzz_xxxyyzz_0, tg_yzzzzz_xxxyyzz_1, tg_yzzzzz_xxxyzz_1, \
                                         tg_yzzzzz_xxxyzzz_0, tg_yzzzzz_xxxyzzz_1, tg_yzzzzz_xxxzzz_1, tg_yzzzzz_xxxzzzz_0, \
                                         tg_yzzzzz_xxxzzzz_1, tg_yzzzzz_xxyyyy_1, tg_yzzzzz_xxyyyyy_0, tg_yzzzzz_xxyyyyy_1, \
                                         tg_yzzzzz_xxyyyyz_0, tg_yzzzzz_xxyyyyz_1, tg_yzzzzz_xxyyyz_1, tg_yzzzzz_xxyyyzz_0, \
                                         tg_yzzzzz_xxyyyzz_1, tg_yzzzzz_xxyyzz_1, tg_yzzzzz_xxyyzzz_0, tg_yzzzzz_xxyyzzz_1, \
                                         tg_yzzzzz_xxyzzz_1, tg_yzzzzz_xxyzzzz_0, tg_yzzzzz_xxyzzzz_1, tg_yzzzzz_xxzzzz_1, \
                                         tg_yzzzzz_xxzzzzz_0, tg_yzzzzz_xxzzzzz_1, tg_yzzzzz_xyyyyy_1, tg_yzzzzz_xyyyyyy_0, \
                                         tg_yzzzzz_xyyyyyy_1, tg_yzzzzz_xyyyyyz_0, tg_yzzzzz_xyyyyyz_1, tg_yzzzzz_xyyyyz_1, \
                                         tg_yzzzzz_xyyyyzz_0, tg_yzzzzz_xyyyyzz_1, tg_yzzzzz_xyyyzz_1, tg_yzzzzz_xyyyzzz_0, \
                                         tg_yzzzzz_xyyyzzz_1, tg_yzzzzz_xyyzzz_1, tg_yzzzzz_xyyzzzz_0, tg_yzzzzz_xyyzzzz_1, \
                                         tg_yzzzzz_xyzzzz_1, tg_yzzzzz_xyzzzzz_0, tg_yzzzzz_xyzzzzz_1, tg_yzzzzz_xzzzzz_1, \
                                         tg_yzzzzz_xzzzzzz_0, tg_yzzzzz_xzzzzzz_1, tg_yzzzzz_yyyyyy_1, tg_yzzzzz_yyyyyyy_0, \
                                         tg_yzzzzz_yyyyyyy_1, tg_yzzzzz_yyyyyyz_0, tg_yzzzzz_yyyyyyz_1, tg_yzzzzz_yyyyyz_1, \
                                         tg_yzzzzz_yyyyyzz_0, tg_yzzzzz_yyyyyzz_1, tg_yzzzzz_yyyyzz_1, tg_yzzzzz_yyyyzzz_0, \
                                         tg_yzzzzz_yyyyzzz_1, tg_yzzzzz_yyyzzz_1, tg_yzzzzz_yyyzzzz_0, tg_yzzzzz_yyyzzzz_1, \
                                         tg_yzzzzz_yyzzzz_1, tg_yzzzzz_yyzzzzz_0, tg_yzzzzz_yyzzzzz_1, tg_yzzzzz_yzzzzz_1, \
                                         tg_yzzzzz_yzzzzzz_0, tg_yzzzzz_yzzzzzz_1, tg_yzzzzz_zzzzzz_1, tg_yzzzzz_zzzzzzz_0, \
                                         tg_yzzzzz_zzzzzzz_1, tg_zzzzzz_xxxxxx_1, tg_zzzzzz_xxxxxxx_0, tg_zzzzzz_xxxxxxx_1, \
                                         tg_zzzzzz_xxxxxxy_0, tg_zzzzzz_xxxxxxy_1, tg_zzzzzz_xxxxxxz_0, tg_zzzzzz_xxxxxxz_1, \
                                         tg_zzzzzz_xxxxxy_1, tg_zzzzzz_xxxxxyy_0, tg_zzzzzz_xxxxxyy_1, tg_zzzzzz_xxxxxyz_0, \
                                         tg_zzzzzz_xxxxxyz_1, tg_zzzzzz_xxxxxz_1, tg_zzzzzz_xxxxxzz_0, tg_zzzzzz_xxxxxzz_1, \
                                         tg_zzzzzz_xxxxyy_1, tg_zzzzzz_xxxxyyy_0, tg_zzzzzz_xxxxyyy_1, tg_zzzzzz_xxxxyyz_0, \
                                         tg_zzzzzz_xxxxyyz_1, tg_zzzzzz_xxxxyz_1, tg_zzzzzz_xxxxyzz_0, tg_zzzzzz_xxxxyzz_1, \
                                         tg_zzzzzz_xxxxzz_1, tg_zzzzzz_xxxxzzz_0, tg_zzzzzz_xxxxzzz_1, tg_zzzzzz_xxxyyy_1, \
                                         tg_zzzzzz_xxxyyyy_0, tg_zzzzzz_xxxyyyy_1, tg_zzzzzz_xxxyyyz_0, tg_zzzzzz_xxxyyyz_1, \
                                         tg_zzzzzz_xxxyyz_1, tg_zzzzzz_xxxyyzz_0, tg_zzzzzz_xxxyyzz_1, tg_zzzzzz_xxxyzz_1, \
                                         tg_zzzzzz_xxxyzzz_0, tg_zzzzzz_xxxyzzz_1, tg_zzzzzz_xxxzzz_1, tg_zzzzzz_xxxzzzz_0, \
                                         tg_zzzzzz_xxxzzzz_1, tg_zzzzzz_xxyyyy_1, tg_zzzzzz_xxyyyyy_0, tg_zzzzzz_xxyyyyy_1, \
                                         tg_zzzzzz_xxyyyyz_0, tg_zzzzzz_xxyyyyz_1, tg_zzzzzz_xxyyyz_1, tg_zzzzzz_xxyyyzz_0, \
                                         tg_zzzzzz_xxyyyzz_1, tg_zzzzzz_xxyyzz_1, tg_zzzzzz_xxyyzzz_0, tg_zzzzzz_xxyyzzz_1, \
                                         tg_zzzzzz_xxyzzz_1, tg_zzzzzz_xxyzzzz_0, tg_zzzzzz_xxyzzzz_1, tg_zzzzzz_xxzzzz_1, \
                                         tg_zzzzzz_xxzzzzz_0, tg_zzzzzz_xxzzzzz_1, tg_zzzzzz_xyyyyy_1, tg_zzzzzz_xyyyyyy_0, \
                                         tg_zzzzzz_xyyyyyy_1, tg_zzzzzz_xyyyyyz_0, tg_zzzzzz_xyyyyyz_1, tg_zzzzzz_xyyyyz_1, \
                                         tg_zzzzzz_xyyyyzz_0, tg_zzzzzz_xyyyyzz_1, tg_zzzzzz_xyyyzz_1, tg_zzzzzz_xyyyzzz_0, \
                                         tg_zzzzzz_xyyyzzz_1, tg_zzzzzz_xyyzzz_1, tg_zzzzzz_xyyzzzz_0, tg_zzzzzz_xyyzzzz_1, \
                                         tg_zzzzzz_xyzzzz_1, tg_zzzzzz_xyzzzzz_0, tg_zzzzzz_xyzzzzz_1, tg_zzzzzz_xzzzzz_1, \
                                         tg_zzzzzz_yyyyyy_1, tg_zzzzzz_yyyyyz_1, tg_zzzzzz_yyyyzz_1, tg_zzzzzz_yyyzzz_1, \
                                         tg_zzzzzz_yyzzzz_1, tg_zzzzzz_yzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fxn = fxn[j];

                    double fr = wp_x[j]; 

                    tg_xyyzzzz_xxxxxxx_0[j] = pb_x * tg_yyzzzz_xxxxxxx_0[j] + fr * tg_yyzzzz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yyzzzz_xxxxxx_1[j];

                    tg_xyyzzzz_xxxxxxy_0[j] = pb_x * tg_yyzzzz_xxxxxxy_0[j] + fr * tg_yyzzzz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yyzzzz_xxxxxy_1[j];

                    tg_xyyzzzz_xxxxxxz_0[j] = pb_x * tg_yyzzzz_xxxxxxz_0[j] + fr * tg_yyzzzz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yyzzzz_xxxxxz_1[j];

                    tg_xyyzzzz_xxxxxyy_0[j] = pb_x * tg_yyzzzz_xxxxxyy_0[j] + fr * tg_yyzzzz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yyzzzz_xxxxyy_1[j];

                    tg_xyyzzzz_xxxxxyz_0[j] = pb_x * tg_yyzzzz_xxxxxyz_0[j] + fr * tg_yyzzzz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yyzzzz_xxxxyz_1[j];

                    tg_xyyzzzz_xxxxxzz_0[j] = pb_x * tg_yyzzzz_xxxxxzz_0[j] + fr * tg_yyzzzz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yyzzzz_xxxxzz_1[j];

                    tg_xyyzzzz_xxxxyyy_0[j] = pb_x * tg_yyzzzz_xxxxyyy_0[j] + fr * tg_yyzzzz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yyzzzz_xxxyyy_1[j];

                    tg_xyyzzzz_xxxxyyz_0[j] = pb_x * tg_yyzzzz_xxxxyyz_0[j] + fr * tg_yyzzzz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yyzzzz_xxxyyz_1[j];

                    tg_xyyzzzz_xxxxyzz_0[j] = pb_x * tg_yyzzzz_xxxxyzz_0[j] + fr * tg_yyzzzz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yyzzzz_xxxyzz_1[j];

                    tg_xyyzzzz_xxxxzzz_0[j] = pb_x * tg_yyzzzz_xxxxzzz_0[j] + fr * tg_yyzzzz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yyzzzz_xxxzzz_1[j];

                    tg_xyyzzzz_xxxyyyy_0[j] = pb_x * tg_yyzzzz_xxxyyyy_0[j] + fr * tg_yyzzzz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yyzzzz_xxyyyy_1[j];

                    tg_xyyzzzz_xxxyyyz_0[j] = pb_x * tg_yyzzzz_xxxyyyz_0[j] + fr * tg_yyzzzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yyzzzz_xxyyyz_1[j];

                    tg_xyyzzzz_xxxyyzz_0[j] = pb_x * tg_yyzzzz_xxxyyzz_0[j] + fr * tg_yyzzzz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yyzzzz_xxyyzz_1[j];

                    tg_xyyzzzz_xxxyzzz_0[j] = pb_x * tg_yyzzzz_xxxyzzz_0[j] + fr * tg_yyzzzz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzzz_xxyzzz_1[j];

                    tg_xyyzzzz_xxxzzzz_0[j] = pb_x * tg_yyzzzz_xxxzzzz_0[j] + fr * tg_yyzzzz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzzz_xxzzzz_1[j];

                    tg_xyyzzzz_xxyyyyy_0[j] = pb_x * tg_yyzzzz_xxyyyyy_0[j] + fr * tg_yyzzzz_xxyyyyy_1[j] + fl1_fxn * tg_yyzzzz_xyyyyy_1[j];

                    tg_xyyzzzz_xxyyyyz_0[j] = pb_x * tg_yyzzzz_xxyyyyz_0[j] + fr * tg_yyzzzz_xxyyyyz_1[j] + fl1_fxn * tg_yyzzzz_xyyyyz_1[j];

                    tg_xyyzzzz_xxyyyzz_0[j] = pb_x * tg_yyzzzz_xxyyyzz_0[j] + fr * tg_yyzzzz_xxyyyzz_1[j] + fl1_fxn * tg_yyzzzz_xyyyzz_1[j];

                    tg_xyyzzzz_xxyyzzz_0[j] = pb_x * tg_yyzzzz_xxyyzzz_0[j] + fr * tg_yyzzzz_xxyyzzz_1[j] + fl1_fxn * tg_yyzzzz_xyyzzz_1[j];

                    tg_xyyzzzz_xxyzzzz_0[j] = pb_x * tg_yyzzzz_xxyzzzz_0[j] + fr * tg_yyzzzz_xxyzzzz_1[j] + fl1_fxn * tg_yyzzzz_xyzzzz_1[j];

                    tg_xyyzzzz_xxzzzzz_0[j] = pb_x * tg_yyzzzz_xxzzzzz_0[j] + fr * tg_yyzzzz_xxzzzzz_1[j] + fl1_fxn * tg_yyzzzz_xzzzzz_1[j];

                    tg_xyyzzzz_xyyyyyy_0[j] = pb_x * tg_yyzzzz_xyyyyyy_0[j] + fr * tg_yyzzzz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yyyyyy_1[j];

                    tg_xyyzzzz_xyyyyyz_0[j] = pb_x * tg_yyzzzz_xyyyyyz_0[j] + fr * tg_yyzzzz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yyyyyz_1[j];

                    tg_xyyzzzz_xyyyyzz_0[j] = pb_x * tg_yyzzzz_xyyyyzz_0[j] + fr * tg_yyzzzz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yyyyzz_1[j];

                    tg_xyyzzzz_xyyyzzz_0[j] = pb_x * tg_yyzzzz_xyyyzzz_0[j] + fr * tg_yyzzzz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yyyzzz_1[j];

                    tg_xyyzzzz_xyyzzzz_0[j] = pb_x * tg_yyzzzz_xyyzzzz_0[j] + fr * tg_yyzzzz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yyzzzz_1[j];

                    tg_xyyzzzz_xyzzzzz_0[j] = pb_x * tg_yyzzzz_xyzzzzz_0[j] + fr * tg_yyzzzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_yzzzzz_1[j];

                    tg_xyyzzzz_xzzzzzz_0[j] = pb_x * tg_yyzzzz_xzzzzzz_0[j] + fr * tg_yyzzzz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzz_zzzzzz_1[j];

                    tg_xyyzzzz_yyyyyyy_0[j] = pb_x * tg_yyzzzz_yyyyyyy_0[j] + fr * tg_yyzzzz_yyyyyyy_1[j];

                    tg_xyyzzzz_yyyyyyz_0[j] = pb_x * tg_yyzzzz_yyyyyyz_0[j] + fr * tg_yyzzzz_yyyyyyz_1[j];

                    tg_xyyzzzz_yyyyyzz_0[j] = pb_x * tg_yyzzzz_yyyyyzz_0[j] + fr * tg_yyzzzz_yyyyyzz_1[j];

                    tg_xyyzzzz_yyyyzzz_0[j] = pb_x * tg_yyzzzz_yyyyzzz_0[j] + fr * tg_yyzzzz_yyyyzzz_1[j];

                    tg_xyyzzzz_yyyzzzz_0[j] = pb_x * tg_yyzzzz_yyyzzzz_0[j] + fr * tg_yyzzzz_yyyzzzz_1[j];

                    tg_xyyzzzz_yyzzzzz_0[j] = pb_x * tg_yyzzzz_yyzzzzz_0[j] + fr * tg_yyzzzz_yyzzzzz_1[j];

                    tg_xyyzzzz_yzzzzzz_0[j] = pb_x * tg_yyzzzz_yzzzzzz_0[j] + fr * tg_yyzzzz_yzzzzzz_1[j];

                    tg_xyyzzzz_zzzzzzz_0[j] = pb_x * tg_yyzzzz_zzzzzzz_0[j] + fr * tg_yyzzzz_zzzzzzz_1[j];

                    tg_xyzzzzz_xxxxxxx_0[j] = pb_x * tg_yzzzzz_xxxxxxx_0[j] + fr * tg_yzzzzz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_yzzzzz_xxxxxx_1[j];

                    tg_xyzzzzz_xxxxxxy_0[j] = pb_x * tg_yzzzzz_xxxxxxy_0[j] + fr * tg_yzzzzz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_yzzzzz_xxxxxy_1[j];

                    tg_xyzzzzz_xxxxxxz_0[j] = pb_x * tg_yzzzzz_xxxxxxz_0[j] + fr * tg_yzzzzz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_yzzzzz_xxxxxz_1[j];

                    tg_xyzzzzz_xxxxxyy_0[j] = pb_x * tg_yzzzzz_xxxxxyy_0[j] + fr * tg_yzzzzz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_yzzzzz_xxxxyy_1[j];

                    tg_xyzzzzz_xxxxxyz_0[j] = pb_x * tg_yzzzzz_xxxxxyz_0[j] + fr * tg_yzzzzz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_yzzzzz_xxxxyz_1[j];

                    tg_xyzzzzz_xxxxxzz_0[j] = pb_x * tg_yzzzzz_xxxxxzz_0[j] + fr * tg_yzzzzz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_yzzzzz_xxxxzz_1[j];

                    tg_xyzzzzz_xxxxyyy_0[j] = pb_x * tg_yzzzzz_xxxxyyy_0[j] + fr * tg_yzzzzz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_yzzzzz_xxxyyy_1[j];

                    tg_xyzzzzz_xxxxyyz_0[j] = pb_x * tg_yzzzzz_xxxxyyz_0[j] + fr * tg_yzzzzz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_yzzzzz_xxxyyz_1[j];

                    tg_xyzzzzz_xxxxyzz_0[j] = pb_x * tg_yzzzzz_xxxxyzz_0[j] + fr * tg_yzzzzz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_yzzzzz_xxxyzz_1[j];

                    tg_xyzzzzz_xxxxzzz_0[j] = pb_x * tg_yzzzzz_xxxxzzz_0[j] + fr * tg_yzzzzz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_yzzzzz_xxxzzz_1[j];

                    tg_xyzzzzz_xxxyyyy_0[j] = pb_x * tg_yzzzzz_xxxyyyy_0[j] + fr * tg_yzzzzz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_yzzzzz_xxyyyy_1[j];

                    tg_xyzzzzz_xxxyyyz_0[j] = pb_x * tg_yzzzzz_xxxyyyz_0[j] + fr * tg_yzzzzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_yzzzzz_xxyyyz_1[j];

                    tg_xyzzzzz_xxxyyzz_0[j] = pb_x * tg_yzzzzz_xxxyyzz_0[j] + fr * tg_yzzzzz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_yzzzzz_xxyyzz_1[j];

                    tg_xyzzzzz_xxxyzzz_0[j] = pb_x * tg_yzzzzz_xxxyzzz_0[j] + fr * tg_yzzzzz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzzz_xxyzzz_1[j];

                    tg_xyzzzzz_xxxzzzz_0[j] = pb_x * tg_yzzzzz_xxxzzzz_0[j] + fr * tg_yzzzzz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzzz_xxzzzz_1[j];

                    tg_xyzzzzz_xxyyyyy_0[j] = pb_x * tg_yzzzzz_xxyyyyy_0[j] + fr * tg_yzzzzz_xxyyyyy_1[j] + fl1_fxn * tg_yzzzzz_xyyyyy_1[j];

                    tg_xyzzzzz_xxyyyyz_0[j] = pb_x * tg_yzzzzz_xxyyyyz_0[j] + fr * tg_yzzzzz_xxyyyyz_1[j] + fl1_fxn * tg_yzzzzz_xyyyyz_1[j];

                    tg_xyzzzzz_xxyyyzz_0[j] = pb_x * tg_yzzzzz_xxyyyzz_0[j] + fr * tg_yzzzzz_xxyyyzz_1[j] + fl1_fxn * tg_yzzzzz_xyyyzz_1[j];

                    tg_xyzzzzz_xxyyzzz_0[j] = pb_x * tg_yzzzzz_xxyyzzz_0[j] + fr * tg_yzzzzz_xxyyzzz_1[j] + fl1_fxn * tg_yzzzzz_xyyzzz_1[j];

                    tg_xyzzzzz_xxyzzzz_0[j] = pb_x * tg_yzzzzz_xxyzzzz_0[j] + fr * tg_yzzzzz_xxyzzzz_1[j] + fl1_fxn * tg_yzzzzz_xyzzzz_1[j];

                    tg_xyzzzzz_xxzzzzz_0[j] = pb_x * tg_yzzzzz_xxzzzzz_0[j] + fr * tg_yzzzzz_xxzzzzz_1[j] + fl1_fxn * tg_yzzzzz_xzzzzz_1[j];

                    tg_xyzzzzz_xyyyyyy_0[j] = pb_x * tg_yzzzzz_xyyyyyy_0[j] + fr * tg_yzzzzz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yyyyyy_1[j];

                    tg_xyzzzzz_xyyyyyz_0[j] = pb_x * tg_yzzzzz_xyyyyyz_0[j] + fr * tg_yzzzzz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yyyyyz_1[j];

                    tg_xyzzzzz_xyyyyzz_0[j] = pb_x * tg_yzzzzz_xyyyyzz_0[j] + fr * tg_yzzzzz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yyyyzz_1[j];

                    tg_xyzzzzz_xyyyzzz_0[j] = pb_x * tg_yzzzzz_xyyyzzz_0[j] + fr * tg_yzzzzz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yyyzzz_1[j];

                    tg_xyzzzzz_xyyzzzz_0[j] = pb_x * tg_yzzzzz_xyyzzzz_0[j] + fr * tg_yzzzzz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yyzzzz_1[j];

                    tg_xyzzzzz_xyzzzzz_0[j] = pb_x * tg_yzzzzz_xyzzzzz_0[j] + fr * tg_yzzzzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_yzzzzz_1[j];

                    tg_xyzzzzz_xzzzzzz_0[j] = pb_x * tg_yzzzzz_xzzzzzz_0[j] + fr * tg_yzzzzz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzz_zzzzzz_1[j];

                    tg_xyzzzzz_yyyyyyy_0[j] = pb_x * tg_yzzzzz_yyyyyyy_0[j] + fr * tg_yzzzzz_yyyyyyy_1[j];

                    tg_xyzzzzz_yyyyyyz_0[j] = pb_x * tg_yzzzzz_yyyyyyz_0[j] + fr * tg_yzzzzz_yyyyyyz_1[j];

                    tg_xyzzzzz_yyyyyzz_0[j] = pb_x * tg_yzzzzz_yyyyyzz_0[j] + fr * tg_yzzzzz_yyyyyzz_1[j];

                    tg_xyzzzzz_yyyyzzz_0[j] = pb_x * tg_yzzzzz_yyyyzzz_0[j] + fr * tg_yzzzzz_yyyyzzz_1[j];

                    tg_xyzzzzz_yyyzzzz_0[j] = pb_x * tg_yzzzzz_yyyzzzz_0[j] + fr * tg_yzzzzz_yyyzzzz_1[j];

                    tg_xyzzzzz_yyzzzzz_0[j] = pb_x * tg_yzzzzz_yyzzzzz_0[j] + fr * tg_yzzzzz_yyzzzzz_1[j];

                    tg_xyzzzzz_yzzzzzz_0[j] = pb_x * tg_yzzzzz_yzzzzzz_0[j] + fr * tg_yzzzzz_yzzzzzz_1[j];

                    tg_xyzzzzz_zzzzzzz_0[j] = pb_x * tg_yzzzzz_zzzzzzz_0[j] + fr * tg_yzzzzz_zzzzzzz_1[j];

                    tg_xzzzzzz_xxxxxxx_0[j] = pb_x * tg_zzzzzz_xxxxxxx_0[j] + fr * tg_zzzzzz_xxxxxxx_1[j] + 3.5 * fl1_fxn * tg_zzzzzz_xxxxxx_1[j];

                    tg_xzzzzzz_xxxxxxy_0[j] = pb_x * tg_zzzzzz_xxxxxxy_0[j] + fr * tg_zzzzzz_xxxxxxy_1[j] + 3.0 * fl1_fxn * tg_zzzzzz_xxxxxy_1[j];

                    tg_xzzzzzz_xxxxxxz_0[j] = pb_x * tg_zzzzzz_xxxxxxz_0[j] + fr * tg_zzzzzz_xxxxxxz_1[j] + 3.0 * fl1_fxn * tg_zzzzzz_xxxxxz_1[j];

                    tg_xzzzzzz_xxxxxyy_0[j] = pb_x * tg_zzzzzz_xxxxxyy_0[j] + fr * tg_zzzzzz_xxxxxyy_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_xxxxyy_1[j];

                    tg_xzzzzzz_xxxxxyz_0[j] = pb_x * tg_zzzzzz_xxxxxyz_0[j] + fr * tg_zzzzzz_xxxxxyz_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_xxxxyz_1[j];

                    tg_xzzzzzz_xxxxxzz_0[j] = pb_x * tg_zzzzzz_xxxxxzz_0[j] + fr * tg_zzzzzz_xxxxxzz_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_xxxxzz_1[j];

                    tg_xzzzzzz_xxxxyyy_0[j] = pb_x * tg_zzzzzz_xxxxyyy_0[j] + fr * tg_zzzzzz_xxxxyyy_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxxyyy_1[j];

                    tg_xzzzzzz_xxxxyyz_0[j] = pb_x * tg_zzzzzz_xxxxyyz_0[j] + fr * tg_zzzzzz_xxxxyyz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxxyyz_1[j];

                    tg_xzzzzzz_xxxxyzz_0[j] = pb_x * tg_zzzzzz_xxxxyzz_0[j] + fr * tg_zzzzzz_xxxxyzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxxyzz_1[j];

                    tg_xzzzzzz_xxxxzzz_0[j] = pb_x * tg_zzzzzz_xxxxzzz_0[j] + fr * tg_zzzzzz_xxxxzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxxzzz_1[j];

                    tg_xzzzzzz_xxxyyyy_0[j] = pb_x * tg_zzzzzz_xxxyyyy_0[j] + fr * tg_zzzzzz_xxxyyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxyyyy_1[j];

                    tg_xzzzzzz_xxxyyyz_0[j] = pb_x * tg_zzzzzz_xxxyyyz_0[j] + fr * tg_zzzzzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxyyyz_1[j];

                    tg_xzzzzzz_xxxyyzz_0[j] = pb_x * tg_zzzzzz_xxxyyzz_0[j] + fr * tg_zzzzzz_xxxyyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxyyzz_1[j];

                    tg_xzzzzzz_xxxyzzz_0[j] = pb_x * tg_zzzzzz_xxxyzzz_0[j] + fr * tg_zzzzzz_xxxyzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxyzzz_1[j];

                    tg_xzzzzzz_xxxzzzz_0[j] = pb_x * tg_zzzzzz_xxxzzzz_0[j] + fr * tg_zzzzzz_xxxzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxzzzz_1[j];

                    tg_xzzzzzz_xxyyyyy_0[j] = pb_x * tg_zzzzzz_xxyyyyy_0[j] + fr * tg_zzzzzz_xxyyyyy_1[j] + fl1_fxn * tg_zzzzzz_xyyyyy_1[j];

                    tg_xzzzzzz_xxyyyyz_0[j] = pb_x * tg_zzzzzz_xxyyyyz_0[j] + fr * tg_zzzzzz_xxyyyyz_1[j] + fl1_fxn * tg_zzzzzz_xyyyyz_1[j];

                    tg_xzzzzzz_xxyyyzz_0[j] = pb_x * tg_zzzzzz_xxyyyzz_0[j] + fr * tg_zzzzzz_xxyyyzz_1[j] + fl1_fxn * tg_zzzzzz_xyyyzz_1[j];

                    tg_xzzzzzz_xxyyzzz_0[j] = pb_x * tg_zzzzzz_xxyyzzz_0[j] + fr * tg_zzzzzz_xxyyzzz_1[j] + fl1_fxn * tg_zzzzzz_xyyzzz_1[j];

                    tg_xzzzzzz_xxyzzzz_0[j] = pb_x * tg_zzzzzz_xxyzzzz_0[j] + fr * tg_zzzzzz_xxyzzzz_1[j] + fl1_fxn * tg_zzzzzz_xyzzzz_1[j];

                    tg_xzzzzzz_xxzzzzz_0[j] = pb_x * tg_zzzzzz_xxzzzzz_0[j] + fr * tg_zzzzzz_xxzzzzz_1[j] + fl1_fxn * tg_zzzzzz_xzzzzz_1[j];

                    tg_xzzzzzz_xyyyyyy_0[j] = pb_x * tg_zzzzzz_xyyyyyy_0[j] + fr * tg_zzzzzz_xyyyyyy_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yyyyyy_1[j];

                    tg_xzzzzzz_xyyyyyz_0[j] = pb_x * tg_zzzzzz_xyyyyyz_0[j] + fr * tg_zzzzzz_xyyyyyz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yyyyyz_1[j];

                    tg_xzzzzzz_xyyyyzz_0[j] = pb_x * tg_zzzzzz_xyyyyzz_0[j] + fr * tg_zzzzzz_xyyyyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yyyyzz_1[j];

                    tg_xzzzzzz_xyyyzzz_0[j] = pb_x * tg_zzzzzz_xyyyzzz_0[j] + fr * tg_zzzzzz_xyyyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yyyzzz_1[j];

                    tg_xzzzzzz_xyyzzzz_0[j] = pb_x * tg_zzzzzz_xyyzzzz_0[j] + fr * tg_zzzzzz_xyyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yyzzzz_1[j];

                    tg_xzzzzzz_xyzzzzz_0[j] = pb_x * tg_zzzzzz_xyzzzzz_0[j] + fr * tg_zzzzzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_yzzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_999_1098(      CMemBlock2D<double>* primBuffer,
                                          const CRecursionMap&       recursionMap,
                                          const CMemBlock2D<double>& osFactors,
                                          const CMemBlock2D<double>& wpDistances,
                                          const CGtoPairsBlock&      braGtoPairsBlock,
                                          const CGtoPairsBlock&      ketGtoPairsBlock,
                                          const int32_t              nKetPrimPairs,
                                          const int32_t              iContrPair)
    {
        // Batch of Integrals (999,1098)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyyy_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 756); 

                auto tg_yyyyyy_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 757); 

                auto tg_yyyyyy_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 758); 

                auto tg_yyyyyy_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 759); 

                auto tg_yyyyyy_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 760); 

                auto tg_yyyyyy_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 761); 

                auto tg_yyyyyy_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 762); 

                auto tg_yyyyyy_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 763); 

                auto tg_yyyyyy_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 764); 

                auto tg_yyyyyy_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 765); 

                auto tg_yyyyyy_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 766); 

                auto tg_yyyyyy_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 767); 

                auto tg_yyyyyy_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 768); 

                auto tg_yyyyyy_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 769); 

                auto tg_yyyyyy_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 770); 

                auto tg_yyyyyy_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 771); 

                auto tg_yyyyyy_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 772); 

                auto tg_yyyyyy_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 773); 

                auto tg_yyyyyy_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 774); 

                auto tg_yyyyyy_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 775); 

                auto tg_yyyyyy_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 776); 

                auto tg_yyyyyy_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 777); 

                auto tg_yyyyyy_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 778); 

                auto tg_yyyyyy_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 779); 

                auto tg_yyyyyy_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 780); 

                auto tg_yyyyyy_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 781); 

                auto tg_yyyyyy_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 782); 

                auto tg_yyyyyy_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 783); 

                auto tg_yyyyyy_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 784); 

                auto tg_yyyyyy_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 785); 

                auto tg_yyyyyy_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 786); 

                auto tg_yyyyyy_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 787); 

                auto tg_yyyyyy_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 788); 

                auto tg_yyyyyy_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 789); 

                auto tg_yyyyyy_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 790); 

                auto tg_yyyyyy_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 791); 

                auto tg_yyyyyz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 792); 

                auto tg_yyyyyz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 793); 

                auto tg_yyyyyz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 794); 

                auto tg_yyyyyz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 795); 

                auto tg_yyyyyz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 796); 

                auto tg_yyyyyz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 797); 

                auto tg_yyyyyz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 798); 

                auto tg_yyyyyz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 799); 

                auto tg_yyyyyz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 800); 

                auto tg_yyyyyz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 801); 

                auto tg_yyyyyz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 802); 

                auto tg_yyyyyz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 803); 

                auto tg_yyyyyz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 804); 

                auto tg_yyyyyz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 805); 

                auto tg_yyyyyz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 806); 

                auto tg_yyyyyz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 807); 

                auto tg_yyyyyz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 808); 

                auto tg_yyyyyz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 809); 

                auto tg_yyyyyz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 810); 

                auto tg_yyyyyz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 811); 

                auto tg_yyyyyz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 812); 

                auto tg_yyyyyz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 813); 

                auto tg_yyyyyz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 814); 

                auto tg_yyyyyz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 815); 

                auto tg_yyyyyz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 816); 

                auto tg_yyyyyz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 817); 

                auto tg_yyyyyz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 818); 

                auto tg_yyyyyz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 819); 

                auto tg_yyyyyz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 820); 

                auto tg_yyyyyz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 821); 

                auto tg_yyyyyz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 822); 

                auto tg_yyyyyz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 823); 

                auto tg_yyyyyz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 824); 

                auto tg_yyyyyz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 825); 

                auto tg_yyyyyz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 826); 

                auto tg_yyyyyz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 827); 

                auto tg_yyyyzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 828); 

                auto tg_yyyyzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 829); 

                auto tg_yyyyzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 830); 

                auto tg_yyyyzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 831); 

                auto tg_yyyyzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 832); 

                auto tg_yyyyzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 833); 

                auto tg_yyyyzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 834); 

                auto tg_yyyyzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 835); 

                auto tg_yyyyzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 836); 

                auto tg_yyyyzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 837); 

                auto tg_yyyyzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 838); 

                auto tg_yyyyzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 839); 

                auto tg_yyyyzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 840); 

                auto tg_yyyyzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 841); 

                auto tg_yyyyzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 842); 

                auto tg_yyyyzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 843); 

                auto tg_yyyyzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 844); 

                auto tg_yyyyzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 845); 

                auto tg_zzzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 999); 

                auto tg_zzzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1000); 

                auto tg_zzzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1001); 

                auto tg_zzzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1002); 

                auto tg_zzzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1003); 

                auto tg_zzzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1004); 

                auto tg_zzzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1005); 

                auto tg_zzzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1006); 

                auto tg_zzzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1007); 

                auto tg_yyyyyy_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 756); 

                auto tg_yyyyyy_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 757); 

                auto tg_yyyyyy_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 758); 

                auto tg_yyyyyy_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 759); 

                auto tg_yyyyyy_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 760); 

                auto tg_yyyyyy_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 761); 

                auto tg_yyyyyy_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 762); 

                auto tg_yyyyyy_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 763); 

                auto tg_yyyyyy_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 764); 

                auto tg_yyyyyy_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 765); 

                auto tg_yyyyyy_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 766); 

                auto tg_yyyyyy_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 767); 

                auto tg_yyyyyy_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 768); 

                auto tg_yyyyyy_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 769); 

                auto tg_yyyyyy_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 770); 

                auto tg_yyyyyy_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 771); 

                auto tg_yyyyyy_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 772); 

                auto tg_yyyyyy_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 773); 

                auto tg_yyyyyy_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 774); 

                auto tg_yyyyyy_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 775); 

                auto tg_yyyyyy_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 776); 

                auto tg_yyyyyy_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 777); 

                auto tg_yyyyyy_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 778); 

                auto tg_yyyyyy_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 779); 

                auto tg_yyyyyy_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 780); 

                auto tg_yyyyyy_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 781); 

                auto tg_yyyyyy_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 782); 

                auto tg_yyyyyy_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 783); 

                auto tg_yyyyyy_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 784); 

                auto tg_yyyyyy_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 785); 

                auto tg_yyyyyy_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 786); 

                auto tg_yyyyyy_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 787); 

                auto tg_yyyyyy_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 788); 

                auto tg_yyyyyy_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 789); 

                auto tg_yyyyyy_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 790); 

                auto tg_yyyyyy_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 791); 

                auto tg_yyyyyz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 792); 

                auto tg_yyyyyz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 793); 

                auto tg_yyyyyz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 794); 

                auto tg_yyyyyz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 795); 

                auto tg_yyyyyz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 796); 

                auto tg_yyyyyz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 797); 

                auto tg_yyyyyz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 798); 

                auto tg_yyyyyz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 799); 

                auto tg_yyyyyz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 800); 

                auto tg_yyyyyz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 801); 

                auto tg_yyyyyz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 802); 

                auto tg_yyyyyz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 803); 

                auto tg_yyyyyz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 804); 

                auto tg_yyyyyz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 805); 

                auto tg_yyyyyz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 806); 

                auto tg_yyyyyz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 807); 

                auto tg_yyyyyz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 808); 

                auto tg_yyyyyz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 809); 

                auto tg_yyyyyz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 810); 

                auto tg_yyyyyz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 811); 

                auto tg_yyyyyz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 812); 

                auto tg_yyyyyz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 813); 

                auto tg_yyyyyz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 814); 

                auto tg_yyyyyz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 815); 

                auto tg_yyyyyz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 816); 

                auto tg_yyyyyz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 817); 

                auto tg_yyyyyz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 818); 

                auto tg_yyyyyz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 819); 

                auto tg_yyyyyz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 820); 

                auto tg_yyyyyz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 821); 

                auto tg_yyyyyz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 822); 

                auto tg_yyyyyz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 823); 

                auto tg_yyyyyz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 824); 

                auto tg_yyyyyz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 825); 

                auto tg_yyyyyz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 826); 

                auto tg_yyyyyz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 827); 

                auto tg_yyyyzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 828); 

                auto tg_yyyyzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 829); 

                auto tg_yyyyzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 830); 

                auto tg_yyyyzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 831); 

                auto tg_yyyyzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 832); 

                auto tg_yyyyzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 833); 

                auto tg_yyyyzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 834); 

                auto tg_yyyyzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 835); 

                auto tg_yyyyzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 836); 

                auto tg_yyyyzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 837); 

                auto tg_yyyyzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 838); 

                auto tg_yyyyzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 839); 

                auto tg_yyyyzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 840); 

                auto tg_yyyyzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 841); 

                auto tg_yyyyzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 842); 

                auto tg_yyyyzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 843); 

                auto tg_yyyyzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 844); 

                auto tg_yyyyzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 845); 

                auto tg_zzzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 999); 

                auto tg_zzzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1000); 

                auto tg_zzzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1001); 

                auto tg_zzzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1002); 

                auto tg_zzzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1003); 

                auto tg_zzzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1004); 

                auto tg_zzzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1005); 

                auto tg_zzzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1006); 

                auto tg_zzzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1007); 

                auto tg_yyyyy_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 543); 

                auto tg_yyyyy_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 558); 

                auto tg_yyyyy_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 599); 

                auto tg_yyyyz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 622); 

                auto tg_yyyzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 629); 

                auto tg_yyyyy_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 540); 

                auto tg_yyyyy_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 541); 

                auto tg_yyyyy_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 542); 

                auto tg_yyyyy_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 543); 

                auto tg_yyyyy_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 544); 

                auto tg_yyyyy_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 545); 

                auto tg_yyyyy_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 546); 

                auto tg_yyyyy_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 547); 

                auto tg_yyyyy_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 548); 

                auto tg_yyyyy_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 549); 

                auto tg_yyyyy_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 550); 

                auto tg_yyyyy_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 551); 

                auto tg_yyyyy_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 552); 

                auto tg_yyyyy_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 553); 

                auto tg_yyyyy_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 554); 

                auto tg_yyyyy_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 555); 

                auto tg_yyyyy_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 556); 

                auto tg_yyyyy_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 557); 

                auto tg_yyyyy_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 558); 

                auto tg_yyyyy_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 559); 

                auto tg_yyyyy_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 560); 

                auto tg_yyyyy_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 561); 

                auto tg_yyyyy_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 562); 

                auto tg_yyyyy_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 563); 

                auto tg_yyyyy_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 564); 

                auto tg_yyyyy_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 565); 

                auto tg_yyyyy_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 566); 

                auto tg_yyyyy_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 567); 

                auto tg_yyyyy_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 568); 

                auto tg_yyyyy_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 569); 

                auto tg_yyyyy_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 570); 

                auto tg_yyyyy_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 571); 

                auto tg_yyyyy_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 572); 

                auto tg_yyyyy_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 573); 

                auto tg_yyyyy_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 574); 

                auto tg_yyyyy_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 575); 

                auto tg_yyyyz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 576); 

                auto tg_yyyyz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 577); 

                auto tg_yyyyz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 578); 

                auto tg_yyyyz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 579); 

                auto tg_yyyyz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 580); 

                auto tg_yyyyz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 581); 

                auto tg_yyyyz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 582); 

                auto tg_yyyyz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 583); 

                auto tg_yyyyz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 584); 

                auto tg_yyyyz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 585); 

                auto tg_yyyyz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 586); 

                auto tg_yyyyz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 587); 

                auto tg_yyyyz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 588); 

                auto tg_yyyyz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 589); 

                auto tg_yyyyz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 590); 

                auto tg_yyyyz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 591); 

                auto tg_yyyyz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 592); 

                auto tg_yyyyz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 593); 

                auto tg_yyyyz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 594); 

                auto tg_yyyyz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 595); 

                auto tg_yyyyz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 596); 

                auto tg_yyyyz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 597); 

                auto tg_yyyyz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 598); 

                auto tg_yyyyz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 599); 

                auto tg_yyyyz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 600); 

                auto tg_yyyyz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 601); 

                auto tg_yyyyz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 602); 

                auto tg_yyyyz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 603); 

                auto tg_yyyyz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 604); 

                auto tg_yyyyz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 605); 

                auto tg_yyyyz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 606); 

                auto tg_yyyyz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 607); 

                auto tg_yyyyz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 608); 

                auto tg_yyyyz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 609); 

                auto tg_yyyyz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 610); 

                auto tg_yyyyz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 611); 

                auto tg_yyyzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 612); 

                auto tg_yyyzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 613); 

                auto tg_yyyzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 614); 

                auto tg_yyyzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 615); 

                auto tg_yyyzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 616); 

                auto tg_yyyzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 617); 

                auto tg_yyyzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 618); 

                auto tg_yyyzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 619); 

                auto tg_yyyzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 620); 

                auto tg_yyyzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 621); 

                auto tg_yyyzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 622); 

                auto tg_yyyzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 623); 

                auto tg_yyyzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 624); 

                auto tg_yyyzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 625); 

                auto tg_yyyzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 626); 

                auto tg_yyyzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 627); 

                auto tg_yyyzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 628); 

                auto tg_yyyzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 629); 

                auto tg_yyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 623); 

                auto tg_yyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 646); 

                auto tg_yyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 656); 

                auto tg_zzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 783); 

                // set up pointers to integrals

                auto tg_xzzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 999); 

                auto tg_xzzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1000); 

                auto tg_xzzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1001); 

                auto tg_xzzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1002); 

                auto tg_xzzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1003); 

                auto tg_xzzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1004); 

                auto tg_xzzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1005); 

                auto tg_xzzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1006); 

                auto tg_xzzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1007); 

                auto tg_yyyyyyy_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1008); 

                auto tg_yyyyyyy_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1009); 

                auto tg_yyyyyyy_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1010); 

                auto tg_yyyyyyy_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1011); 

                auto tg_yyyyyyy_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1012); 

                auto tg_yyyyyyy_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1013); 

                auto tg_yyyyyyy_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1014); 

                auto tg_yyyyyyy_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1015); 

                auto tg_yyyyyyy_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1016); 

                auto tg_yyyyyyy_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1017); 

                auto tg_yyyyyyy_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1018); 

                auto tg_yyyyyyy_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1019); 

                auto tg_yyyyyyy_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1020); 

                auto tg_yyyyyyy_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1021); 

                auto tg_yyyyyyy_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1022); 

                auto tg_yyyyyyy_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1023); 

                auto tg_yyyyyyy_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1024); 

                auto tg_yyyyyyy_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1025); 

                auto tg_yyyyyyy_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1026); 

                auto tg_yyyyyyy_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1027); 

                auto tg_yyyyyyy_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1028); 

                auto tg_yyyyyyy_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1029); 

                auto tg_yyyyyyy_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1030); 

                auto tg_yyyyyyy_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1031); 

                auto tg_yyyyyyy_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1032); 

                auto tg_yyyyyyy_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1033); 

                auto tg_yyyyyyy_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1034); 

                auto tg_yyyyyyy_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1035); 

                auto tg_yyyyyyy_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1036); 

                auto tg_yyyyyyy_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1037); 

                auto tg_yyyyyyy_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1038); 

                auto tg_yyyyyyy_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1039); 

                auto tg_yyyyyyy_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1040); 

                auto tg_yyyyyyy_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1041); 

                auto tg_yyyyyyy_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1042); 

                auto tg_yyyyyyy_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1043); 

                auto tg_yyyyyyz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1044); 

                auto tg_yyyyyyz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1045); 

                auto tg_yyyyyyz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1046); 

                auto tg_yyyyyyz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1047); 

                auto tg_yyyyyyz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1048); 

                auto tg_yyyyyyz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1049); 

                auto tg_yyyyyyz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1050); 

                auto tg_yyyyyyz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1051); 

                auto tg_yyyyyyz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1052); 

                auto tg_yyyyyyz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1053); 

                auto tg_yyyyyyz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1054); 

                auto tg_yyyyyyz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1055); 

                auto tg_yyyyyyz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1056); 

                auto tg_yyyyyyz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1057); 

                auto tg_yyyyyyz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1058); 

                auto tg_yyyyyyz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1059); 

                auto tg_yyyyyyz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1060); 

                auto tg_yyyyyyz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1061); 

                auto tg_yyyyyyz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1062); 

                auto tg_yyyyyyz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1063); 

                auto tg_yyyyyyz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1064); 

                auto tg_yyyyyyz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1065); 

                auto tg_yyyyyyz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1066); 

                auto tg_yyyyyyz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1067); 

                auto tg_yyyyyyz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1068); 

                auto tg_yyyyyyz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1069); 

                auto tg_yyyyyyz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1070); 

                auto tg_yyyyyyz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1071); 

                auto tg_yyyyyyz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1072); 

                auto tg_yyyyyyz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1073); 

                auto tg_yyyyyyz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1074); 

                auto tg_yyyyyyz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1075); 

                auto tg_yyyyyyz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1076); 

                auto tg_yyyyyyz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1077); 

                auto tg_yyyyyyz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1078); 

                auto tg_yyyyyyz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1079); 

                auto tg_yyyyyzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1080); 

                auto tg_yyyyyzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1081); 

                auto tg_yyyyyzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1082); 

                auto tg_yyyyyzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1083); 

                auto tg_yyyyyzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1084); 

                auto tg_yyyyyzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1085); 

                auto tg_yyyyyzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1086); 

                auto tg_yyyyyzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1087); 

                auto tg_yyyyyzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1088); 

                auto tg_yyyyyzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1089); 

                auto tg_yyyyyzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1090); 

                auto tg_yyyyyzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1091); 

                auto tg_yyyyyzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1092); 

                auto tg_yyyyyzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1093); 

                auto tg_yyyyyzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1094); 

                auto tg_yyyyyzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1095); 

                auto tg_yyyyyzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1096); 

                auto tg_yyyyyzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1097); 

                // Batch of Integrals (999,1098)

                #pragma omp simd aligned(fxn, fza, tg_xzzzzzz_xzzzzzz_0, tg_xzzzzzz_yyyyyyy_0, \
                                         tg_xzzzzzz_yyyyyyz_0, tg_xzzzzzz_yyyyyzz_0, tg_xzzzzzz_yyyyzzz_0, tg_xzzzzzz_yyyzzzz_0, \
                                         tg_xzzzzzz_yyzzzzz_0, tg_xzzzzzz_yzzzzzz_0, tg_xzzzzzz_zzzzzzz_0, tg_yyyyy_xxxxxxx_0, \
                                         tg_yyyyy_xxxxxxx_1, tg_yyyyy_xxxxxxy_0, tg_yyyyy_xxxxxxy_1, tg_yyyyy_xxxxxxz_0, \
                                         tg_yyyyy_xxxxxxz_1, tg_yyyyy_xxxxxyy_0, tg_yyyyy_xxxxxyy_1, tg_yyyyy_xxxxxyz_0, \
                                         tg_yyyyy_xxxxxyz_1, tg_yyyyy_xxxxxzz_0, tg_yyyyy_xxxxxzz_1, tg_yyyyy_xxxxyyy_0, \
                                         tg_yyyyy_xxxxyyy_1, tg_yyyyy_xxxxyyz_0, tg_yyyyy_xxxxyyz_1, tg_yyyyy_xxxxyzz_0, \
                                         tg_yyyyy_xxxxyzz_1, tg_yyyyy_xxxxzzz_0, tg_yyyyy_xxxxzzz_1, tg_yyyyy_xxxyyyy_0, \
                                         tg_yyyyy_xxxyyyy_1, tg_yyyyy_xxxyyyz_0, tg_yyyyy_xxxyyyz_1, tg_yyyyy_xxxyyzz_0, \
                                         tg_yyyyy_xxxyyzz_1, tg_yyyyy_xxxyzzz_0, tg_yyyyy_xxxyzzz_1, tg_yyyyy_xxxzzzz_0, \
                                         tg_yyyyy_xxxzzzz_1, tg_yyyyy_xxyyyyy_0, tg_yyyyy_xxyyyyy_1, tg_yyyyy_xxyyyyz_0, \
                                         tg_yyyyy_xxyyyyz_1, tg_yyyyy_xxyyyzz_0, tg_yyyyy_xxyyyzz_1, tg_yyyyy_xxyyzzz_0, \
                                         tg_yyyyy_xxyyzzz_1, tg_yyyyy_xxyzzzz_0, tg_yyyyy_xxyzzzz_1, tg_yyyyy_xxzzzzz_0, \
                                         tg_yyyyy_xxzzzzz_1, tg_yyyyy_xyyyyyy_0, tg_yyyyy_xyyyyyy_1, tg_yyyyy_xyyyyyz_0, \
                                         tg_yyyyy_xyyyyyz_1, tg_yyyyy_xyyyyzz_0, tg_yyyyy_xyyyyzz_1, tg_yyyyy_xyyyzzz_0, \
                                         tg_yyyyy_xyyyzzz_1, tg_yyyyy_xyyzzzz_0, tg_yyyyy_xyyzzzz_1, tg_yyyyy_xyzzzzz_0, \
                                         tg_yyyyy_xyzzzzz_1, tg_yyyyy_xzzzzzz_0, tg_yyyyy_xzzzzzz_1, tg_yyyyy_yyyyyyy_0, \
                                         tg_yyyyy_yyyyyyy_1, tg_yyyyy_yyyyyyz_0, tg_yyyyy_yyyyyyz_1, tg_yyyyy_yyyyyzz_0, \
                                         tg_yyyyy_yyyyyzz_1, tg_yyyyy_yyyyzzz_0, tg_yyyyy_yyyyzzz_1, tg_yyyyy_yyyzzzz_0, \
                                         tg_yyyyy_yyyzzzz_1, tg_yyyyy_yyzzzzz_0, tg_yyyyy_yyzzzzz_1, tg_yyyyy_yzzzzzz_0, \
                                         tg_yyyyy_yzzzzzz_1, tg_yyyyy_zzzzzzz_0, tg_yyyyy_zzzzzzz_1, tg_yyyyyy_xxxxxx_1, \
                                         tg_yyyyyy_xxxxxxx_0, tg_yyyyyy_xxxxxxx_1, tg_yyyyyy_xxxxxxy_0, tg_yyyyyy_xxxxxxy_1, \
                                         tg_yyyyyy_xxxxxxz_0, tg_yyyyyy_xxxxxxz_1, tg_yyyyyy_xxxxxy_1, tg_yyyyyy_xxxxxyy_0, \
                                         tg_yyyyyy_xxxxxyy_1, tg_yyyyyy_xxxxxyz_0, tg_yyyyyy_xxxxxyz_1, tg_yyyyyy_xxxxxz_1, \
                                         tg_yyyyyy_xxxxxzz_0, tg_yyyyyy_xxxxxzz_1, tg_yyyyyy_xxxxyy_1, tg_yyyyyy_xxxxyyy_0, \
                                         tg_yyyyyy_xxxxyyy_1, tg_yyyyyy_xxxxyyz_0, tg_yyyyyy_xxxxyyz_1, tg_yyyyyy_xxxxyz_1, \
                                         tg_yyyyyy_xxxxyzz_0, tg_yyyyyy_xxxxyzz_1, tg_yyyyyy_xxxxzz_1, tg_yyyyyy_xxxxzzz_0, \
                                         tg_yyyyyy_xxxxzzz_1, tg_yyyyyy_xxxyyy_1, tg_yyyyyy_xxxyyyy_0, tg_yyyyyy_xxxyyyy_1, \
                                         tg_yyyyyy_xxxyyyz_0, tg_yyyyyy_xxxyyyz_1, tg_yyyyyy_xxxyyz_1, tg_yyyyyy_xxxyyzz_0, \
                                         tg_yyyyyy_xxxyyzz_1, tg_yyyyyy_xxxyzz_1, tg_yyyyyy_xxxyzzz_0, tg_yyyyyy_xxxyzzz_1, \
                                         tg_yyyyyy_xxxzzz_1, tg_yyyyyy_xxxzzzz_0, tg_yyyyyy_xxxzzzz_1, tg_yyyyyy_xxyyyy_1, \
                                         tg_yyyyyy_xxyyyyy_0, tg_yyyyyy_xxyyyyy_1, tg_yyyyyy_xxyyyyz_0, tg_yyyyyy_xxyyyyz_1, \
                                         tg_yyyyyy_xxyyyz_1, tg_yyyyyy_xxyyyzz_0, tg_yyyyyy_xxyyyzz_1, tg_yyyyyy_xxyyzz_1, \
                                         tg_yyyyyy_xxyyzzz_0, tg_yyyyyy_xxyyzzz_1, tg_yyyyyy_xxyzzz_1, tg_yyyyyy_xxyzzzz_0, \
                                         tg_yyyyyy_xxyzzzz_1, tg_yyyyyy_xxzzzz_1, tg_yyyyyy_xxzzzzz_0, tg_yyyyyy_xxzzzzz_1, \
                                         tg_yyyyyy_xyyyyy_1, tg_yyyyyy_xyyyyyy_0, tg_yyyyyy_xyyyyyy_1, tg_yyyyyy_xyyyyyz_0, \
                                         tg_yyyyyy_xyyyyyz_1, tg_yyyyyy_xyyyyz_1, tg_yyyyyy_xyyyyzz_0, tg_yyyyyy_xyyyyzz_1, \
                                         tg_yyyyyy_xyyyzz_1, tg_yyyyyy_xyyyzzz_0, tg_yyyyyy_xyyyzzz_1, tg_yyyyyy_xyyzzz_1, \
                                         tg_yyyyyy_xyyzzzz_0, tg_yyyyyy_xyyzzzz_1, tg_yyyyyy_xyzzzz_1, tg_yyyyyy_xyzzzzz_0, \
                                         tg_yyyyyy_xyzzzzz_1, tg_yyyyyy_xzzzzz_1, tg_yyyyyy_xzzzzzz_0, tg_yyyyyy_xzzzzzz_1, \
                                         tg_yyyyyy_yyyyyy_1, tg_yyyyyy_yyyyyyy_0, tg_yyyyyy_yyyyyyy_1, tg_yyyyyy_yyyyyyz_0, \
                                         tg_yyyyyy_yyyyyyz_1, tg_yyyyyy_yyyyyz_1, tg_yyyyyy_yyyyyzz_0, tg_yyyyyy_yyyyyzz_1, \
                                         tg_yyyyyy_yyyyzz_1, tg_yyyyyy_yyyyzzz_0, tg_yyyyyy_yyyyzzz_1, tg_yyyyyy_yyyzzz_1, \
                                         tg_yyyyyy_yyyzzzz_0, tg_yyyyyy_yyyzzzz_1, tg_yyyyyy_yyzzzz_1, tg_yyyyyy_yyzzzzz_0, \
                                         tg_yyyyyy_yyzzzzz_1, tg_yyyyyy_yzzzzz_1, tg_yyyyyy_yzzzzzz_0, tg_yyyyyy_yzzzzzz_1, \
                                         tg_yyyyyy_zzzzzz_1, tg_yyyyyy_zzzzzzz_0, tg_yyyyyy_zzzzzzz_1, tg_yyyyyyy_xxxxxxx_0, \
                                         tg_yyyyyyy_xxxxxxy_0, tg_yyyyyyy_xxxxxxz_0, tg_yyyyyyy_xxxxxyy_0, tg_yyyyyyy_xxxxxyz_0, \
                                         tg_yyyyyyy_xxxxxzz_0, tg_yyyyyyy_xxxxyyy_0, tg_yyyyyyy_xxxxyyz_0, tg_yyyyyyy_xxxxyzz_0, \
                                         tg_yyyyyyy_xxxxzzz_0, tg_yyyyyyy_xxxyyyy_0, tg_yyyyyyy_xxxyyyz_0, tg_yyyyyyy_xxxyyzz_0, \
                                         tg_yyyyyyy_xxxyzzz_0, tg_yyyyyyy_xxxzzzz_0, tg_yyyyyyy_xxyyyyy_0, tg_yyyyyyy_xxyyyyz_0, \
                                         tg_yyyyyyy_xxyyyzz_0, tg_yyyyyyy_xxyyzzz_0, tg_yyyyyyy_xxyzzzz_0, tg_yyyyyyy_xxzzzzz_0, \
                                         tg_yyyyyyy_xyyyyyy_0, tg_yyyyyyy_xyyyyyz_0, tg_yyyyyyy_xyyyyzz_0, tg_yyyyyyy_xyyyzzz_0, \
                                         tg_yyyyyyy_xyyzzzz_0, tg_yyyyyyy_xyzzzzz_0, tg_yyyyyyy_xzzzzzz_0, tg_yyyyyyy_yyyyyyy_0, \
                                         tg_yyyyyyy_yyyyyyz_0, tg_yyyyyyy_yyyyyzz_0, tg_yyyyyyy_yyyyzzz_0, tg_yyyyyyy_yyyzzzz_0, \
                                         tg_yyyyyyy_yyzzzzz_0, tg_yyyyyyy_yzzzzzz_0, tg_yyyyyyy_zzzzzzz_0, tg_yyyyyyz_xxxxxxx_0, \
                                         tg_yyyyyyz_xxxxxxy_0, tg_yyyyyyz_xxxxxxz_0, tg_yyyyyyz_xxxxxyy_0, tg_yyyyyyz_xxxxxyz_0, \
                                         tg_yyyyyyz_xxxxxzz_0, tg_yyyyyyz_xxxxyyy_0, tg_yyyyyyz_xxxxyyz_0, tg_yyyyyyz_xxxxyzz_0, \
                                         tg_yyyyyyz_xxxxzzz_0, tg_yyyyyyz_xxxyyyy_0, tg_yyyyyyz_xxxyyyz_0, tg_yyyyyyz_xxxyyzz_0, \
                                         tg_yyyyyyz_xxxyzzz_0, tg_yyyyyyz_xxxzzzz_0, tg_yyyyyyz_xxyyyyy_0, tg_yyyyyyz_xxyyyyz_0, \
                                         tg_yyyyyyz_xxyyyzz_0, tg_yyyyyyz_xxyyzzz_0, tg_yyyyyyz_xxyzzzz_0, tg_yyyyyyz_xxzzzzz_0, \
                                         tg_yyyyyyz_xyyyyyy_0, tg_yyyyyyz_xyyyyyz_0, tg_yyyyyyz_xyyyyzz_0, tg_yyyyyyz_xyyyzzz_0, \
                                         tg_yyyyyyz_xyyzzzz_0, tg_yyyyyyz_xyzzzzz_0, tg_yyyyyyz_xzzzzzz_0, tg_yyyyyyz_yyyyyyy_0, \
                                         tg_yyyyyyz_yyyyyyz_0, tg_yyyyyyz_yyyyyzz_0, tg_yyyyyyz_yyyyzzz_0, tg_yyyyyyz_yyyzzzz_0, \
                                         tg_yyyyyyz_yyzzzzz_0, tg_yyyyyyz_yzzzzzz_0, tg_yyyyyyz_zzzzzzz_0, tg_yyyyyz_xxxxxx_1, \
                                         tg_yyyyyz_xxxxxxx_0, tg_yyyyyz_xxxxxxx_1, tg_yyyyyz_xxxxxxy_0, tg_yyyyyz_xxxxxxy_1, \
                                         tg_yyyyyz_xxxxxxz_0, tg_yyyyyz_xxxxxxz_1, tg_yyyyyz_xxxxxy_1, tg_yyyyyz_xxxxxyy_0, \
                                         tg_yyyyyz_xxxxxyy_1, tg_yyyyyz_xxxxxyz_0, tg_yyyyyz_xxxxxyz_1, tg_yyyyyz_xxxxxz_1, \
                                         tg_yyyyyz_xxxxxzz_0, tg_yyyyyz_xxxxxzz_1, tg_yyyyyz_xxxxyy_1, tg_yyyyyz_xxxxyyy_0, \
                                         tg_yyyyyz_xxxxyyy_1, tg_yyyyyz_xxxxyyz_0, tg_yyyyyz_xxxxyyz_1, tg_yyyyyz_xxxxyz_1, \
                                         tg_yyyyyz_xxxxyzz_0, tg_yyyyyz_xxxxyzz_1, tg_yyyyyz_xxxxzz_1, tg_yyyyyz_xxxxzzz_0, \
                                         tg_yyyyyz_xxxxzzz_1, tg_yyyyyz_xxxyyy_1, tg_yyyyyz_xxxyyyy_0, tg_yyyyyz_xxxyyyy_1, \
                                         tg_yyyyyz_xxxyyyz_0, tg_yyyyyz_xxxyyyz_1, tg_yyyyyz_xxxyyz_1, tg_yyyyyz_xxxyyzz_0, \
                                         tg_yyyyyz_xxxyyzz_1, tg_yyyyyz_xxxyzz_1, tg_yyyyyz_xxxyzzz_0, tg_yyyyyz_xxxyzzz_1, \
                                         tg_yyyyyz_xxxzzz_1, tg_yyyyyz_xxxzzzz_0, tg_yyyyyz_xxxzzzz_1, tg_yyyyyz_xxyyyy_1, \
                                         tg_yyyyyz_xxyyyyy_0, tg_yyyyyz_xxyyyyy_1, tg_yyyyyz_xxyyyyz_0, tg_yyyyyz_xxyyyyz_1, \
                                         tg_yyyyyz_xxyyyz_1, tg_yyyyyz_xxyyyzz_0, tg_yyyyyz_xxyyyzz_1, tg_yyyyyz_xxyyzz_1, \
                                         tg_yyyyyz_xxyyzzz_0, tg_yyyyyz_xxyyzzz_1, tg_yyyyyz_xxyzzz_1, tg_yyyyyz_xxyzzzz_0, \
                                         tg_yyyyyz_xxyzzzz_1, tg_yyyyyz_xxzzzz_1, tg_yyyyyz_xxzzzzz_0, tg_yyyyyz_xxzzzzz_1, \
                                         tg_yyyyyz_xyyyyy_1, tg_yyyyyz_xyyyyyy_0, tg_yyyyyz_xyyyyyy_1, tg_yyyyyz_xyyyyyz_0, \
                                         tg_yyyyyz_xyyyyyz_1, tg_yyyyyz_xyyyyz_1, tg_yyyyyz_xyyyyzz_0, tg_yyyyyz_xyyyyzz_1, \
                                         tg_yyyyyz_xyyyzz_1, tg_yyyyyz_xyyyzzz_0, tg_yyyyyz_xyyyzzz_1, tg_yyyyyz_xyyzzz_1, \
                                         tg_yyyyyz_xyyzzzz_0, tg_yyyyyz_xyyzzzz_1, tg_yyyyyz_xyzzzz_1, tg_yyyyyz_xyzzzzz_0, \
                                         tg_yyyyyz_xyzzzzz_1, tg_yyyyyz_xzzzzz_1, tg_yyyyyz_xzzzzzz_0, tg_yyyyyz_xzzzzzz_1, \
                                         tg_yyyyyz_yyyyyy_1, tg_yyyyyz_yyyyyyy_0, tg_yyyyyz_yyyyyyy_1, tg_yyyyyz_yyyyyyz_0, \
                                         tg_yyyyyz_yyyyyyz_1, tg_yyyyyz_yyyyyz_1, tg_yyyyyz_yyyyyzz_0, tg_yyyyyz_yyyyyzz_1, \
                                         tg_yyyyyz_yyyyzz_1, tg_yyyyyz_yyyyzzz_0, tg_yyyyyz_yyyyzzz_1, tg_yyyyyz_yyyzzz_1, \
                                         tg_yyyyyz_yyyzzzz_0, tg_yyyyyz_yyyzzzz_1, tg_yyyyyz_yyzzzz_1, tg_yyyyyz_yyzzzzz_0, \
                                         tg_yyyyyz_yyzzzzz_1, tg_yyyyyz_yzzzzz_1, tg_yyyyyz_yzzzzzz_0, tg_yyyyyz_yzzzzzz_1, \
                                         tg_yyyyyz_zzzzzz_1, tg_yyyyyz_zzzzzzz_0, tg_yyyyyz_zzzzzzz_1, tg_yyyyyzz_xxxxxxx_0, \
                                         tg_yyyyyzz_xxxxxxy_0, tg_yyyyyzz_xxxxxxz_0, tg_yyyyyzz_xxxxxyy_0, tg_yyyyyzz_xxxxxyz_0, \
                                         tg_yyyyyzz_xxxxxzz_0, tg_yyyyyzz_xxxxyyy_0, tg_yyyyyzz_xxxxyyz_0, tg_yyyyyzz_xxxxyzz_0, \
                                         tg_yyyyyzz_xxxxzzz_0, tg_yyyyyzz_xxxyyyy_0, tg_yyyyyzz_xxxyyyz_0, tg_yyyyyzz_xxxyyzz_0, \
                                         tg_yyyyyzz_xxxyzzz_0, tg_yyyyyzz_xxxzzzz_0, tg_yyyyyzz_xxyyyyy_0, tg_yyyyyzz_xxyyyyz_0, \
                                         tg_yyyyyzz_xxyyyzz_0, tg_yyyyz_xxxxxxx_0, tg_yyyyz_xxxxxxx_1, tg_yyyyz_xxxxxxy_0, \
                                         tg_yyyyz_xxxxxxy_1, tg_yyyyz_xxxxxxz_0, tg_yyyyz_xxxxxxz_1, tg_yyyyz_xxxxxyy_0, \
                                         tg_yyyyz_xxxxxyy_1, tg_yyyyz_xxxxxyz_0, tg_yyyyz_xxxxxyz_1, tg_yyyyz_xxxxxzz_0, \
                                         tg_yyyyz_xxxxxzz_1, tg_yyyyz_xxxxyyy_0, tg_yyyyz_xxxxyyy_1, tg_yyyyz_xxxxyyz_0, \
                                         tg_yyyyz_xxxxyyz_1, tg_yyyyz_xxxxyzz_0, tg_yyyyz_xxxxyzz_1, tg_yyyyz_xxxxzzz_0, \
                                         tg_yyyyz_xxxxzzz_1, tg_yyyyz_xxxyyyy_0, tg_yyyyz_xxxyyyy_1, tg_yyyyz_xxxyyyz_0, \
                                         tg_yyyyz_xxxyyyz_1, tg_yyyyz_xxxyyzz_0, tg_yyyyz_xxxyyzz_1, tg_yyyyz_xxxyzzz_0, \
                                         tg_yyyyz_xxxyzzz_1, tg_yyyyz_xxxzzzz_0, tg_yyyyz_xxxzzzz_1, tg_yyyyz_xxyyyyy_0, \
                                         tg_yyyyz_xxyyyyy_1, tg_yyyyz_xxyyyyz_0, tg_yyyyz_xxyyyyz_1, tg_yyyyz_xxyyyzz_0, \
                                         tg_yyyyz_xxyyyzz_1, tg_yyyyz_xxyyzzz_0, tg_yyyyz_xxyyzzz_1, tg_yyyyz_xxyzzzz_0, \
                                         tg_yyyyz_xxyzzzz_1, tg_yyyyz_xxzzzzz_0, tg_yyyyz_xxzzzzz_1, tg_yyyyz_xyyyyyy_0, \
                                         tg_yyyyz_xyyyyyy_1, tg_yyyyz_xyyyyyz_0, tg_yyyyz_xyyyyyz_1, tg_yyyyz_xyyyyzz_0, \
                                         tg_yyyyz_xyyyyzz_1, tg_yyyyz_xyyyzzz_0, tg_yyyyz_xyyyzzz_1, tg_yyyyz_xyyzzzz_0, \
                                         tg_yyyyz_xyyzzzz_1, tg_yyyyz_xyzzzzz_0, tg_yyyyz_xyzzzzz_1, tg_yyyyz_xzzzzzz_0, \
                                         tg_yyyyz_xzzzzzz_1, tg_yyyyz_yyyyyyy_0, tg_yyyyz_yyyyyyy_1, tg_yyyyz_yyyyyyz_0, \
                                         tg_yyyyz_yyyyyyz_1, tg_yyyyz_yyyyyzz_0, tg_yyyyz_yyyyyzz_1, tg_yyyyz_yyyyzzz_0, \
                                         tg_yyyyz_yyyyzzz_1, tg_yyyyz_yyyzzzz_0, tg_yyyyz_yyyzzzz_1, tg_yyyyz_yyzzzzz_0, \
                                         tg_yyyyz_yyzzzzz_1, tg_yyyyz_yzzzzzz_0, tg_yyyyz_yzzzzzz_1, tg_yyyyz_zzzzzzz_0, \
                                         tg_yyyyz_zzzzzzz_1, tg_yyyyzz_xxxxxx_1, tg_yyyyzz_xxxxxxx_0, tg_yyyyzz_xxxxxxx_1, \
                                         tg_yyyyzz_xxxxxxy_0, tg_yyyyzz_xxxxxxy_1, tg_yyyyzz_xxxxxxz_0, tg_yyyyzz_xxxxxxz_1, \
                                         tg_yyyyzz_xxxxxy_1, tg_yyyyzz_xxxxxyy_0, tg_yyyyzz_xxxxxyy_1, tg_yyyyzz_xxxxxyz_0, \
                                         tg_yyyyzz_xxxxxyz_1, tg_yyyyzz_xxxxxz_1, tg_yyyyzz_xxxxxzz_0, tg_yyyyzz_xxxxxzz_1, \
                                         tg_yyyyzz_xxxxyy_1, tg_yyyyzz_xxxxyyy_0, tg_yyyyzz_xxxxyyy_1, tg_yyyyzz_xxxxyyz_0, \
                                         tg_yyyyzz_xxxxyyz_1, tg_yyyyzz_xxxxyz_1, tg_yyyyzz_xxxxyzz_0, tg_yyyyzz_xxxxyzz_1, \
                                         tg_yyyyzz_xxxxzz_1, tg_yyyyzz_xxxxzzz_0, tg_yyyyzz_xxxxzzz_1, tg_yyyyzz_xxxyyy_1, \
                                         tg_yyyyzz_xxxyyyy_0, tg_yyyyzz_xxxyyyy_1, tg_yyyyzz_xxxyyyz_0, tg_yyyyzz_xxxyyyz_1, \
                                         tg_yyyyzz_xxxyyz_1, tg_yyyyzz_xxxyyzz_0, tg_yyyyzz_xxxyyzz_1, tg_yyyyzz_xxxyzz_1, \
                                         tg_yyyyzz_xxxyzzz_0, tg_yyyyzz_xxxyzzz_1, tg_yyyyzz_xxxzzz_1, tg_yyyyzz_xxxzzzz_0, \
                                         tg_yyyyzz_xxxzzzz_1, tg_yyyyzz_xxyyyy_1, tg_yyyyzz_xxyyyyy_0, tg_yyyyzz_xxyyyyy_1, \
                                         tg_yyyyzz_xxyyyyz_0, tg_yyyyzz_xxyyyyz_1, tg_yyyyzz_xxyyyz_1, tg_yyyyzz_xxyyyzz_0, \
                                         tg_yyyyzz_xxyyyzz_1, tg_yyyyzz_xxyyzz_1, tg_yyyzz_xxxxxxx_0, tg_yyyzz_xxxxxxx_1, \
                                         tg_yyyzz_xxxxxxy_0, tg_yyyzz_xxxxxxy_1, tg_yyyzz_xxxxxxz_0, tg_yyyzz_xxxxxxz_1, \
                                         tg_yyyzz_xxxxxyy_0, tg_yyyzz_xxxxxyy_1, tg_yyyzz_xxxxxyz_0, tg_yyyzz_xxxxxyz_1, \
                                         tg_yyyzz_xxxxxzz_0, tg_yyyzz_xxxxxzz_1, tg_yyyzz_xxxxyyy_0, tg_yyyzz_xxxxyyy_1, \
                                         tg_yyyzz_xxxxyyz_0, tg_yyyzz_xxxxyyz_1, tg_yyyzz_xxxxyzz_0, tg_yyyzz_xxxxyzz_1, \
                                         tg_yyyzz_xxxxzzz_0, tg_yyyzz_xxxxzzz_1, tg_yyyzz_xxxyyyy_0, tg_yyyzz_xxxyyyy_1, \
                                         tg_yyyzz_xxxyyyz_0, tg_yyyzz_xxxyyyz_1, tg_yyyzz_xxxyyzz_0, tg_yyyzz_xxxyyzz_1, \
                                         tg_yyyzz_xxxyzzz_0, tg_yyyzz_xxxyzzz_1, tg_yyyzz_xxxzzzz_0, tg_yyyzz_xxxzzzz_1, \
                                         tg_yyyzz_xxyyyyy_0, tg_yyyzz_xxyyyyy_1, tg_yyyzz_xxyyyyz_0, tg_yyyzz_xxyyyyz_1, \
                                         tg_yyyzz_xxyyyzz_0, tg_yyyzz_xxyyyzz_1, tg_zzzzzz_xzzzzzz_0, tg_zzzzzz_xzzzzzz_1, \
                                         tg_zzzzzz_yyyyyyy_0, tg_zzzzzz_yyyyyyy_1, tg_zzzzzz_yyyyyyz_0, tg_zzzzzz_yyyyyyz_1, \
                                         tg_zzzzzz_yyyyyzz_0, tg_zzzzzz_yyyyyzz_1, tg_zzzzzz_yyyyzzz_0, tg_zzzzzz_yyyyzzz_1, \
                                         tg_zzzzzz_yyyzzzz_0, tg_zzzzzz_yyyzzzz_1, tg_zzzzzz_yyzzzzz_0, tg_zzzzzz_yyzzzzz_1, \
                                         tg_zzzzzz_yzzzzzz_0, tg_zzzzzz_yzzzzzz_1, tg_zzzzzz_zzzzzz_1, tg_zzzzzz_zzzzzzz_0, \
                                         tg_zzzzzz_zzzzzzz_1, wp_x, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xzzzzzz_xzzzzzz_0[j] = pb_x * tg_zzzzzz_xzzzzzz_0[j] + fr * tg_zzzzzz_xzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_zzzzzz_1[j];

                    tg_xzzzzzz_yyyyyyy_0[j] = pb_x * tg_zzzzzz_yyyyyyy_0[j] + fr * tg_zzzzzz_yyyyyyy_1[j];

                    tg_xzzzzzz_yyyyyyz_0[j] = pb_x * tg_zzzzzz_yyyyyyz_0[j] + fr * tg_zzzzzz_yyyyyyz_1[j];

                    tg_xzzzzzz_yyyyyzz_0[j] = pb_x * tg_zzzzzz_yyyyyzz_0[j] + fr * tg_zzzzzz_yyyyyzz_1[j];

                    tg_xzzzzzz_yyyyzzz_0[j] = pb_x * tg_zzzzzz_yyyyzzz_0[j] + fr * tg_zzzzzz_yyyyzzz_1[j];

                    tg_xzzzzzz_yyyzzzz_0[j] = pb_x * tg_zzzzzz_yyyzzzz_0[j] + fr * tg_zzzzzz_yyyzzzz_1[j];

                    tg_xzzzzzz_yyzzzzz_0[j] = pb_x * tg_zzzzzz_yyzzzzz_0[j] + fr * tg_zzzzzz_yyzzzzz_1[j];

                    tg_xzzzzzz_yzzzzzz_0[j] = pb_x * tg_zzzzzz_yzzzzzz_0[j] + fr * tg_zzzzzz_yzzzzzz_1[j];

                    tg_xzzzzzz_zzzzzzz_0[j] = pb_x * tg_zzzzzz_zzzzzzz_0[j] + fr * tg_zzzzzz_zzzzzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyyy_xxxxxxx_0[j] = pb_y * tg_yyyyyy_xxxxxxx_0[j] + fr * tg_yyyyyy_xxxxxxx_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxxx_0[j] - tg_yyyyy_xxxxxxx_1[j] * fl1_fza);

                    tg_yyyyyyy_xxxxxxy_0[j] = pb_y * tg_yyyyyy_xxxxxxy_0[j] + fr * tg_yyyyyy_xxxxxxy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxxy_0[j] - tg_yyyyy_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xxxxxx_1[j];

                    tg_yyyyyyy_xxxxxxz_0[j] = pb_y * tg_yyyyyy_xxxxxxz_0[j] + fr * tg_yyyyyy_xxxxxxz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxxz_0[j] - tg_yyyyy_xxxxxxz_1[j] * fl1_fza);

                    tg_yyyyyyy_xxxxxyy_0[j] = pb_y * tg_yyyyyy_xxxxxyy_0[j] + fr * tg_yyyyyy_xxxxxyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxyy_0[j] - tg_yyyyy_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_xxxxxy_1[j];

                    tg_yyyyyyy_xxxxxyz_0[j] = pb_y * tg_yyyyyy_xxxxxyz_0[j] + fr * tg_yyyyyy_xxxxxyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxyz_0[j] - tg_yyyyy_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xxxxxz_1[j];

                    tg_yyyyyyy_xxxxxzz_0[j] = pb_y * tg_yyyyyy_xxxxxzz_0[j] + fr * tg_yyyyyy_xxxxxzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxxzz_0[j] - tg_yyyyy_xxxxxzz_1[j] * fl1_fza);

                    tg_yyyyyyy_xxxxyyy_0[j] = pb_y * tg_yyyyyy_xxxxyyy_0[j] + fr * tg_yyyyyy_xxxxyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxyyy_0[j] - tg_yyyyy_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyy_xxxxyy_1[j];

                    tg_yyyyyyy_xxxxyyz_0[j] = pb_y * tg_yyyyyy_xxxxyyz_0[j] + fr * tg_yyyyyy_xxxxyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxyyz_0[j] - tg_yyyyy_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_xxxxyz_1[j];

                    tg_yyyyyyy_xxxxyzz_0[j] = pb_y * tg_yyyyyy_xxxxyzz_0[j] + fr * tg_yyyyyy_xxxxyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxyzz_0[j] - tg_yyyyy_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xxxxzz_1[j];

                    tg_yyyyyyy_xxxxzzz_0[j] = pb_y * tg_yyyyyy_xxxxzzz_0[j] + fr * tg_yyyyyy_xxxxzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxxzzz_0[j] - tg_yyyyy_xxxxzzz_1[j] * fl1_fza);

                    tg_yyyyyyy_xxxyyyy_0[j] = pb_y * tg_yyyyyy_xxxyyyy_0[j] + fr * tg_yyyyyy_xxxyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxyyyy_0[j] - tg_yyyyy_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyy_xxxyyy_1[j];

                    tg_yyyyyyy_xxxyyyz_0[j] = pb_y * tg_yyyyyy_xxxyyyz_0[j] + fr * tg_yyyyyy_xxxyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxyyyz_0[j] - tg_yyyyy_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyy_xxxyyz_1[j];

                    tg_yyyyyyy_xxxyyzz_0[j] = pb_y * tg_yyyyyy_xxxyyzz_0[j] + fr * tg_yyyyyy_xxxyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxyyzz_0[j] - tg_yyyyy_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_xxxyzz_1[j];

                    tg_yyyyyyy_xxxyzzz_0[j] = pb_y * tg_yyyyyy_xxxyzzz_0[j] + fr * tg_yyyyyy_xxxyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxyzzz_0[j] - tg_yyyyy_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xxxzzz_1[j];

                    tg_yyyyyyy_xxxzzzz_0[j] = pb_y * tg_yyyyyy_xxxzzzz_0[j] + fr * tg_yyyyyy_xxxzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxxzzzz_0[j] - tg_yyyyy_xxxzzzz_1[j] * fl1_fza);

                    tg_yyyyyyy_xxyyyyy_0[j] = pb_y * tg_yyyyyy_xxyyyyy_0[j] + fr * tg_yyyyyy_xxyyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxyyyyy_0[j] - tg_yyyyy_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyy_xxyyyy_1[j];

                    tg_yyyyyyy_xxyyyyz_0[j] = pb_y * tg_yyyyyy_xxyyyyz_0[j] + fr * tg_yyyyyy_xxyyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxyyyyz_0[j] - tg_yyyyy_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyy_xxyyyz_1[j];

                    tg_yyyyyyy_xxyyyzz_0[j] = pb_y * tg_yyyyyy_xxyyyzz_0[j] + fr * tg_yyyyyy_xxyyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxyyyzz_0[j] - tg_yyyyy_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyy_xxyyzz_1[j];

                    tg_yyyyyyy_xxyyzzz_0[j] = pb_y * tg_yyyyyy_xxyyzzz_0[j] + fr * tg_yyyyyy_xxyyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxyyzzz_0[j] - tg_yyyyy_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_xxyzzz_1[j];

                    tg_yyyyyyy_xxyzzzz_0[j] = pb_y * tg_yyyyyy_xxyzzzz_0[j] + fr * tg_yyyyyy_xxyzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxyzzzz_0[j] - tg_yyyyy_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xxzzzz_1[j];

                    tg_yyyyyyy_xxzzzzz_0[j] = pb_y * tg_yyyyyy_xxzzzzz_0[j] + fr * tg_yyyyyy_xxzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xxzzzzz_0[j] - tg_yyyyy_xxzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyy_xyyyyyy_0[j] = pb_y * tg_yyyyyy_xyyyyyy_0[j] + fr * tg_yyyyyy_xyyyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyyyyyy_0[j] - tg_yyyyy_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyy_xyyyyy_1[j];

                    tg_yyyyyyy_xyyyyyz_0[j] = pb_y * tg_yyyyyy_xyyyyyz_0[j] + fr * tg_yyyyyy_xyyyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyyyyyz_0[j] - tg_yyyyy_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyy_xyyyyz_1[j];

                    tg_yyyyyyy_xyyyyzz_0[j] = pb_y * tg_yyyyyy_xyyyyzz_0[j] + fr * tg_yyyyyy_xyyyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyyyyzz_0[j] - tg_yyyyy_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyy_xyyyzz_1[j];

                    tg_yyyyyyy_xyyyzzz_0[j] = pb_y * tg_yyyyyy_xyyyzzz_0[j] + fr * tg_yyyyyy_xyyyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyyyzzz_0[j] - tg_yyyyy_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyy_xyyzzz_1[j];

                    tg_yyyyyyy_xyyzzzz_0[j] = pb_y * tg_yyyyyy_xyyzzzz_0[j] + fr * tg_yyyyyy_xyyzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyyzzzz_0[j] - tg_yyyyy_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_xyzzzz_1[j];

                    tg_yyyyyyy_xyzzzzz_0[j] = pb_y * tg_yyyyyy_xyzzzzz_0[j] + fr * tg_yyyyyy_xyzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xyzzzzz_0[j] - tg_yyyyy_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_xzzzzz_1[j];

                    tg_yyyyyyy_xzzzzzz_0[j] = pb_y * tg_yyyyyy_xzzzzzz_0[j] + fr * tg_yyyyyy_xzzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_xzzzzzz_0[j] - tg_yyyyy_xzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyy_yyyyyyy_0[j] = pb_y * tg_yyyyyy_yyyyyyy_0[j] + fr * tg_yyyyyy_yyyyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyyyyyy_0[j] - tg_yyyyy_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyyy_yyyyyy_1[j];

                    tg_yyyyyyy_yyyyyyz_0[j] = pb_y * tg_yyyyyy_yyyyyyz_0[j] + fr * tg_yyyyyy_yyyyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyyyyyz_0[j] - tg_yyyyy_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyy_yyyyyz_1[j];

                    tg_yyyyyyy_yyyyyzz_0[j] = pb_y * tg_yyyyyy_yyyyyzz_0[j] + fr * tg_yyyyyy_yyyyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyyyyzz_0[j] - tg_yyyyy_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyy_yyyyzz_1[j];

                    tg_yyyyyyy_yyyyzzz_0[j] = pb_y * tg_yyyyyy_yyyyzzz_0[j] + fr * tg_yyyyyy_yyyyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyyyzzz_0[j] - tg_yyyyy_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyy_yyyzzz_1[j];

                    tg_yyyyyyy_yyyzzzz_0[j] = pb_y * tg_yyyyyy_yyyzzzz_0[j] + fr * tg_yyyyyy_yyyzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyyzzzz_0[j] - tg_yyyyy_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyy_yyzzzz_1[j];

                    tg_yyyyyyy_yyzzzzz_0[j] = pb_y * tg_yyyyyy_yyzzzzz_0[j] + fr * tg_yyyyyy_yyzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yyzzzzz_0[j] - tg_yyyyy_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyy_yzzzzz_1[j];

                    tg_yyyyyyy_yzzzzzz_0[j] = pb_y * tg_yyyyyy_yzzzzzz_0[j] + fr * tg_yyyyyy_yzzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_yzzzzzz_0[j] - tg_yyyyy_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyy_zzzzzz_1[j];

                    tg_yyyyyyy_zzzzzzz_0[j] = pb_y * tg_yyyyyy_zzzzzzz_0[j] + fr * tg_yyyyyy_zzzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyy_zzzzzzz_0[j] - tg_yyyyy_zzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyz_xxxxxxx_0[j] = pb_y * tg_yyyyyz_xxxxxxx_0[j] + fr * tg_yyyyyz_xxxxxxx_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxxx_0[j] - tg_yyyyz_xxxxxxx_1[j] * fl1_fza);

                    tg_yyyyyyz_xxxxxxy_0[j] = pb_y * tg_yyyyyz_xxxxxxy_0[j] + fr * tg_yyyyyz_xxxxxxy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxxy_0[j] - tg_yyyyz_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xxxxxx_1[j];

                    tg_yyyyyyz_xxxxxxz_0[j] = pb_y * tg_yyyyyz_xxxxxxz_0[j] + fr * tg_yyyyyz_xxxxxxz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxxz_0[j] - tg_yyyyz_xxxxxxz_1[j] * fl1_fza);

                    tg_yyyyyyz_xxxxxyy_0[j] = pb_y * tg_yyyyyz_xxxxxyy_0[j] + fr * tg_yyyyyz_xxxxxyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxyy_0[j] - tg_yyyyz_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_xxxxxy_1[j];

                    tg_yyyyyyz_xxxxxyz_0[j] = pb_y * tg_yyyyyz_xxxxxyz_0[j] + fr * tg_yyyyyz_xxxxxyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxyz_0[j] - tg_yyyyz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xxxxxz_1[j];

                    tg_yyyyyyz_xxxxxzz_0[j] = pb_y * tg_yyyyyz_xxxxxzz_0[j] + fr * tg_yyyyyz_xxxxxzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxxzz_0[j] - tg_yyyyz_xxxxxzz_1[j] * fl1_fza);

                    tg_yyyyyyz_xxxxyyy_0[j] = pb_y * tg_yyyyyz_xxxxyyy_0[j] + fr * tg_yyyyyz_xxxxyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxyyy_0[j] - tg_yyyyz_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyz_xxxxyy_1[j];

                    tg_yyyyyyz_xxxxyyz_0[j] = pb_y * tg_yyyyyz_xxxxyyz_0[j] + fr * tg_yyyyyz_xxxxyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxyyz_0[j] - tg_yyyyz_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_xxxxyz_1[j];

                    tg_yyyyyyz_xxxxyzz_0[j] = pb_y * tg_yyyyyz_xxxxyzz_0[j] + fr * tg_yyyyyz_xxxxyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxyzz_0[j] - tg_yyyyz_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xxxxzz_1[j];

                    tg_yyyyyyz_xxxxzzz_0[j] = pb_y * tg_yyyyyz_xxxxzzz_0[j] + fr * tg_yyyyyz_xxxxzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxxzzz_0[j] - tg_yyyyz_xxxxzzz_1[j] * fl1_fza);

                    tg_yyyyyyz_xxxyyyy_0[j] = pb_y * tg_yyyyyz_xxxyyyy_0[j] + fr * tg_yyyyyz_xxxyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxyyyy_0[j] - tg_yyyyz_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyz_xxxyyy_1[j];

                    tg_yyyyyyz_xxxyyyz_0[j] = pb_y * tg_yyyyyz_xxxyyyz_0[j] + fr * tg_yyyyyz_xxxyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxyyyz_0[j] - tg_yyyyz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyz_xxxyyz_1[j];

                    tg_yyyyyyz_xxxyyzz_0[j] = pb_y * tg_yyyyyz_xxxyyzz_0[j] + fr * tg_yyyyyz_xxxyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxyyzz_0[j] - tg_yyyyz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_xxxyzz_1[j];

                    tg_yyyyyyz_xxxyzzz_0[j] = pb_y * tg_yyyyyz_xxxyzzz_0[j] + fr * tg_yyyyyz_xxxyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxyzzz_0[j] - tg_yyyyz_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xxxzzz_1[j];

                    tg_yyyyyyz_xxxzzzz_0[j] = pb_y * tg_yyyyyz_xxxzzzz_0[j] + fr * tg_yyyyyz_xxxzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxxzzzz_0[j] - tg_yyyyz_xxxzzzz_1[j] * fl1_fza);

                    tg_yyyyyyz_xxyyyyy_0[j] = pb_y * tg_yyyyyz_xxyyyyy_0[j] + fr * tg_yyyyyz_xxyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxyyyyy_0[j] - tg_yyyyz_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyz_xxyyyy_1[j];

                    tg_yyyyyyz_xxyyyyz_0[j] = pb_y * tg_yyyyyz_xxyyyyz_0[j] + fr * tg_yyyyyz_xxyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxyyyyz_0[j] - tg_yyyyz_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyz_xxyyyz_1[j];

                    tg_yyyyyyz_xxyyyzz_0[j] = pb_y * tg_yyyyyz_xxyyyzz_0[j] + fr * tg_yyyyyz_xxyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxyyyzz_0[j] - tg_yyyyz_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyz_xxyyzz_1[j];

                    tg_yyyyyyz_xxyyzzz_0[j] = pb_y * tg_yyyyyz_xxyyzzz_0[j] + fr * tg_yyyyyz_xxyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxyyzzz_0[j] - tg_yyyyz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_xxyzzz_1[j];

                    tg_yyyyyyz_xxyzzzz_0[j] = pb_y * tg_yyyyyz_xxyzzzz_0[j] + fr * tg_yyyyyz_xxyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxyzzzz_0[j] - tg_yyyyz_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xxzzzz_1[j];

                    tg_yyyyyyz_xxzzzzz_0[j] = pb_y * tg_yyyyyz_xxzzzzz_0[j] + fr * tg_yyyyyz_xxzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xxzzzzz_0[j] - tg_yyyyz_xxzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyz_xyyyyyy_0[j] = pb_y * tg_yyyyyz_xyyyyyy_0[j] + fr * tg_yyyyyz_xyyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyyyyyy_0[j] - tg_yyyyz_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyz_xyyyyy_1[j];

                    tg_yyyyyyz_xyyyyyz_0[j] = pb_y * tg_yyyyyz_xyyyyyz_0[j] + fr * tg_yyyyyz_xyyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyyyyyz_0[j] - tg_yyyyz_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyz_xyyyyz_1[j];

                    tg_yyyyyyz_xyyyyzz_0[j] = pb_y * tg_yyyyyz_xyyyyzz_0[j] + fr * tg_yyyyyz_xyyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyyyyzz_0[j] - tg_yyyyz_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyz_xyyyzz_1[j];

                    tg_yyyyyyz_xyyyzzz_0[j] = pb_y * tg_yyyyyz_xyyyzzz_0[j] + fr * tg_yyyyyz_xyyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyyyzzz_0[j] - tg_yyyyz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyz_xyyzzz_1[j];

                    tg_yyyyyyz_xyyzzzz_0[j] = pb_y * tg_yyyyyz_xyyzzzz_0[j] + fr * tg_yyyyyz_xyyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyyzzzz_0[j] - tg_yyyyz_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_xyzzzz_1[j];

                    tg_yyyyyyz_xyzzzzz_0[j] = pb_y * tg_yyyyyz_xyzzzzz_0[j] + fr * tg_yyyyyz_xyzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xyzzzzz_0[j] - tg_yyyyz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_xzzzzz_1[j];

                    tg_yyyyyyz_xzzzzzz_0[j] = pb_y * tg_yyyyyz_xzzzzzz_0[j] + fr * tg_yyyyyz_xzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_xzzzzzz_0[j] - tg_yyyyz_xzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyz_yyyyyyy_0[j] = pb_y * tg_yyyyyz_yyyyyyy_0[j] + fr * tg_yyyyyz_yyyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyyyyyy_0[j] - tg_yyyyz_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyyz_yyyyyy_1[j];

                    tg_yyyyyyz_yyyyyyz_0[j] = pb_y * tg_yyyyyz_yyyyyyz_0[j] + fr * tg_yyyyyz_yyyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyyyyyz_0[j] - tg_yyyyz_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyz_yyyyyz_1[j];

                    tg_yyyyyyz_yyyyyzz_0[j] = pb_y * tg_yyyyyz_yyyyyzz_0[j] + fr * tg_yyyyyz_yyyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyyyyzz_0[j] - tg_yyyyz_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyz_yyyyzz_1[j];

                    tg_yyyyyyz_yyyyzzz_0[j] = pb_y * tg_yyyyyz_yyyyzzz_0[j] + fr * tg_yyyyyz_yyyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyyyzzz_0[j] - tg_yyyyz_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyz_yyyzzz_1[j];

                    tg_yyyyyyz_yyyzzzz_0[j] = pb_y * tg_yyyyyz_yyyzzzz_0[j] + fr * tg_yyyyyz_yyyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyyzzzz_0[j] - tg_yyyyz_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyz_yyzzzz_1[j];

                    tg_yyyyyyz_yyzzzzz_0[j] = pb_y * tg_yyyyyz_yyzzzzz_0[j] + fr * tg_yyyyyz_yyzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yyzzzzz_0[j] - tg_yyyyz_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyz_yzzzzz_1[j];

                    tg_yyyyyyz_yzzzzzz_0[j] = pb_y * tg_yyyyyz_yzzzzzz_0[j] + fr * tg_yyyyyz_yzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_yzzzzzz_0[j] - tg_yyyyz_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyz_zzzzzz_1[j];

                    tg_yyyyyyz_zzzzzzz_0[j] = pb_y * tg_yyyyyz_zzzzzzz_0[j] + fr * tg_yyyyyz_zzzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyz_zzzzzzz_0[j] - tg_yyyyz_zzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyzz_xxxxxxx_0[j] = pb_y * tg_yyyyzz_xxxxxxx_0[j] + fr * tg_yyyyzz_xxxxxxx_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxxx_0[j] - tg_yyyzz_xxxxxxx_1[j] * fl1_fza);

                    tg_yyyyyzz_xxxxxxy_0[j] = pb_y * tg_yyyyzz_xxxxxxy_0[j] + fr * tg_yyyyzz_xxxxxxy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxxy_0[j] - tg_yyyzz_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xxxxxx_1[j];

                    tg_yyyyyzz_xxxxxxz_0[j] = pb_y * tg_yyyyzz_xxxxxxz_0[j] + fr * tg_yyyyzz_xxxxxxz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxxz_0[j] - tg_yyyzz_xxxxxxz_1[j] * fl1_fza);

                    tg_yyyyyzz_xxxxxyy_0[j] = pb_y * tg_yyyyzz_xxxxxyy_0[j] + fr * tg_yyyyzz_xxxxxyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxyy_0[j] - tg_yyyzz_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_xxxxxy_1[j];

                    tg_yyyyyzz_xxxxxyz_0[j] = pb_y * tg_yyyyzz_xxxxxyz_0[j] + fr * tg_yyyyzz_xxxxxyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxyz_0[j] - tg_yyyzz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xxxxxz_1[j];

                    tg_yyyyyzz_xxxxxzz_0[j] = pb_y * tg_yyyyzz_xxxxxzz_0[j] + fr * tg_yyyyzz_xxxxxzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxxzz_0[j] - tg_yyyzz_xxxxxzz_1[j] * fl1_fza);

                    tg_yyyyyzz_xxxxyyy_0[j] = pb_y * tg_yyyyzz_xxxxyyy_0[j] + fr * tg_yyyyzz_xxxxyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxyyy_0[j] - tg_yyyzz_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzz_xxxxyy_1[j];

                    tg_yyyyyzz_xxxxyyz_0[j] = pb_y * tg_yyyyzz_xxxxyyz_0[j] + fr * tg_yyyyzz_xxxxyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxyyz_0[j] - tg_yyyzz_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_xxxxyz_1[j];

                    tg_yyyyyzz_xxxxyzz_0[j] = pb_y * tg_yyyyzz_xxxxyzz_0[j] + fr * tg_yyyyzz_xxxxyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxyzz_0[j] - tg_yyyzz_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xxxxzz_1[j];

                    tg_yyyyyzz_xxxxzzz_0[j] = pb_y * tg_yyyyzz_xxxxzzz_0[j] + fr * tg_yyyyzz_xxxxzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxxzzz_0[j] - tg_yyyzz_xxxxzzz_1[j] * fl1_fza);

                    tg_yyyyyzz_xxxyyyy_0[j] = pb_y * tg_yyyyzz_xxxyyyy_0[j] + fr * tg_yyyyzz_xxxyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxyyyy_0[j] - tg_yyyzz_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzz_xxxyyy_1[j];

                    tg_yyyyyzz_xxxyyyz_0[j] = pb_y * tg_yyyyzz_xxxyyyz_0[j] + fr * tg_yyyyzz_xxxyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxyyyz_0[j] - tg_yyyzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzz_xxxyyz_1[j];

                    tg_yyyyyzz_xxxyyzz_0[j] = pb_y * tg_yyyyzz_xxxyyzz_0[j] + fr * tg_yyyyzz_xxxyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxyyzz_0[j] - tg_yyyzz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_xxxyzz_1[j];

                    tg_yyyyyzz_xxxyzzz_0[j] = pb_y * tg_yyyyzz_xxxyzzz_0[j] + fr * tg_yyyyzz_xxxyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxyzzz_0[j] - tg_yyyzz_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xxxzzz_1[j];

                    tg_yyyyyzz_xxxzzzz_0[j] = pb_y * tg_yyyyzz_xxxzzzz_0[j] + fr * tg_yyyyzz_xxxzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxxzzzz_0[j] - tg_yyyzz_xxxzzzz_1[j] * fl1_fza);

                    tg_yyyyyzz_xxyyyyy_0[j] = pb_y * tg_yyyyzz_xxyyyyy_0[j] + fr * tg_yyyyzz_xxyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxyyyyy_0[j] - tg_yyyzz_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyzz_xxyyyy_1[j];

                    tg_yyyyyzz_xxyyyyz_0[j] = pb_y * tg_yyyyzz_xxyyyyz_0[j] + fr * tg_yyyyzz_xxyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxyyyyz_0[j] - tg_yyyzz_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzz_xxyyyz_1[j];

                    tg_yyyyyzz_xxyyyzz_0[j] = pb_y * tg_yyyyzz_xxyyyzz_0[j] + fr * tg_yyyyzz_xxyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxyyyzz_0[j] - tg_yyyzz_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzz_xxyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_1098_1197(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1098,1197)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 846); 

                auto tg_yyyyzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 847); 

                auto tg_yyyyzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 848); 

                auto tg_yyyyzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 849); 

                auto tg_yyyyzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 850); 

                auto tg_yyyyzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 851); 

                auto tg_yyyyzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 852); 

                auto tg_yyyyzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 853); 

                auto tg_yyyyzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 854); 

                auto tg_yyyyzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 855); 

                auto tg_yyyyzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 856); 

                auto tg_yyyyzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 857); 

                auto tg_yyyyzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 858); 

                auto tg_yyyyzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 859); 

                auto tg_yyyyzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 860); 

                auto tg_yyyyzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 861); 

                auto tg_yyyyzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 862); 

                auto tg_yyyyzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 863); 

                auto tg_yyyzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 864); 

                auto tg_yyyzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 865); 

                auto tg_yyyzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 866); 

                auto tg_yyyzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 867); 

                auto tg_yyyzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 868); 

                auto tg_yyyzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 869); 

                auto tg_yyyzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 870); 

                auto tg_yyyzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 871); 

                auto tg_yyyzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 872); 

                auto tg_yyyzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 873); 

                auto tg_yyyzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 874); 

                auto tg_yyyzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 875); 

                auto tg_yyyzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 876); 

                auto tg_yyyzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 877); 

                auto tg_yyyzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 878); 

                auto tg_yyyzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 879); 

                auto tg_yyyzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 880); 

                auto tg_yyyzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 881); 

                auto tg_yyyzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 882); 

                auto tg_yyyzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 883); 

                auto tg_yyyzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 884); 

                auto tg_yyyzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 885); 

                auto tg_yyyzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 886); 

                auto tg_yyyzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 887); 

                auto tg_yyyzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 888); 

                auto tg_yyyzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 889); 

                auto tg_yyyzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 890); 

                auto tg_yyyzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 891); 

                auto tg_yyyzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 892); 

                auto tg_yyyzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 893); 

                auto tg_yyyzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 894); 

                auto tg_yyyzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 895); 

                auto tg_yyyzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 896); 

                auto tg_yyyzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 897); 

                auto tg_yyyzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 898); 

                auto tg_yyyzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 899); 

                auto tg_yyzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 900); 

                auto tg_yyzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 901); 

                auto tg_yyzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 902); 

                auto tg_yyzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 903); 

                auto tg_yyzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 904); 

                auto tg_yyzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 905); 

                auto tg_yyzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 906); 

                auto tg_yyzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 907); 

                auto tg_yyzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 908); 

                auto tg_yyzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 909); 

                auto tg_yyzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 910); 

                auto tg_yyzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 911); 

                auto tg_yyzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 912); 

                auto tg_yyzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 913); 

                auto tg_yyzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 914); 

                auto tg_yyzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 915); 

                auto tg_yyzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 916); 

                auto tg_yyzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 917); 

                auto tg_yyzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 918); 

                auto tg_yyzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 919); 

                auto tg_yyzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 920); 

                auto tg_yyzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 921); 

                auto tg_yyzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 922); 

                auto tg_yyzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 923); 

                auto tg_yyzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 924); 

                auto tg_yyzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 925); 

                auto tg_yyzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 926); 

                auto tg_yyzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 927); 

                auto tg_yyzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 928); 

                auto tg_yyzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 929); 

                auto tg_yyzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 930); 

                auto tg_yyzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 931); 

                auto tg_yyzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 932); 

                auto tg_yyzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 933); 

                auto tg_yyzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 934); 

                auto tg_yyzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 935); 

                auto tg_yzzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 936); 

                auto tg_yzzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 937); 

                auto tg_yzzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 938); 

                auto tg_yzzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 939); 

                auto tg_yzzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 940); 

                auto tg_yzzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 941); 

                auto tg_yzzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 942); 

                auto tg_yzzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 943); 

                auto tg_yzzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 944); 

                auto tg_yyyyzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 846); 

                auto tg_yyyyzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 847); 

                auto tg_yyyyzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 848); 

                auto tg_yyyyzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 849); 

                auto tg_yyyyzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 850); 

                auto tg_yyyyzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 851); 

                auto tg_yyyyzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 852); 

                auto tg_yyyyzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 853); 

                auto tg_yyyyzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 854); 

                auto tg_yyyyzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 855); 

                auto tg_yyyyzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 856); 

                auto tg_yyyyzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 857); 

                auto tg_yyyyzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 858); 

                auto tg_yyyyzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 859); 

                auto tg_yyyyzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 860); 

                auto tg_yyyyzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 861); 

                auto tg_yyyyzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 862); 

                auto tg_yyyyzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 863); 

                auto tg_yyyzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 864); 

                auto tg_yyyzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 865); 

                auto tg_yyyzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 866); 

                auto tg_yyyzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 867); 

                auto tg_yyyzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 868); 

                auto tg_yyyzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 869); 

                auto tg_yyyzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 870); 

                auto tg_yyyzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 871); 

                auto tg_yyyzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 872); 

                auto tg_yyyzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 873); 

                auto tg_yyyzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 874); 

                auto tg_yyyzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 875); 

                auto tg_yyyzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 876); 

                auto tg_yyyzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 877); 

                auto tg_yyyzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 878); 

                auto tg_yyyzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 879); 

                auto tg_yyyzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 880); 

                auto tg_yyyzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 881); 

                auto tg_yyyzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 882); 

                auto tg_yyyzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 883); 

                auto tg_yyyzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 884); 

                auto tg_yyyzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 885); 

                auto tg_yyyzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 886); 

                auto tg_yyyzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 887); 

                auto tg_yyyzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 888); 

                auto tg_yyyzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 889); 

                auto tg_yyyzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 890); 

                auto tg_yyyzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 891); 

                auto tg_yyyzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 892); 

                auto tg_yyyzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 893); 

                auto tg_yyyzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 894); 

                auto tg_yyyzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 895); 

                auto tg_yyyzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 896); 

                auto tg_yyyzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 897); 

                auto tg_yyyzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 898); 

                auto tg_yyyzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 899); 

                auto tg_yyzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 900); 

                auto tg_yyzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 901); 

                auto tg_yyzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 902); 

                auto tg_yyzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 903); 

                auto tg_yyzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 904); 

                auto tg_yyzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 905); 

                auto tg_yyzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 906); 

                auto tg_yyzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 907); 

                auto tg_yyzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 908); 

                auto tg_yyzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 909); 

                auto tg_yyzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 910); 

                auto tg_yyzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 911); 

                auto tg_yyzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 912); 

                auto tg_yyzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 913); 

                auto tg_yyzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 914); 

                auto tg_yyzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 915); 

                auto tg_yyzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 916); 

                auto tg_yyzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 917); 

                auto tg_yyzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 918); 

                auto tg_yyzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 919); 

                auto tg_yyzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 920); 

                auto tg_yyzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 921); 

                auto tg_yyzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 922); 

                auto tg_yyzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 923); 

                auto tg_yyzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 924); 

                auto tg_yyzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 925); 

                auto tg_yyzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 926); 

                auto tg_yyzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 927); 

                auto tg_yyzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 928); 

                auto tg_yyzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 929); 

                auto tg_yyzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 930); 

                auto tg_yyzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 931); 

                auto tg_yyzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 932); 

                auto tg_yyzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 933); 

                auto tg_yyzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 934); 

                auto tg_yyzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 935); 

                auto tg_yzzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 936); 

                auto tg_yzzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 937); 

                auto tg_yzzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 938); 

                auto tg_yzzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 939); 

                auto tg_yzzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 940); 

                auto tg_yzzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 941); 

                auto tg_yzzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 942); 

                auto tg_yzzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 943); 

                auto tg_yzzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 944); 

                auto tg_yyyzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 636); 

                auto tg_yyyzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 699); 

                auto tg_yzzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 701); 

                auto tg_yzzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 714); 

                auto tg_yzzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 728); 

                auto tg_yyyzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 630); 

                auto tg_yyyzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 631); 

                auto tg_yyyzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 632); 

                auto tg_yyyzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 633); 

                auto tg_yyyzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 634); 

                auto tg_yyyzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 635); 

                auto tg_yyyzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 636); 

                auto tg_yyyzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 637); 

                auto tg_yyyzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 638); 

                auto tg_yyyzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 639); 

                auto tg_yyyzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 640); 

                auto tg_yyyzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 641); 

                auto tg_yyyzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 642); 

                auto tg_yyyzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 643); 

                auto tg_yyyzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 644); 

                auto tg_yyyzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 645); 

                auto tg_yyyzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 646); 

                auto tg_yyyzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 647); 

                auto tg_yyzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 648); 

                auto tg_yyzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 649); 

                auto tg_yyzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 650); 

                auto tg_yyzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 651); 

                auto tg_yyzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 652); 

                auto tg_yyzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 653); 

                auto tg_yyzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 654); 

                auto tg_yyzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 655); 

                auto tg_yyzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 656); 

                auto tg_yyzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 657); 

                auto tg_yyzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 658); 

                auto tg_yyzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 659); 

                auto tg_yyzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 660); 

                auto tg_yyzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 661); 

                auto tg_yyzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 662); 

                auto tg_yyzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 663); 

                auto tg_yyzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 664); 

                auto tg_yyzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 665); 

                auto tg_yyzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 666); 

                auto tg_yyzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 667); 

                auto tg_yyzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 668); 

                auto tg_yyzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 669); 

                auto tg_yyzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 670); 

                auto tg_yyzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 671); 

                auto tg_yyzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 672); 

                auto tg_yyzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 673); 

                auto tg_yyzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 674); 

                auto tg_yyzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 675); 

                auto tg_yyzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 676); 

                auto tg_yyzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 677); 

                auto tg_yyzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 678); 

                auto tg_yyzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 679); 

                auto tg_yyzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 680); 

                auto tg_yyzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 681); 

                auto tg_yyzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 682); 

                auto tg_yyzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 683); 

                auto tg_yzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 684); 

                auto tg_yzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 685); 

                auto tg_yzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 686); 

                auto tg_yzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 687); 

                auto tg_yzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 688); 

                auto tg_yzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 689); 

                auto tg_yzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 690); 

                auto tg_yzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 691); 

                auto tg_yzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 692); 

                auto tg_yzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 693); 

                auto tg_yzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 694); 

                auto tg_yzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 695); 

                auto tg_yzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 696); 

                auto tg_yzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 697); 

                auto tg_yzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 698); 

                auto tg_yzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 699); 

                auto tg_yzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 700); 

                auto tg_yzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 701); 

                auto tg_yzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 702); 

                auto tg_yzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 703); 

                auto tg_yzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 704); 

                auto tg_yzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 705); 

                auto tg_yzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 706); 

                auto tg_yzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 707); 

                auto tg_yzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 708); 

                auto tg_yzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 709); 

                auto tg_yzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 710); 

                auto tg_yzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 711); 

                auto tg_yzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 712); 

                auto tg_yzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 713); 

                auto tg_yzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 714); 

                auto tg_yzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 715); 

                auto tg_yzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 716); 

                auto tg_yzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 717); 

                auto tg_yzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 718); 

                auto tg_yzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 719); 

                auto tg_zzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 728); 

                auto tg_yyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 678); 

                auto tg_yyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 699); 

                auto tg_yyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 733); 

                // set up pointers to integrals

                auto tg_yyyyyzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1098); 

                auto tg_yyyyyzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1099); 

                auto tg_yyyyyzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1100); 

                auto tg_yyyyyzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1101); 

                auto tg_yyyyyzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1102); 

                auto tg_yyyyyzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1103); 

                auto tg_yyyyyzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1104); 

                auto tg_yyyyyzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1105); 

                auto tg_yyyyyzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1106); 

                auto tg_yyyyyzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1107); 

                auto tg_yyyyyzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1108); 

                auto tg_yyyyyzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1109); 

                auto tg_yyyyyzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1110); 

                auto tg_yyyyyzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1111); 

                auto tg_yyyyyzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1112); 

                auto tg_yyyyyzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1113); 

                auto tg_yyyyyzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1114); 

                auto tg_yyyyyzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1115); 

                auto tg_yyyyzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1116); 

                auto tg_yyyyzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1117); 

                auto tg_yyyyzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1118); 

                auto tg_yyyyzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1119); 

                auto tg_yyyyzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1120); 

                auto tg_yyyyzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1121); 

                auto tg_yyyyzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1122); 

                auto tg_yyyyzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1123); 

                auto tg_yyyyzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1124); 

                auto tg_yyyyzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1125); 

                auto tg_yyyyzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1126); 

                auto tg_yyyyzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1127); 

                auto tg_yyyyzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1128); 

                auto tg_yyyyzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1129); 

                auto tg_yyyyzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1130); 

                auto tg_yyyyzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1131); 

                auto tg_yyyyzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1132); 

                auto tg_yyyyzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1133); 

                auto tg_yyyyzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1134); 

                auto tg_yyyyzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1135); 

                auto tg_yyyyzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1136); 

                auto tg_yyyyzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1137); 

                auto tg_yyyyzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1138); 

                auto tg_yyyyzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1139); 

                auto tg_yyyyzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1140); 

                auto tg_yyyyzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1141); 

                auto tg_yyyyzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1142); 

                auto tg_yyyyzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1143); 

                auto tg_yyyyzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1144); 

                auto tg_yyyyzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1145); 

                auto tg_yyyyzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1146); 

                auto tg_yyyyzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1147); 

                auto tg_yyyyzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1148); 

                auto tg_yyyyzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1149); 

                auto tg_yyyyzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1150); 

                auto tg_yyyyzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1151); 

                auto tg_yyyzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1152); 

                auto tg_yyyzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1153); 

                auto tg_yyyzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1154); 

                auto tg_yyyzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1155); 

                auto tg_yyyzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1156); 

                auto tg_yyyzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1157); 

                auto tg_yyyzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1158); 

                auto tg_yyyzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1159); 

                auto tg_yyyzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1160); 

                auto tg_yyyzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1161); 

                auto tg_yyyzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1162); 

                auto tg_yyyzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1163); 

                auto tg_yyyzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1164); 

                auto tg_yyyzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1165); 

                auto tg_yyyzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1166); 

                auto tg_yyyzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1167); 

                auto tg_yyyzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1168); 

                auto tg_yyyzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1169); 

                auto tg_yyyzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1170); 

                auto tg_yyyzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1171); 

                auto tg_yyyzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1172); 

                auto tg_yyyzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1173); 

                auto tg_yyyzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1174); 

                auto tg_yyyzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1175); 

                auto tg_yyyzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1176); 

                auto tg_yyyzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1177); 

                auto tg_yyyzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1178); 

                auto tg_yyyzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1179); 

                auto tg_yyyzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1180); 

                auto tg_yyyzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1181); 

                auto tg_yyyzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1182); 

                auto tg_yyyzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1183); 

                auto tg_yyyzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1184); 

                auto tg_yyyzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1185); 

                auto tg_yyyzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1186); 

                auto tg_yyyzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1187); 

                auto tg_yyzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1188); 

                auto tg_yyzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1189); 

                auto tg_yyzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1190); 

                auto tg_yyzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1191); 

                auto tg_yyzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1192); 

                auto tg_yyzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1193); 

                auto tg_yyzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1194); 

                auto tg_yyzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1195); 

                auto tg_yyzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1196); 

                // Batch of Integrals (1098,1197)

                #pragma omp simd aligned(fxn, fza, tg_yyyyyzz_xxyyzzz_0, tg_yyyyyzz_xxyzzzz_0, \
                                         tg_yyyyyzz_xxzzzzz_0, tg_yyyyyzz_xyyyyyy_0, tg_yyyyyzz_xyyyyyz_0, tg_yyyyyzz_xyyyyzz_0, \
                                         tg_yyyyyzz_xyyyzzz_0, tg_yyyyyzz_xyyzzzz_0, tg_yyyyyzz_xyzzzzz_0, tg_yyyyyzz_xzzzzzz_0, \
                                         tg_yyyyyzz_yyyyyyy_0, tg_yyyyyzz_yyyyyyz_0, tg_yyyyyzz_yyyyyzz_0, tg_yyyyyzz_yyyyzzz_0, \
                                         tg_yyyyyzz_yyyzzzz_0, tg_yyyyyzz_yyzzzzz_0, tg_yyyyyzz_yzzzzzz_0, tg_yyyyyzz_zzzzzzz_0, \
                                         tg_yyyyzz_xxyyzzz_0, tg_yyyyzz_xxyyzzz_1, tg_yyyyzz_xxyzzz_1, tg_yyyyzz_xxyzzzz_0, \
                                         tg_yyyyzz_xxyzzzz_1, tg_yyyyzz_xxzzzz_1, tg_yyyyzz_xxzzzzz_0, tg_yyyyzz_xxzzzzz_1, \
                                         tg_yyyyzz_xyyyyy_1, tg_yyyyzz_xyyyyyy_0, tg_yyyyzz_xyyyyyy_1, tg_yyyyzz_xyyyyyz_0, \
                                         tg_yyyyzz_xyyyyyz_1, tg_yyyyzz_xyyyyz_1, tg_yyyyzz_xyyyyzz_0, tg_yyyyzz_xyyyyzz_1, \
                                         tg_yyyyzz_xyyyzz_1, tg_yyyyzz_xyyyzzz_0, tg_yyyyzz_xyyyzzz_1, tg_yyyyzz_xyyzzz_1, \
                                         tg_yyyyzz_xyyzzzz_0, tg_yyyyzz_xyyzzzz_1, tg_yyyyzz_xyzzzz_1, tg_yyyyzz_xyzzzzz_0, \
                                         tg_yyyyzz_xyzzzzz_1, tg_yyyyzz_xzzzzz_1, tg_yyyyzz_xzzzzzz_0, tg_yyyyzz_xzzzzzz_1, \
                                         tg_yyyyzz_yyyyyy_1, tg_yyyyzz_yyyyyyy_0, tg_yyyyzz_yyyyyyy_1, tg_yyyyzz_yyyyyyz_0, \
                                         tg_yyyyzz_yyyyyyz_1, tg_yyyyzz_yyyyyz_1, tg_yyyyzz_yyyyyzz_0, tg_yyyyzz_yyyyyzz_1, \
                                         tg_yyyyzz_yyyyzz_1, tg_yyyyzz_yyyyzzz_0, tg_yyyyzz_yyyyzzz_1, tg_yyyyzz_yyyzzz_1, \
                                         tg_yyyyzz_yyyzzzz_0, tg_yyyyzz_yyyzzzz_1, tg_yyyyzz_yyzzzz_1, tg_yyyyzz_yyzzzzz_0, \
                                         tg_yyyyzz_yyzzzzz_1, tg_yyyyzz_yzzzzz_1, tg_yyyyzz_yzzzzzz_0, tg_yyyyzz_yzzzzzz_1, \
                                         tg_yyyyzz_zzzzzz_1, tg_yyyyzz_zzzzzzz_0, tg_yyyyzz_zzzzzzz_1, tg_yyyyzzz_xxxxxxx_0, \
                                         tg_yyyyzzz_xxxxxxy_0, tg_yyyyzzz_xxxxxxz_0, tg_yyyyzzz_xxxxxyy_0, tg_yyyyzzz_xxxxxyz_0, \
                                         tg_yyyyzzz_xxxxxzz_0, tg_yyyyzzz_xxxxyyy_0, tg_yyyyzzz_xxxxyyz_0, tg_yyyyzzz_xxxxyzz_0, \
                                         tg_yyyyzzz_xxxxzzz_0, tg_yyyyzzz_xxxyyyy_0, tg_yyyyzzz_xxxyyyz_0, tg_yyyyzzz_xxxyyzz_0, \
                                         tg_yyyyzzz_xxxyzzz_0, tg_yyyyzzz_xxxzzzz_0, tg_yyyyzzz_xxyyyyy_0, tg_yyyyzzz_xxyyyyz_0, \
                                         tg_yyyyzzz_xxyyyzz_0, tg_yyyyzzz_xxyyzzz_0, tg_yyyyzzz_xxyzzzz_0, tg_yyyyzzz_xxzzzzz_0, \
                                         tg_yyyyzzz_xyyyyyy_0, tg_yyyyzzz_xyyyyyz_0, tg_yyyyzzz_xyyyyzz_0, tg_yyyyzzz_xyyyzzz_0, \
                                         tg_yyyyzzz_xyyzzzz_0, tg_yyyyzzz_xyzzzzz_0, tg_yyyyzzz_xzzzzzz_0, tg_yyyyzzz_yyyyyyy_0, \
                                         tg_yyyyzzz_yyyyyyz_0, tg_yyyyzzz_yyyyyzz_0, tg_yyyyzzz_yyyyzzz_0, tg_yyyyzzz_yyyzzzz_0, \
                                         tg_yyyyzzz_yyzzzzz_0, tg_yyyyzzz_yzzzzzz_0, tg_yyyyzzz_zzzzzzz_0, tg_yyyzz_xxyyzzz_0, \
                                         tg_yyyzz_xxyyzzz_1, tg_yyyzz_xxyzzzz_0, tg_yyyzz_xxyzzzz_1, tg_yyyzz_xxzzzzz_0, \
                                         tg_yyyzz_xxzzzzz_1, tg_yyyzz_xyyyyyy_0, tg_yyyzz_xyyyyyy_1, tg_yyyzz_xyyyyyz_0, \
                                         tg_yyyzz_xyyyyyz_1, tg_yyyzz_xyyyyzz_0, tg_yyyzz_xyyyyzz_1, tg_yyyzz_xyyyzzz_0, \
                                         tg_yyyzz_xyyyzzz_1, tg_yyyzz_xyyzzzz_0, tg_yyyzz_xyyzzzz_1, tg_yyyzz_xyzzzzz_0, \
                                         tg_yyyzz_xyzzzzz_1, tg_yyyzz_xzzzzzz_0, tg_yyyzz_xzzzzzz_1, tg_yyyzz_yyyyyyy_0, \
                                         tg_yyyzz_yyyyyyy_1, tg_yyyzz_yyyyyyz_0, tg_yyyzz_yyyyyyz_1, tg_yyyzz_yyyyyzz_0, \
                                         tg_yyyzz_yyyyyzz_1, tg_yyyzz_yyyyzzz_0, tg_yyyzz_yyyyzzz_1, tg_yyyzz_yyyzzzz_0, \
                                         tg_yyyzz_yyyzzzz_1, tg_yyyzz_yyzzzzz_0, tg_yyyzz_yyzzzzz_1, tg_yyyzz_yzzzzzz_0, \
                                         tg_yyyzz_yzzzzzz_1, tg_yyyzz_zzzzzzz_0, tg_yyyzz_zzzzzzz_1, tg_yyyzzz_xxxxxx_1, \
                                         tg_yyyzzz_xxxxxxx_0, tg_yyyzzz_xxxxxxx_1, tg_yyyzzz_xxxxxxy_0, tg_yyyzzz_xxxxxxy_1, \
                                         tg_yyyzzz_xxxxxxz_0, tg_yyyzzz_xxxxxxz_1, tg_yyyzzz_xxxxxy_1, tg_yyyzzz_xxxxxyy_0, \
                                         tg_yyyzzz_xxxxxyy_1, tg_yyyzzz_xxxxxyz_0, tg_yyyzzz_xxxxxyz_1, tg_yyyzzz_xxxxxz_1, \
                                         tg_yyyzzz_xxxxxzz_0, tg_yyyzzz_xxxxxzz_1, tg_yyyzzz_xxxxyy_1, tg_yyyzzz_xxxxyyy_0, \
                                         tg_yyyzzz_xxxxyyy_1, tg_yyyzzz_xxxxyyz_0, tg_yyyzzz_xxxxyyz_1, tg_yyyzzz_xxxxyz_1, \
                                         tg_yyyzzz_xxxxyzz_0, tg_yyyzzz_xxxxyzz_1, tg_yyyzzz_xxxxzz_1, tg_yyyzzz_xxxxzzz_0, \
                                         tg_yyyzzz_xxxxzzz_1, tg_yyyzzz_xxxyyy_1, tg_yyyzzz_xxxyyyy_0, tg_yyyzzz_xxxyyyy_1, \
                                         tg_yyyzzz_xxxyyyz_0, tg_yyyzzz_xxxyyyz_1, tg_yyyzzz_xxxyyz_1, tg_yyyzzz_xxxyyzz_0, \
                                         tg_yyyzzz_xxxyyzz_1, tg_yyyzzz_xxxyzz_1, tg_yyyzzz_xxxyzzz_0, tg_yyyzzz_xxxyzzz_1, \
                                         tg_yyyzzz_xxxzzz_1, tg_yyyzzz_xxxzzzz_0, tg_yyyzzz_xxxzzzz_1, tg_yyyzzz_xxyyyy_1, \
                                         tg_yyyzzz_xxyyyyy_0, tg_yyyzzz_xxyyyyy_1, tg_yyyzzz_xxyyyyz_0, tg_yyyzzz_xxyyyyz_1, \
                                         tg_yyyzzz_xxyyyz_1, tg_yyyzzz_xxyyyzz_0, tg_yyyzzz_xxyyyzz_1, tg_yyyzzz_xxyyzz_1, \
                                         tg_yyyzzz_xxyyzzz_0, tg_yyyzzz_xxyyzzz_1, tg_yyyzzz_xxyzzz_1, tg_yyyzzz_xxyzzzz_0, \
                                         tg_yyyzzz_xxyzzzz_1, tg_yyyzzz_xxzzzz_1, tg_yyyzzz_xxzzzzz_0, tg_yyyzzz_xxzzzzz_1, \
                                         tg_yyyzzz_xyyyyy_1, tg_yyyzzz_xyyyyyy_0, tg_yyyzzz_xyyyyyy_1, tg_yyyzzz_xyyyyyz_0, \
                                         tg_yyyzzz_xyyyyyz_1, tg_yyyzzz_xyyyyz_1, tg_yyyzzz_xyyyyzz_0, tg_yyyzzz_xyyyyzz_1, \
                                         tg_yyyzzz_xyyyzz_1, tg_yyyzzz_xyyyzzz_0, tg_yyyzzz_xyyyzzz_1, tg_yyyzzz_xyyzzz_1, \
                                         tg_yyyzzz_xyyzzzz_0, tg_yyyzzz_xyyzzzz_1, tg_yyyzzz_xyzzzz_1, tg_yyyzzz_xyzzzzz_0, \
                                         tg_yyyzzz_xyzzzzz_1, tg_yyyzzz_xzzzzz_1, tg_yyyzzz_xzzzzzz_0, tg_yyyzzz_xzzzzzz_1, \
                                         tg_yyyzzz_yyyyyy_1, tg_yyyzzz_yyyyyyy_0, tg_yyyzzz_yyyyyyy_1, tg_yyyzzz_yyyyyyz_0, \
                                         tg_yyyzzz_yyyyyyz_1, tg_yyyzzz_yyyyyz_1, tg_yyyzzz_yyyyyzz_0, tg_yyyzzz_yyyyyzz_1, \
                                         tg_yyyzzz_yyyyzz_1, tg_yyyzzz_yyyyzzz_0, tg_yyyzzz_yyyyzzz_1, tg_yyyzzz_yyyzzz_1, \
                                         tg_yyyzzz_yyyzzzz_0, tg_yyyzzz_yyyzzzz_1, tg_yyyzzz_yyzzzz_1, tg_yyyzzz_yyzzzzz_0, \
                                         tg_yyyzzz_yyzzzzz_1, tg_yyyzzz_yzzzzz_1, tg_yyyzzz_yzzzzzz_0, tg_yyyzzz_yzzzzzz_1, \
                                         tg_yyyzzz_zzzzzz_1, tg_yyyzzz_zzzzzzz_0, tg_yyyzzz_zzzzzzz_1, tg_yyyzzzz_xxxxxxx_0, \
                                         tg_yyyzzzz_xxxxxxy_0, tg_yyyzzzz_xxxxxxz_0, tg_yyyzzzz_xxxxxyy_0, tg_yyyzzzz_xxxxxyz_0, \
                                         tg_yyyzzzz_xxxxxzz_0, tg_yyyzzzz_xxxxyyy_0, tg_yyyzzzz_xxxxyyz_0, tg_yyyzzzz_xxxxyzz_0, \
                                         tg_yyyzzzz_xxxxzzz_0, tg_yyyzzzz_xxxyyyy_0, tg_yyyzzzz_xxxyyyz_0, tg_yyyzzzz_xxxyyzz_0, \
                                         tg_yyyzzzz_xxxyzzz_0, tg_yyyzzzz_xxxzzzz_0, tg_yyyzzzz_xxyyyyy_0, tg_yyyzzzz_xxyyyyz_0, \
                                         tg_yyyzzzz_xxyyyzz_0, tg_yyyzzzz_xxyyzzz_0, tg_yyyzzzz_xxyzzzz_0, tg_yyyzzzz_xxzzzzz_0, \
                                         tg_yyyzzzz_xyyyyyy_0, tg_yyyzzzz_xyyyyyz_0, tg_yyyzzzz_xyyyyzz_0, tg_yyyzzzz_xyyyzzz_0, \
                                         tg_yyyzzzz_xyyzzzz_0, tg_yyyzzzz_xyzzzzz_0, tg_yyyzzzz_xzzzzzz_0, tg_yyyzzzz_yyyyyyy_0, \
                                         tg_yyyzzzz_yyyyyyz_0, tg_yyyzzzz_yyyyyzz_0, tg_yyyzzzz_yyyyzzz_0, tg_yyyzzzz_yyyzzzz_0, \
                                         tg_yyyzzzz_yyzzzzz_0, tg_yyyzzzz_yzzzzzz_0, tg_yyyzzzz_zzzzzzz_0, tg_yyzzz_xxxxxxx_0, \
                                         tg_yyzzz_xxxxxxx_1, tg_yyzzz_xxxxxxy_0, tg_yyzzz_xxxxxxy_1, tg_yyzzz_xxxxxxz_0, \
                                         tg_yyzzz_xxxxxxz_1, tg_yyzzz_xxxxxyy_0, tg_yyzzz_xxxxxyy_1, tg_yyzzz_xxxxxyz_0, \
                                         tg_yyzzz_xxxxxyz_1, tg_yyzzz_xxxxxzz_0, tg_yyzzz_xxxxxzz_1, tg_yyzzz_xxxxyyy_0, \
                                         tg_yyzzz_xxxxyyy_1, tg_yyzzz_xxxxyyz_0, tg_yyzzz_xxxxyyz_1, tg_yyzzz_xxxxyzz_0, \
                                         tg_yyzzz_xxxxyzz_1, tg_yyzzz_xxxxzzz_0, tg_yyzzz_xxxxzzz_1, tg_yyzzz_xxxyyyy_0, \
                                         tg_yyzzz_xxxyyyy_1, tg_yyzzz_xxxyyyz_0, tg_yyzzz_xxxyyyz_1, tg_yyzzz_xxxyyzz_0, \
                                         tg_yyzzz_xxxyyzz_1, tg_yyzzz_xxxyzzz_0, tg_yyzzz_xxxyzzz_1, tg_yyzzz_xxxzzzz_0, \
                                         tg_yyzzz_xxxzzzz_1, tg_yyzzz_xxyyyyy_0, tg_yyzzz_xxyyyyy_1, tg_yyzzz_xxyyyyz_0, \
                                         tg_yyzzz_xxyyyyz_1, tg_yyzzz_xxyyyzz_0, tg_yyzzz_xxyyyzz_1, tg_yyzzz_xxyyzzz_0, \
                                         tg_yyzzz_xxyyzzz_1, tg_yyzzz_xxyzzzz_0, tg_yyzzz_xxyzzzz_1, tg_yyzzz_xxzzzzz_0, \
                                         tg_yyzzz_xxzzzzz_1, tg_yyzzz_xyyyyyy_0, tg_yyzzz_xyyyyyy_1, tg_yyzzz_xyyyyyz_0, \
                                         tg_yyzzz_xyyyyyz_1, tg_yyzzz_xyyyyzz_0, tg_yyzzz_xyyyyzz_1, tg_yyzzz_xyyyzzz_0, \
                                         tg_yyzzz_xyyyzzz_1, tg_yyzzz_xyyzzzz_0, tg_yyzzz_xyyzzzz_1, tg_yyzzz_xyzzzzz_0, \
                                         tg_yyzzz_xyzzzzz_1, tg_yyzzz_xzzzzzz_0, tg_yyzzz_xzzzzzz_1, tg_yyzzz_yyyyyyy_0, \
                                         tg_yyzzz_yyyyyyy_1, tg_yyzzz_yyyyyyz_0, tg_yyzzz_yyyyyyz_1, tg_yyzzz_yyyyyzz_0, \
                                         tg_yyzzz_yyyyyzz_1, tg_yyzzz_yyyyzzz_0, tg_yyzzz_yyyyzzz_1, tg_yyzzz_yyyzzzz_0, \
                                         tg_yyzzz_yyyzzzz_1, tg_yyzzz_yyzzzzz_0, tg_yyzzz_yyzzzzz_1, tg_yyzzz_yzzzzzz_0, \
                                         tg_yyzzz_yzzzzzz_1, tg_yyzzz_zzzzzzz_0, tg_yyzzz_zzzzzzz_1, tg_yyzzzz_xxxxxx_1, \
                                         tg_yyzzzz_xxxxxxx_0, tg_yyzzzz_xxxxxxx_1, tg_yyzzzz_xxxxxxy_0, tg_yyzzzz_xxxxxxy_1, \
                                         tg_yyzzzz_xxxxxxz_0, tg_yyzzzz_xxxxxxz_1, tg_yyzzzz_xxxxxy_1, tg_yyzzzz_xxxxxyy_0, \
                                         tg_yyzzzz_xxxxxyy_1, tg_yyzzzz_xxxxxyz_0, tg_yyzzzz_xxxxxyz_1, tg_yyzzzz_xxxxxz_1, \
                                         tg_yyzzzz_xxxxxzz_0, tg_yyzzzz_xxxxxzz_1, tg_yyzzzz_xxxxyy_1, tg_yyzzzz_xxxxyyy_0, \
                                         tg_yyzzzz_xxxxyyy_1, tg_yyzzzz_xxxxyyz_0, tg_yyzzzz_xxxxyyz_1, tg_yyzzzz_xxxxyz_1, \
                                         tg_yyzzzz_xxxxyzz_0, tg_yyzzzz_xxxxyzz_1, tg_yyzzzz_xxxxzz_1, tg_yyzzzz_xxxxzzz_0, \
                                         tg_yyzzzz_xxxxzzz_1, tg_yyzzzz_xxxyyy_1, tg_yyzzzz_xxxyyyy_0, tg_yyzzzz_xxxyyyy_1, \
                                         tg_yyzzzz_xxxyyyz_0, tg_yyzzzz_xxxyyyz_1, tg_yyzzzz_xxxyyz_1, tg_yyzzzz_xxxyyzz_0, \
                                         tg_yyzzzz_xxxyyzz_1, tg_yyzzzz_xxxyzz_1, tg_yyzzzz_xxxyzzz_0, tg_yyzzzz_xxxyzzz_1, \
                                         tg_yyzzzz_xxxzzz_1, tg_yyzzzz_xxxzzzz_0, tg_yyzzzz_xxxzzzz_1, tg_yyzzzz_xxyyyy_1, \
                                         tg_yyzzzz_xxyyyyy_0, tg_yyzzzz_xxyyyyy_1, tg_yyzzzz_xxyyyyz_0, tg_yyzzzz_xxyyyyz_1, \
                                         tg_yyzzzz_xxyyyz_1, tg_yyzzzz_xxyyyzz_0, tg_yyzzzz_xxyyyzz_1, tg_yyzzzz_xxyyzz_1, \
                                         tg_yyzzzz_xxyyzzz_0, tg_yyzzzz_xxyyzzz_1, tg_yyzzzz_xxyzzz_1, tg_yyzzzz_xxyzzzz_0, \
                                         tg_yyzzzz_xxyzzzz_1, tg_yyzzzz_xxzzzz_1, tg_yyzzzz_xxzzzzz_0, tg_yyzzzz_xxzzzzz_1, \
                                         tg_yyzzzz_xyyyyy_1, tg_yyzzzz_xyyyyyy_0, tg_yyzzzz_xyyyyyy_1, tg_yyzzzz_xyyyyyz_0, \
                                         tg_yyzzzz_xyyyyyz_1, tg_yyzzzz_xyyyyz_1, tg_yyzzzz_xyyyyzz_0, tg_yyzzzz_xyyyyzz_1, \
                                         tg_yyzzzz_xyyyzz_1, tg_yyzzzz_xyyyzzz_0, tg_yyzzzz_xyyyzzz_1, tg_yyzzzz_xyyzzz_1, \
                                         tg_yyzzzz_xyyzzzz_0, tg_yyzzzz_xyyzzzz_1, tg_yyzzzz_xyzzzz_1, tg_yyzzzz_xyzzzzz_0, \
                                         tg_yyzzzz_xyzzzzz_1, tg_yyzzzz_xzzzzz_1, tg_yyzzzz_xzzzzzz_0, tg_yyzzzz_xzzzzzz_1, \
                                         tg_yyzzzz_yyyyyy_1, tg_yyzzzz_yyyyyyy_0, tg_yyzzzz_yyyyyyy_1, tg_yyzzzz_yyyyyyz_0, \
                                         tg_yyzzzz_yyyyyyz_1, tg_yyzzzz_yyyyyz_1, tg_yyzzzz_yyyyyzz_0, tg_yyzzzz_yyyyyzz_1, \
                                         tg_yyzzzz_yyyyzz_1, tg_yyzzzz_yyyyzzz_0, tg_yyzzzz_yyyyzzz_1, tg_yyzzzz_yyyzzz_1, \
                                         tg_yyzzzz_yyyzzzz_0, tg_yyzzzz_yyyzzzz_1, tg_yyzzzz_yyzzzz_1, tg_yyzzzz_yyzzzzz_0, \
                                         tg_yyzzzz_yyzzzzz_1, tg_yyzzzz_yzzzzz_1, tg_yyzzzz_yzzzzzz_0, tg_yyzzzz_yzzzzzz_1, \
                                         tg_yyzzzz_zzzzzz_1, tg_yyzzzz_zzzzzzz_0, tg_yyzzzz_zzzzzzz_1, tg_yyzzzzz_xxxxxxx_0, \
                                         tg_yyzzzzz_xxxxxxy_0, tg_yyzzzzz_xxxxxxz_0, tg_yyzzzzz_xxxxxyy_0, tg_yyzzzzz_xxxxxyz_0, \
                                         tg_yyzzzzz_xxxxxzz_0, tg_yyzzzzz_xxxxyyy_0, tg_yyzzzzz_xxxxyyz_0, tg_yyzzzzz_xxxxyzz_0, \
                                         tg_yzzzz_xxxxxxx_0, tg_yzzzz_xxxxxxx_1, tg_yzzzz_xxxxxxy_0, tg_yzzzz_xxxxxxy_1, \
                                         tg_yzzzz_xxxxxxz_0, tg_yzzzz_xxxxxxz_1, tg_yzzzz_xxxxxyy_0, tg_yzzzz_xxxxxyy_1, \
                                         tg_yzzzz_xxxxxyz_0, tg_yzzzz_xxxxxyz_1, tg_yzzzz_xxxxxzz_0, tg_yzzzz_xxxxxzz_1, \
                                         tg_yzzzz_xxxxyyy_0, tg_yzzzz_xxxxyyy_1, tg_yzzzz_xxxxyyz_0, tg_yzzzz_xxxxyyz_1, \
                                         tg_yzzzz_xxxxyzz_0, tg_yzzzz_xxxxyzz_1, tg_yzzzz_xxxxzzz_0, tg_yzzzz_xxxxzzz_1, \
                                         tg_yzzzz_xxxyyyy_0, tg_yzzzz_xxxyyyy_1, tg_yzzzz_xxxyyyz_0, tg_yzzzz_xxxyyyz_1, \
                                         tg_yzzzz_xxxyyzz_0, tg_yzzzz_xxxyyzz_1, tg_yzzzz_xxxyzzz_0, tg_yzzzz_xxxyzzz_1, \
                                         tg_yzzzz_xxxzzzz_0, tg_yzzzz_xxxzzzz_1, tg_yzzzz_xxyyyyy_0, tg_yzzzz_xxyyyyy_1, \
                                         tg_yzzzz_xxyyyyz_0, tg_yzzzz_xxyyyyz_1, tg_yzzzz_xxyyyzz_0, tg_yzzzz_xxyyyzz_1, \
                                         tg_yzzzz_xxyyzzz_0, tg_yzzzz_xxyyzzz_1, tg_yzzzz_xxyzzzz_0, tg_yzzzz_xxyzzzz_1, \
                                         tg_yzzzz_xxzzzzz_0, tg_yzzzz_xxzzzzz_1, tg_yzzzz_xyyyyyy_0, tg_yzzzz_xyyyyyy_1, \
                                         tg_yzzzz_xyyyyyz_0, tg_yzzzz_xyyyyyz_1, tg_yzzzz_xyyyyzz_0, tg_yzzzz_xyyyyzz_1, \
                                         tg_yzzzz_xyyyzzz_0, tg_yzzzz_xyyyzzz_1, tg_yzzzz_xyyzzzz_0, tg_yzzzz_xyyzzzz_1, \
                                         tg_yzzzz_xyzzzzz_0, tg_yzzzz_xyzzzzz_1, tg_yzzzz_xzzzzzz_0, tg_yzzzz_xzzzzzz_1, \
                                         tg_yzzzz_yyyyyyy_0, tg_yzzzz_yyyyyyy_1, tg_yzzzz_yyyyyyz_0, tg_yzzzz_yyyyyyz_1, \
                                         tg_yzzzz_yyyyyzz_0, tg_yzzzz_yyyyyzz_1, tg_yzzzz_yyyyzzz_0, tg_yzzzz_yyyyzzz_1, \
                                         tg_yzzzz_yyyzzzz_0, tg_yzzzz_yyyzzzz_1, tg_yzzzz_yyzzzzz_0, tg_yzzzz_yyzzzzz_1, \
                                         tg_yzzzz_yzzzzzz_0, tg_yzzzz_yzzzzzz_1, tg_yzzzz_zzzzzzz_0, tg_yzzzz_zzzzzzz_1, \
                                         tg_yzzzzz_xxxxxx_1, tg_yzzzzz_xxxxxxx_0, tg_yzzzzz_xxxxxxx_1, tg_yzzzzz_xxxxxxy_0, \
                                         tg_yzzzzz_xxxxxxy_1, tg_yzzzzz_xxxxxxz_0, tg_yzzzzz_xxxxxxz_1, tg_yzzzzz_xxxxxy_1, \
                                         tg_yzzzzz_xxxxxyy_0, tg_yzzzzz_xxxxxyy_1, tg_yzzzzz_xxxxxyz_0, tg_yzzzzz_xxxxxyz_1, \
                                         tg_yzzzzz_xxxxxz_1, tg_yzzzzz_xxxxxzz_0, tg_yzzzzz_xxxxxzz_1, tg_yzzzzz_xxxxyy_1, \
                                         tg_yzzzzz_xxxxyyy_0, tg_yzzzzz_xxxxyyy_1, tg_yzzzzz_xxxxyyz_0, tg_yzzzzz_xxxxyyz_1, \
                                         tg_yzzzzz_xxxxyz_1, tg_yzzzzz_xxxxyzz_0, tg_yzzzzz_xxxxyzz_1, tg_yzzzzz_xxxxzz_1, \
                                         tg_zzzzz_xxxxxxx_0, tg_zzzzz_xxxxxxx_1, tg_zzzzz_xxxxxxy_0, tg_zzzzz_xxxxxxy_1, \
                                         tg_zzzzz_xxxxxxz_0, tg_zzzzz_xxxxxxz_1, tg_zzzzz_xxxxxyy_0, tg_zzzzz_xxxxxyy_1, \
                                         tg_zzzzz_xxxxxyz_0, tg_zzzzz_xxxxxyz_1, tg_zzzzz_xxxxxzz_0, tg_zzzzz_xxxxxzz_1, \
                                         tg_zzzzz_xxxxyyy_0, tg_zzzzz_xxxxyyy_1, tg_zzzzz_xxxxyyz_0, tg_zzzzz_xxxxyyz_1, \
                                         tg_zzzzz_xxxxyzz_0, tg_zzzzz_xxxxyzz_1, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyyyyzz_xxyyzzz_0[j] = pb_y * tg_yyyyzz_xxyyzzz_0[j] + fr * tg_yyyyzz_xxyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxyyzzz_0[j] - tg_yyyzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_xxyzzz_1[j];

                    tg_yyyyyzz_xxyzzzz_0[j] = pb_y * tg_yyyyzz_xxyzzzz_0[j] + fr * tg_yyyyzz_xxyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxyzzzz_0[j] - tg_yyyzz_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xxzzzz_1[j];

                    tg_yyyyyzz_xxzzzzz_0[j] = pb_y * tg_yyyyzz_xxzzzzz_0[j] + fr * tg_yyyyzz_xxzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xxzzzzz_0[j] - tg_yyyzz_xxzzzzz_1[j] * fl1_fza);

                    tg_yyyyyzz_xyyyyyy_0[j] = pb_y * tg_yyyyzz_xyyyyyy_0[j] + fr * tg_yyyyzz_xyyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyyyyyy_0[j] - tg_yyyzz_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyzz_xyyyyy_1[j];

                    tg_yyyyyzz_xyyyyyz_0[j] = pb_y * tg_yyyyzz_xyyyyyz_0[j] + fr * tg_yyyyzz_xyyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyyyyyz_0[j] - tg_yyyzz_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyzz_xyyyyz_1[j];

                    tg_yyyyyzz_xyyyyzz_0[j] = pb_y * tg_yyyyzz_xyyyyzz_0[j] + fr * tg_yyyyzz_xyyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyyyyzz_0[j] - tg_yyyzz_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzz_xyyyzz_1[j];

                    tg_yyyyyzz_xyyyzzz_0[j] = pb_y * tg_yyyyzz_xyyyzzz_0[j] + fr * tg_yyyyzz_xyyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyyyzzz_0[j] - tg_yyyzz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzz_xyyzzz_1[j];

                    tg_yyyyyzz_xyyzzzz_0[j] = pb_y * tg_yyyyzz_xyyzzzz_0[j] + fr * tg_yyyyzz_xyyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyyzzzz_0[j] - tg_yyyzz_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_xyzzzz_1[j];

                    tg_yyyyyzz_xyzzzzz_0[j] = pb_y * tg_yyyyzz_xyzzzzz_0[j] + fr * tg_yyyyzz_xyzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xyzzzzz_0[j] - tg_yyyzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_xzzzzz_1[j];

                    tg_yyyyyzz_xzzzzzz_0[j] = pb_y * tg_yyyyzz_xzzzzzz_0[j] + fr * tg_yyyyzz_xzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_xzzzzzz_0[j] - tg_yyyzz_xzzzzzz_1[j] * fl1_fza);

                    tg_yyyyyzz_yyyyyyy_0[j] = pb_y * tg_yyyyzz_yyyyyyy_0[j] + fr * tg_yyyyzz_yyyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyyyyyy_0[j] - tg_yyyzz_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyyzz_yyyyyy_1[j];

                    tg_yyyyyzz_yyyyyyz_0[j] = pb_y * tg_yyyyzz_yyyyyyz_0[j] + fr * tg_yyyyzz_yyyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyyyyyz_0[j] - tg_yyyzz_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyzz_yyyyyz_1[j];

                    tg_yyyyyzz_yyyyyzz_0[j] = pb_y * tg_yyyyzz_yyyyyzz_0[j] + fr * tg_yyyyzz_yyyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyyyyzz_0[j] - tg_yyyzz_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyzz_yyyyzz_1[j];

                    tg_yyyyyzz_yyyyzzz_0[j] = pb_y * tg_yyyyzz_yyyyzzz_0[j] + fr * tg_yyyyzz_yyyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyyyzzz_0[j] - tg_yyyzz_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzz_yyyzzz_1[j];

                    tg_yyyyyzz_yyyzzzz_0[j] = pb_y * tg_yyyyzz_yyyzzzz_0[j] + fr * tg_yyyyzz_yyyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyyzzzz_0[j] - tg_yyyzz_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzz_yyzzzz_1[j];

                    tg_yyyyyzz_yyzzzzz_0[j] = pb_y * tg_yyyyzz_yyzzzzz_0[j] + fr * tg_yyyyzz_yyzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yyzzzzz_0[j] - tg_yyyzz_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzz_yzzzzz_1[j];

                    tg_yyyyyzz_yzzzzzz_0[j] = pb_y * tg_yyyyzz_yzzzzzz_0[j] + fr * tg_yyyyzz_yzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_yzzzzzz_0[j] - tg_yyyzz_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzz_zzzzzz_1[j];

                    tg_yyyyyzz_zzzzzzz_0[j] = pb_y * tg_yyyyzz_zzzzzzz_0[j] + fr * tg_yyyyzz_zzzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzz_zzzzzzz_0[j] - tg_yyyzz_zzzzzzz_1[j] * fl1_fza);

                    tg_yyyyzzz_xxxxxxx_0[j] = pb_y * tg_yyyzzz_xxxxxxx_0[j] + fr * tg_yyyzzz_xxxxxxx_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxxx_0[j] - tg_yyzzz_xxxxxxx_1[j] * fl1_fza);

                    tg_yyyyzzz_xxxxxxy_0[j] = pb_y * tg_yyyzzz_xxxxxxy_0[j] + fr * tg_yyyzzz_xxxxxxy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxxy_0[j] - tg_yyzzz_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xxxxxx_1[j];

                    tg_yyyyzzz_xxxxxxz_0[j] = pb_y * tg_yyyzzz_xxxxxxz_0[j] + fr * tg_yyyzzz_xxxxxxz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxxz_0[j] - tg_yyzzz_xxxxxxz_1[j] * fl1_fza);

                    tg_yyyyzzz_xxxxxyy_0[j] = pb_y * tg_yyyzzz_xxxxxyy_0[j] + fr * tg_yyyzzz_xxxxxyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxyy_0[j] - tg_yyzzz_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_xxxxxy_1[j];

                    tg_yyyyzzz_xxxxxyz_0[j] = pb_y * tg_yyyzzz_xxxxxyz_0[j] + fr * tg_yyyzzz_xxxxxyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxyz_0[j] - tg_yyzzz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xxxxxz_1[j];

                    tg_yyyyzzz_xxxxxzz_0[j] = pb_y * tg_yyyzzz_xxxxxzz_0[j] + fr * tg_yyyzzz_xxxxxzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxxzz_0[j] - tg_yyzzz_xxxxxzz_1[j] * fl1_fza);

                    tg_yyyyzzz_xxxxyyy_0[j] = pb_y * tg_yyyzzz_xxxxyyy_0[j] + fr * tg_yyyzzz_xxxxyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxyyy_0[j] - tg_yyzzz_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzz_xxxxyy_1[j];

                    tg_yyyyzzz_xxxxyyz_0[j] = pb_y * tg_yyyzzz_xxxxyyz_0[j] + fr * tg_yyyzzz_xxxxyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxyyz_0[j] - tg_yyzzz_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_xxxxyz_1[j];

                    tg_yyyyzzz_xxxxyzz_0[j] = pb_y * tg_yyyzzz_xxxxyzz_0[j] + fr * tg_yyyzzz_xxxxyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxyzz_0[j] - tg_yyzzz_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xxxxzz_1[j];

                    tg_yyyyzzz_xxxxzzz_0[j] = pb_y * tg_yyyzzz_xxxxzzz_0[j] + fr * tg_yyyzzz_xxxxzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxxzzz_0[j] - tg_yyzzz_xxxxzzz_1[j] * fl1_fza);

                    tg_yyyyzzz_xxxyyyy_0[j] = pb_y * tg_yyyzzz_xxxyyyy_0[j] + fr * tg_yyyzzz_xxxyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxyyyy_0[j] - tg_yyzzz_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzz_xxxyyy_1[j];

                    tg_yyyyzzz_xxxyyyz_0[j] = pb_y * tg_yyyzzz_xxxyyyz_0[j] + fr * tg_yyyzzz_xxxyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxyyyz_0[j] - tg_yyzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzz_xxxyyz_1[j];

                    tg_yyyyzzz_xxxyyzz_0[j] = pb_y * tg_yyyzzz_xxxyyzz_0[j] + fr * tg_yyyzzz_xxxyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxyyzz_0[j] - tg_yyzzz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_xxxyzz_1[j];

                    tg_yyyyzzz_xxxyzzz_0[j] = pb_y * tg_yyyzzz_xxxyzzz_0[j] + fr * tg_yyyzzz_xxxyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxyzzz_0[j] - tg_yyzzz_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xxxzzz_1[j];

                    tg_yyyyzzz_xxxzzzz_0[j] = pb_y * tg_yyyzzz_xxxzzzz_0[j] + fr * tg_yyyzzz_xxxzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxxzzzz_0[j] - tg_yyzzz_xxxzzzz_1[j] * fl1_fza);

                    tg_yyyyzzz_xxyyyyy_0[j] = pb_y * tg_yyyzzz_xxyyyyy_0[j] + fr * tg_yyyzzz_xxyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxyyyyy_0[j] - tg_yyzzz_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzzz_xxyyyy_1[j];

                    tg_yyyyzzz_xxyyyyz_0[j] = pb_y * tg_yyyzzz_xxyyyyz_0[j] + fr * tg_yyyzzz_xxyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxyyyyz_0[j] - tg_yyzzz_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzz_xxyyyz_1[j];

                    tg_yyyyzzz_xxyyyzz_0[j] = pb_y * tg_yyyzzz_xxyyyzz_0[j] + fr * tg_yyyzzz_xxyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxyyyzz_0[j] - tg_yyzzz_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzz_xxyyzz_1[j];

                    tg_yyyyzzz_xxyyzzz_0[j] = pb_y * tg_yyyzzz_xxyyzzz_0[j] + fr * tg_yyyzzz_xxyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxyyzzz_0[j] - tg_yyzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_xxyzzz_1[j];

                    tg_yyyyzzz_xxyzzzz_0[j] = pb_y * tg_yyyzzz_xxyzzzz_0[j] + fr * tg_yyyzzz_xxyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxyzzzz_0[j] - tg_yyzzz_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xxzzzz_1[j];

                    tg_yyyyzzz_xxzzzzz_0[j] = pb_y * tg_yyyzzz_xxzzzzz_0[j] + fr * tg_yyyzzz_xxzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xxzzzzz_0[j] - tg_yyzzz_xxzzzzz_1[j] * fl1_fza);

                    tg_yyyyzzz_xyyyyyy_0[j] = pb_y * tg_yyyzzz_xyyyyyy_0[j] + fr * tg_yyyzzz_xyyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyyyyyy_0[j] - tg_yyzzz_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzzz_xyyyyy_1[j];

                    tg_yyyyzzz_xyyyyyz_0[j] = pb_y * tg_yyyzzz_xyyyyyz_0[j] + fr * tg_yyyzzz_xyyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyyyyyz_0[j] - tg_yyzzz_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzzz_xyyyyz_1[j];

                    tg_yyyyzzz_xyyyyzz_0[j] = pb_y * tg_yyyzzz_xyyyyzz_0[j] + fr * tg_yyyzzz_xyyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyyyyzz_0[j] - tg_yyzzz_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzz_xyyyzz_1[j];

                    tg_yyyyzzz_xyyyzzz_0[j] = pb_y * tg_yyyzzz_xyyyzzz_0[j] + fr * tg_yyyzzz_xyyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyyyzzz_0[j] - tg_yyzzz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzz_xyyzzz_1[j];

                    tg_yyyyzzz_xyyzzzz_0[j] = pb_y * tg_yyyzzz_xyyzzzz_0[j] + fr * tg_yyyzzz_xyyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyyzzzz_0[j] - tg_yyzzz_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_xyzzzz_1[j];

                    tg_yyyyzzz_xyzzzzz_0[j] = pb_y * tg_yyyzzz_xyzzzzz_0[j] + fr * tg_yyyzzz_xyzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xyzzzzz_0[j] - tg_yyzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_xzzzzz_1[j];

                    tg_yyyyzzz_xzzzzzz_0[j] = pb_y * tg_yyyzzz_xzzzzzz_0[j] + fr * tg_yyyzzz_xzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_xzzzzzz_0[j] - tg_yyzzz_xzzzzzz_1[j] * fl1_fza);

                    tg_yyyyzzz_yyyyyyy_0[j] = pb_y * tg_yyyzzz_yyyyyyy_0[j] + fr * tg_yyyzzz_yyyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyyyyyy_0[j] - tg_yyzzz_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyyzzz_yyyyyy_1[j];

                    tg_yyyyzzz_yyyyyyz_0[j] = pb_y * tg_yyyzzz_yyyyyyz_0[j] + fr * tg_yyyzzz_yyyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyyyyyz_0[j] - tg_yyzzz_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzzz_yyyyyz_1[j];

                    tg_yyyyzzz_yyyyyzz_0[j] = pb_y * tg_yyyzzz_yyyyyzz_0[j] + fr * tg_yyyzzz_yyyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyyyyzz_0[j] - tg_yyzzz_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzzz_yyyyzz_1[j];

                    tg_yyyyzzz_yyyyzzz_0[j] = pb_y * tg_yyyzzz_yyyyzzz_0[j] + fr * tg_yyyzzz_yyyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyyyzzz_0[j] - tg_yyzzz_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzz_yyyzzz_1[j];

                    tg_yyyyzzz_yyyzzzz_0[j] = pb_y * tg_yyyzzz_yyyzzzz_0[j] + fr * tg_yyyzzz_yyyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyyzzzz_0[j] - tg_yyzzz_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzz_yyzzzz_1[j];

                    tg_yyyyzzz_yyzzzzz_0[j] = pb_y * tg_yyyzzz_yyzzzzz_0[j] + fr * tg_yyyzzz_yyzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yyzzzzz_0[j] - tg_yyzzz_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzz_yzzzzz_1[j];

                    tg_yyyyzzz_yzzzzzz_0[j] = pb_y * tg_yyyzzz_yzzzzzz_0[j] + fr * tg_yyyzzz_yzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_yzzzzzz_0[j] - tg_yyzzz_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzz_zzzzzz_1[j];

                    tg_yyyyzzz_zzzzzzz_0[j] = pb_y * tg_yyyzzz_zzzzzzz_0[j] + fr * tg_yyyzzz_zzzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzz_zzzzzzz_0[j] - tg_yyzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_yyyzzzz_xxxxxxx_0[j] = pb_y * tg_yyzzzz_xxxxxxx_0[j] + fr * tg_yyzzzz_xxxxxxx_1[j] + fl1_fx * (tg_yzzzz_xxxxxxx_0[j] - tg_yzzzz_xxxxxxx_1[j] * fl1_fza);

                    tg_yyyzzzz_xxxxxxy_0[j] = pb_y * tg_yyzzzz_xxxxxxy_0[j] + fr * tg_yyzzzz_xxxxxxy_1[j] + fl1_fx * (tg_yzzzz_xxxxxxy_0[j] - tg_yzzzz_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xxxxxx_1[j];

                    tg_yyyzzzz_xxxxxxz_0[j] = pb_y * tg_yyzzzz_xxxxxxz_0[j] + fr * tg_yyzzzz_xxxxxxz_1[j] + fl1_fx * (tg_yzzzz_xxxxxxz_0[j] - tg_yzzzz_xxxxxxz_1[j] * fl1_fza);

                    tg_yyyzzzz_xxxxxyy_0[j] = pb_y * tg_yyzzzz_xxxxxyy_0[j] + fr * tg_yyzzzz_xxxxxyy_1[j] + fl1_fx * (tg_yzzzz_xxxxxyy_0[j] - tg_yzzzz_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_xxxxxy_1[j];

                    tg_yyyzzzz_xxxxxyz_0[j] = pb_y * tg_yyzzzz_xxxxxyz_0[j] + fr * tg_yyzzzz_xxxxxyz_1[j] + fl1_fx * (tg_yzzzz_xxxxxyz_0[j] - tg_yzzzz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xxxxxz_1[j];

                    tg_yyyzzzz_xxxxxzz_0[j] = pb_y * tg_yyzzzz_xxxxxzz_0[j] + fr * tg_yyzzzz_xxxxxzz_1[j] + fl1_fx * (tg_yzzzz_xxxxxzz_0[j] - tg_yzzzz_xxxxxzz_1[j] * fl1_fza);

                    tg_yyyzzzz_xxxxyyy_0[j] = pb_y * tg_yyzzzz_xxxxyyy_0[j] + fr * tg_yyzzzz_xxxxyyy_1[j] + fl1_fx * (tg_yzzzz_xxxxyyy_0[j] - tg_yzzzz_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzz_xxxxyy_1[j];

                    tg_yyyzzzz_xxxxyyz_0[j] = pb_y * tg_yyzzzz_xxxxyyz_0[j] + fr * tg_yyzzzz_xxxxyyz_1[j] + fl1_fx * (tg_yzzzz_xxxxyyz_0[j] - tg_yzzzz_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_xxxxyz_1[j];

                    tg_yyyzzzz_xxxxyzz_0[j] = pb_y * tg_yyzzzz_xxxxyzz_0[j] + fr * tg_yyzzzz_xxxxyzz_1[j] + fl1_fx * (tg_yzzzz_xxxxyzz_0[j] - tg_yzzzz_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xxxxzz_1[j];

                    tg_yyyzzzz_xxxxzzz_0[j] = pb_y * tg_yyzzzz_xxxxzzz_0[j] + fr * tg_yyzzzz_xxxxzzz_1[j] + fl1_fx * (tg_yzzzz_xxxxzzz_0[j] - tg_yzzzz_xxxxzzz_1[j] * fl1_fza);

                    tg_yyyzzzz_xxxyyyy_0[j] = pb_y * tg_yyzzzz_xxxyyyy_0[j] + fr * tg_yyzzzz_xxxyyyy_1[j] + fl1_fx * (tg_yzzzz_xxxyyyy_0[j] - tg_yzzzz_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzz_xxxyyy_1[j];

                    tg_yyyzzzz_xxxyyyz_0[j] = pb_y * tg_yyzzzz_xxxyyyz_0[j] + fr * tg_yyzzzz_xxxyyyz_1[j] + fl1_fx * (tg_yzzzz_xxxyyyz_0[j] - tg_yzzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzz_xxxyyz_1[j];

                    tg_yyyzzzz_xxxyyzz_0[j] = pb_y * tg_yyzzzz_xxxyyzz_0[j] + fr * tg_yyzzzz_xxxyyzz_1[j] + fl1_fx * (tg_yzzzz_xxxyyzz_0[j] - tg_yzzzz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_xxxyzz_1[j];

                    tg_yyyzzzz_xxxyzzz_0[j] = pb_y * tg_yyzzzz_xxxyzzz_0[j] + fr * tg_yyzzzz_xxxyzzz_1[j] + fl1_fx * (tg_yzzzz_xxxyzzz_0[j] - tg_yzzzz_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xxxzzz_1[j];

                    tg_yyyzzzz_xxxzzzz_0[j] = pb_y * tg_yyzzzz_xxxzzzz_0[j] + fr * tg_yyzzzz_xxxzzzz_1[j] + fl1_fx * (tg_yzzzz_xxxzzzz_0[j] - tg_yzzzz_xxxzzzz_1[j] * fl1_fza);

                    tg_yyyzzzz_xxyyyyy_0[j] = pb_y * tg_yyzzzz_xxyyyyy_0[j] + fr * tg_yyzzzz_xxyyyyy_1[j] + fl1_fx * (tg_yzzzz_xxyyyyy_0[j] - tg_yzzzz_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzzz_xxyyyy_1[j];

                    tg_yyyzzzz_xxyyyyz_0[j] = pb_y * tg_yyzzzz_xxyyyyz_0[j] + fr * tg_yyzzzz_xxyyyyz_1[j] + fl1_fx * (tg_yzzzz_xxyyyyz_0[j] - tg_yzzzz_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzz_xxyyyz_1[j];

                    tg_yyyzzzz_xxyyyzz_0[j] = pb_y * tg_yyzzzz_xxyyyzz_0[j] + fr * tg_yyzzzz_xxyyyzz_1[j] + fl1_fx * (tg_yzzzz_xxyyyzz_0[j] - tg_yzzzz_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzz_xxyyzz_1[j];

                    tg_yyyzzzz_xxyyzzz_0[j] = pb_y * tg_yyzzzz_xxyyzzz_0[j] + fr * tg_yyzzzz_xxyyzzz_1[j] + fl1_fx * (tg_yzzzz_xxyyzzz_0[j] - tg_yzzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_xxyzzz_1[j];

                    tg_yyyzzzz_xxyzzzz_0[j] = pb_y * tg_yyzzzz_xxyzzzz_0[j] + fr * tg_yyzzzz_xxyzzzz_1[j] + fl1_fx * (tg_yzzzz_xxyzzzz_0[j] - tg_yzzzz_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xxzzzz_1[j];

                    tg_yyyzzzz_xxzzzzz_0[j] = pb_y * tg_yyzzzz_xxzzzzz_0[j] + fr * tg_yyzzzz_xxzzzzz_1[j] + fl1_fx * (tg_yzzzz_xxzzzzz_0[j] - tg_yzzzz_xxzzzzz_1[j] * fl1_fza);

                    tg_yyyzzzz_xyyyyyy_0[j] = pb_y * tg_yyzzzz_xyyyyyy_0[j] + fr * tg_yyzzzz_xyyyyyy_1[j] + fl1_fx * (tg_yzzzz_xyyyyyy_0[j] - tg_yzzzz_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzzz_xyyyyy_1[j];

                    tg_yyyzzzz_xyyyyyz_0[j] = pb_y * tg_yyzzzz_xyyyyyz_0[j] + fr * tg_yyzzzz_xyyyyyz_1[j] + fl1_fx * (tg_yzzzz_xyyyyyz_0[j] - tg_yzzzz_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzzz_xyyyyz_1[j];

                    tg_yyyzzzz_xyyyyzz_0[j] = pb_y * tg_yyzzzz_xyyyyzz_0[j] + fr * tg_yyzzzz_xyyyyzz_1[j] + fl1_fx * (tg_yzzzz_xyyyyzz_0[j] - tg_yzzzz_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzz_xyyyzz_1[j];

                    tg_yyyzzzz_xyyyzzz_0[j] = pb_y * tg_yyzzzz_xyyyzzz_0[j] + fr * tg_yyzzzz_xyyyzzz_1[j] + fl1_fx * (tg_yzzzz_xyyyzzz_0[j] - tg_yzzzz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzz_xyyzzz_1[j];

                    tg_yyyzzzz_xyyzzzz_0[j] = pb_y * tg_yyzzzz_xyyzzzz_0[j] + fr * tg_yyzzzz_xyyzzzz_1[j] + fl1_fx * (tg_yzzzz_xyyzzzz_0[j] - tg_yzzzz_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_xyzzzz_1[j];

                    tg_yyyzzzz_xyzzzzz_0[j] = pb_y * tg_yyzzzz_xyzzzzz_0[j] + fr * tg_yyzzzz_xyzzzzz_1[j] + fl1_fx * (tg_yzzzz_xyzzzzz_0[j] - tg_yzzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_xzzzzz_1[j];

                    tg_yyyzzzz_xzzzzzz_0[j] = pb_y * tg_yyzzzz_xzzzzzz_0[j] + fr * tg_yyzzzz_xzzzzzz_1[j] + fl1_fx * (tg_yzzzz_xzzzzzz_0[j] - tg_yzzzz_xzzzzzz_1[j] * fl1_fza);

                    tg_yyyzzzz_yyyyyyy_0[j] = pb_y * tg_yyzzzz_yyyyyyy_0[j] + fr * tg_yyzzzz_yyyyyyy_1[j] + fl1_fx * (tg_yzzzz_yyyyyyy_0[j] - tg_yzzzz_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yyzzzz_yyyyyy_1[j];

                    tg_yyyzzzz_yyyyyyz_0[j] = pb_y * tg_yyzzzz_yyyyyyz_0[j] + fr * tg_yyzzzz_yyyyyyz_1[j] + fl1_fx * (tg_yzzzz_yyyyyyz_0[j] - tg_yzzzz_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzzz_yyyyyz_1[j];

                    tg_yyyzzzz_yyyyyzz_0[j] = pb_y * tg_yyzzzz_yyyyyzz_0[j] + fr * tg_yyzzzz_yyyyyzz_1[j] + fl1_fx * (tg_yzzzz_yyyyyzz_0[j] - tg_yzzzz_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzzz_yyyyzz_1[j];

                    tg_yyyzzzz_yyyyzzz_0[j] = pb_y * tg_yyzzzz_yyyyzzz_0[j] + fr * tg_yyzzzz_yyyyzzz_1[j] + fl1_fx * (tg_yzzzz_yyyyzzz_0[j] - tg_yzzzz_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzz_yyyzzz_1[j];

                    tg_yyyzzzz_yyyzzzz_0[j] = pb_y * tg_yyzzzz_yyyzzzz_0[j] + fr * tg_yyzzzz_yyyzzzz_1[j] + fl1_fx * (tg_yzzzz_yyyzzzz_0[j] - tg_yzzzz_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzz_yyzzzz_1[j];

                    tg_yyyzzzz_yyzzzzz_0[j] = pb_y * tg_yyzzzz_yyzzzzz_0[j] + fr * tg_yyzzzz_yyzzzzz_1[j] + fl1_fx * (tg_yzzzz_yyzzzzz_0[j] - tg_yzzzz_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzz_yzzzzz_1[j];

                    tg_yyyzzzz_yzzzzzz_0[j] = pb_y * tg_yyzzzz_yzzzzzz_0[j] + fr * tg_yyzzzz_yzzzzzz_1[j] + fl1_fx * (tg_yzzzz_yzzzzzz_0[j] - tg_yzzzz_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzz_zzzzzz_1[j];

                    tg_yyyzzzz_zzzzzzz_0[j] = pb_y * tg_yyzzzz_zzzzzzz_0[j] + fr * tg_yyzzzz_zzzzzzz_1[j] + fl1_fx * (tg_yzzzz_zzzzzzz_0[j] - tg_yzzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_yyzzzzz_xxxxxxx_0[j] = pb_y * tg_yzzzzz_xxxxxxx_0[j] + fr * tg_yzzzzz_xxxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxx_0[j] - tg_zzzzz_xxxxxxx_1[j] * fl1_fza);

                    tg_yyzzzzz_xxxxxxy_0[j] = pb_y * tg_yzzzzz_xxxxxxy_0[j] + fr * tg_yzzzzz_xxxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxy_0[j] - tg_zzzzz_xxxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xxxxxx_1[j];

                    tg_yyzzzzz_xxxxxxz_0[j] = pb_y * tg_yzzzzz_xxxxxxz_0[j] + fr * tg_yzzzzz_xxxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxxz_0[j] - tg_zzzzz_xxxxxxz_1[j] * fl1_fza);

                    tg_yyzzzzz_xxxxxyy_0[j] = pb_y * tg_yzzzzz_xxxxxyy_0[j] + fr * tg_yzzzzz_xxxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxyy_0[j] - tg_zzzzz_xxxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_xxxxxy_1[j];

                    tg_yyzzzzz_xxxxxyz_0[j] = pb_y * tg_yzzzzz_xxxxxyz_0[j] + fr * tg_yzzzzz_xxxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxyz_0[j] - tg_zzzzz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xxxxxz_1[j];

                    tg_yyzzzzz_xxxxxzz_0[j] = pb_y * tg_yzzzzz_xxxxxzz_0[j] + fr * tg_yzzzzz_xxxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxxzz_0[j] - tg_zzzzz_xxxxxzz_1[j] * fl1_fza);

                    tg_yyzzzzz_xxxxyyy_0[j] = pb_y * tg_yzzzzz_xxxxyyy_0[j] + fr * tg_yzzzzz_xxxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyyy_0[j] - tg_zzzzz_xxxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzz_xxxxyy_1[j];

                    tg_yyzzzzz_xxxxyyz_0[j] = pb_y * tg_yzzzzz_xxxxyyz_0[j] + fr * tg_yzzzzz_xxxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyyz_0[j] - tg_zzzzz_xxxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_xxxxyz_1[j];

                    tg_yyzzzzz_xxxxyzz_0[j] = pb_y * tg_yzzzzz_xxxxyzz_0[j] + fr * tg_yzzzzz_xxxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxyzz_0[j] - tg_zzzzz_xxxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xxxxzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSKSK_1197_1296(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1197,1296)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {7, -1, -1, -1},
                                             {7, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_7_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_7_7_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_6_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_5_7_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_5_7_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {5, -1, -1, -1}, {7, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yzzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 945); 

                auto tg_yzzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 946); 

                auto tg_yzzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 947); 

                auto tg_yzzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 948); 

                auto tg_yzzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 949); 

                auto tg_yzzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 950); 

                auto tg_yzzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 951); 

                auto tg_yzzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 952); 

                auto tg_yzzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 953); 

                auto tg_yzzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 954); 

                auto tg_yzzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 955); 

                auto tg_yzzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 956); 

                auto tg_yzzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 957); 

                auto tg_yzzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 958); 

                auto tg_yzzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 959); 

                auto tg_yzzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 960); 

                auto tg_yzzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 961); 

                auto tg_yzzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 962); 

                auto tg_yzzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 963); 

                auto tg_yzzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 964); 

                auto tg_yzzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 965); 

                auto tg_yzzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 966); 

                auto tg_yzzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 967); 

                auto tg_yzzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 968); 

                auto tg_yzzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 969); 

                auto tg_yzzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 970); 

                auto tg_yzzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 971); 

                auto tg_zzzzzz_xxxxxxx_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 972); 

                auto tg_zzzzzz_xxxxxxy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 973); 

                auto tg_zzzzzz_xxxxxxz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 974); 

                auto tg_zzzzzz_xxxxxyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 975); 

                auto tg_zzzzzz_xxxxxyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 976); 

                auto tg_zzzzzz_xxxxxzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 977); 

                auto tg_zzzzzz_xxxxyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 978); 

                auto tg_zzzzzz_xxxxyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 979); 

                auto tg_zzzzzz_xxxxyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 980); 

                auto tg_zzzzzz_xxxxzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 981); 

                auto tg_zzzzzz_xxxyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 982); 

                auto tg_zzzzzz_xxxyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 983); 

                auto tg_zzzzzz_xxxyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 984); 

                auto tg_zzzzzz_xxxyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 985); 

                auto tg_zzzzzz_xxxzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 986); 

                auto tg_zzzzzz_xxyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 987); 

                auto tg_zzzzzz_xxyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 988); 

                auto tg_zzzzzz_xxyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 989); 

                auto tg_zzzzzz_xxyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 990); 

                auto tg_zzzzzz_xxyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 991); 

                auto tg_zzzzzz_xxzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 992); 

                auto tg_zzzzzz_xyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 993); 

                auto tg_zzzzzz_xyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 994); 

                auto tg_zzzzzz_xyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 995); 

                auto tg_zzzzzz_xyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 996); 

                auto tg_zzzzzz_xyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 997); 

                auto tg_zzzzzz_xyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 998); 

                auto tg_zzzzzz_xzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 999); 

                auto tg_zzzzzz_yyyyyyy_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1000); 

                auto tg_zzzzzz_yyyyyyz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1001); 

                auto tg_zzzzzz_yyyyyzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1002); 

                auto tg_zzzzzz_yyyyzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1003); 

                auto tg_zzzzzz_yyyzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1004); 

                auto tg_zzzzzz_yyzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1005); 

                auto tg_zzzzzz_yzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1006); 

                auto tg_zzzzzz_zzzzzzz_0 = primBuffer[pidx_g_6_7_m0].data(1008 * idx + 1007); 

                auto tg_yzzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 945); 

                auto tg_yzzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 946); 

                auto tg_yzzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 947); 

                auto tg_yzzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 948); 

                auto tg_yzzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 949); 

                auto tg_yzzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 950); 

                auto tg_yzzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 951); 

                auto tg_yzzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 952); 

                auto tg_yzzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 953); 

                auto tg_yzzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 954); 

                auto tg_yzzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 955); 

                auto tg_yzzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 956); 

                auto tg_yzzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 957); 

                auto tg_yzzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 958); 

                auto tg_yzzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 959); 

                auto tg_yzzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 960); 

                auto tg_yzzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 961); 

                auto tg_yzzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 962); 

                auto tg_yzzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 963); 

                auto tg_yzzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 964); 

                auto tg_yzzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 965); 

                auto tg_yzzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 966); 

                auto tg_yzzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 967); 

                auto tg_yzzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 968); 

                auto tg_yzzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 969); 

                auto tg_yzzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 970); 

                auto tg_yzzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 971); 

                auto tg_zzzzzz_xxxxxxx_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 972); 

                auto tg_zzzzzz_xxxxxxy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 973); 

                auto tg_zzzzzz_xxxxxxz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 974); 

                auto tg_zzzzzz_xxxxxyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 975); 

                auto tg_zzzzzz_xxxxxyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 976); 

                auto tg_zzzzzz_xxxxxzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 977); 

                auto tg_zzzzzz_xxxxyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 978); 

                auto tg_zzzzzz_xxxxyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 979); 

                auto tg_zzzzzz_xxxxyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 980); 

                auto tg_zzzzzz_xxxxzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 981); 

                auto tg_zzzzzz_xxxyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 982); 

                auto tg_zzzzzz_xxxyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 983); 

                auto tg_zzzzzz_xxxyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 984); 

                auto tg_zzzzzz_xxxyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 985); 

                auto tg_zzzzzz_xxxzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 986); 

                auto tg_zzzzzz_xxyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 987); 

                auto tg_zzzzzz_xxyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 988); 

                auto tg_zzzzzz_xxyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 989); 

                auto tg_zzzzzz_xxyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 990); 

                auto tg_zzzzzz_xxyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 991); 

                auto tg_zzzzzz_xxzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 992); 

                auto tg_zzzzzz_xyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 993); 

                auto tg_zzzzzz_xyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 994); 

                auto tg_zzzzzz_xyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 995); 

                auto tg_zzzzzz_xyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 996); 

                auto tg_zzzzzz_xyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 997); 

                auto tg_zzzzzz_xyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 998); 

                auto tg_zzzzzz_xzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 999); 

                auto tg_zzzzzz_yyyyyyy_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1000); 

                auto tg_zzzzzz_yyyyyyz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1001); 

                auto tg_zzzzzz_yyyyyzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1002); 

                auto tg_zzzzzz_yyyyzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1003); 

                auto tg_zzzzzz_yyyzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1004); 

                auto tg_zzzzzz_yyzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1005); 

                auto tg_zzzzzz_yzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1006); 

                auto tg_zzzzzz_zzzzzzz_1 = primBuffer[pidx_g_6_7_m1].data(1008 * idx + 1007); 

                auto tg_zzzzz_xxxxxxx_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_0 = primBuffer[pidx_g_5_7_m0].data(756 * idx + 755); 

                auto tg_zzzzz_xxxxxxx_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 720); 

                auto tg_zzzzz_xxxxxxy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 721); 

                auto tg_zzzzz_xxxxxxz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 722); 

                auto tg_zzzzz_xxxxxyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 723); 

                auto tg_zzzzz_xxxxxyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 724); 

                auto tg_zzzzz_xxxxxzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 725); 

                auto tg_zzzzz_xxxxyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 726); 

                auto tg_zzzzz_xxxxyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 727); 

                auto tg_zzzzz_xxxxyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 728); 

                auto tg_zzzzz_xxxxzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 729); 

                auto tg_zzzzz_xxxyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 730); 

                auto tg_zzzzz_xxxyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 731); 

                auto tg_zzzzz_xxxyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 732); 

                auto tg_zzzzz_xxxyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 733); 

                auto tg_zzzzz_xxxzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 734); 

                auto tg_zzzzz_xxyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 735); 

                auto tg_zzzzz_xxyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 736); 

                auto tg_zzzzz_xxyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 737); 

                auto tg_zzzzz_xxyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 738); 

                auto tg_zzzzz_xxyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 739); 

                auto tg_zzzzz_xxzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 740); 

                auto tg_zzzzz_xyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 741); 

                auto tg_zzzzz_xyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 742); 

                auto tg_zzzzz_xyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 743); 

                auto tg_zzzzz_xyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 744); 

                auto tg_zzzzz_xyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 745); 

                auto tg_zzzzz_xyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 746); 

                auto tg_zzzzz_xzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 747); 

                auto tg_zzzzz_yyyyyyy_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 748); 

                auto tg_zzzzz_yyyyyyz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 749); 

                auto tg_zzzzz_yyyyyzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 750); 

                auto tg_zzzzz_yyyyzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 751); 

                auto tg_zzzzz_yyyzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 752); 

                auto tg_zzzzz_yyzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 753); 

                auto tg_zzzzz_yzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 754); 

                auto tg_zzzzz_zzzzzzz_1 = primBuffer[pidx_g_5_7_m1].data(756 * idx + 755); 

                auto tg_yzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 743); 

                auto tg_yzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 775); 

                auto tg_zzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 782); 

                auto tg_zzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 783); 

                // set up pointers to integrals

                auto tg_yyzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1197); 

                auto tg_yyzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1198); 

                auto tg_yyzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1199); 

                auto tg_yyzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1200); 

                auto tg_yyzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1201); 

                auto tg_yyzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1202); 

                auto tg_yyzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1203); 

                auto tg_yyzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1204); 

                auto tg_yyzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1205); 

                auto tg_yyzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1206); 

                auto tg_yyzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1207); 

                auto tg_yyzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1208); 

                auto tg_yyzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1209); 

                auto tg_yyzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1210); 

                auto tg_yyzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1211); 

                auto tg_yyzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1212); 

                auto tg_yyzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1213); 

                auto tg_yyzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1214); 

                auto tg_yyzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1215); 

                auto tg_yyzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1216); 

                auto tg_yyzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1217); 

                auto tg_yyzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1218); 

                auto tg_yyzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1219); 

                auto tg_yyzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1220); 

                auto tg_yyzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1221); 

                auto tg_yyzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1222); 

                auto tg_yyzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1223); 

                auto tg_yzzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1224); 

                auto tg_yzzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1225); 

                auto tg_yzzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1226); 

                auto tg_yzzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1227); 

                auto tg_yzzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1228); 

                auto tg_yzzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1229); 

                auto tg_yzzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1230); 

                auto tg_yzzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1231); 

                auto tg_yzzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1232); 

                auto tg_yzzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1233); 

                auto tg_yzzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1234); 

                auto tg_yzzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1235); 

                auto tg_yzzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1236); 

                auto tg_yzzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1237); 

                auto tg_yzzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1238); 

                auto tg_yzzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1239); 

                auto tg_yzzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1240); 

                auto tg_yzzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1241); 

                auto tg_yzzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1242); 

                auto tg_yzzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1243); 

                auto tg_yzzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1244); 

                auto tg_yzzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1245); 

                auto tg_yzzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1246); 

                auto tg_yzzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1247); 

                auto tg_yzzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1248); 

                auto tg_yzzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1249); 

                auto tg_yzzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1250); 

                auto tg_yzzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1251); 

                auto tg_yzzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1252); 

                auto tg_yzzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1253); 

                auto tg_yzzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1254); 

                auto tg_yzzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1255); 

                auto tg_yzzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1256); 

                auto tg_yzzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1257); 

                auto tg_yzzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1258); 

                auto tg_yzzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1259); 

                auto tg_zzzzzzz_xxxxxxx_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1260); 

                auto tg_zzzzzzz_xxxxxxy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1261); 

                auto tg_zzzzzzz_xxxxxxz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1262); 

                auto tg_zzzzzzz_xxxxxyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1263); 

                auto tg_zzzzzzz_xxxxxyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1264); 

                auto tg_zzzzzzz_xxxxxzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1265); 

                auto tg_zzzzzzz_xxxxyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1266); 

                auto tg_zzzzzzz_xxxxyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1267); 

                auto tg_zzzzzzz_xxxxyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1268); 

                auto tg_zzzzzzz_xxxxzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1269); 

                auto tg_zzzzzzz_xxxyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1270); 

                auto tg_zzzzzzz_xxxyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1271); 

                auto tg_zzzzzzz_xxxyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1272); 

                auto tg_zzzzzzz_xxxyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1273); 

                auto tg_zzzzzzz_xxxzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1274); 

                auto tg_zzzzzzz_xxyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1275); 

                auto tg_zzzzzzz_xxyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1276); 

                auto tg_zzzzzzz_xxyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1277); 

                auto tg_zzzzzzz_xxyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1278); 

                auto tg_zzzzzzz_xxyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1279); 

                auto tg_zzzzzzz_xxzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1280); 

                auto tg_zzzzzzz_xyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1281); 

                auto tg_zzzzzzz_xyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1282); 

                auto tg_zzzzzzz_xyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1283); 

                auto tg_zzzzzzz_xyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1284); 

                auto tg_zzzzzzz_xyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1285); 

                auto tg_zzzzzzz_xyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1286); 

                auto tg_zzzzzzz_xzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1287); 

                auto tg_zzzzzzz_yyyyyyy_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1288); 

                auto tg_zzzzzzz_yyyyyyz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1289); 

                auto tg_zzzzzzz_yyyyyzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1290); 

                auto tg_zzzzzzz_yyyyzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1291); 

                auto tg_zzzzzzz_yyyzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1292); 

                auto tg_zzzzzzz_yyzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1293); 

                auto tg_zzzzzzz_yzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1294); 

                auto tg_zzzzzzz_zzzzzzz_0 = primBuffer[pidx_g_7_7_m0].data(1296 * idx + 1295); 

                // Batch of Integrals (1197,1296)

                #pragma omp simd aligned(fxn, fza, tg_yyzzzzz_xxxxzzz_0, tg_yyzzzzz_xxxyyyy_0, \
                                         tg_yyzzzzz_xxxyyyz_0, tg_yyzzzzz_xxxyyzz_0, tg_yyzzzzz_xxxyzzz_0, tg_yyzzzzz_xxxzzzz_0, \
                                         tg_yyzzzzz_xxyyyyy_0, tg_yyzzzzz_xxyyyyz_0, tg_yyzzzzz_xxyyyzz_0, tg_yyzzzzz_xxyyzzz_0, \
                                         tg_yyzzzzz_xxyzzzz_0, tg_yyzzzzz_xxzzzzz_0, tg_yyzzzzz_xyyyyyy_0, tg_yyzzzzz_xyyyyyz_0, \
                                         tg_yyzzzzz_xyyyyzz_0, tg_yyzzzzz_xyyyzzz_0, tg_yyzzzzz_xyyzzzz_0, tg_yyzzzzz_xyzzzzz_0, \
                                         tg_yyzzzzz_xzzzzzz_0, tg_yyzzzzz_yyyyyyy_0, tg_yyzzzzz_yyyyyyz_0, tg_yyzzzzz_yyyyyzz_0, \
                                         tg_yyzzzzz_yyyyzzz_0, tg_yyzzzzz_yyyzzzz_0, tg_yyzzzzz_yyzzzzz_0, tg_yyzzzzz_yzzzzzz_0, \
                                         tg_yyzzzzz_zzzzzzz_0, tg_yzzzzz_xxxxzzz_0, tg_yzzzzz_xxxxzzz_1, tg_yzzzzz_xxxyyy_1, \
                                         tg_yzzzzz_xxxyyyy_0, tg_yzzzzz_xxxyyyy_1, tg_yzzzzz_xxxyyyz_0, tg_yzzzzz_xxxyyyz_1, \
                                         tg_yzzzzz_xxxyyz_1, tg_yzzzzz_xxxyyzz_0, tg_yzzzzz_xxxyyzz_1, tg_yzzzzz_xxxyzz_1, \
                                         tg_yzzzzz_xxxyzzz_0, tg_yzzzzz_xxxyzzz_1, tg_yzzzzz_xxxzzz_1, tg_yzzzzz_xxxzzzz_0, \
                                         tg_yzzzzz_xxxzzzz_1, tg_yzzzzz_xxyyyy_1, tg_yzzzzz_xxyyyyy_0, tg_yzzzzz_xxyyyyy_1, \
                                         tg_yzzzzz_xxyyyyz_0, tg_yzzzzz_xxyyyyz_1, tg_yzzzzz_xxyyyz_1, tg_yzzzzz_xxyyyzz_0, \
                                         tg_yzzzzz_xxyyyzz_1, tg_yzzzzz_xxyyzz_1, tg_yzzzzz_xxyyzzz_0, tg_yzzzzz_xxyyzzz_1, \
                                         tg_yzzzzz_xxyzzz_1, tg_yzzzzz_xxyzzzz_0, tg_yzzzzz_xxyzzzz_1, tg_yzzzzz_xxzzzz_1, \
                                         tg_yzzzzz_xxzzzzz_0, tg_yzzzzz_xxzzzzz_1, tg_yzzzzz_xyyyyy_1, tg_yzzzzz_xyyyyyy_0, \
                                         tg_yzzzzz_xyyyyyy_1, tg_yzzzzz_xyyyyyz_0, tg_yzzzzz_xyyyyyz_1, tg_yzzzzz_xyyyyz_1, \
                                         tg_yzzzzz_xyyyyzz_0, tg_yzzzzz_xyyyyzz_1, tg_yzzzzz_xyyyzz_1, tg_yzzzzz_xyyyzzz_0, \
                                         tg_yzzzzz_xyyyzzz_1, tg_yzzzzz_xyyzzz_1, tg_yzzzzz_xyyzzzz_0, tg_yzzzzz_xyyzzzz_1, \
                                         tg_yzzzzz_xyzzzz_1, tg_yzzzzz_xyzzzzz_0, tg_yzzzzz_xyzzzzz_1, tg_yzzzzz_xzzzzz_1, \
                                         tg_yzzzzz_xzzzzzz_0, tg_yzzzzz_xzzzzzz_1, tg_yzzzzz_yyyyyy_1, tg_yzzzzz_yyyyyyy_0, \
                                         tg_yzzzzz_yyyyyyy_1, tg_yzzzzz_yyyyyyz_0, tg_yzzzzz_yyyyyyz_1, tg_yzzzzz_yyyyyz_1, \
                                         tg_yzzzzz_yyyyyzz_0, tg_yzzzzz_yyyyyzz_1, tg_yzzzzz_yyyyzz_1, tg_yzzzzz_yyyyzzz_0, \
                                         tg_yzzzzz_yyyyzzz_1, tg_yzzzzz_yyyzzz_1, tg_yzzzzz_yyyzzzz_0, tg_yzzzzz_yyyzzzz_1, \
                                         tg_yzzzzz_yyzzzz_1, tg_yzzzzz_yyzzzzz_0, tg_yzzzzz_yyzzzzz_1, tg_yzzzzz_yzzzzz_1, \
                                         tg_yzzzzz_yzzzzzz_0, tg_yzzzzz_yzzzzzz_1, tg_yzzzzz_zzzzzz_1, tg_yzzzzz_zzzzzzz_0, \
                                         tg_yzzzzz_zzzzzzz_1, tg_yzzzzzz_xxxxxxx_0, tg_yzzzzzz_xxxxxxy_0, tg_yzzzzzz_xxxxxxz_0, \
                                         tg_yzzzzzz_xxxxxyy_0, tg_yzzzzzz_xxxxxyz_0, tg_yzzzzzz_xxxxxzz_0, tg_yzzzzzz_xxxxyyy_0, \
                                         tg_yzzzzzz_xxxxyyz_0, tg_yzzzzzz_xxxxyzz_0, tg_yzzzzzz_xxxxzzz_0, tg_yzzzzzz_xxxyyyy_0, \
                                         tg_yzzzzzz_xxxyyyz_0, tg_yzzzzzz_xxxyyzz_0, tg_yzzzzzz_xxxyzzz_0, tg_yzzzzzz_xxxzzzz_0, \
                                         tg_yzzzzzz_xxyyyyy_0, tg_yzzzzzz_xxyyyyz_0, tg_yzzzzzz_xxyyyzz_0, tg_yzzzzzz_xxyyzzz_0, \
                                         tg_yzzzzzz_xxyzzzz_0, tg_yzzzzzz_xxzzzzz_0, tg_yzzzzzz_xyyyyyy_0, tg_yzzzzzz_xyyyyyz_0, \
                                         tg_yzzzzzz_xyyyyzz_0, tg_yzzzzzz_xyyyzzz_0, tg_yzzzzzz_xyyzzzz_0, tg_yzzzzzz_xyzzzzz_0, \
                                         tg_yzzzzzz_xzzzzzz_0, tg_yzzzzzz_yyyyyyy_0, tg_yzzzzzz_yyyyyyz_0, tg_yzzzzzz_yyyyyzz_0, \
                                         tg_yzzzzzz_yyyyzzz_0, tg_yzzzzzz_yyyzzzz_0, tg_yzzzzzz_yyzzzzz_0, tg_yzzzzzz_yzzzzzz_0, \
                                         tg_yzzzzzz_zzzzzzz_0, tg_zzzzz_xxxxxxx_0, tg_zzzzz_xxxxxxx_1, tg_zzzzz_xxxxxxy_0, \
                                         tg_zzzzz_xxxxxxy_1, tg_zzzzz_xxxxxxz_0, tg_zzzzz_xxxxxxz_1, tg_zzzzz_xxxxxyy_0, \
                                         tg_zzzzz_xxxxxyy_1, tg_zzzzz_xxxxxyz_0, tg_zzzzz_xxxxxyz_1, tg_zzzzz_xxxxxzz_0, \
                                         tg_zzzzz_xxxxxzz_1, tg_zzzzz_xxxxyyy_0, tg_zzzzz_xxxxyyy_1, tg_zzzzz_xxxxyyz_0, \
                                         tg_zzzzz_xxxxyyz_1, tg_zzzzz_xxxxyzz_0, tg_zzzzz_xxxxyzz_1, tg_zzzzz_xxxxzzz_0, \
                                         tg_zzzzz_xxxxzzz_1, tg_zzzzz_xxxyyyy_0, tg_zzzzz_xxxyyyy_1, tg_zzzzz_xxxyyyz_0, \
                                         tg_zzzzz_xxxyyyz_1, tg_zzzzz_xxxyyzz_0, tg_zzzzz_xxxyyzz_1, tg_zzzzz_xxxyzzz_0, \
                                         tg_zzzzz_xxxyzzz_1, tg_zzzzz_xxxzzzz_0, tg_zzzzz_xxxzzzz_1, tg_zzzzz_xxyyyyy_0, \
                                         tg_zzzzz_xxyyyyy_1, tg_zzzzz_xxyyyyz_0, tg_zzzzz_xxyyyyz_1, tg_zzzzz_xxyyyzz_0, \
                                         tg_zzzzz_xxyyyzz_1, tg_zzzzz_xxyyzzz_0, tg_zzzzz_xxyyzzz_1, tg_zzzzz_xxyzzzz_0, \
                                         tg_zzzzz_xxyzzzz_1, tg_zzzzz_xxzzzzz_0, tg_zzzzz_xxzzzzz_1, tg_zzzzz_xyyyyyy_0, \
                                         tg_zzzzz_xyyyyyy_1, tg_zzzzz_xyyyyyz_0, tg_zzzzz_xyyyyyz_1, tg_zzzzz_xyyyyzz_0, \
                                         tg_zzzzz_xyyyyzz_1, tg_zzzzz_xyyyzzz_0, tg_zzzzz_xyyyzzz_1, tg_zzzzz_xyyzzzz_0, \
                                         tg_zzzzz_xyyzzzz_1, tg_zzzzz_xyzzzzz_0, tg_zzzzz_xyzzzzz_1, tg_zzzzz_xzzzzzz_0, \
                                         tg_zzzzz_xzzzzzz_1, tg_zzzzz_yyyyyyy_0, tg_zzzzz_yyyyyyy_1, tg_zzzzz_yyyyyyz_0, \
                                         tg_zzzzz_yyyyyyz_1, tg_zzzzz_yyyyyzz_0, tg_zzzzz_yyyyyzz_1, tg_zzzzz_yyyyzzz_0, \
                                         tg_zzzzz_yyyyzzz_1, tg_zzzzz_yyyzzzz_0, tg_zzzzz_yyyzzzz_1, tg_zzzzz_yyzzzzz_0, \
                                         tg_zzzzz_yyzzzzz_1, tg_zzzzz_yzzzzzz_0, tg_zzzzz_yzzzzzz_1, tg_zzzzz_zzzzzzz_0, \
                                         tg_zzzzz_zzzzzzz_1, tg_zzzzzz_xxxxxx_1, tg_zzzzzz_xxxxxxx_0, tg_zzzzzz_xxxxxxx_1, \
                                         tg_zzzzzz_xxxxxxy_0, tg_zzzzzz_xxxxxxy_1, tg_zzzzzz_xxxxxxz_0, tg_zzzzzz_xxxxxxz_1, \
                                         tg_zzzzzz_xxxxxy_1, tg_zzzzzz_xxxxxyy_0, tg_zzzzzz_xxxxxyy_1, tg_zzzzzz_xxxxxyz_0, \
                                         tg_zzzzzz_xxxxxyz_1, tg_zzzzzz_xxxxxz_1, tg_zzzzzz_xxxxxzz_0, tg_zzzzzz_xxxxxzz_1, \
                                         tg_zzzzzz_xxxxyy_1, tg_zzzzzz_xxxxyyy_0, tg_zzzzzz_xxxxyyy_1, tg_zzzzzz_xxxxyyz_0, \
                                         tg_zzzzzz_xxxxyyz_1, tg_zzzzzz_xxxxyz_1, tg_zzzzzz_xxxxyzz_0, tg_zzzzzz_xxxxyzz_1, \
                                         tg_zzzzzz_xxxxzz_1, tg_zzzzzz_xxxxzzz_0, tg_zzzzzz_xxxxzzz_1, tg_zzzzzz_xxxyyy_1, \
                                         tg_zzzzzz_xxxyyyy_0, tg_zzzzzz_xxxyyyy_1, tg_zzzzzz_xxxyyyz_0, tg_zzzzzz_xxxyyyz_1, \
                                         tg_zzzzzz_xxxyyz_1, tg_zzzzzz_xxxyyzz_0, tg_zzzzzz_xxxyyzz_1, tg_zzzzzz_xxxyzz_1, \
                                         tg_zzzzzz_xxxyzzz_0, tg_zzzzzz_xxxyzzz_1, tg_zzzzzz_xxxzzz_1, tg_zzzzzz_xxxzzzz_0, \
                                         tg_zzzzzz_xxxzzzz_1, tg_zzzzzz_xxyyyy_1, tg_zzzzzz_xxyyyyy_0, tg_zzzzzz_xxyyyyy_1, \
                                         tg_zzzzzz_xxyyyyz_0, tg_zzzzzz_xxyyyyz_1, tg_zzzzzz_xxyyyz_1, tg_zzzzzz_xxyyyzz_0, \
                                         tg_zzzzzz_xxyyyzz_1, tg_zzzzzz_xxyyzz_1, tg_zzzzzz_xxyyzzz_0, tg_zzzzzz_xxyyzzz_1, \
                                         tg_zzzzzz_xxyzzz_1, tg_zzzzzz_xxyzzzz_0, tg_zzzzzz_xxyzzzz_1, tg_zzzzzz_xxzzzz_1, \
                                         tg_zzzzzz_xxzzzzz_0, tg_zzzzzz_xxzzzzz_1, tg_zzzzzz_xyyyyy_1, tg_zzzzzz_xyyyyyy_0, \
                                         tg_zzzzzz_xyyyyyy_1, tg_zzzzzz_xyyyyyz_0, tg_zzzzzz_xyyyyyz_1, tg_zzzzzz_xyyyyz_1, \
                                         tg_zzzzzz_xyyyyzz_0, tg_zzzzzz_xyyyyzz_1, tg_zzzzzz_xyyyzz_1, tg_zzzzzz_xyyyzzz_0, \
                                         tg_zzzzzz_xyyyzzz_1, tg_zzzzzz_xyyzzz_1, tg_zzzzzz_xyyzzzz_0, tg_zzzzzz_xyyzzzz_1, \
                                         tg_zzzzzz_xyzzzz_1, tg_zzzzzz_xyzzzzz_0, tg_zzzzzz_xyzzzzz_1, tg_zzzzzz_xzzzzz_1, \
                                         tg_zzzzzz_xzzzzzz_0, tg_zzzzzz_xzzzzzz_1, tg_zzzzzz_yyyyyy_1, tg_zzzzzz_yyyyyyy_0, \
                                         tg_zzzzzz_yyyyyyy_1, tg_zzzzzz_yyyyyyz_0, tg_zzzzzz_yyyyyyz_1, tg_zzzzzz_yyyyyz_1, \
                                         tg_zzzzzz_yyyyyzz_0, tg_zzzzzz_yyyyyzz_1, tg_zzzzzz_yyyyzz_1, tg_zzzzzz_yyyyzzz_0, \
                                         tg_zzzzzz_yyyyzzz_1, tg_zzzzzz_yyyzzz_1, tg_zzzzzz_yyyzzzz_0, tg_zzzzzz_yyyzzzz_1, \
                                         tg_zzzzzz_yyzzzz_1, tg_zzzzzz_yyzzzzz_0, tg_zzzzzz_yyzzzzz_1, tg_zzzzzz_yzzzzz_1, \
                                         tg_zzzzzz_yzzzzzz_0, tg_zzzzzz_yzzzzzz_1, tg_zzzzzz_zzzzzz_1, tg_zzzzzz_zzzzzzz_0, \
                                         tg_zzzzzz_zzzzzzz_1, tg_zzzzzzz_xxxxxxx_0, tg_zzzzzzz_xxxxxxy_0, tg_zzzzzzz_xxxxxxz_0, \
                                         tg_zzzzzzz_xxxxxyy_0, tg_zzzzzzz_xxxxxyz_0, tg_zzzzzzz_xxxxxzz_0, tg_zzzzzzz_xxxxyyy_0, \
                                         tg_zzzzzzz_xxxxyyz_0, tg_zzzzzzz_xxxxyzz_0, tg_zzzzzzz_xxxxzzz_0, tg_zzzzzzz_xxxyyyy_0, \
                                         tg_zzzzzzz_xxxyyyz_0, tg_zzzzzzz_xxxyyzz_0, tg_zzzzzzz_xxxyzzz_0, tg_zzzzzzz_xxxzzzz_0, \
                                         tg_zzzzzzz_xxyyyyy_0, tg_zzzzzzz_xxyyyyz_0, tg_zzzzzzz_xxyyyzz_0, tg_zzzzzzz_xxyyzzz_0, \
                                         tg_zzzzzzz_xxyzzzz_0, tg_zzzzzzz_xxzzzzz_0, tg_zzzzzzz_xyyyyyy_0, tg_zzzzzzz_xyyyyyz_0, \
                                         tg_zzzzzzz_xyyyyzz_0, tg_zzzzzzz_xyyyzzz_0, tg_zzzzzzz_xyyzzzz_0, tg_zzzzzzz_xyzzzzz_0, \
                                         tg_zzzzzzz_xzzzzzz_0, tg_zzzzzzz_yyyyyyy_0, tg_zzzzzzz_yyyyyyz_0, tg_zzzzzzz_yyyyyzz_0, \
                                         tg_zzzzzzz_yyyyzzz_0, tg_zzzzzzz_yyyzzzz_0, tg_zzzzzzz_yyzzzzz_0, tg_zzzzzzz_yzzzzzz_0, \
                                         tg_zzzzzzz_zzzzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyzzzzz_xxxxzzz_0[j] = pb_y * tg_yzzzzz_xxxxzzz_0[j] + fr * tg_yzzzzz_xxxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxxzzz_0[j] - tg_zzzzz_xxxxzzz_1[j] * fl1_fza);

                    tg_yyzzzzz_xxxyyyy_0[j] = pb_y * tg_yzzzzz_xxxyyyy_0[j] + fr * tg_yzzzzz_xxxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyyy_0[j] - tg_zzzzz_xxxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzz_xxxyyy_1[j];

                    tg_yyzzzzz_xxxyyyz_0[j] = pb_y * tg_yzzzzz_xxxyyyz_0[j] + fr * tg_yzzzzz_xxxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyyz_0[j] - tg_zzzzz_xxxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzz_xxxyyz_1[j];

                    tg_yyzzzzz_xxxyyzz_0[j] = pb_y * tg_yzzzzz_xxxyyzz_0[j] + fr * tg_yzzzzz_xxxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyyzz_0[j] - tg_zzzzz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_xxxyzz_1[j];

                    tg_yyzzzzz_xxxyzzz_0[j] = pb_y * tg_yzzzzz_xxxyzzz_0[j] + fr * tg_yzzzzz_xxxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxyzzz_0[j] - tg_zzzzz_xxxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xxxzzz_1[j];

                    tg_yyzzzzz_xxxzzzz_0[j] = pb_y * tg_yzzzzz_xxxzzzz_0[j] + fr * tg_yzzzzz_xxxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxxzzzz_0[j] - tg_zzzzz_xxxzzzz_1[j] * fl1_fza);

                    tg_yyzzzzz_xxyyyyy_0[j] = pb_y * tg_yzzzzz_xxyyyyy_0[j] + fr * tg_yzzzzz_xxyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyyy_0[j] - tg_zzzzz_xxyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzzz_xxyyyy_1[j];

                    tg_yyzzzzz_xxyyyyz_0[j] = pb_y * tg_yzzzzz_xxyyyyz_0[j] + fr * tg_yzzzzz_xxyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyyz_0[j] - tg_zzzzz_xxyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzz_xxyyyz_1[j];

                    tg_yyzzzzz_xxyyyzz_0[j] = pb_y * tg_yzzzzz_xxyyyzz_0[j] + fr * tg_yzzzzz_xxyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyyzz_0[j] - tg_zzzzz_xxyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzz_xxyyzz_1[j];

                    tg_yyzzzzz_xxyyzzz_0[j] = pb_y * tg_yzzzzz_xxyyzzz_0[j] + fr * tg_yzzzzz_xxyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyyzzz_0[j] - tg_zzzzz_xxyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_xxyzzz_1[j];

                    tg_yyzzzzz_xxyzzzz_0[j] = pb_y * tg_yzzzzz_xxyzzzz_0[j] + fr * tg_yzzzzz_xxyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxyzzzz_0[j] - tg_zzzzz_xxyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xxzzzz_1[j];

                    tg_yyzzzzz_xxzzzzz_0[j] = pb_y * tg_yzzzzz_xxzzzzz_0[j] + fr * tg_yzzzzz_xxzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xxzzzzz_0[j] - tg_zzzzz_xxzzzzz_1[j] * fl1_fza);

                    tg_yyzzzzz_xyyyyyy_0[j] = pb_y * tg_yzzzzz_xyyyyyy_0[j] + fr * tg_yzzzzz_xyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyyy_0[j] - tg_zzzzz_xyyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzzz_xyyyyy_1[j];

                    tg_yyzzzzz_xyyyyyz_0[j] = pb_y * tg_yzzzzz_xyyyyyz_0[j] + fr * tg_yzzzzz_xyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyyz_0[j] - tg_zzzzz_xyyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzzz_xyyyyz_1[j];

                    tg_yyzzzzz_xyyyyzz_0[j] = pb_y * tg_yzzzzz_xyyyyzz_0[j] + fr * tg_yzzzzz_xyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyyzz_0[j] - tg_zzzzz_xyyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzz_xyyyzz_1[j];

                    tg_yyzzzzz_xyyyzzz_0[j] = pb_y * tg_yzzzzz_xyyyzzz_0[j] + fr * tg_yzzzzz_xyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyyzzz_0[j] - tg_zzzzz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzz_xyyzzz_1[j];

                    tg_yyzzzzz_xyyzzzz_0[j] = pb_y * tg_yzzzzz_xyyzzzz_0[j] + fr * tg_yzzzzz_xyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyyzzzz_0[j] - tg_zzzzz_xyyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_xyzzzz_1[j];

                    tg_yyzzzzz_xyzzzzz_0[j] = pb_y * tg_yzzzzz_xyzzzzz_0[j] + fr * tg_yzzzzz_xyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xyzzzzz_0[j] - tg_zzzzz_xyzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_xzzzzz_1[j];

                    tg_yyzzzzz_xzzzzzz_0[j] = pb_y * tg_yzzzzz_xzzzzzz_0[j] + fr * tg_yzzzzz_xzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_xzzzzzz_0[j] - tg_zzzzz_xzzzzzz_1[j] * fl1_fza);

                    tg_yyzzzzz_yyyyyyy_0[j] = pb_y * tg_yzzzzz_yyyyyyy_0[j] + fr * tg_yzzzzz_yyyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyyy_0[j] - tg_zzzzz_yyyyyyy_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_yzzzzz_yyyyyy_1[j];

                    tg_yyzzzzz_yyyyyyz_0[j] = pb_y * tg_yzzzzz_yyyyyyz_0[j] + fr * tg_yzzzzz_yyyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyyz_0[j] - tg_zzzzz_yyyyyyz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzzz_yyyyyz_1[j];

                    tg_yyzzzzz_yyyyyzz_0[j] = pb_y * tg_yzzzzz_yyyyyzz_0[j] + fr * tg_yzzzzz_yyyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyyzz_0[j] - tg_zzzzz_yyyyyzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzzz_yyyyzz_1[j];

                    tg_yyzzzzz_yyyyzzz_0[j] = pb_y * tg_yzzzzz_yyyyzzz_0[j] + fr * tg_yzzzzz_yyyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyyzzz_0[j] - tg_zzzzz_yyyyzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzz_yyyzzz_1[j];

                    tg_yyzzzzz_yyyzzzz_0[j] = pb_y * tg_yzzzzz_yyyzzzz_0[j] + fr * tg_yzzzzz_yyyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyyzzzz_0[j] - tg_zzzzz_yyyzzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzz_yyzzzz_1[j];

                    tg_yyzzzzz_yyzzzzz_0[j] = pb_y * tg_yzzzzz_yyzzzzz_0[j] + fr * tg_yzzzzz_yyzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yyzzzzz_0[j] - tg_zzzzz_yyzzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzz_yzzzzz_1[j];

                    tg_yyzzzzz_yzzzzzz_0[j] = pb_y * tg_yzzzzz_yzzzzzz_0[j] + fr * tg_yzzzzz_yzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_yzzzzzz_0[j] - tg_zzzzz_yzzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzz_zzzzzz_1[j];

                    tg_yyzzzzz_zzzzzzz_0[j] = pb_y * tg_yzzzzz_zzzzzzz_0[j] + fr * tg_yzzzzz_zzzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzz_zzzzzzz_0[j] - tg_zzzzz_zzzzzzz_1[j] * fl1_fza);

                    tg_yzzzzzz_xxxxxxx_0[j] = pb_y * tg_zzzzzz_xxxxxxx_0[j] + fr * tg_zzzzzz_xxxxxxx_1[j];

                    tg_yzzzzzz_xxxxxxy_0[j] = pb_y * tg_zzzzzz_xxxxxxy_0[j] + fr * tg_zzzzzz_xxxxxxy_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xxxxxx_1[j];

                    tg_yzzzzzz_xxxxxxz_0[j] = pb_y * tg_zzzzzz_xxxxxxz_0[j] + fr * tg_zzzzzz_xxxxxxz_1[j];

                    tg_yzzzzzz_xxxxxyy_0[j] = pb_y * tg_zzzzzz_xxxxxyy_0[j] + fr * tg_zzzzzz_xxxxxyy_1[j] + fl1_fxn * tg_zzzzzz_xxxxxy_1[j];

                    tg_yzzzzzz_xxxxxyz_0[j] = pb_y * tg_zzzzzz_xxxxxyz_0[j] + fr * tg_zzzzzz_xxxxxyz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xxxxxz_1[j];

                    tg_yzzzzzz_xxxxxzz_0[j] = pb_y * tg_zzzzzz_xxxxxzz_0[j] + fr * tg_zzzzzz_xxxxxzz_1[j];

                    tg_yzzzzzz_xxxxyyy_0[j] = pb_y * tg_zzzzzz_xxxxyyy_0[j] + fr * tg_zzzzzz_xxxxyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxxxyy_1[j];

                    tg_yzzzzzz_xxxxyyz_0[j] = pb_y * tg_zzzzzz_xxxxyyz_0[j] + fr * tg_zzzzzz_xxxxyyz_1[j] + fl1_fxn * tg_zzzzzz_xxxxyz_1[j];

                    tg_yzzzzzz_xxxxyzz_0[j] = pb_y * tg_zzzzzz_xxxxyzz_0[j] + fr * tg_zzzzzz_xxxxyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xxxxzz_1[j];

                    tg_yzzzzzz_xxxxzzz_0[j] = pb_y * tg_zzzzzz_xxxxzzz_0[j] + fr * tg_zzzzzz_xxxxzzz_1[j];

                    tg_yzzzzzz_xxxyyyy_0[j] = pb_y * tg_zzzzzz_xxxyyyy_0[j] + fr * tg_zzzzzz_xxxyyyy_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxxyyy_1[j];

                    tg_yzzzzzz_xxxyyyz_0[j] = pb_y * tg_zzzzzz_xxxyyyz_0[j] + fr * tg_zzzzzz_xxxyyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxxyyz_1[j];

                    tg_yzzzzzz_xxxyyzz_0[j] = pb_y * tg_zzzzzz_xxxyyzz_0[j] + fr * tg_zzzzzz_xxxyyzz_1[j] + fl1_fxn * tg_zzzzzz_xxxyzz_1[j];

                    tg_yzzzzzz_xxxyzzz_0[j] = pb_y * tg_zzzzzz_xxxyzzz_0[j] + fr * tg_zzzzzz_xxxyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xxxzzz_1[j];

                    tg_yzzzzzz_xxxzzzz_0[j] = pb_y * tg_zzzzzz_xxxzzzz_0[j] + fr * tg_zzzzzz_xxxzzzz_1[j];

                    tg_yzzzzzz_xxyyyyy_0[j] = pb_y * tg_zzzzzz_xxyyyyy_0[j] + fr * tg_zzzzzz_xxyyyyy_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_xxyyyy_1[j];

                    tg_yzzzzzz_xxyyyyz_0[j] = pb_y * tg_zzzzzz_xxyyyyz_0[j] + fr * tg_zzzzzz_xxyyyyz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xxyyyz_1[j];

                    tg_yzzzzzz_xxyyyzz_0[j] = pb_y * tg_zzzzzz_xxyyyzz_0[j] + fr * tg_zzzzzz_xxyyyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xxyyzz_1[j];

                    tg_yzzzzzz_xxyyzzz_0[j] = pb_y * tg_zzzzzz_xxyyzzz_0[j] + fr * tg_zzzzzz_xxyyzzz_1[j] + fl1_fxn * tg_zzzzzz_xxyzzz_1[j];

                    tg_yzzzzzz_xxyzzzz_0[j] = pb_y * tg_zzzzzz_xxyzzzz_0[j] + fr * tg_zzzzzz_xxyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xxzzzz_1[j];

                    tg_yzzzzzz_xxzzzzz_0[j] = pb_y * tg_zzzzzz_xxzzzzz_0[j] + fr * tg_zzzzzz_xxzzzzz_1[j];

                    tg_yzzzzzz_xyyyyyy_0[j] = pb_y * tg_zzzzzz_xyyyyyy_0[j] + fr * tg_zzzzzz_xyyyyyy_1[j] + 3.0 * fl1_fxn * tg_zzzzzz_xyyyyy_1[j];

                    tg_yzzzzzz_xyyyyyz_0[j] = pb_y * tg_zzzzzz_xyyyyyz_0[j] + fr * tg_zzzzzz_xyyyyyz_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_xyyyyz_1[j];

                    tg_yzzzzzz_xyyyyzz_0[j] = pb_y * tg_zzzzzz_xyyyyzz_0[j] + fr * tg_zzzzzz_xyyyyzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_xyyyzz_1[j];

                    tg_yzzzzzz_xyyyzzz_0[j] = pb_y * tg_zzzzzz_xyyyzzz_0[j] + fr * tg_zzzzzz_xyyyzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_xyyzzz_1[j];

                    tg_yzzzzzz_xyyzzzz_0[j] = pb_y * tg_zzzzzz_xyyzzzz_0[j] + fr * tg_zzzzzz_xyyzzzz_1[j] + fl1_fxn * tg_zzzzzz_xyzzzz_1[j];

                    tg_yzzzzzz_xyzzzzz_0[j] = pb_y * tg_zzzzzz_xyzzzzz_0[j] + fr * tg_zzzzzz_xyzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_xzzzzz_1[j];

                    tg_yzzzzzz_xzzzzzz_0[j] = pb_y * tg_zzzzzz_xzzzzzz_0[j] + fr * tg_zzzzzz_xzzzzzz_1[j];

                    tg_yzzzzzz_yyyyyyy_0[j] = pb_y * tg_zzzzzz_yyyyyyy_0[j] + fr * tg_zzzzzz_yyyyyyy_1[j] + 3.5 * fl1_fxn * tg_zzzzzz_yyyyyy_1[j];

                    tg_yzzzzzz_yyyyyyz_0[j] = pb_y * tg_zzzzzz_yyyyyyz_0[j] + fr * tg_zzzzzz_yyyyyyz_1[j] + 3.0 * fl1_fxn * tg_zzzzzz_yyyyyz_1[j];

                    tg_yzzzzzz_yyyyyzz_0[j] = pb_y * tg_zzzzzz_yyyyyzz_0[j] + fr * tg_zzzzzz_yyyyyzz_1[j] + 2.5 * fl1_fxn * tg_zzzzzz_yyyyzz_1[j];

                    tg_yzzzzzz_yyyyzzz_0[j] = pb_y * tg_zzzzzz_yyyyzzz_0[j] + fr * tg_zzzzzz_yyyyzzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzz_yyyzzz_1[j];

                    tg_yzzzzzz_yyyzzzz_0[j] = pb_y * tg_zzzzzz_yyyzzzz_0[j] + fr * tg_zzzzzz_yyyzzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzz_yyzzzz_1[j];

                    tg_yzzzzzz_yyzzzzz_0[j] = pb_y * tg_zzzzzz_yyzzzzz_0[j] + fr * tg_zzzzzz_yyzzzzz_1[j] + fl1_fxn * tg_zzzzzz_yzzzzz_1[j];

                    tg_yzzzzzz_yzzzzzz_0[j] = pb_y * tg_zzzzzz_yzzzzzz_0[j] + fr * tg_zzzzzz_yzzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzz_zzzzzz_1[j];

                    tg_yzzzzzz_zzzzzzz_0[j] = pb_y * tg_zzzzzz_zzzzzzz_0[j] + fr * tg_zzzzzz_zzzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzzz_xxxxxxx_0[j] = pb_z * tg_zzzzzz_xxxxxxx_0[j] + fr * tg_zzzzzz_xxxxxxx_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxxx_0[j] - tg_zzzzz_xxxxxxx_1[j] * fl1_fza);

                    tg_zzzzzzz_xxxxxxy_0[j] = pb_z * tg_zzzzzz_xxxxxxy_0[j] + fr * tg_zzzzzz_xxxxxxy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxxy_0[j] - tg_zzzzz_xxxxxxy_1[j] * fl1_fza);

                    tg_zzzzzzz_xxxxxxz_0[j] = pb_z * tg_zzzzzz_xxxxxxz_0[j] + fr * tg_zzzzzz_xxxxxxz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxxz_0[j] - tg_zzzzz_xxxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xxxxxx_1[j];

                    tg_zzzzzzz_xxxxxyy_0[j] = pb_z * tg_zzzzzz_xxxxxyy_0[j] + fr * tg_zzzzzz_xxxxxyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxyy_0[j] - tg_zzzzz_xxxxxyy_1[j] * fl1_fza);

                    tg_zzzzzzz_xxxxxyz_0[j] = pb_z * tg_zzzzzz_xxxxxyz_0[j] + fr * tg_zzzzzz_xxxxxyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxyz_0[j] - tg_zzzzz_xxxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xxxxxy_1[j];

                    tg_zzzzzzz_xxxxxzz_0[j] = pb_z * tg_zzzzzz_xxxxxzz_0[j] + fr * tg_zzzzzz_xxxxxzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxxzz_0[j] - tg_zzzzz_xxxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_xxxxxz_1[j];

                    tg_zzzzzzz_xxxxyyy_0[j] = pb_z * tg_zzzzzz_xxxxyyy_0[j] + fr * tg_zzzzzz_xxxxyyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxyyy_0[j] - tg_zzzzz_xxxxyyy_1[j] * fl1_fza);

                    tg_zzzzzzz_xxxxyyz_0[j] = pb_z * tg_zzzzzz_xxxxyyz_0[j] + fr * tg_zzzzzz_xxxxyyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxyyz_0[j] - tg_zzzzz_xxxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xxxxyy_1[j];

                    tg_zzzzzzz_xxxxyzz_0[j] = pb_z * tg_zzzzzz_xxxxyzz_0[j] + fr * tg_zzzzzz_xxxxyzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxyzz_0[j] - tg_zzzzz_xxxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_xxxxyz_1[j];

                    tg_zzzzzzz_xxxxzzz_0[j] = pb_z * tg_zzzzzz_xxxxzzz_0[j] + fr * tg_zzzzzz_xxxxzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxxzzz_0[j] - tg_zzzzz_xxxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzz_xxxxzz_1[j];

                    tg_zzzzzzz_xxxyyyy_0[j] = pb_z * tg_zzzzzz_xxxyyyy_0[j] + fr * tg_zzzzzz_xxxyyyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxyyyy_0[j] - tg_zzzzz_xxxyyyy_1[j] * fl1_fza);

                    tg_zzzzzzz_xxxyyyz_0[j] = pb_z * tg_zzzzzz_xxxyyyz_0[j] + fr * tg_zzzzzz_xxxyyyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxyyyz_0[j] - tg_zzzzz_xxxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xxxyyy_1[j];

                    tg_zzzzzzz_xxxyyzz_0[j] = pb_z * tg_zzzzzz_xxxyyzz_0[j] + fr * tg_zzzzzz_xxxyyzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxyyzz_0[j] - tg_zzzzz_xxxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_xxxyyz_1[j];

                    tg_zzzzzzz_xxxyzzz_0[j] = pb_z * tg_zzzzzz_xxxyzzz_0[j] + fr * tg_zzzzzz_xxxyzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxyzzz_0[j] - tg_zzzzz_xxxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzz_xxxyzz_1[j];

                    tg_zzzzzzz_xxxzzzz_0[j] = pb_z * tg_zzzzzz_xxxzzzz_0[j] + fr * tg_zzzzzz_xxxzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxxzzzz_0[j] - tg_zzzzz_xxxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzz_xxxzzz_1[j];

                    tg_zzzzzzz_xxyyyyy_0[j] = pb_z * tg_zzzzzz_xxyyyyy_0[j] + fr * tg_zzzzzz_xxyyyyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxyyyyy_0[j] - tg_zzzzz_xxyyyyy_1[j] * fl1_fza);

                    tg_zzzzzzz_xxyyyyz_0[j] = pb_z * tg_zzzzzz_xxyyyyz_0[j] + fr * tg_zzzzzz_xxyyyyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxyyyyz_0[j] - tg_zzzzz_xxyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xxyyyy_1[j];

                    tg_zzzzzzz_xxyyyzz_0[j] = pb_z * tg_zzzzzz_xxyyyzz_0[j] + fr * tg_zzzzzz_xxyyyzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxyyyzz_0[j] - tg_zzzzz_xxyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_xxyyyz_1[j];

                    tg_zzzzzzz_xxyyzzz_0[j] = pb_z * tg_zzzzzz_xxyyzzz_0[j] + fr * tg_zzzzzz_xxyyzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxyyzzz_0[j] - tg_zzzzz_xxyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzz_xxyyzz_1[j];

                    tg_zzzzzzz_xxyzzzz_0[j] = pb_z * tg_zzzzzz_xxyzzzz_0[j] + fr * tg_zzzzzz_xxyzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxyzzzz_0[j] - tg_zzzzz_xxyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzz_xxyzzz_1[j];

                    tg_zzzzzzz_xxzzzzz_0[j] = pb_z * tg_zzzzzz_xxzzzzz_0[j] + fr * tg_zzzzzz_xxzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xxzzzzz_0[j] - tg_zzzzz_xxzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzzz_xxzzzz_1[j];

                    tg_zzzzzzz_xyyyyyy_0[j] = pb_z * tg_zzzzzz_xyyyyyy_0[j] + fr * tg_zzzzzz_xyyyyyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyyyyyy_0[j] - tg_zzzzz_xyyyyyy_1[j] * fl1_fza);

                    tg_zzzzzzz_xyyyyyz_0[j] = pb_z * tg_zzzzzz_xyyyyyz_0[j] + fr * tg_zzzzzz_xyyyyyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyyyyyz_0[j] - tg_zzzzz_xyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_xyyyyy_1[j];

                    tg_zzzzzzz_xyyyyzz_0[j] = pb_z * tg_zzzzzz_xyyyyzz_0[j] + fr * tg_zzzzzz_xyyyyzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyyyyzz_0[j] - tg_zzzzz_xyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_xyyyyz_1[j];

                    tg_zzzzzzz_xyyyzzz_0[j] = pb_z * tg_zzzzzz_xyyyzzz_0[j] + fr * tg_zzzzzz_xyyyzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyyyzzz_0[j] - tg_zzzzz_xyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzz_xyyyzz_1[j];

                    tg_zzzzzzz_xyyzzzz_0[j] = pb_z * tg_zzzzzz_xyyzzzz_0[j] + fr * tg_zzzzzz_xyyzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyyzzzz_0[j] - tg_zzzzz_xyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzz_xyyzzz_1[j];

                    tg_zzzzzzz_xyzzzzz_0[j] = pb_z * tg_zzzzzz_xyzzzzz_0[j] + fr * tg_zzzzzz_xyzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xyzzzzz_0[j] - tg_zzzzz_xyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzzz_xyzzzz_1[j];

                    tg_zzzzzzz_xzzzzzz_0[j] = pb_z * tg_zzzzzz_xzzzzzz_0[j] + fr * tg_zzzzzz_xzzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_xzzzzzz_0[j] - tg_zzzzz_xzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzzz_xzzzzz_1[j];

                    tg_zzzzzzz_yyyyyyy_0[j] = pb_z * tg_zzzzzz_yyyyyyy_0[j] + fr * tg_zzzzzz_yyyyyyy_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyyyyyy_0[j] - tg_zzzzz_yyyyyyy_1[j] * fl1_fza);

                    tg_zzzzzzz_yyyyyyz_0[j] = pb_z * tg_zzzzzz_yyyyyyz_0[j] + fr * tg_zzzzzz_yyyyyyz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyyyyyz_0[j] - tg_zzzzz_yyyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzz_yyyyyy_1[j];

                    tg_zzzzzzz_yyyyyzz_0[j] = pb_z * tg_zzzzzz_yyyyyzz_0[j] + fr * tg_zzzzzz_yyyyyzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyyyyzz_0[j] - tg_zzzzz_yyyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzz_yyyyyz_1[j];

                    tg_zzzzzzz_yyyyzzz_0[j] = pb_z * tg_zzzzzz_yyyyzzz_0[j] + fr * tg_zzzzzz_yyyyzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyyyzzz_0[j] - tg_zzzzz_yyyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzz_yyyyzz_1[j];

                    tg_zzzzzzz_yyyzzzz_0[j] = pb_z * tg_zzzzzz_yyyzzzz_0[j] + fr * tg_zzzzzz_yyyzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyyzzzz_0[j] - tg_zzzzz_yyyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzz_yyyzzz_1[j];

                    tg_zzzzzzz_yyzzzzz_0[j] = pb_z * tg_zzzzzz_yyzzzzz_0[j] + fr * tg_zzzzzz_yyzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yyzzzzz_0[j] - tg_zzzzz_yyzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzzz_yyzzzz_1[j];

                    tg_zzzzzzz_yzzzzzz_0[j] = pb_z * tg_zzzzzz_yzzzzzz_0[j] + fr * tg_zzzzzz_yzzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_yzzzzzz_0[j] - tg_zzzzz_yzzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzzz_yzzzzz_1[j];

                    tg_zzzzzzz_zzzzzzz_0[j] = pb_z * tg_zzzzzz_zzzzzzz_0[j] + fr * tg_zzzzzz_zzzzzzz_1[j] + 3.0 * fl1_fx * (tg_zzzzz_zzzzzzz_0[j] - tg_zzzzz_zzzzzzz_1[j] * fl1_fza) + 3.5 * fl1_fxn * tg_zzzzzz_zzzzzz_1[j];
                }

                idx++;
            }
        }
    }


} // erirecfunc namespace

