//
//                           VELOXCHEM 1.0-RC
//      ---------------------------------------------------
//                     An Electronic Structure Code
//
//  Copyright © 2018-2020 by VeloxChem developers. All rights reserved.
//  Contact: https://veloxchem.org/contact

#include "ElectronRepulsionRecFuncForLI.hpp"

namespace erirecfunc { // erirecfunc namespace

    void
    compElectronRepulsionForSLSI(      CMemBlock2D<double>* primBuffer,
                                 const CRecursionMap&       recursionMap,
                                 const CMemBlock2D<double>& osFactors,
                                 const CMemBlock2D<double>& wpDistances,
                                 const CGtoPairsBlock&      braGtoPairsBlock,
                                 const CGtoPairsBlock&      ketGtoPairsBlock,
                                 const int32_t              nKetPrimPairs,
                                 const int32_t              iContrPair)
    {
        erirecfunc::compElectronRepulsionForSLSI_0_97(primBuffer,
                                                      recursionMap,
                                                      osFactors,
                                                      wpDistances, 
                                                      braGtoPairsBlock,
                                                      ketGtoPairsBlock,
                                                      nKetPrimPairs,
                                                      iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_97_194(primBuffer,
                                                        recursionMap,
                                                        osFactors,
                                                        wpDistances, 
                                                        braGtoPairsBlock,
                                                        ketGtoPairsBlock,
                                                        nKetPrimPairs,
                                                        iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_194_291(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_291_388(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_388_485(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_485_582(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_582_679(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_679_776(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_776_873(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_873_970(primBuffer,
                                                         recursionMap,
                                                         osFactors,
                                                         wpDistances, 
                                                         braGtoPairsBlock,
                                                         ketGtoPairsBlock,
                                                         nKetPrimPairs,
                                                         iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_970_1067(primBuffer,
                                                          recursionMap,
                                                          osFactors,
                                                          wpDistances, 
                                                          braGtoPairsBlock,
                                                          ketGtoPairsBlock,
                                                          nKetPrimPairs,
                                                          iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_1067_1164(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 

        erirecfunc::compElectronRepulsionForSLSI_1164_1260(primBuffer,
                                                           recursionMap,
                                                           osFactors,
                                                           wpDistances, 
                                                           braGtoPairsBlock,
                                                           ketGtoPairsBlock,
                                                           nKetPrimPairs,
                                                           iContrPair); 
    }

    void
    compElectronRepulsionForSLSI_0_97(      CMemBlock2D<double>* primBuffer,
                                      const CRecursionMap&       recursionMap,
                                      const CMemBlock2D<double>& osFactors,
                                      const CMemBlock2D<double>& wpDistances,
                                      const CGtoPairsBlock&      braGtoPairsBlock,
                                      const CGtoPairsBlock&      ketGtoPairsBlock,
                                      const int32_t              nKetPrimPairs,
                                      const int32_t              iContrPair)
    {
        // Batch of Integrals (0,97)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxxx_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx); 

                auto tg_xxxxxxx_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1); 

                auto tg_xxxxxxx_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 2); 

                auto tg_xxxxxxx_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 3); 

                auto tg_xxxxxxx_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 4); 

                auto tg_xxxxxxx_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 5); 

                auto tg_xxxxxxx_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 6); 

                auto tg_xxxxxxx_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 7); 

                auto tg_xxxxxxx_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 8); 

                auto tg_xxxxxxx_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 9); 

                auto tg_xxxxxxx_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 10); 

                auto tg_xxxxxxx_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 11); 

                auto tg_xxxxxxx_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 12); 

                auto tg_xxxxxxx_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 13); 

                auto tg_xxxxxxx_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 14); 

                auto tg_xxxxxxx_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 15); 

                auto tg_xxxxxxx_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 16); 

                auto tg_xxxxxxx_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 17); 

                auto tg_xxxxxxx_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 18); 

                auto tg_xxxxxxx_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 19); 

                auto tg_xxxxxxx_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 20); 

                auto tg_xxxxxxx_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 21); 

                auto tg_xxxxxxx_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 22); 

                auto tg_xxxxxxx_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 23); 

                auto tg_xxxxxxx_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 24); 

                auto tg_xxxxxxx_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 25); 

                auto tg_xxxxxxx_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 26); 

                auto tg_xxxxxxx_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 27); 

                auto tg_xxxxxxy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 28); 

                auto tg_xxxxxxy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 29); 

                auto tg_xxxxxxy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 30); 

                auto tg_xxxxxxy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 31); 

                auto tg_xxxxxxy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 32); 

                auto tg_xxxxxxy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 33); 

                auto tg_xxxxxxy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 34); 

                auto tg_xxxxxxy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 35); 

                auto tg_xxxxxxy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 36); 

                auto tg_xxxxxxy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 37); 

                auto tg_xxxxxxy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 38); 

                auto tg_xxxxxxy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 39); 

                auto tg_xxxxxxy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 40); 

                auto tg_xxxxxxy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 41); 

                auto tg_xxxxxxy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 42); 

                auto tg_xxxxxxy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 43); 

                auto tg_xxxxxxy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 44); 

                auto tg_xxxxxxy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 45); 

                auto tg_xxxxxxy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 46); 

                auto tg_xxxxxxy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 47); 

                auto tg_xxxxxxy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 48); 

                auto tg_xxxxxxy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 49); 

                auto tg_xxxxxxy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 50); 

                auto tg_xxxxxxy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 51); 

                auto tg_xxxxxxy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 52); 

                auto tg_xxxxxxy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 53); 

                auto tg_xxxxxxy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 54); 

                auto tg_xxxxxxy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 55); 

                auto tg_xxxxxxz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 56); 

                auto tg_xxxxxxz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 57); 

                auto tg_xxxxxxz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 58); 

                auto tg_xxxxxxz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 59); 

                auto tg_xxxxxxz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 60); 

                auto tg_xxxxxxz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 61); 

                auto tg_xxxxxxz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 62); 

                auto tg_xxxxxxz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 63); 

                auto tg_xxxxxxz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 64); 

                auto tg_xxxxxxz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 65); 

                auto tg_xxxxxxz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 66); 

                auto tg_xxxxxxz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 67); 

                auto tg_xxxxxxz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 68); 

                auto tg_xxxxxxz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 69); 

                auto tg_xxxxxxz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 70); 

                auto tg_xxxxxxz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 71); 

                auto tg_xxxxxxz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 72); 

                auto tg_xxxxxxz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 73); 

                auto tg_xxxxxxz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 74); 

                auto tg_xxxxxxz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 75); 

                auto tg_xxxxxxz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 76); 

                auto tg_xxxxxxz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 77); 

                auto tg_xxxxxxz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 78); 

                auto tg_xxxxxxz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 79); 

                auto tg_xxxxxxz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 80); 

                auto tg_xxxxxxz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 81); 

                auto tg_xxxxxxz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 82); 

                auto tg_xxxxxxz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 83); 

                auto tg_xxxxxyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 84); 

                auto tg_xxxxxyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 85); 

                auto tg_xxxxxyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 86); 

                auto tg_xxxxxyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 87); 

                auto tg_xxxxxyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 88); 

                auto tg_xxxxxyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 89); 

                auto tg_xxxxxyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 90); 

                auto tg_xxxxxyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 91); 

                auto tg_xxxxxyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 92); 

                auto tg_xxxxxyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 93); 

                auto tg_xxxxxyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 94); 

                auto tg_xxxxxyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 95); 

                auto tg_xxxxxyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 96); 

                auto tg_xxxxxxx_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx); 

                auto tg_xxxxxxx_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1); 

                auto tg_xxxxxxx_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 2); 

                auto tg_xxxxxxx_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 3); 

                auto tg_xxxxxxx_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 4); 

                auto tg_xxxxxxx_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 5); 

                auto tg_xxxxxxx_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 6); 

                auto tg_xxxxxxx_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 7); 

                auto tg_xxxxxxx_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 8); 

                auto tg_xxxxxxx_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 9); 

                auto tg_xxxxxxx_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 10); 

                auto tg_xxxxxxx_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 11); 

                auto tg_xxxxxxx_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 12); 

                auto tg_xxxxxxx_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 13); 

                auto tg_xxxxxxx_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 14); 

                auto tg_xxxxxxx_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 15); 

                auto tg_xxxxxxx_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 16); 

                auto tg_xxxxxxx_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 17); 

                auto tg_xxxxxxx_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 18); 

                auto tg_xxxxxxx_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 19); 

                auto tg_xxxxxxx_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 20); 

                auto tg_xxxxxxx_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 21); 

                auto tg_xxxxxxx_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 22); 

                auto tg_xxxxxxx_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 23); 

                auto tg_xxxxxxx_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 24); 

                auto tg_xxxxxxx_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 25); 

                auto tg_xxxxxxx_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 26); 

                auto tg_xxxxxxx_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 27); 

                auto tg_xxxxxxy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 28); 

                auto tg_xxxxxxy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 29); 

                auto tg_xxxxxxy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 30); 

                auto tg_xxxxxxy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 31); 

                auto tg_xxxxxxy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 32); 

                auto tg_xxxxxxy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 33); 

                auto tg_xxxxxxy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 34); 

                auto tg_xxxxxxy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 35); 

                auto tg_xxxxxxy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 36); 

                auto tg_xxxxxxy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 37); 

                auto tg_xxxxxxy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 38); 

                auto tg_xxxxxxy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 39); 

                auto tg_xxxxxxy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 40); 

                auto tg_xxxxxxy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 41); 

                auto tg_xxxxxxy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 42); 

                auto tg_xxxxxxy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 43); 

                auto tg_xxxxxxy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 44); 

                auto tg_xxxxxxy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 45); 

                auto tg_xxxxxxy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 46); 

                auto tg_xxxxxxy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 47); 

                auto tg_xxxxxxy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 48); 

                auto tg_xxxxxxy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 49); 

                auto tg_xxxxxxy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 50); 

                auto tg_xxxxxxy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 51); 

                auto tg_xxxxxxy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 52); 

                auto tg_xxxxxxy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 53); 

                auto tg_xxxxxxy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 54); 

                auto tg_xxxxxxy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 55); 

                auto tg_xxxxxxz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 56); 

                auto tg_xxxxxxz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 57); 

                auto tg_xxxxxxz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 58); 

                auto tg_xxxxxxz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 59); 

                auto tg_xxxxxxz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 60); 

                auto tg_xxxxxxz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 61); 

                auto tg_xxxxxxz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 62); 

                auto tg_xxxxxxz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 63); 

                auto tg_xxxxxxz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 64); 

                auto tg_xxxxxxz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 65); 

                auto tg_xxxxxxz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 66); 

                auto tg_xxxxxxz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 67); 

                auto tg_xxxxxxz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 68); 

                auto tg_xxxxxxz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 69); 

                auto tg_xxxxxxz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 70); 

                auto tg_xxxxxxz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 71); 

                auto tg_xxxxxxz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 72); 

                auto tg_xxxxxxz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 73); 

                auto tg_xxxxxxz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 74); 

                auto tg_xxxxxxz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 75); 

                auto tg_xxxxxxz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 76); 

                auto tg_xxxxxxz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 77); 

                auto tg_xxxxxxz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 78); 

                auto tg_xxxxxxz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 79); 

                auto tg_xxxxxxz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 80); 

                auto tg_xxxxxxz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 81); 

                auto tg_xxxxxxz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 82); 

                auto tg_xxxxxxz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 83); 

                auto tg_xxxxxyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 84); 

                auto tg_xxxxxyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 85); 

                auto tg_xxxxxyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 86); 

                auto tg_xxxxxyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 87); 

                auto tg_xxxxxyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 88); 

                auto tg_xxxxxyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 89); 

                auto tg_xxxxxyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 90); 

                auto tg_xxxxxyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 91); 

                auto tg_xxxxxyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 92); 

                auto tg_xxxxxyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 93); 

                auto tg_xxxxxyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 94); 

                auto tg_xxxxxyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 95); 

                auto tg_xxxxxyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 96); 

                auto tg_xxxxxx_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx); 

                auto tg_xxxxxx_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 1); 

                auto tg_xxxxxx_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 2); 

                auto tg_xxxxxx_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 3); 

                auto tg_xxxxxx_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 4); 

                auto tg_xxxxxx_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 5); 

                auto tg_xxxxxx_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 6); 

                auto tg_xxxxxx_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 7); 

                auto tg_xxxxxx_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 8); 

                auto tg_xxxxxx_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 9); 

                auto tg_xxxxxx_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 10); 

                auto tg_xxxxxx_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 11); 

                auto tg_xxxxxx_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 12); 

                auto tg_xxxxxx_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 13); 

                auto tg_xxxxxx_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 14); 

                auto tg_xxxxxx_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 15); 

                auto tg_xxxxxx_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 16); 

                auto tg_xxxxxx_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 17); 

                auto tg_xxxxxx_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 18); 

                auto tg_xxxxxx_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 19); 

                auto tg_xxxxxx_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 20); 

                auto tg_xxxxxx_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 21); 

                auto tg_xxxxxx_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 22); 

                auto tg_xxxxxx_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 23); 

                auto tg_xxxxxx_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 24); 

                auto tg_xxxxxx_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 25); 

                auto tg_xxxxxx_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 26); 

                auto tg_xxxxxx_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 27); 

                auto tg_xxxxxy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 28); 

                auto tg_xxxxxy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 29); 

                auto tg_xxxxxy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 30); 

                auto tg_xxxxxy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 31); 

                auto tg_xxxxxy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 32); 

                auto tg_xxxxxy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 33); 

                auto tg_xxxxxy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 34); 

                auto tg_xxxxxy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 35); 

                auto tg_xxxxxy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 36); 

                auto tg_xxxxxy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 37); 

                auto tg_xxxxxy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 38); 

                auto tg_xxxxxy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 39); 

                auto tg_xxxxxy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 40); 

                auto tg_xxxxxy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 41); 

                auto tg_xxxxxy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 42); 

                auto tg_xxxxxy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 43); 

                auto tg_xxxxxy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 44); 

                auto tg_xxxxxy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 45); 

                auto tg_xxxxxy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 46); 

                auto tg_xxxxxy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 47); 

                auto tg_xxxxxy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 48); 

                auto tg_xxxxxy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 49); 

                auto tg_xxxxxy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 50); 

                auto tg_xxxxxy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 51); 

                auto tg_xxxxxy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 52); 

                auto tg_xxxxxy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 53); 

                auto tg_xxxxxy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 54); 

                auto tg_xxxxxy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 55); 

                auto tg_xxxxxz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 56); 

                auto tg_xxxxxz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 57); 

                auto tg_xxxxxz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 58); 

                auto tg_xxxxxz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 59); 

                auto tg_xxxxxz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 60); 

                auto tg_xxxxxz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 61); 

                auto tg_xxxxxz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 62); 

                auto tg_xxxxxz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 63); 

                auto tg_xxxxxz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 64); 

                auto tg_xxxxxz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 65); 

                auto tg_xxxxxz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 66); 

                auto tg_xxxxxz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 67); 

                auto tg_xxxxxz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 68); 

                auto tg_xxxxxz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 69); 

                auto tg_xxxxxz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 70); 

                auto tg_xxxxxz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 71); 

                auto tg_xxxxxz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 72); 

                auto tg_xxxxxz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 73); 

                auto tg_xxxxxz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 74); 

                auto tg_xxxxxz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 75); 

                auto tg_xxxxxz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 76); 

                auto tg_xxxxxz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 77); 

                auto tg_xxxxxz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 78); 

                auto tg_xxxxxz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 79); 

                auto tg_xxxxxz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 80); 

                auto tg_xxxxxz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 81); 

                auto tg_xxxxxz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 82); 

                auto tg_xxxxxz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 83); 

                auto tg_xxxxyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 84); 

                auto tg_xxxxyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 85); 

                auto tg_xxxxyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 86); 

                auto tg_xxxxyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 87); 

                auto tg_xxxxyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 88); 

                auto tg_xxxxyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 89); 

                auto tg_xxxxyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 90); 

                auto tg_xxxxyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 91); 

                auto tg_xxxxyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 92); 

                auto tg_xxxxyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 93); 

                auto tg_xxxxyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 94); 

                auto tg_xxxxyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 95); 

                auto tg_xxxxyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 96); 

                auto tg_xxxxxx_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx); 

                auto tg_xxxxxx_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 1); 

                auto tg_xxxxxx_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 2); 

                auto tg_xxxxxx_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 3); 

                auto tg_xxxxxx_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 4); 

                auto tg_xxxxxx_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 5); 

                auto tg_xxxxxx_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 6); 

                auto tg_xxxxxx_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 7); 

                auto tg_xxxxxx_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 8); 

                auto tg_xxxxxx_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 9); 

                auto tg_xxxxxx_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 10); 

                auto tg_xxxxxx_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 11); 

                auto tg_xxxxxx_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 12); 

                auto tg_xxxxxx_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 13); 

                auto tg_xxxxxx_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 14); 

                auto tg_xxxxxx_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 15); 

                auto tg_xxxxxx_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 16); 

                auto tg_xxxxxx_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 17); 

                auto tg_xxxxxx_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 18); 

                auto tg_xxxxxx_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 19); 

                auto tg_xxxxxx_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 20); 

                auto tg_xxxxxx_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 21); 

                auto tg_xxxxxx_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 22); 

                auto tg_xxxxxx_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 23); 

                auto tg_xxxxxx_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 24); 

                auto tg_xxxxxx_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 25); 

                auto tg_xxxxxx_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 26); 

                auto tg_xxxxxx_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 27); 

                auto tg_xxxxxy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 28); 

                auto tg_xxxxxy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 29); 

                auto tg_xxxxxy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 30); 

                auto tg_xxxxxy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 31); 

                auto tg_xxxxxy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 32); 

                auto tg_xxxxxy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 33); 

                auto tg_xxxxxy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 34); 

                auto tg_xxxxxy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 35); 

                auto tg_xxxxxy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 36); 

                auto tg_xxxxxy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 37); 

                auto tg_xxxxxy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 38); 

                auto tg_xxxxxy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 39); 

                auto tg_xxxxxy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 40); 

                auto tg_xxxxxy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 41); 

                auto tg_xxxxxy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 42); 

                auto tg_xxxxxy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 43); 

                auto tg_xxxxxy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 44); 

                auto tg_xxxxxy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 45); 

                auto tg_xxxxxy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 46); 

                auto tg_xxxxxy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 47); 

                auto tg_xxxxxy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 48); 

                auto tg_xxxxxy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 49); 

                auto tg_xxxxxy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 50); 

                auto tg_xxxxxy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 51); 

                auto tg_xxxxxy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 52); 

                auto tg_xxxxxy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 53); 

                auto tg_xxxxxy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 54); 

                auto tg_xxxxxy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 55); 

                auto tg_xxxxxz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 56); 

                auto tg_xxxxxz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 57); 

                auto tg_xxxxxz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 58); 

                auto tg_xxxxxz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 59); 

                auto tg_xxxxxz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 60); 

                auto tg_xxxxxz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 61); 

                auto tg_xxxxxz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 62); 

                auto tg_xxxxxz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 63); 

                auto tg_xxxxxz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 64); 

                auto tg_xxxxxz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 65); 

                auto tg_xxxxxz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 66); 

                auto tg_xxxxxz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 67); 

                auto tg_xxxxxz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 68); 

                auto tg_xxxxxz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 69); 

                auto tg_xxxxxz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 70); 

                auto tg_xxxxxz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 71); 

                auto tg_xxxxxz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 72); 

                auto tg_xxxxxz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 73); 

                auto tg_xxxxxz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 74); 

                auto tg_xxxxxz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 75); 

                auto tg_xxxxxz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 76); 

                auto tg_xxxxxz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 77); 

                auto tg_xxxxxz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 78); 

                auto tg_xxxxxz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 79); 

                auto tg_xxxxxz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 80); 

                auto tg_xxxxxz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 81); 

                auto tg_xxxxxz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 82); 

                auto tg_xxxxxz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 83); 

                auto tg_xxxxyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 84); 

                auto tg_xxxxyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 85); 

                auto tg_xxxxyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 86); 

                auto tg_xxxxyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 87); 

                auto tg_xxxxyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 88); 

                auto tg_xxxxyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 89); 

                auto tg_xxxxyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 90); 

                auto tg_xxxxyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 91); 

                auto tg_xxxxyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 92); 

                auto tg_xxxxyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 93); 

                auto tg_xxxxyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 94); 

                auto tg_xxxxyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 95); 

                auto tg_xxxxyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 96); 

                auto tg_xxxxxxx_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx); 

                auto tg_xxxxxxx_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 1); 

                auto tg_xxxxxxx_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 2); 

                auto tg_xxxxxxx_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 3); 

                auto tg_xxxxxxx_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 4); 

                auto tg_xxxxxxx_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 5); 

                auto tg_xxxxxxx_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 6); 

                auto tg_xxxxxxx_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 7); 

                auto tg_xxxxxxx_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 8); 

                auto tg_xxxxxxx_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 9); 

                auto tg_xxxxxxx_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 10); 

                auto tg_xxxxxxx_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 11); 

                auto tg_xxxxxxx_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 12); 

                auto tg_xxxxxxx_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 13); 

                auto tg_xxxxxxx_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 14); 

                auto tg_xxxxxxx_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 15); 

                auto tg_xxxxxxx_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 16); 

                auto tg_xxxxxxx_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 17); 

                auto tg_xxxxxxx_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 18); 

                auto tg_xxxxxxx_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 19); 

                auto tg_xxxxxxx_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 20); 

                auto tg_xxxxxxy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 21); 

                auto tg_xxxxxxy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 22); 

                auto tg_xxxxxxy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 23); 

                auto tg_xxxxxxy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 24); 

                auto tg_xxxxxxy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 25); 

                auto tg_xxxxxxy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 26); 

                auto tg_xxxxxxy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 27); 

                auto tg_xxxxxxy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 28); 

                auto tg_xxxxxxy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 29); 

                auto tg_xxxxxxy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 30); 

                auto tg_xxxxxxy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 31); 

                auto tg_xxxxxxy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 32); 

                auto tg_xxxxxxy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 33); 

                auto tg_xxxxxxy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 34); 

                auto tg_xxxxxxy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 35); 

                auto tg_xxxxxxy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 36); 

                auto tg_xxxxxxy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 37); 

                auto tg_xxxxxxy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 38); 

                auto tg_xxxxxxy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 39); 

                auto tg_xxxxxxy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 40); 

                auto tg_xxxxxxy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 41); 

                auto tg_xxxxxxz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 42); 

                auto tg_xxxxxxz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 43); 

                auto tg_xxxxxxz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 44); 

                auto tg_xxxxxxz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 45); 

                auto tg_xxxxxxz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 46); 

                auto tg_xxxxxxz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 47); 

                auto tg_xxxxxxz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 48); 

                auto tg_xxxxxxz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 49); 

                auto tg_xxxxxxz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 50); 

                auto tg_xxxxxxz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 51); 

                auto tg_xxxxxxz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 52); 

                auto tg_xxxxxxz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 53); 

                auto tg_xxxxxxz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 54); 

                auto tg_xxxxxxz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 55); 

                auto tg_xxxxxxz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 56); 

                auto tg_xxxxxxz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 57); 

                auto tg_xxxxxxz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 58); 

                auto tg_xxxxxxz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 59); 

                auto tg_xxxxxxz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 60); 

                auto tg_xxxxxxz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 61); 

                auto tg_xxxxxxz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 62); 

                auto tg_xxxxxyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 63); 

                auto tg_xxxxxyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 64); 

                auto tg_xxxxxyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 65); 

                auto tg_xxxxxyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 66); 

                auto tg_xxxxxyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 67); 

                auto tg_xxxxxyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 68); 

                auto tg_xxxxxyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 69); 

                auto tg_xxxxxyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 70); 

                auto tg_xxxxxyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 71); 

                auto tg_xxxxxyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 72); 

                auto tg_xxxxxyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 73); 

                auto tg_xxxxxyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 74); 

                auto tg_xxxxxyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 75); 

                // set up pointers to integrals

                auto tg_xxxxxxxx_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx); 

                auto tg_xxxxxxxx_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1); 

                auto tg_xxxxxxxx_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 2); 

                auto tg_xxxxxxxx_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 3); 

                auto tg_xxxxxxxx_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 4); 

                auto tg_xxxxxxxx_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 5); 

                auto tg_xxxxxxxx_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 6); 

                auto tg_xxxxxxxx_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 7); 

                auto tg_xxxxxxxx_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 8); 

                auto tg_xxxxxxxx_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 9); 

                auto tg_xxxxxxxx_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 10); 

                auto tg_xxxxxxxx_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 11); 

                auto tg_xxxxxxxx_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 12); 

                auto tg_xxxxxxxx_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 13); 

                auto tg_xxxxxxxx_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 14); 

                auto tg_xxxxxxxx_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 15); 

                auto tg_xxxxxxxx_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 16); 

                auto tg_xxxxxxxx_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 17); 

                auto tg_xxxxxxxx_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 18); 

                auto tg_xxxxxxxx_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 19); 

                auto tg_xxxxxxxx_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 20); 

                auto tg_xxxxxxxx_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 21); 

                auto tg_xxxxxxxx_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 22); 

                auto tg_xxxxxxxx_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 23); 

                auto tg_xxxxxxxx_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 24); 

                auto tg_xxxxxxxx_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 25); 

                auto tg_xxxxxxxx_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 26); 

                auto tg_xxxxxxxx_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 27); 

                auto tg_xxxxxxxy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 28); 

                auto tg_xxxxxxxy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 29); 

                auto tg_xxxxxxxy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 30); 

                auto tg_xxxxxxxy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 31); 

                auto tg_xxxxxxxy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 32); 

                auto tg_xxxxxxxy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 33); 

                auto tg_xxxxxxxy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 34); 

                auto tg_xxxxxxxy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 35); 

                auto tg_xxxxxxxy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 36); 

                auto tg_xxxxxxxy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 37); 

                auto tg_xxxxxxxy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 38); 

                auto tg_xxxxxxxy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 39); 

                auto tg_xxxxxxxy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 40); 

                auto tg_xxxxxxxy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 41); 

                auto tg_xxxxxxxy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 42); 

                auto tg_xxxxxxxy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 43); 

                auto tg_xxxxxxxy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 44); 

                auto tg_xxxxxxxy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 45); 

                auto tg_xxxxxxxy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 46); 

                auto tg_xxxxxxxy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 47); 

                auto tg_xxxxxxxy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 48); 

                auto tg_xxxxxxxy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 49); 

                auto tg_xxxxxxxy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 50); 

                auto tg_xxxxxxxy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 51); 

                auto tg_xxxxxxxy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 52); 

                auto tg_xxxxxxxy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 53); 

                auto tg_xxxxxxxy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 54); 

                auto tg_xxxxxxxy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 55); 

                auto tg_xxxxxxxz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 56); 

                auto tg_xxxxxxxz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 57); 

                auto tg_xxxxxxxz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 58); 

                auto tg_xxxxxxxz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 59); 

                auto tg_xxxxxxxz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 60); 

                auto tg_xxxxxxxz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 61); 

                auto tg_xxxxxxxz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 62); 

                auto tg_xxxxxxxz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 63); 

                auto tg_xxxxxxxz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 64); 

                auto tg_xxxxxxxz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 65); 

                auto tg_xxxxxxxz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 66); 

                auto tg_xxxxxxxz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 67); 

                auto tg_xxxxxxxz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 68); 

                auto tg_xxxxxxxz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 69); 

                auto tg_xxxxxxxz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 70); 

                auto tg_xxxxxxxz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 71); 

                auto tg_xxxxxxxz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 72); 

                auto tg_xxxxxxxz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 73); 

                auto tg_xxxxxxxz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 74); 

                auto tg_xxxxxxxz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 75); 

                auto tg_xxxxxxxz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 76); 

                auto tg_xxxxxxxz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 77); 

                auto tg_xxxxxxxz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 78); 

                auto tg_xxxxxxxz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 79); 

                auto tg_xxxxxxxz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 80); 

                auto tg_xxxxxxxz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 81); 

                auto tg_xxxxxxxz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 82); 

                auto tg_xxxxxxxz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 83); 

                auto tg_xxxxxxyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 84); 

                auto tg_xxxxxxyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 85); 

                auto tg_xxxxxxyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 86); 

                auto tg_xxxxxxyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 87); 

                auto tg_xxxxxxyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 88); 

                auto tg_xxxxxxyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 89); 

                auto tg_xxxxxxyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 90); 

                auto tg_xxxxxxyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 91); 

                auto tg_xxxxxxyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 92); 

                auto tg_xxxxxxyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 93); 

                auto tg_xxxxxxyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 94); 

                auto tg_xxxxxxyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 95); 

                auto tg_xxxxxxyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 96); 

                // Batch of Integrals (0,97)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxx_xxxxxx_0, tg_xxxxxx_xxxxxx_1, tg_xxxxxx_xxxxxy_0, \
                                         tg_xxxxxx_xxxxxy_1, tg_xxxxxx_xxxxxz_0, tg_xxxxxx_xxxxxz_1, tg_xxxxxx_xxxxyy_0, \
                                         tg_xxxxxx_xxxxyy_1, tg_xxxxxx_xxxxyz_0, tg_xxxxxx_xxxxyz_1, tg_xxxxxx_xxxxzz_0, \
                                         tg_xxxxxx_xxxxzz_1, tg_xxxxxx_xxxyyy_0, tg_xxxxxx_xxxyyy_1, tg_xxxxxx_xxxyyz_0, \
                                         tg_xxxxxx_xxxyyz_1, tg_xxxxxx_xxxyzz_0, tg_xxxxxx_xxxyzz_1, tg_xxxxxx_xxxzzz_0, \
                                         tg_xxxxxx_xxxzzz_1, tg_xxxxxx_xxyyyy_0, tg_xxxxxx_xxyyyy_1, tg_xxxxxx_xxyyyz_0, \
                                         tg_xxxxxx_xxyyyz_1, tg_xxxxxx_xxyyzz_0, tg_xxxxxx_xxyyzz_1, tg_xxxxxx_xxyzzz_0, \
                                         tg_xxxxxx_xxyzzz_1, tg_xxxxxx_xxzzzz_0, tg_xxxxxx_xxzzzz_1, tg_xxxxxx_xyyyyy_0, \
                                         tg_xxxxxx_xyyyyy_1, tg_xxxxxx_xyyyyz_0, tg_xxxxxx_xyyyyz_1, tg_xxxxxx_xyyyzz_0, \
                                         tg_xxxxxx_xyyyzz_1, tg_xxxxxx_xyyzzz_0, tg_xxxxxx_xyyzzz_1, tg_xxxxxx_xyzzzz_0, \
                                         tg_xxxxxx_xyzzzz_1, tg_xxxxxx_xzzzzz_0, tg_xxxxxx_xzzzzz_1, tg_xxxxxx_yyyyyy_0, \
                                         tg_xxxxxx_yyyyyy_1, tg_xxxxxx_yyyyyz_0, tg_xxxxxx_yyyyyz_1, tg_xxxxxx_yyyyzz_0, \
                                         tg_xxxxxx_yyyyzz_1, tg_xxxxxx_yyyzzz_0, tg_xxxxxx_yyyzzz_1, tg_xxxxxx_yyzzzz_0, \
                                         tg_xxxxxx_yyzzzz_1, tg_xxxxxx_yzzzzz_0, tg_xxxxxx_yzzzzz_1, tg_xxxxxx_zzzzzz_0, \
                                         tg_xxxxxx_zzzzzz_1, tg_xxxxxxx_xxxxx_1, tg_xxxxxxx_xxxxxx_0, tg_xxxxxxx_xxxxxx_1, \
                                         tg_xxxxxxx_xxxxxy_0, tg_xxxxxxx_xxxxxy_1, tg_xxxxxxx_xxxxxz_0, tg_xxxxxxx_xxxxxz_1, \
                                         tg_xxxxxxx_xxxxy_1, tg_xxxxxxx_xxxxyy_0, tg_xxxxxxx_xxxxyy_1, tg_xxxxxxx_xxxxyz_0, \
                                         tg_xxxxxxx_xxxxyz_1, tg_xxxxxxx_xxxxz_1, tg_xxxxxxx_xxxxzz_0, tg_xxxxxxx_xxxxzz_1, \
                                         tg_xxxxxxx_xxxyy_1, tg_xxxxxxx_xxxyyy_0, tg_xxxxxxx_xxxyyy_1, tg_xxxxxxx_xxxyyz_0, \
                                         tg_xxxxxxx_xxxyyz_1, tg_xxxxxxx_xxxyz_1, tg_xxxxxxx_xxxyzz_0, tg_xxxxxxx_xxxyzz_1, \
                                         tg_xxxxxxx_xxxzz_1, tg_xxxxxxx_xxxzzz_0, tg_xxxxxxx_xxxzzz_1, tg_xxxxxxx_xxyyy_1, \
                                         tg_xxxxxxx_xxyyyy_0, tg_xxxxxxx_xxyyyy_1, tg_xxxxxxx_xxyyyz_0, tg_xxxxxxx_xxyyyz_1, \
                                         tg_xxxxxxx_xxyyz_1, tg_xxxxxxx_xxyyzz_0, tg_xxxxxxx_xxyyzz_1, tg_xxxxxxx_xxyzz_1, \
                                         tg_xxxxxxx_xxyzzz_0, tg_xxxxxxx_xxyzzz_1, tg_xxxxxxx_xxzzz_1, tg_xxxxxxx_xxzzzz_0, \
                                         tg_xxxxxxx_xxzzzz_1, tg_xxxxxxx_xyyyy_1, tg_xxxxxxx_xyyyyy_0, tg_xxxxxxx_xyyyyy_1, \
                                         tg_xxxxxxx_xyyyyz_0, tg_xxxxxxx_xyyyyz_1, tg_xxxxxxx_xyyyz_1, tg_xxxxxxx_xyyyzz_0, \
                                         tg_xxxxxxx_xyyyzz_1, tg_xxxxxxx_xyyzz_1, tg_xxxxxxx_xyyzzz_0, tg_xxxxxxx_xyyzzz_1, \
                                         tg_xxxxxxx_xyzzz_1, tg_xxxxxxx_xyzzzz_0, tg_xxxxxxx_xyzzzz_1, tg_xxxxxxx_xzzzz_1, \
                                         tg_xxxxxxx_xzzzzz_0, tg_xxxxxxx_xzzzzz_1, tg_xxxxxxx_yyyyy_1, tg_xxxxxxx_yyyyyy_0, \
                                         tg_xxxxxxx_yyyyyy_1, tg_xxxxxxx_yyyyyz_0, tg_xxxxxxx_yyyyyz_1, tg_xxxxxxx_yyyyz_1, \
                                         tg_xxxxxxx_yyyyzz_0, tg_xxxxxxx_yyyyzz_1, tg_xxxxxxx_yyyzz_1, tg_xxxxxxx_yyyzzz_0, \
                                         tg_xxxxxxx_yyyzzz_1, tg_xxxxxxx_yyzzz_1, tg_xxxxxxx_yyzzzz_0, tg_xxxxxxx_yyzzzz_1, \
                                         tg_xxxxxxx_yzzzz_1, tg_xxxxxxx_yzzzzz_0, tg_xxxxxxx_yzzzzz_1, tg_xxxxxxx_zzzzz_1, \
                                         tg_xxxxxxx_zzzzzz_0, tg_xxxxxxx_zzzzzz_1, tg_xxxxxxxx_xxxxxx_0, tg_xxxxxxxx_xxxxxy_0, \
                                         tg_xxxxxxxx_xxxxxz_0, tg_xxxxxxxx_xxxxyy_0, tg_xxxxxxxx_xxxxyz_0, tg_xxxxxxxx_xxxxzz_0, \
                                         tg_xxxxxxxx_xxxyyy_0, tg_xxxxxxxx_xxxyyz_0, tg_xxxxxxxx_xxxyzz_0, tg_xxxxxxxx_xxxzzz_0, \
                                         tg_xxxxxxxx_xxyyyy_0, tg_xxxxxxxx_xxyyyz_0, tg_xxxxxxxx_xxyyzz_0, tg_xxxxxxxx_xxyzzz_0, \
                                         tg_xxxxxxxx_xxzzzz_0, tg_xxxxxxxx_xyyyyy_0, tg_xxxxxxxx_xyyyyz_0, tg_xxxxxxxx_xyyyzz_0, \
                                         tg_xxxxxxxx_xyyzzz_0, tg_xxxxxxxx_xyzzzz_0, tg_xxxxxxxx_xzzzzz_0, tg_xxxxxxxx_yyyyyy_0, \
                                         tg_xxxxxxxx_yyyyyz_0, tg_xxxxxxxx_yyyyzz_0, tg_xxxxxxxx_yyyzzz_0, tg_xxxxxxxx_yyzzzz_0, \
                                         tg_xxxxxxxx_yzzzzz_0, tg_xxxxxxxx_zzzzzz_0, tg_xxxxxxxy_xxxxxx_0, tg_xxxxxxxy_xxxxxy_0, \
                                         tg_xxxxxxxy_xxxxxz_0, tg_xxxxxxxy_xxxxyy_0, tg_xxxxxxxy_xxxxyz_0, tg_xxxxxxxy_xxxxzz_0, \
                                         tg_xxxxxxxy_xxxyyy_0, tg_xxxxxxxy_xxxyyz_0, tg_xxxxxxxy_xxxyzz_0, tg_xxxxxxxy_xxxzzz_0, \
                                         tg_xxxxxxxy_xxyyyy_0, tg_xxxxxxxy_xxyyyz_0, tg_xxxxxxxy_xxyyzz_0, tg_xxxxxxxy_xxyzzz_0, \
                                         tg_xxxxxxxy_xxzzzz_0, tg_xxxxxxxy_xyyyyy_0, tg_xxxxxxxy_xyyyyz_0, tg_xxxxxxxy_xyyyzz_0, \
                                         tg_xxxxxxxy_xyyzzz_0, tg_xxxxxxxy_xyzzzz_0, tg_xxxxxxxy_xzzzzz_0, tg_xxxxxxxy_yyyyyy_0, \
                                         tg_xxxxxxxy_yyyyyz_0, tg_xxxxxxxy_yyyyzz_0, tg_xxxxxxxy_yyyzzz_0, tg_xxxxxxxy_yyzzzz_0, \
                                         tg_xxxxxxxy_yzzzzz_0, tg_xxxxxxxy_zzzzzz_0, tg_xxxxxxxz_xxxxxx_0, tg_xxxxxxxz_xxxxxy_0, \
                                         tg_xxxxxxxz_xxxxxz_0, tg_xxxxxxxz_xxxxyy_0, tg_xxxxxxxz_xxxxyz_0, tg_xxxxxxxz_xxxxzz_0, \
                                         tg_xxxxxxxz_xxxyyy_0, tg_xxxxxxxz_xxxyyz_0, tg_xxxxxxxz_xxxyzz_0, tg_xxxxxxxz_xxxzzz_0, \
                                         tg_xxxxxxxz_xxyyyy_0, tg_xxxxxxxz_xxyyyz_0, tg_xxxxxxxz_xxyyzz_0, tg_xxxxxxxz_xxyzzz_0, \
                                         tg_xxxxxxxz_xxzzzz_0, tg_xxxxxxxz_xyyyyy_0, tg_xxxxxxxz_xyyyyz_0, tg_xxxxxxxz_xyyyzz_0, \
                                         tg_xxxxxxxz_xyyzzz_0, tg_xxxxxxxz_xyzzzz_0, tg_xxxxxxxz_xzzzzz_0, tg_xxxxxxxz_yyyyyy_0, \
                                         tg_xxxxxxxz_yyyyyz_0, tg_xxxxxxxz_yyyyzz_0, tg_xxxxxxxz_yyyzzz_0, tg_xxxxxxxz_yyzzzz_0, \
                                         tg_xxxxxxxz_yzzzzz_0, tg_xxxxxxxz_zzzzzz_0, tg_xxxxxxy_xxxxx_1, tg_xxxxxxy_xxxxxx_0, \
                                         tg_xxxxxxy_xxxxxx_1, tg_xxxxxxy_xxxxxy_0, tg_xxxxxxy_xxxxxy_1, tg_xxxxxxy_xxxxxz_0, \
                                         tg_xxxxxxy_xxxxxz_1, tg_xxxxxxy_xxxxy_1, tg_xxxxxxy_xxxxyy_0, tg_xxxxxxy_xxxxyy_1, \
                                         tg_xxxxxxy_xxxxyz_0, tg_xxxxxxy_xxxxyz_1, tg_xxxxxxy_xxxxz_1, tg_xxxxxxy_xxxxzz_0, \
                                         tg_xxxxxxy_xxxxzz_1, tg_xxxxxxy_xxxyy_1, tg_xxxxxxy_xxxyyy_0, tg_xxxxxxy_xxxyyy_1, \
                                         tg_xxxxxxy_xxxyyz_0, tg_xxxxxxy_xxxyyz_1, tg_xxxxxxy_xxxyz_1, tg_xxxxxxy_xxxyzz_0, \
                                         tg_xxxxxxy_xxxyzz_1, tg_xxxxxxy_xxxzz_1, tg_xxxxxxy_xxxzzz_0, tg_xxxxxxy_xxxzzz_1, \
                                         tg_xxxxxxy_xxyyy_1, tg_xxxxxxy_xxyyyy_0, tg_xxxxxxy_xxyyyy_1, tg_xxxxxxy_xxyyyz_0, \
                                         tg_xxxxxxy_xxyyyz_1, tg_xxxxxxy_xxyyz_1, tg_xxxxxxy_xxyyzz_0, tg_xxxxxxy_xxyyzz_1, \
                                         tg_xxxxxxy_xxyzz_1, tg_xxxxxxy_xxyzzz_0, tg_xxxxxxy_xxyzzz_1, tg_xxxxxxy_xxzzz_1, \
                                         tg_xxxxxxy_xxzzzz_0, tg_xxxxxxy_xxzzzz_1, tg_xxxxxxy_xyyyy_1, tg_xxxxxxy_xyyyyy_0, \
                                         tg_xxxxxxy_xyyyyy_1, tg_xxxxxxy_xyyyyz_0, tg_xxxxxxy_xyyyyz_1, tg_xxxxxxy_xyyyz_1, \
                                         tg_xxxxxxy_xyyyzz_0, tg_xxxxxxy_xyyyzz_1, tg_xxxxxxy_xyyzz_1, tg_xxxxxxy_xyyzzz_0, \
                                         tg_xxxxxxy_xyyzzz_1, tg_xxxxxxy_xyzzz_1, tg_xxxxxxy_xyzzzz_0, tg_xxxxxxy_xyzzzz_1, \
                                         tg_xxxxxxy_xzzzz_1, tg_xxxxxxy_xzzzzz_0, tg_xxxxxxy_xzzzzz_1, tg_xxxxxxy_yyyyy_1, \
                                         tg_xxxxxxy_yyyyyy_0, tg_xxxxxxy_yyyyyy_1, tg_xxxxxxy_yyyyyz_0, tg_xxxxxxy_yyyyyz_1, \
                                         tg_xxxxxxy_yyyyz_1, tg_xxxxxxy_yyyyzz_0, tg_xxxxxxy_yyyyzz_1, tg_xxxxxxy_yyyzz_1, \
                                         tg_xxxxxxy_yyyzzz_0, tg_xxxxxxy_yyyzzz_1, tg_xxxxxxy_yyzzz_1, tg_xxxxxxy_yyzzzz_0, \
                                         tg_xxxxxxy_yyzzzz_1, tg_xxxxxxy_yzzzz_1, tg_xxxxxxy_yzzzzz_0, tg_xxxxxxy_yzzzzz_1, \
                                         tg_xxxxxxy_zzzzz_1, tg_xxxxxxy_zzzzzz_0, tg_xxxxxxy_zzzzzz_1, tg_xxxxxxyy_xxxxxx_0, \
                                         tg_xxxxxxyy_xxxxxy_0, tg_xxxxxxyy_xxxxxz_0, tg_xxxxxxyy_xxxxyy_0, tg_xxxxxxyy_xxxxyz_0, \
                                         tg_xxxxxxyy_xxxxzz_0, tg_xxxxxxyy_xxxyyy_0, tg_xxxxxxyy_xxxyyz_0, tg_xxxxxxyy_xxxyzz_0, \
                                         tg_xxxxxxyy_xxxzzz_0, tg_xxxxxxyy_xxyyyy_0, tg_xxxxxxyy_xxyyyz_0, tg_xxxxxxyy_xxyyzz_0, \
                                         tg_xxxxxxz_xxxxx_1, tg_xxxxxxz_xxxxxx_0, tg_xxxxxxz_xxxxxx_1, tg_xxxxxxz_xxxxxy_0, \
                                         tg_xxxxxxz_xxxxxy_1, tg_xxxxxxz_xxxxxz_0, tg_xxxxxxz_xxxxxz_1, tg_xxxxxxz_xxxxy_1, \
                                         tg_xxxxxxz_xxxxyy_0, tg_xxxxxxz_xxxxyy_1, tg_xxxxxxz_xxxxyz_0, tg_xxxxxxz_xxxxyz_1, \
                                         tg_xxxxxxz_xxxxz_1, tg_xxxxxxz_xxxxzz_0, tg_xxxxxxz_xxxxzz_1, tg_xxxxxxz_xxxyy_1, \
                                         tg_xxxxxxz_xxxyyy_0, tg_xxxxxxz_xxxyyy_1, tg_xxxxxxz_xxxyyz_0, tg_xxxxxxz_xxxyyz_1, \
                                         tg_xxxxxxz_xxxyz_1, tg_xxxxxxz_xxxyzz_0, tg_xxxxxxz_xxxyzz_1, tg_xxxxxxz_xxxzz_1, \
                                         tg_xxxxxxz_xxxzzz_0, tg_xxxxxxz_xxxzzz_1, tg_xxxxxxz_xxyyy_1, tg_xxxxxxz_xxyyyy_0, \
                                         tg_xxxxxxz_xxyyyy_1, tg_xxxxxxz_xxyyyz_0, tg_xxxxxxz_xxyyyz_1, tg_xxxxxxz_xxyyz_1, \
                                         tg_xxxxxxz_xxyyzz_0, tg_xxxxxxz_xxyyzz_1, tg_xxxxxxz_xxyzz_1, tg_xxxxxxz_xxyzzz_0, \
                                         tg_xxxxxxz_xxyzzz_1, tg_xxxxxxz_xxzzz_1, tg_xxxxxxz_xxzzzz_0, tg_xxxxxxz_xxzzzz_1, \
                                         tg_xxxxxxz_xyyyy_1, tg_xxxxxxz_xyyyyy_0, tg_xxxxxxz_xyyyyy_1, tg_xxxxxxz_xyyyyz_0, \
                                         tg_xxxxxxz_xyyyyz_1, tg_xxxxxxz_xyyyz_1, tg_xxxxxxz_xyyyzz_0, tg_xxxxxxz_xyyyzz_1, \
                                         tg_xxxxxxz_xyyzz_1, tg_xxxxxxz_xyyzzz_0, tg_xxxxxxz_xyyzzz_1, tg_xxxxxxz_xyzzz_1, \
                                         tg_xxxxxxz_xyzzzz_0, tg_xxxxxxz_xyzzzz_1, tg_xxxxxxz_xzzzz_1, tg_xxxxxxz_xzzzzz_0, \
                                         tg_xxxxxxz_xzzzzz_1, tg_xxxxxxz_yyyyy_1, tg_xxxxxxz_yyyyyy_0, tg_xxxxxxz_yyyyyy_1, \
                                         tg_xxxxxxz_yyyyyz_0, tg_xxxxxxz_yyyyyz_1, tg_xxxxxxz_yyyyz_1, tg_xxxxxxz_yyyyzz_0, \
                                         tg_xxxxxxz_yyyyzz_1, tg_xxxxxxz_yyyzz_1, tg_xxxxxxz_yyyzzz_0, tg_xxxxxxz_yyyzzz_1, \
                                         tg_xxxxxxz_yyzzz_1, tg_xxxxxxz_yyzzzz_0, tg_xxxxxxz_yyzzzz_1, tg_xxxxxxz_yzzzz_1, \
                                         tg_xxxxxxz_yzzzzz_0, tg_xxxxxxz_yzzzzz_1, tg_xxxxxxz_zzzzz_1, tg_xxxxxxz_zzzzzz_0, \
                                         tg_xxxxxxz_zzzzzz_1, tg_xxxxxy_xxxxxx_0, tg_xxxxxy_xxxxxx_1, tg_xxxxxy_xxxxxy_0, \
                                         tg_xxxxxy_xxxxxy_1, tg_xxxxxy_xxxxxz_0, tg_xxxxxy_xxxxxz_1, tg_xxxxxy_xxxxyy_0, \
                                         tg_xxxxxy_xxxxyy_1, tg_xxxxxy_xxxxyz_0, tg_xxxxxy_xxxxyz_1, tg_xxxxxy_xxxxzz_0, \
                                         tg_xxxxxy_xxxxzz_1, tg_xxxxxy_xxxyyy_0, tg_xxxxxy_xxxyyy_1, tg_xxxxxy_xxxyyz_0, \
                                         tg_xxxxxy_xxxyyz_1, tg_xxxxxy_xxxyzz_0, tg_xxxxxy_xxxyzz_1, tg_xxxxxy_xxxzzz_0, \
                                         tg_xxxxxy_xxxzzz_1, tg_xxxxxy_xxyyyy_0, tg_xxxxxy_xxyyyy_1, tg_xxxxxy_xxyyyz_0, \
                                         tg_xxxxxy_xxyyyz_1, tg_xxxxxy_xxyyzz_0, tg_xxxxxy_xxyyzz_1, tg_xxxxxy_xxyzzz_0, \
                                         tg_xxxxxy_xxyzzz_1, tg_xxxxxy_xxzzzz_0, tg_xxxxxy_xxzzzz_1, tg_xxxxxy_xyyyyy_0, \
                                         tg_xxxxxy_xyyyyy_1, tg_xxxxxy_xyyyyz_0, tg_xxxxxy_xyyyyz_1, tg_xxxxxy_xyyyzz_0, \
                                         tg_xxxxxy_xyyyzz_1, tg_xxxxxy_xyyzzz_0, tg_xxxxxy_xyyzzz_1, tg_xxxxxy_xyzzzz_0, \
                                         tg_xxxxxy_xyzzzz_1, tg_xxxxxy_xzzzzz_0, tg_xxxxxy_xzzzzz_1, tg_xxxxxy_yyyyyy_0, \
                                         tg_xxxxxy_yyyyyy_1, tg_xxxxxy_yyyyyz_0, tg_xxxxxy_yyyyyz_1, tg_xxxxxy_yyyyzz_0, \
                                         tg_xxxxxy_yyyyzz_1, tg_xxxxxy_yyyzzz_0, tg_xxxxxy_yyyzzz_1, tg_xxxxxy_yyzzzz_0, \
                                         tg_xxxxxy_yyzzzz_1, tg_xxxxxy_yzzzzz_0, tg_xxxxxy_yzzzzz_1, tg_xxxxxy_zzzzzz_0, \
                                         tg_xxxxxy_zzzzzz_1, tg_xxxxxyy_xxxxx_1, tg_xxxxxyy_xxxxxx_0, tg_xxxxxyy_xxxxxx_1, \
                                         tg_xxxxxyy_xxxxxy_0, tg_xxxxxyy_xxxxxy_1, tg_xxxxxyy_xxxxxz_0, tg_xxxxxyy_xxxxxz_1, \
                                         tg_xxxxxyy_xxxxy_1, tg_xxxxxyy_xxxxyy_0, tg_xxxxxyy_xxxxyy_1, tg_xxxxxyy_xxxxyz_0, \
                                         tg_xxxxxyy_xxxxyz_1, tg_xxxxxyy_xxxxz_1, tg_xxxxxyy_xxxxzz_0, tg_xxxxxyy_xxxxzz_1, \
                                         tg_xxxxxyy_xxxyy_1, tg_xxxxxyy_xxxyyy_0, tg_xxxxxyy_xxxyyy_1, tg_xxxxxyy_xxxyyz_0, \
                                         tg_xxxxxyy_xxxyyz_1, tg_xxxxxyy_xxxyz_1, tg_xxxxxyy_xxxyzz_0, tg_xxxxxyy_xxxyzz_1, \
                                         tg_xxxxxyy_xxxzz_1, tg_xxxxxyy_xxxzzz_0, tg_xxxxxyy_xxxzzz_1, tg_xxxxxyy_xxyyy_1, \
                                         tg_xxxxxyy_xxyyyy_0, tg_xxxxxyy_xxyyyy_1, tg_xxxxxyy_xxyyyz_0, tg_xxxxxyy_xxyyyz_1, \
                                         tg_xxxxxyy_xxyyz_1, tg_xxxxxyy_xxyyzz_0, tg_xxxxxyy_xxyyzz_1, tg_xxxxxyy_xxyzz_1, \
                                         tg_xxxxxyy_xxzzz_1, tg_xxxxxyy_xyyyy_1, tg_xxxxxyy_xyyyz_1, tg_xxxxxyy_xyyzz_1, \
                                         tg_xxxxxz_xxxxxx_0, tg_xxxxxz_xxxxxx_1, tg_xxxxxz_xxxxxy_0, tg_xxxxxz_xxxxxy_1, \
                                         tg_xxxxxz_xxxxxz_0, tg_xxxxxz_xxxxxz_1, tg_xxxxxz_xxxxyy_0, tg_xxxxxz_xxxxyy_1, \
                                         tg_xxxxxz_xxxxyz_0, tg_xxxxxz_xxxxyz_1, tg_xxxxxz_xxxxzz_0, tg_xxxxxz_xxxxzz_1, \
                                         tg_xxxxxz_xxxyyy_0, tg_xxxxxz_xxxyyy_1, tg_xxxxxz_xxxyyz_0, tg_xxxxxz_xxxyyz_1, \
                                         tg_xxxxxz_xxxyzz_0, tg_xxxxxz_xxxyzz_1, tg_xxxxxz_xxxzzz_0, tg_xxxxxz_xxxzzz_1, \
                                         tg_xxxxxz_xxyyyy_0, tg_xxxxxz_xxyyyy_1, tg_xxxxxz_xxyyyz_0, tg_xxxxxz_xxyyyz_1, \
                                         tg_xxxxxz_xxyyzz_0, tg_xxxxxz_xxyyzz_1, tg_xxxxxz_xxyzzz_0, tg_xxxxxz_xxyzzz_1, \
                                         tg_xxxxxz_xxzzzz_0, tg_xxxxxz_xxzzzz_1, tg_xxxxxz_xyyyyy_0, tg_xxxxxz_xyyyyy_1, \
                                         tg_xxxxxz_xyyyyz_0, tg_xxxxxz_xyyyyz_1, tg_xxxxxz_xyyyzz_0, tg_xxxxxz_xyyyzz_1, \
                                         tg_xxxxxz_xyyzzz_0, tg_xxxxxz_xyyzzz_1, tg_xxxxxz_xyzzzz_0, tg_xxxxxz_xyzzzz_1, \
                                         tg_xxxxxz_xzzzzz_0, tg_xxxxxz_xzzzzz_1, tg_xxxxxz_yyyyyy_0, tg_xxxxxz_yyyyyy_1, \
                                         tg_xxxxxz_yyyyyz_0, tg_xxxxxz_yyyyyz_1, tg_xxxxxz_yyyyzz_0, tg_xxxxxz_yyyyzz_1, \
                                         tg_xxxxxz_yyyzzz_0, tg_xxxxxz_yyyzzz_1, tg_xxxxxz_yyzzzz_0, tg_xxxxxz_yyzzzz_1, \
                                         tg_xxxxxz_yzzzzz_0, tg_xxxxxz_yzzzzz_1, tg_xxxxxz_zzzzzz_0, tg_xxxxxz_zzzzzz_1, \
                                         tg_xxxxyy_xxxxxx_0, tg_xxxxyy_xxxxxx_1, tg_xxxxyy_xxxxxy_0, tg_xxxxyy_xxxxxy_1, \
                                         tg_xxxxyy_xxxxxz_0, tg_xxxxyy_xxxxxz_1, tg_xxxxyy_xxxxyy_0, tg_xxxxyy_xxxxyy_1, \
                                         tg_xxxxyy_xxxxyz_0, tg_xxxxyy_xxxxyz_1, tg_xxxxyy_xxxxzz_0, tg_xxxxyy_xxxxzz_1, \
                                         tg_xxxxyy_xxxyyy_0, tg_xxxxyy_xxxyyy_1, tg_xxxxyy_xxxyyz_0, tg_xxxxyy_xxxyyz_1, \
                                         tg_xxxxyy_xxxyzz_0, tg_xxxxyy_xxxyzz_1, tg_xxxxyy_xxxzzz_0, tg_xxxxyy_xxxzzz_1, \
                                         tg_xxxxyy_xxyyyy_0, tg_xxxxyy_xxyyyy_1, tg_xxxxyy_xxyyyz_0, tg_xxxxyy_xxyyyz_1, \
                                         tg_xxxxyy_xxyyzz_0, tg_xxxxyy_xxyyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxxx_xxxxxx_0[j] = pb_x * tg_xxxxxxx_xxxxxx_0[j] + fr * tg_xxxxxxx_xxxxxx_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxxx_0[j] - tg_xxxxxx_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxxx_xxxxx_1[j];

                    tg_xxxxxxxx_xxxxxy_0[j] = pb_x * tg_xxxxxxx_xxxxxy_0[j] + fr * tg_xxxxxxx_xxxxxy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxxy_0[j] - tg_xxxxxx_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxx_xxxxy_1[j];

                    tg_xxxxxxxx_xxxxxz_0[j] = pb_x * tg_xxxxxxx_xxxxxz_0[j] + fr * tg_xxxxxxx_xxxxxz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxxz_0[j] - tg_xxxxxx_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxx_xxxxz_1[j];

                    tg_xxxxxxxx_xxxxyy_0[j] = pb_x * tg_xxxxxxx_xxxxyy_0[j] + fr * tg_xxxxxxx_xxxxyy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxyy_0[j] - tg_xxxxxx_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxx_xxxyy_1[j];

                    tg_xxxxxxxx_xxxxyz_0[j] = pb_x * tg_xxxxxxx_xxxxyz_0[j] + fr * tg_xxxxxxx_xxxxyz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxyz_0[j] - tg_xxxxxx_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxx_xxxyz_1[j];

                    tg_xxxxxxxx_xxxxzz_0[j] = pb_x * tg_xxxxxxx_xxxxzz_0[j] + fr * tg_xxxxxxx_xxxxzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxxzz_0[j] - tg_xxxxxx_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxx_xxxzz_1[j];

                    tg_xxxxxxxx_xxxyyy_0[j] = pb_x * tg_xxxxxxx_xxxyyy_0[j] + fr * tg_xxxxxxx_xxxyyy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxyyy_0[j] - tg_xxxxxx_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxx_xxyyy_1[j];

                    tg_xxxxxxxx_xxxyyz_0[j] = pb_x * tg_xxxxxxx_xxxyyz_0[j] + fr * tg_xxxxxxx_xxxyyz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxyyz_0[j] - tg_xxxxxx_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxx_xxyyz_1[j];

                    tg_xxxxxxxx_xxxyzz_0[j] = pb_x * tg_xxxxxxx_xxxyzz_0[j] + fr * tg_xxxxxxx_xxxyzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxyzz_0[j] - tg_xxxxxx_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxx_xxyzz_1[j];

                    tg_xxxxxxxx_xxxzzz_0[j] = pb_x * tg_xxxxxxx_xxxzzz_0[j] + fr * tg_xxxxxxx_xxxzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxxzzz_0[j] - tg_xxxxxx_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxx_xxzzz_1[j];

                    tg_xxxxxxxx_xxyyyy_0[j] = pb_x * tg_xxxxxxx_xxyyyy_0[j] + fr * tg_xxxxxxx_xxyyyy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxyyyy_0[j] - tg_xxxxxx_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_xyyyy_1[j];

                    tg_xxxxxxxx_xxyyyz_0[j] = pb_x * tg_xxxxxxx_xxyyyz_0[j] + fr * tg_xxxxxxx_xxyyyz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxyyyz_0[j] - tg_xxxxxx_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_xyyyz_1[j];

                    tg_xxxxxxxx_xxyyzz_0[j] = pb_x * tg_xxxxxxx_xxyyzz_0[j] + fr * tg_xxxxxxx_xxyyzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxyyzz_0[j] - tg_xxxxxx_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_xyyzz_1[j];

                    tg_xxxxxxxx_xxyzzz_0[j] = pb_x * tg_xxxxxxx_xxyzzz_0[j] + fr * tg_xxxxxxx_xxyzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxyzzz_0[j] - tg_xxxxxx_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_xyzzz_1[j];

                    tg_xxxxxxxx_xxzzzz_0[j] = pb_x * tg_xxxxxxx_xxzzzz_0[j] + fr * tg_xxxxxxx_xxzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xxzzzz_0[j] - tg_xxxxxx_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxx_xzzzz_1[j];

                    tg_xxxxxxxx_xyyyyy_0[j] = pb_x * tg_xxxxxxx_xyyyyy_0[j] + fr * tg_xxxxxxx_xyyyyy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xyyyyy_0[j] - tg_xxxxxx_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_yyyyy_1[j];

                    tg_xxxxxxxx_xyyyyz_0[j] = pb_x * tg_xxxxxxx_xyyyyz_0[j] + fr * tg_xxxxxxx_xyyyyz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xyyyyz_0[j] - tg_xxxxxx_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_yyyyz_1[j];

                    tg_xxxxxxxx_xyyyzz_0[j] = pb_x * tg_xxxxxxx_xyyyzz_0[j] + fr * tg_xxxxxxx_xyyyzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xyyyzz_0[j] - tg_xxxxxx_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_yyyzz_1[j];

                    tg_xxxxxxxx_xyyzzz_0[j] = pb_x * tg_xxxxxxx_xyyzzz_0[j] + fr * tg_xxxxxxx_xyyzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xyyzzz_0[j] - tg_xxxxxx_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_yyzzz_1[j];

                    tg_xxxxxxxx_xyzzzz_0[j] = pb_x * tg_xxxxxxx_xyzzzz_0[j] + fr * tg_xxxxxxx_xyzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xyzzzz_0[j] - tg_xxxxxx_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_yzzzz_1[j];

                    tg_xxxxxxxx_xzzzzz_0[j] = pb_x * tg_xxxxxxx_xzzzzz_0[j] + fr * tg_xxxxxxx_xzzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_xzzzzz_0[j] - tg_xxxxxx_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxx_zzzzz_1[j];

                    tg_xxxxxxxx_yyyyyy_0[j] = pb_x * tg_xxxxxxx_yyyyyy_0[j] + fr * tg_xxxxxxx_yyyyyy_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yyyyyy_0[j] - tg_xxxxxx_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxxx_yyyyyz_0[j] = pb_x * tg_xxxxxxx_yyyyyz_0[j] + fr * tg_xxxxxxx_yyyyyz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yyyyyz_0[j] - tg_xxxxxx_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxxx_yyyyzz_0[j] = pb_x * tg_xxxxxxx_yyyyzz_0[j] + fr * tg_xxxxxxx_yyyyzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yyyyzz_0[j] - tg_xxxxxx_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxxx_yyyzzz_0[j] = pb_x * tg_xxxxxxx_yyyzzz_0[j] + fr * tg_xxxxxxx_yyyzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yyyzzz_0[j] - tg_xxxxxx_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxxx_yyzzzz_0[j] = pb_x * tg_xxxxxxx_yyzzzz_0[j] + fr * tg_xxxxxxx_yyzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yyzzzz_0[j] - tg_xxxxxx_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxx_yzzzzz_0[j] = pb_x * tg_xxxxxxx_yzzzzz_0[j] + fr * tg_xxxxxxx_yzzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_yzzzzz_0[j] - tg_xxxxxx_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxx_zzzzzz_0[j] = pb_x * tg_xxxxxxx_zzzzzz_0[j] + fr * tg_xxxxxxx_zzzzzz_1[j] + 3.5 * fl1_fx * (tg_xxxxxx_zzzzzz_0[j] - tg_xxxxxx_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxy_xxxxxx_0[j] = pb_x * tg_xxxxxxy_xxxxxx_0[j] + fr * tg_xxxxxxy_xxxxxx_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxxx_0[j] - tg_xxxxxy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxxy_xxxxx_1[j];

                    tg_xxxxxxxy_xxxxxy_0[j] = pb_x * tg_xxxxxxy_xxxxxy_0[j] + fr * tg_xxxxxxy_xxxxxy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxxy_0[j] - tg_xxxxxy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxy_xxxxy_1[j];

                    tg_xxxxxxxy_xxxxxz_0[j] = pb_x * tg_xxxxxxy_xxxxxz_0[j] + fr * tg_xxxxxxy_xxxxxz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxxz_0[j] - tg_xxxxxy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxy_xxxxz_1[j];

                    tg_xxxxxxxy_xxxxyy_0[j] = pb_x * tg_xxxxxxy_xxxxyy_0[j] + fr * tg_xxxxxxy_xxxxyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxyy_0[j] - tg_xxxxxy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxy_xxxyy_1[j];

                    tg_xxxxxxxy_xxxxyz_0[j] = pb_x * tg_xxxxxxy_xxxxyz_0[j] + fr * tg_xxxxxxy_xxxxyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxyz_0[j] - tg_xxxxxy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxy_xxxyz_1[j];

                    tg_xxxxxxxy_xxxxzz_0[j] = pb_x * tg_xxxxxxy_xxxxzz_0[j] + fr * tg_xxxxxxy_xxxxzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxxzz_0[j] - tg_xxxxxy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxy_xxxzz_1[j];

                    tg_xxxxxxxy_xxxyyy_0[j] = pb_x * tg_xxxxxxy_xxxyyy_0[j] + fr * tg_xxxxxxy_xxxyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxyyy_0[j] - tg_xxxxxy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxy_xxyyy_1[j];

                    tg_xxxxxxxy_xxxyyz_0[j] = pb_x * tg_xxxxxxy_xxxyyz_0[j] + fr * tg_xxxxxxy_xxxyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxyyz_0[j] - tg_xxxxxy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxy_xxyyz_1[j];

                    tg_xxxxxxxy_xxxyzz_0[j] = pb_x * tg_xxxxxxy_xxxyzz_0[j] + fr * tg_xxxxxxy_xxxyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxyzz_0[j] - tg_xxxxxy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxy_xxyzz_1[j];

                    tg_xxxxxxxy_xxxzzz_0[j] = pb_x * tg_xxxxxxy_xxxzzz_0[j] + fr * tg_xxxxxxy_xxxzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxxzzz_0[j] - tg_xxxxxy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxy_xxzzz_1[j];

                    tg_xxxxxxxy_xxyyyy_0[j] = pb_x * tg_xxxxxxy_xxyyyy_0[j] + fr * tg_xxxxxxy_xxyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxyyyy_0[j] - tg_xxxxxy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_xyyyy_1[j];

                    tg_xxxxxxxy_xxyyyz_0[j] = pb_x * tg_xxxxxxy_xxyyyz_0[j] + fr * tg_xxxxxxy_xxyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxyyyz_0[j] - tg_xxxxxy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_xyyyz_1[j];

                    tg_xxxxxxxy_xxyyzz_0[j] = pb_x * tg_xxxxxxy_xxyyzz_0[j] + fr * tg_xxxxxxy_xxyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxyyzz_0[j] - tg_xxxxxy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_xyyzz_1[j];

                    tg_xxxxxxxy_xxyzzz_0[j] = pb_x * tg_xxxxxxy_xxyzzz_0[j] + fr * tg_xxxxxxy_xxyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxyzzz_0[j] - tg_xxxxxy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_xyzzz_1[j];

                    tg_xxxxxxxy_xxzzzz_0[j] = pb_x * tg_xxxxxxy_xxzzzz_0[j] + fr * tg_xxxxxxy_xxzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xxzzzz_0[j] - tg_xxxxxy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxy_xzzzz_1[j];

                    tg_xxxxxxxy_xyyyyy_0[j] = pb_x * tg_xxxxxxy_xyyyyy_0[j] + fr * tg_xxxxxxy_xyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xyyyyy_0[j] - tg_xxxxxy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_yyyyy_1[j];

                    tg_xxxxxxxy_xyyyyz_0[j] = pb_x * tg_xxxxxxy_xyyyyz_0[j] + fr * tg_xxxxxxy_xyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xyyyyz_0[j] - tg_xxxxxy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_yyyyz_1[j];

                    tg_xxxxxxxy_xyyyzz_0[j] = pb_x * tg_xxxxxxy_xyyyzz_0[j] + fr * tg_xxxxxxy_xyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xyyyzz_0[j] - tg_xxxxxy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_yyyzz_1[j];

                    tg_xxxxxxxy_xyyzzz_0[j] = pb_x * tg_xxxxxxy_xyyzzz_0[j] + fr * tg_xxxxxxy_xyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xyyzzz_0[j] - tg_xxxxxy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_yyzzz_1[j];

                    tg_xxxxxxxy_xyzzzz_0[j] = pb_x * tg_xxxxxxy_xyzzzz_0[j] + fr * tg_xxxxxxy_xyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xyzzzz_0[j] - tg_xxxxxy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_yzzzz_1[j];

                    tg_xxxxxxxy_xzzzzz_0[j] = pb_x * tg_xxxxxxy_xzzzzz_0[j] + fr * tg_xxxxxxy_xzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_xzzzzz_0[j] - tg_xxxxxy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxy_zzzzz_1[j];

                    tg_xxxxxxxy_yyyyyy_0[j] = pb_x * tg_xxxxxxy_yyyyyy_0[j] + fr * tg_xxxxxxy_yyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yyyyyy_0[j] - tg_xxxxxy_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxxy_yyyyyz_0[j] = pb_x * tg_xxxxxxy_yyyyyz_0[j] + fr * tg_xxxxxxy_yyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yyyyyz_0[j] - tg_xxxxxy_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxxy_yyyyzz_0[j] = pb_x * tg_xxxxxxy_yyyyzz_0[j] + fr * tg_xxxxxxy_yyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yyyyzz_0[j] - tg_xxxxxy_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxxy_yyyzzz_0[j] = pb_x * tg_xxxxxxy_yyyzzz_0[j] + fr * tg_xxxxxxy_yyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yyyzzz_0[j] - tg_xxxxxy_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxxy_yyzzzz_0[j] = pb_x * tg_xxxxxxy_yyzzzz_0[j] + fr * tg_xxxxxxy_yyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yyzzzz_0[j] - tg_xxxxxy_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxy_yzzzzz_0[j] = pb_x * tg_xxxxxxy_yzzzzz_0[j] + fr * tg_xxxxxxy_yzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_yzzzzz_0[j] - tg_xxxxxy_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxy_zzzzzz_0[j] = pb_x * tg_xxxxxxy_zzzzzz_0[j] + fr * tg_xxxxxxy_zzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxy_zzzzzz_0[j] - tg_xxxxxy_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxz_xxxxxx_0[j] = pb_x * tg_xxxxxxz_xxxxxx_0[j] + fr * tg_xxxxxxz_xxxxxx_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxxx_0[j] - tg_xxxxxz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxxz_xxxxx_1[j];

                    tg_xxxxxxxz_xxxxxy_0[j] = pb_x * tg_xxxxxxz_xxxxxy_0[j] + fr * tg_xxxxxxz_xxxxxy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxxy_0[j] - tg_xxxxxz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxz_xxxxy_1[j];

                    tg_xxxxxxxz_xxxxxz_0[j] = pb_x * tg_xxxxxxz_xxxxxz_0[j] + fr * tg_xxxxxxz_xxxxxz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxxz_0[j] - tg_xxxxxz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxxz_xxxxz_1[j];

                    tg_xxxxxxxz_xxxxyy_0[j] = pb_x * tg_xxxxxxz_xxxxyy_0[j] + fr * tg_xxxxxxz_xxxxyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxyy_0[j] - tg_xxxxxz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxz_xxxyy_1[j];

                    tg_xxxxxxxz_xxxxyz_0[j] = pb_x * tg_xxxxxxz_xxxxyz_0[j] + fr * tg_xxxxxxz_xxxxyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxyz_0[j] - tg_xxxxxz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxz_xxxyz_1[j];

                    tg_xxxxxxxz_xxxxzz_0[j] = pb_x * tg_xxxxxxz_xxxxzz_0[j] + fr * tg_xxxxxxz_xxxxzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxxzz_0[j] - tg_xxxxxz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxxz_xxxzz_1[j];

                    tg_xxxxxxxz_xxxyyy_0[j] = pb_x * tg_xxxxxxz_xxxyyy_0[j] + fr * tg_xxxxxxz_xxxyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxyyy_0[j] - tg_xxxxxz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxz_xxyyy_1[j];

                    tg_xxxxxxxz_xxxyyz_0[j] = pb_x * tg_xxxxxxz_xxxyyz_0[j] + fr * tg_xxxxxxz_xxxyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxyyz_0[j] - tg_xxxxxz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxz_xxyyz_1[j];

                    tg_xxxxxxxz_xxxyzz_0[j] = pb_x * tg_xxxxxxz_xxxyzz_0[j] + fr * tg_xxxxxxz_xxxyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxyzz_0[j] - tg_xxxxxz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxz_xxyzz_1[j];

                    tg_xxxxxxxz_xxxzzz_0[j] = pb_x * tg_xxxxxxz_xxxzzz_0[j] + fr * tg_xxxxxxz_xxxzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxxzzz_0[j] - tg_xxxxxz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxxz_xxzzz_1[j];

                    tg_xxxxxxxz_xxyyyy_0[j] = pb_x * tg_xxxxxxz_xxyyyy_0[j] + fr * tg_xxxxxxz_xxyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxyyyy_0[j] - tg_xxxxxz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_xyyyy_1[j];

                    tg_xxxxxxxz_xxyyyz_0[j] = pb_x * tg_xxxxxxz_xxyyyz_0[j] + fr * tg_xxxxxxz_xxyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxyyyz_0[j] - tg_xxxxxz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_xyyyz_1[j];

                    tg_xxxxxxxz_xxyyzz_0[j] = pb_x * tg_xxxxxxz_xxyyzz_0[j] + fr * tg_xxxxxxz_xxyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxyyzz_0[j] - tg_xxxxxz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_xyyzz_1[j];

                    tg_xxxxxxxz_xxyzzz_0[j] = pb_x * tg_xxxxxxz_xxyzzz_0[j] + fr * tg_xxxxxxz_xxyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxyzzz_0[j] - tg_xxxxxz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_xyzzz_1[j];

                    tg_xxxxxxxz_xxzzzz_0[j] = pb_x * tg_xxxxxxz_xxzzzz_0[j] + fr * tg_xxxxxxz_xxzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xxzzzz_0[j] - tg_xxxxxz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxxz_xzzzz_1[j];

                    tg_xxxxxxxz_xyyyyy_0[j] = pb_x * tg_xxxxxxz_xyyyyy_0[j] + fr * tg_xxxxxxz_xyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xyyyyy_0[j] - tg_xxxxxz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_yyyyy_1[j];

                    tg_xxxxxxxz_xyyyyz_0[j] = pb_x * tg_xxxxxxz_xyyyyz_0[j] + fr * tg_xxxxxxz_xyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xyyyyz_0[j] - tg_xxxxxz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_yyyyz_1[j];

                    tg_xxxxxxxz_xyyyzz_0[j] = pb_x * tg_xxxxxxz_xyyyzz_0[j] + fr * tg_xxxxxxz_xyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xyyyzz_0[j] - tg_xxxxxz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_yyyzz_1[j];

                    tg_xxxxxxxz_xyyzzz_0[j] = pb_x * tg_xxxxxxz_xyyzzz_0[j] + fr * tg_xxxxxxz_xyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xyyzzz_0[j] - tg_xxxxxz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_yyzzz_1[j];

                    tg_xxxxxxxz_xyzzzz_0[j] = pb_x * tg_xxxxxxz_xyzzzz_0[j] + fr * tg_xxxxxxz_xyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xyzzzz_0[j] - tg_xxxxxz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_yzzzz_1[j];

                    tg_xxxxxxxz_xzzzzz_0[j] = pb_x * tg_xxxxxxz_xzzzzz_0[j] + fr * tg_xxxxxxz_xzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_xzzzzz_0[j] - tg_xxxxxz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxxz_zzzzz_1[j];

                    tg_xxxxxxxz_yyyyyy_0[j] = pb_x * tg_xxxxxxz_yyyyyy_0[j] + fr * tg_xxxxxxz_yyyyyy_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yyyyyy_0[j] - tg_xxxxxz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxxz_yyyyyz_0[j] = pb_x * tg_xxxxxxz_yyyyyz_0[j] + fr * tg_xxxxxxz_yyyyyz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yyyyyz_0[j] - tg_xxxxxz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxxz_yyyyzz_0[j] = pb_x * tg_xxxxxxz_yyyyzz_0[j] + fr * tg_xxxxxxz_yyyyzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yyyyzz_0[j] - tg_xxxxxz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxxz_yyyzzz_0[j] = pb_x * tg_xxxxxxz_yyyzzz_0[j] + fr * tg_xxxxxxz_yyyzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yyyzzz_0[j] - tg_xxxxxz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxxz_yyzzzz_0[j] = pb_x * tg_xxxxxxz_yyzzzz_0[j] + fr * tg_xxxxxxz_yyzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yyzzzz_0[j] - tg_xxxxxz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxz_yzzzzz_0[j] = pb_x * tg_xxxxxxz_yzzzzz_0[j] + fr * tg_xxxxxxz_yzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_yzzzzz_0[j] - tg_xxxxxz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxxz_zzzzzz_0[j] = pb_x * tg_xxxxxxz_zzzzzz_0[j] + fr * tg_xxxxxxz_zzzzzz_1[j] + 3.0 * fl1_fx * (tg_xxxxxz_zzzzzz_0[j] - tg_xxxxxz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyy_xxxxxx_0[j] = pb_x * tg_xxxxxyy_xxxxxx_0[j] + fr * tg_xxxxxyy_xxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxxx_0[j] - tg_xxxxyy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxyy_xxxxx_1[j];

                    tg_xxxxxxyy_xxxxxy_0[j] = pb_x * tg_xxxxxyy_xxxxxy_0[j] + fr * tg_xxxxxyy_xxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxxy_0[j] - tg_xxxxyy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxyy_xxxxy_1[j];

                    tg_xxxxxxyy_xxxxxz_0[j] = pb_x * tg_xxxxxyy_xxxxxz_0[j] + fr * tg_xxxxxyy_xxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxxz_0[j] - tg_xxxxyy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxyy_xxxxz_1[j];

                    tg_xxxxxxyy_xxxxyy_0[j] = pb_x * tg_xxxxxyy_xxxxyy_0[j] + fr * tg_xxxxxyy_xxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxyy_0[j] - tg_xxxxyy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyy_xxxyy_1[j];

                    tg_xxxxxxyy_xxxxyz_0[j] = pb_x * tg_xxxxxyy_xxxxyz_0[j] + fr * tg_xxxxxyy_xxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxyz_0[j] - tg_xxxxyy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyy_xxxyz_1[j];

                    tg_xxxxxxyy_xxxxzz_0[j] = pb_x * tg_xxxxxyy_xxxxzz_0[j] + fr * tg_xxxxxyy_xxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxxzz_0[j] - tg_xxxxyy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyy_xxxzz_1[j];

                    tg_xxxxxxyy_xxxyyy_0[j] = pb_x * tg_xxxxxyy_xxxyyy_0[j] + fr * tg_xxxxxyy_xxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxyyy_0[j] - tg_xxxxyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyy_xxyyy_1[j];

                    tg_xxxxxxyy_xxxyyz_0[j] = pb_x * tg_xxxxxyy_xxxyyz_0[j] + fr * tg_xxxxxyy_xxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxyyz_0[j] - tg_xxxxyy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyy_xxyyz_1[j];

                    tg_xxxxxxyy_xxxyzz_0[j] = pb_x * tg_xxxxxyy_xxxyzz_0[j] + fr * tg_xxxxxyy_xxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxyzz_0[j] - tg_xxxxyy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyy_xxyzz_1[j];

                    tg_xxxxxxyy_xxxzzz_0[j] = pb_x * tg_xxxxxyy_xxxzzz_0[j] + fr * tg_xxxxxyy_xxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxxzzz_0[j] - tg_xxxxyy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyy_xxzzz_1[j];

                    tg_xxxxxxyy_xxyyyy_0[j] = pb_x * tg_xxxxxyy_xxyyyy_0[j] + fr * tg_xxxxxyy_xxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxyyyy_0[j] - tg_xxxxyy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_xyyyy_1[j];

                    tg_xxxxxxyy_xxyyyz_0[j] = pb_x * tg_xxxxxyy_xxyyyz_0[j] + fr * tg_xxxxxyy_xxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxyyyz_0[j] - tg_xxxxyy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_xyyyz_1[j];

                    tg_xxxxxxyy_xxyyzz_0[j] = pb_x * tg_xxxxxyy_xxyyzz_0[j] + fr * tg_xxxxxyy_xxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxyyzz_0[j] - tg_xxxxyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_xyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_97_194(      CMemBlock2D<double>* primBuffer,
                                        const CRecursionMap&       recursionMap,
                                        const CMemBlock2D<double>& osFactors,
                                        const CMemBlock2D<double>& wpDistances,
                                        const CGtoPairsBlock&      braGtoPairsBlock,
                                        const CGtoPairsBlock&      ketGtoPairsBlock,
                                        const int32_t              nKetPrimPairs,
                                        const int32_t              iContrPair)
    {
        // Batch of Integrals (97,194)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxxyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 97); 

                auto tg_xxxxxyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 98); 

                auto tg_xxxxxyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 99); 

                auto tg_xxxxxyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 100); 

                auto tg_xxxxxyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 101); 

                auto tg_xxxxxyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 102); 

                auto tg_xxxxxyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 103); 

                auto tg_xxxxxyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 104); 

                auto tg_xxxxxyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 105); 

                auto tg_xxxxxyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 106); 

                auto tg_xxxxxyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 107); 

                auto tg_xxxxxyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 108); 

                auto tg_xxxxxyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 109); 

                auto tg_xxxxxyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 110); 

                auto tg_xxxxxyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 111); 

                auto tg_xxxxxyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 112); 

                auto tg_xxxxxyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 113); 

                auto tg_xxxxxyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 114); 

                auto tg_xxxxxyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 115); 

                auto tg_xxxxxyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 116); 

                auto tg_xxxxxyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 117); 

                auto tg_xxxxxyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 118); 

                auto tg_xxxxxyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 119); 

                auto tg_xxxxxyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 120); 

                auto tg_xxxxxyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 121); 

                auto tg_xxxxxyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 122); 

                auto tg_xxxxxyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 123); 

                auto tg_xxxxxyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 124); 

                auto tg_xxxxxyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 125); 

                auto tg_xxxxxyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 126); 

                auto tg_xxxxxyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 127); 

                auto tg_xxxxxyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 128); 

                auto tg_xxxxxyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 129); 

                auto tg_xxxxxyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 130); 

                auto tg_xxxxxyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 131); 

                auto tg_xxxxxyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 132); 

                auto tg_xxxxxyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 133); 

                auto tg_xxxxxyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 134); 

                auto tg_xxxxxyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 135); 

                auto tg_xxxxxyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 136); 

                auto tg_xxxxxyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 137); 

                auto tg_xxxxxyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 138); 

                auto tg_xxxxxyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 139); 

                auto tg_xxxxxzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 140); 

                auto tg_xxxxxzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 141); 

                auto tg_xxxxxzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 142); 

                auto tg_xxxxxzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 143); 

                auto tg_xxxxxzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 144); 

                auto tg_xxxxxzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 145); 

                auto tg_xxxxxzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 146); 

                auto tg_xxxxxzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 147); 

                auto tg_xxxxxzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 148); 

                auto tg_xxxxxzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 149); 

                auto tg_xxxxxzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 150); 

                auto tg_xxxxxzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 151); 

                auto tg_xxxxxzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 152); 

                auto tg_xxxxxzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 153); 

                auto tg_xxxxxzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 154); 

                auto tg_xxxxxzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 155); 

                auto tg_xxxxxzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 156); 

                auto tg_xxxxxzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 157); 

                auto tg_xxxxxzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 158); 

                auto tg_xxxxxzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 159); 

                auto tg_xxxxxzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 160); 

                auto tg_xxxxxzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 161); 

                auto tg_xxxxxzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 162); 

                auto tg_xxxxxzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 163); 

                auto tg_xxxxxzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 164); 

                auto tg_xxxxxzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 165); 

                auto tg_xxxxxzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 166); 

                auto tg_xxxxxzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 167); 

                auto tg_xxxxyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 168); 

                auto tg_xxxxyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 169); 

                auto tg_xxxxyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 170); 

                auto tg_xxxxyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 171); 

                auto tg_xxxxyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 172); 

                auto tg_xxxxyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 173); 

                auto tg_xxxxyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 174); 

                auto tg_xxxxyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 175); 

                auto tg_xxxxyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 176); 

                auto tg_xxxxyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 177); 

                auto tg_xxxxyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 178); 

                auto tg_xxxxyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 179); 

                auto tg_xxxxyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 180); 

                auto tg_xxxxyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 181); 

                auto tg_xxxxyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 182); 

                auto tg_xxxxyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 183); 

                auto tg_xxxxyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 184); 

                auto tg_xxxxyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 185); 

                auto tg_xxxxyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 186); 

                auto tg_xxxxyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 187); 

                auto tg_xxxxyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 188); 

                auto tg_xxxxyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 189); 

                auto tg_xxxxyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 190); 

                auto tg_xxxxyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 191); 

                auto tg_xxxxyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 192); 

                auto tg_xxxxyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 193); 

                auto tg_xxxxxyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 97); 

                auto tg_xxxxxyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 98); 

                auto tg_xxxxxyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 99); 

                auto tg_xxxxxyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 100); 

                auto tg_xxxxxyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 101); 

                auto tg_xxxxxyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 102); 

                auto tg_xxxxxyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 103); 

                auto tg_xxxxxyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 104); 

                auto tg_xxxxxyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 105); 

                auto tg_xxxxxyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 106); 

                auto tg_xxxxxyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 107); 

                auto tg_xxxxxyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 108); 

                auto tg_xxxxxyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 109); 

                auto tg_xxxxxyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 110); 

                auto tg_xxxxxyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 111); 

                auto tg_xxxxxyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 112); 

                auto tg_xxxxxyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 113); 

                auto tg_xxxxxyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 114); 

                auto tg_xxxxxyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 115); 

                auto tg_xxxxxyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 116); 

                auto tg_xxxxxyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 117); 

                auto tg_xxxxxyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 118); 

                auto tg_xxxxxyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 119); 

                auto tg_xxxxxyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 120); 

                auto tg_xxxxxyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 121); 

                auto tg_xxxxxyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 122); 

                auto tg_xxxxxyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 123); 

                auto tg_xxxxxyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 124); 

                auto tg_xxxxxyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 125); 

                auto tg_xxxxxyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 126); 

                auto tg_xxxxxyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 127); 

                auto tg_xxxxxyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 128); 

                auto tg_xxxxxyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 129); 

                auto tg_xxxxxyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 130); 

                auto tg_xxxxxyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 131); 

                auto tg_xxxxxyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 132); 

                auto tg_xxxxxyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 133); 

                auto tg_xxxxxyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 134); 

                auto tg_xxxxxyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 135); 

                auto tg_xxxxxyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 136); 

                auto tg_xxxxxyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 137); 

                auto tg_xxxxxyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 138); 

                auto tg_xxxxxyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 139); 

                auto tg_xxxxxzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 140); 

                auto tg_xxxxxzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 141); 

                auto tg_xxxxxzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 142); 

                auto tg_xxxxxzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 143); 

                auto tg_xxxxxzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 144); 

                auto tg_xxxxxzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 145); 

                auto tg_xxxxxzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 146); 

                auto tg_xxxxxzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 147); 

                auto tg_xxxxxzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 148); 

                auto tg_xxxxxzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 149); 

                auto tg_xxxxxzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 150); 

                auto tg_xxxxxzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 151); 

                auto tg_xxxxxzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 152); 

                auto tg_xxxxxzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 153); 

                auto tg_xxxxxzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 154); 

                auto tg_xxxxxzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 155); 

                auto tg_xxxxxzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 156); 

                auto tg_xxxxxzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 157); 

                auto tg_xxxxxzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 158); 

                auto tg_xxxxxzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 159); 

                auto tg_xxxxxzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 160); 

                auto tg_xxxxxzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 161); 

                auto tg_xxxxxzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 162); 

                auto tg_xxxxxzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 163); 

                auto tg_xxxxxzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 164); 

                auto tg_xxxxxzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 165); 

                auto tg_xxxxxzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 166); 

                auto tg_xxxxxzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 167); 

                auto tg_xxxxyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 168); 

                auto tg_xxxxyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 169); 

                auto tg_xxxxyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 170); 

                auto tg_xxxxyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 171); 

                auto tg_xxxxyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 172); 

                auto tg_xxxxyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 173); 

                auto tg_xxxxyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 174); 

                auto tg_xxxxyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 175); 

                auto tg_xxxxyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 176); 

                auto tg_xxxxyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 177); 

                auto tg_xxxxyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 178); 

                auto tg_xxxxyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 179); 

                auto tg_xxxxyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 180); 

                auto tg_xxxxyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 181); 

                auto tg_xxxxyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 182); 

                auto tg_xxxxyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 183); 

                auto tg_xxxxyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 184); 

                auto tg_xxxxyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 185); 

                auto tg_xxxxyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 186); 

                auto tg_xxxxyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 187); 

                auto tg_xxxxyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 188); 

                auto tg_xxxxyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 189); 

                auto tg_xxxxyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 190); 

                auto tg_xxxxyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 191); 

                auto tg_xxxxyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 192); 

                auto tg_xxxxyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 193); 

                auto tg_xxxxyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 97); 

                auto tg_xxxxyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 98); 

                auto tg_xxxxyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 99); 

                auto tg_xxxxyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 100); 

                auto tg_xxxxyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 101); 

                auto tg_xxxxyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 102); 

                auto tg_xxxxyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 103); 

                auto tg_xxxxyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 104); 

                auto tg_xxxxyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 105); 

                auto tg_xxxxyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 106); 

                auto tg_xxxxyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 107); 

                auto tg_xxxxyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 108); 

                auto tg_xxxxyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 109); 

                auto tg_xxxxyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 110); 

                auto tg_xxxxyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 111); 

                auto tg_xxxxyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 112); 

                auto tg_xxxxyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 113); 

                auto tg_xxxxyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 114); 

                auto tg_xxxxyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 115); 

                auto tg_xxxxyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 116); 

                auto tg_xxxxyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 117); 

                auto tg_xxxxyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 118); 

                auto tg_xxxxyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 119); 

                auto tg_xxxxyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 120); 

                auto tg_xxxxyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 121); 

                auto tg_xxxxyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 122); 

                auto tg_xxxxyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 123); 

                auto tg_xxxxyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 124); 

                auto tg_xxxxyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 125); 

                auto tg_xxxxyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 126); 

                auto tg_xxxxyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 127); 

                auto tg_xxxxyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 128); 

                auto tg_xxxxyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 129); 

                auto tg_xxxxyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 130); 

                auto tg_xxxxyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 131); 

                auto tg_xxxxyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 132); 

                auto tg_xxxxyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 133); 

                auto tg_xxxxyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 134); 

                auto tg_xxxxyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 135); 

                auto tg_xxxxyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 136); 

                auto tg_xxxxyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 137); 

                auto tg_xxxxyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 138); 

                auto tg_xxxxyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 139); 

                auto tg_xxxxzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 140); 

                auto tg_xxxxzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 141); 

                auto tg_xxxxzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 142); 

                auto tg_xxxxzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 143); 

                auto tg_xxxxzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 144); 

                auto tg_xxxxzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 145); 

                auto tg_xxxxzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 146); 

                auto tg_xxxxzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 147); 

                auto tg_xxxxzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 148); 

                auto tg_xxxxzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 149); 

                auto tg_xxxxzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 150); 

                auto tg_xxxxzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 151); 

                auto tg_xxxxzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 152); 

                auto tg_xxxxzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 153); 

                auto tg_xxxxzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 154); 

                auto tg_xxxxzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 155); 

                auto tg_xxxxzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 156); 

                auto tg_xxxxzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 157); 

                auto tg_xxxxzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 158); 

                auto tg_xxxxzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 159); 

                auto tg_xxxxzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 160); 

                auto tg_xxxxzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 161); 

                auto tg_xxxxzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 162); 

                auto tg_xxxxzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 163); 

                auto tg_xxxxzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 164); 

                auto tg_xxxxzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 165); 

                auto tg_xxxxzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 166); 

                auto tg_xxxxzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 167); 

                auto tg_xxxyyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 168); 

                auto tg_xxxyyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 169); 

                auto tg_xxxyyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 170); 

                auto tg_xxxyyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 171); 

                auto tg_xxxyyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 172); 

                auto tg_xxxyyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 173); 

                auto tg_xxxyyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 174); 

                auto tg_xxxyyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 175); 

                auto tg_xxxyyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 176); 

                auto tg_xxxyyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 177); 

                auto tg_xxxyyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 178); 

                auto tg_xxxyyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 179); 

                auto tg_xxxyyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 180); 

                auto tg_xxxyyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 181); 

                auto tg_xxxyyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 182); 

                auto tg_xxxyyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 183); 

                auto tg_xxxyyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 184); 

                auto tg_xxxyyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 185); 

                auto tg_xxxyyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 186); 

                auto tg_xxxyyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 187); 

                auto tg_xxxyyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 188); 

                auto tg_xxxyyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 189); 

                auto tg_xxxyyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 190); 

                auto tg_xxxyyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 191); 

                auto tg_xxxyyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 192); 

                auto tg_xxxyyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 193); 

                auto tg_xxxxyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 97); 

                auto tg_xxxxyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 98); 

                auto tg_xxxxyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 99); 

                auto tg_xxxxyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 100); 

                auto tg_xxxxyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 101); 

                auto tg_xxxxyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 102); 

                auto tg_xxxxyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 103); 

                auto tg_xxxxyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 104); 

                auto tg_xxxxyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 105); 

                auto tg_xxxxyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 106); 

                auto tg_xxxxyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 107); 

                auto tg_xxxxyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 108); 

                auto tg_xxxxyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 109); 

                auto tg_xxxxyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 110); 

                auto tg_xxxxyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 111); 

                auto tg_xxxxyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 112); 

                auto tg_xxxxyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 113); 

                auto tg_xxxxyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 114); 

                auto tg_xxxxyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 115); 

                auto tg_xxxxyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 116); 

                auto tg_xxxxyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 117); 

                auto tg_xxxxyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 118); 

                auto tg_xxxxyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 119); 

                auto tg_xxxxyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 120); 

                auto tg_xxxxyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 121); 

                auto tg_xxxxyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 122); 

                auto tg_xxxxyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 123); 

                auto tg_xxxxyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 124); 

                auto tg_xxxxyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 125); 

                auto tg_xxxxyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 126); 

                auto tg_xxxxyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 127); 

                auto tg_xxxxyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 128); 

                auto tg_xxxxyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 129); 

                auto tg_xxxxyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 130); 

                auto tg_xxxxyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 131); 

                auto tg_xxxxyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 132); 

                auto tg_xxxxyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 133); 

                auto tg_xxxxyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 134); 

                auto tg_xxxxyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 135); 

                auto tg_xxxxyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 136); 

                auto tg_xxxxyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 137); 

                auto tg_xxxxyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 138); 

                auto tg_xxxxyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 139); 

                auto tg_xxxxzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 140); 

                auto tg_xxxxzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 141); 

                auto tg_xxxxzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 142); 

                auto tg_xxxxzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 143); 

                auto tg_xxxxzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 144); 

                auto tg_xxxxzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 145); 

                auto tg_xxxxzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 146); 

                auto tg_xxxxzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 147); 

                auto tg_xxxxzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 148); 

                auto tg_xxxxzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 149); 

                auto tg_xxxxzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 150); 

                auto tg_xxxxzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 151); 

                auto tg_xxxxzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 152); 

                auto tg_xxxxzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 153); 

                auto tg_xxxxzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 154); 

                auto tg_xxxxzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 155); 

                auto tg_xxxxzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 156); 

                auto tg_xxxxzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 157); 

                auto tg_xxxxzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 158); 

                auto tg_xxxxzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 159); 

                auto tg_xxxxzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 160); 

                auto tg_xxxxzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 161); 

                auto tg_xxxxzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 162); 

                auto tg_xxxxzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 163); 

                auto tg_xxxxzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 164); 

                auto tg_xxxxzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 165); 

                auto tg_xxxxzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 166); 

                auto tg_xxxxzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 167); 

                auto tg_xxxyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 168); 

                auto tg_xxxyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 169); 

                auto tg_xxxyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 170); 

                auto tg_xxxyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 171); 

                auto tg_xxxyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 172); 

                auto tg_xxxyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 173); 

                auto tg_xxxyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 174); 

                auto tg_xxxyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 175); 

                auto tg_xxxyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 176); 

                auto tg_xxxyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 177); 

                auto tg_xxxyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 178); 

                auto tg_xxxyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 179); 

                auto tg_xxxyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 180); 

                auto tg_xxxyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 181); 

                auto tg_xxxyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 182); 

                auto tg_xxxyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 183); 

                auto tg_xxxyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 184); 

                auto tg_xxxyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 185); 

                auto tg_xxxyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 186); 

                auto tg_xxxyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 187); 

                auto tg_xxxyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 188); 

                auto tg_xxxyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 189); 

                auto tg_xxxyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 190); 

                auto tg_xxxyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 191); 

                auto tg_xxxyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 192); 

                auto tg_xxxyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 193); 

                auto tg_xxxxxyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 76); 

                auto tg_xxxxxyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 77); 

                auto tg_xxxxxyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 78); 

                auto tg_xxxxxyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 79); 

                auto tg_xxxxxyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 80); 

                auto tg_xxxxxyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 81); 

                auto tg_xxxxxyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 82); 

                auto tg_xxxxxyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 83); 

                auto tg_xxxxxyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 84); 

                auto tg_xxxxxyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 85); 

                auto tg_xxxxxyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 86); 

                auto tg_xxxxxyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 87); 

                auto tg_xxxxxyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 88); 

                auto tg_xxxxxyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 89); 

                auto tg_xxxxxyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 90); 

                auto tg_xxxxxyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 91); 

                auto tg_xxxxxyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 92); 

                auto tg_xxxxxyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 93); 

                auto tg_xxxxxyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 94); 

                auto tg_xxxxxyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 95); 

                auto tg_xxxxxyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 96); 

                auto tg_xxxxxyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 97); 

                auto tg_xxxxxyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 98); 

                auto tg_xxxxxyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 99); 

                auto tg_xxxxxyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 100); 

                auto tg_xxxxxyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 101); 

                auto tg_xxxxxyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 102); 

                auto tg_xxxxxyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 103); 

                auto tg_xxxxxyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 104); 

                auto tg_xxxxxzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 105); 

                auto tg_xxxxxzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 106); 

                auto tg_xxxxxzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 107); 

                auto tg_xxxxxzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 108); 

                auto tg_xxxxxzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 109); 

                auto tg_xxxxxzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 110); 

                auto tg_xxxxxzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 111); 

                auto tg_xxxxxzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 112); 

                auto tg_xxxxxzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 113); 

                auto tg_xxxxxzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 114); 

                auto tg_xxxxxzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 115); 

                auto tg_xxxxxzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 116); 

                auto tg_xxxxxzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 117); 

                auto tg_xxxxxzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 118); 

                auto tg_xxxxxzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 119); 

                auto tg_xxxxxzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 120); 

                auto tg_xxxxxzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 121); 

                auto tg_xxxxxzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 122); 

                auto tg_xxxxxzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 123); 

                auto tg_xxxxxzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 124); 

                auto tg_xxxxxzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 125); 

                auto tg_xxxxyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 126); 

                auto tg_xxxxyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 127); 

                auto tg_xxxxyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 128); 

                auto tg_xxxxyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 129); 

                auto tg_xxxxyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 130); 

                auto tg_xxxxyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 131); 

                auto tg_xxxxyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 132); 

                auto tg_xxxxyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 133); 

                auto tg_xxxxyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 134); 

                auto tg_xxxxyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 135); 

                auto tg_xxxxyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 136); 

                auto tg_xxxxyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 137); 

                auto tg_xxxxyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 138); 

                auto tg_xxxxyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 139); 

                auto tg_xxxxyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 140); 

                auto tg_xxxxyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 141); 

                auto tg_xxxxyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 142); 

                auto tg_xxxxyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 143); 

                auto tg_xxxxyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 144); 

                auto tg_xxxxyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 145); 

                auto tg_xxxxyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 146); 

                // set up pointers to integrals

                auto tg_xxxxxxyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 97); 

                auto tg_xxxxxxyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 98); 

                auto tg_xxxxxxyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 99); 

                auto tg_xxxxxxyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 100); 

                auto tg_xxxxxxyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 101); 

                auto tg_xxxxxxyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 102); 

                auto tg_xxxxxxyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 103); 

                auto tg_xxxxxxyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 104); 

                auto tg_xxxxxxyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 105); 

                auto tg_xxxxxxyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 106); 

                auto tg_xxxxxxyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 107); 

                auto tg_xxxxxxyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 108); 

                auto tg_xxxxxxyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 109); 

                auto tg_xxxxxxyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 110); 

                auto tg_xxxxxxyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 111); 

                auto tg_xxxxxxyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 112); 

                auto tg_xxxxxxyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 113); 

                auto tg_xxxxxxyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 114); 

                auto tg_xxxxxxyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 115); 

                auto tg_xxxxxxyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 116); 

                auto tg_xxxxxxyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 117); 

                auto tg_xxxxxxyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 118); 

                auto tg_xxxxxxyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 119); 

                auto tg_xxxxxxyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 120); 

                auto tg_xxxxxxyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 121); 

                auto tg_xxxxxxyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 122); 

                auto tg_xxxxxxyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 123); 

                auto tg_xxxxxxyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 124); 

                auto tg_xxxxxxyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 125); 

                auto tg_xxxxxxyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 126); 

                auto tg_xxxxxxyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 127); 

                auto tg_xxxxxxyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 128); 

                auto tg_xxxxxxyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 129); 

                auto tg_xxxxxxyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 130); 

                auto tg_xxxxxxyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 131); 

                auto tg_xxxxxxyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 132); 

                auto tg_xxxxxxyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 133); 

                auto tg_xxxxxxyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 134); 

                auto tg_xxxxxxyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 135); 

                auto tg_xxxxxxyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 136); 

                auto tg_xxxxxxyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 137); 

                auto tg_xxxxxxyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 138); 

                auto tg_xxxxxxyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 139); 

                auto tg_xxxxxxzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 140); 

                auto tg_xxxxxxzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 141); 

                auto tg_xxxxxxzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 142); 

                auto tg_xxxxxxzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 143); 

                auto tg_xxxxxxzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 144); 

                auto tg_xxxxxxzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 145); 

                auto tg_xxxxxxzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 146); 

                auto tg_xxxxxxzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 147); 

                auto tg_xxxxxxzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 148); 

                auto tg_xxxxxxzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 149); 

                auto tg_xxxxxxzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 150); 

                auto tg_xxxxxxzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 151); 

                auto tg_xxxxxxzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 152); 

                auto tg_xxxxxxzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 153); 

                auto tg_xxxxxxzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 154); 

                auto tg_xxxxxxzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 155); 

                auto tg_xxxxxxzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 156); 

                auto tg_xxxxxxzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 157); 

                auto tg_xxxxxxzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 158); 

                auto tg_xxxxxxzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 159); 

                auto tg_xxxxxxzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 160); 

                auto tg_xxxxxxzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 161); 

                auto tg_xxxxxxzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 162); 

                auto tg_xxxxxxzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 163); 

                auto tg_xxxxxxzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 164); 

                auto tg_xxxxxxzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 165); 

                auto tg_xxxxxxzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 166); 

                auto tg_xxxxxxzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 167); 

                auto tg_xxxxxyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 168); 

                auto tg_xxxxxyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 169); 

                auto tg_xxxxxyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 170); 

                auto tg_xxxxxyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 171); 

                auto tg_xxxxxyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 172); 

                auto tg_xxxxxyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 173); 

                auto tg_xxxxxyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 174); 

                auto tg_xxxxxyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 175); 

                auto tg_xxxxxyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 176); 

                auto tg_xxxxxyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 177); 

                auto tg_xxxxxyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 178); 

                auto tg_xxxxxyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 179); 

                auto tg_xxxxxyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 180); 

                auto tg_xxxxxyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 181); 

                auto tg_xxxxxyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 182); 

                auto tg_xxxxxyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 183); 

                auto tg_xxxxxyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 184); 

                auto tg_xxxxxyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 185); 

                auto tg_xxxxxyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 186); 

                auto tg_xxxxxyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 187); 

                auto tg_xxxxxyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 188); 

                auto tg_xxxxxyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 189); 

                auto tg_xxxxxyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 190); 

                auto tg_xxxxxyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 191); 

                auto tg_xxxxxyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 192); 

                auto tg_xxxxxyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 193); 

                // Batch of Integrals (97,194)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxxyy_xxyzzz_0, tg_xxxxxxyy_xxzzzz_0, \
                                         tg_xxxxxxyy_xyyyyy_0, tg_xxxxxxyy_xyyyyz_0, tg_xxxxxxyy_xyyyzz_0, tg_xxxxxxyy_xyyzzz_0, \
                                         tg_xxxxxxyy_xyzzzz_0, tg_xxxxxxyy_xzzzzz_0, tg_xxxxxxyy_yyyyyy_0, tg_xxxxxxyy_yyyyyz_0, \
                                         tg_xxxxxxyy_yyyyzz_0, tg_xxxxxxyy_yyyzzz_0, tg_xxxxxxyy_yyzzzz_0, tg_xxxxxxyy_yzzzzz_0, \
                                         tg_xxxxxxyy_zzzzzz_0, tg_xxxxxxyz_xxxxxx_0, tg_xxxxxxyz_xxxxxy_0, tg_xxxxxxyz_xxxxxz_0, \
                                         tg_xxxxxxyz_xxxxyy_0, tg_xxxxxxyz_xxxxyz_0, tg_xxxxxxyz_xxxxzz_0, tg_xxxxxxyz_xxxyyy_0, \
                                         tg_xxxxxxyz_xxxyyz_0, tg_xxxxxxyz_xxxyzz_0, tg_xxxxxxyz_xxxzzz_0, tg_xxxxxxyz_xxyyyy_0, \
                                         tg_xxxxxxyz_xxyyyz_0, tg_xxxxxxyz_xxyyzz_0, tg_xxxxxxyz_xxyzzz_0, tg_xxxxxxyz_xxzzzz_0, \
                                         tg_xxxxxxyz_xyyyyy_0, tg_xxxxxxyz_xyyyyz_0, tg_xxxxxxyz_xyyyzz_0, tg_xxxxxxyz_xyyzzz_0, \
                                         tg_xxxxxxyz_xyzzzz_0, tg_xxxxxxyz_xzzzzz_0, tg_xxxxxxyz_yyyyyy_0, tg_xxxxxxyz_yyyyyz_0, \
                                         tg_xxxxxxyz_yyyyzz_0, tg_xxxxxxyz_yyyzzz_0, tg_xxxxxxyz_yyzzzz_0, tg_xxxxxxyz_yzzzzz_0, \
                                         tg_xxxxxxyz_zzzzzz_0, tg_xxxxxxzz_xxxxxx_0, tg_xxxxxxzz_xxxxxy_0, tg_xxxxxxzz_xxxxxz_0, \
                                         tg_xxxxxxzz_xxxxyy_0, tg_xxxxxxzz_xxxxyz_0, tg_xxxxxxzz_xxxxzz_0, tg_xxxxxxzz_xxxyyy_0, \
                                         tg_xxxxxxzz_xxxyyz_0, tg_xxxxxxzz_xxxyzz_0, tg_xxxxxxzz_xxxzzz_0, tg_xxxxxxzz_xxyyyy_0, \
                                         tg_xxxxxxzz_xxyyyz_0, tg_xxxxxxzz_xxyyzz_0, tg_xxxxxxzz_xxyzzz_0, tg_xxxxxxzz_xxzzzz_0, \
                                         tg_xxxxxxzz_xyyyyy_0, tg_xxxxxxzz_xyyyyz_0, tg_xxxxxxzz_xyyyzz_0, tg_xxxxxxzz_xyyzzz_0, \
                                         tg_xxxxxxzz_xyzzzz_0, tg_xxxxxxzz_xzzzzz_0, tg_xxxxxxzz_yyyyyy_0, tg_xxxxxxzz_yyyyyz_0, \
                                         tg_xxxxxxzz_yyyyzz_0, tg_xxxxxxzz_yyyzzz_0, tg_xxxxxxzz_yyzzzz_0, tg_xxxxxxzz_yzzzzz_0, \
                                         tg_xxxxxxzz_zzzzzz_0, tg_xxxxxyy_xxyzzz_0, tg_xxxxxyy_xxyzzz_1, tg_xxxxxyy_xxzzzz_0, \
                                         tg_xxxxxyy_xxzzzz_1, tg_xxxxxyy_xyyyyy_0, tg_xxxxxyy_xyyyyy_1, tg_xxxxxyy_xyyyyz_0, \
                                         tg_xxxxxyy_xyyyyz_1, tg_xxxxxyy_xyyyzz_0, tg_xxxxxyy_xyyyzz_1, tg_xxxxxyy_xyyzzz_0, \
                                         tg_xxxxxyy_xyyzzz_1, tg_xxxxxyy_xyzzz_1, tg_xxxxxyy_xyzzzz_0, tg_xxxxxyy_xyzzzz_1, \
                                         tg_xxxxxyy_xzzzz_1, tg_xxxxxyy_xzzzzz_0, tg_xxxxxyy_xzzzzz_1, tg_xxxxxyy_yyyyy_1, \
                                         tg_xxxxxyy_yyyyyy_0, tg_xxxxxyy_yyyyyy_1, tg_xxxxxyy_yyyyyz_0, tg_xxxxxyy_yyyyyz_1, \
                                         tg_xxxxxyy_yyyyz_1, tg_xxxxxyy_yyyyzz_0, tg_xxxxxyy_yyyyzz_1, tg_xxxxxyy_yyyzz_1, \
                                         tg_xxxxxyy_yyyzzz_0, tg_xxxxxyy_yyyzzz_1, tg_xxxxxyy_yyzzz_1, tg_xxxxxyy_yyzzzz_0, \
                                         tg_xxxxxyy_yyzzzz_1, tg_xxxxxyy_yzzzz_1, tg_xxxxxyy_yzzzzz_0, tg_xxxxxyy_yzzzzz_1, \
                                         tg_xxxxxyy_zzzzz_1, tg_xxxxxyy_zzzzzz_0, tg_xxxxxyy_zzzzzz_1, tg_xxxxxyyy_xxxxxx_0, \
                                         tg_xxxxxyyy_xxxxxy_0, tg_xxxxxyyy_xxxxxz_0, tg_xxxxxyyy_xxxxyy_0, tg_xxxxxyyy_xxxxyz_0, \
                                         tg_xxxxxyyy_xxxxzz_0, tg_xxxxxyyy_xxxyyy_0, tg_xxxxxyyy_xxxyyz_0, tg_xxxxxyyy_xxxyzz_0, \
                                         tg_xxxxxyyy_xxxzzz_0, tg_xxxxxyyy_xxyyyy_0, tg_xxxxxyyy_xxyyyz_0, tg_xxxxxyyy_xxyyzz_0, \
                                         tg_xxxxxyyy_xxyzzz_0, tg_xxxxxyyy_xxzzzz_0, tg_xxxxxyyy_xyyyyy_0, tg_xxxxxyyy_xyyyyz_0, \
                                         tg_xxxxxyyy_xyyyzz_0, tg_xxxxxyyy_xyyzzz_0, tg_xxxxxyyy_xyzzzz_0, tg_xxxxxyyy_xzzzzz_0, \
                                         tg_xxxxxyyy_yyyyyy_0, tg_xxxxxyyy_yyyyyz_0, tg_xxxxxyyy_yyyyzz_0, tg_xxxxxyyy_yyyzzz_0, \
                                         tg_xxxxxyyy_yyzzzz_0, tg_xxxxxyz_xxxxx_1, tg_xxxxxyz_xxxxxx_0, tg_xxxxxyz_xxxxxx_1, \
                                         tg_xxxxxyz_xxxxxy_0, tg_xxxxxyz_xxxxxy_1, tg_xxxxxyz_xxxxxz_0, tg_xxxxxyz_xxxxxz_1, \
                                         tg_xxxxxyz_xxxxy_1, tg_xxxxxyz_xxxxyy_0, tg_xxxxxyz_xxxxyy_1, tg_xxxxxyz_xxxxyz_0, \
                                         tg_xxxxxyz_xxxxyz_1, tg_xxxxxyz_xxxxz_1, tg_xxxxxyz_xxxxzz_0, tg_xxxxxyz_xxxxzz_1, \
                                         tg_xxxxxyz_xxxyy_1, tg_xxxxxyz_xxxyyy_0, tg_xxxxxyz_xxxyyy_1, tg_xxxxxyz_xxxyyz_0, \
                                         tg_xxxxxyz_xxxyyz_1, tg_xxxxxyz_xxxyz_1, tg_xxxxxyz_xxxyzz_0, tg_xxxxxyz_xxxyzz_1, \
                                         tg_xxxxxyz_xxxzz_1, tg_xxxxxyz_xxxzzz_0, tg_xxxxxyz_xxxzzz_1, tg_xxxxxyz_xxyyy_1, \
                                         tg_xxxxxyz_xxyyyy_0, tg_xxxxxyz_xxyyyy_1, tg_xxxxxyz_xxyyyz_0, tg_xxxxxyz_xxyyyz_1, \
                                         tg_xxxxxyz_xxyyz_1, tg_xxxxxyz_xxyyzz_0, tg_xxxxxyz_xxyyzz_1, tg_xxxxxyz_xxyzz_1, \
                                         tg_xxxxxyz_xxyzzz_0, tg_xxxxxyz_xxyzzz_1, tg_xxxxxyz_xxzzz_1, tg_xxxxxyz_xxzzzz_0, \
                                         tg_xxxxxyz_xxzzzz_1, tg_xxxxxyz_xyyyy_1, tg_xxxxxyz_xyyyyy_0, tg_xxxxxyz_xyyyyy_1, \
                                         tg_xxxxxyz_xyyyyz_0, tg_xxxxxyz_xyyyyz_1, tg_xxxxxyz_xyyyz_1, tg_xxxxxyz_xyyyzz_0, \
                                         tg_xxxxxyz_xyyyzz_1, tg_xxxxxyz_xyyzz_1, tg_xxxxxyz_xyyzzz_0, tg_xxxxxyz_xyyzzz_1, \
                                         tg_xxxxxyz_xyzzz_1, tg_xxxxxyz_xyzzzz_0, tg_xxxxxyz_xyzzzz_1, tg_xxxxxyz_xzzzz_1, \
                                         tg_xxxxxyz_xzzzzz_0, tg_xxxxxyz_xzzzzz_1, tg_xxxxxyz_yyyyy_1, tg_xxxxxyz_yyyyyy_0, \
                                         tg_xxxxxyz_yyyyyy_1, tg_xxxxxyz_yyyyyz_0, tg_xxxxxyz_yyyyyz_1, tg_xxxxxyz_yyyyz_1, \
                                         tg_xxxxxyz_yyyyzz_0, tg_xxxxxyz_yyyyzz_1, tg_xxxxxyz_yyyzz_1, tg_xxxxxyz_yyyzzz_0, \
                                         tg_xxxxxyz_yyyzzz_1, tg_xxxxxyz_yyzzz_1, tg_xxxxxyz_yyzzzz_0, tg_xxxxxyz_yyzzzz_1, \
                                         tg_xxxxxyz_yzzzz_1, tg_xxxxxyz_yzzzzz_0, tg_xxxxxyz_yzzzzz_1, tg_xxxxxyz_zzzzz_1, \
                                         tg_xxxxxyz_zzzzzz_0, tg_xxxxxyz_zzzzzz_1, tg_xxxxxzz_xxxxx_1, tg_xxxxxzz_xxxxxx_0, \
                                         tg_xxxxxzz_xxxxxx_1, tg_xxxxxzz_xxxxxy_0, tg_xxxxxzz_xxxxxy_1, tg_xxxxxzz_xxxxxz_0, \
                                         tg_xxxxxzz_xxxxxz_1, tg_xxxxxzz_xxxxy_1, tg_xxxxxzz_xxxxyy_0, tg_xxxxxzz_xxxxyy_1, \
                                         tg_xxxxxzz_xxxxyz_0, tg_xxxxxzz_xxxxyz_1, tg_xxxxxzz_xxxxz_1, tg_xxxxxzz_xxxxzz_0, \
                                         tg_xxxxxzz_xxxxzz_1, tg_xxxxxzz_xxxyy_1, tg_xxxxxzz_xxxyyy_0, tg_xxxxxzz_xxxyyy_1, \
                                         tg_xxxxxzz_xxxyyz_0, tg_xxxxxzz_xxxyyz_1, tg_xxxxxzz_xxxyz_1, tg_xxxxxzz_xxxyzz_0, \
                                         tg_xxxxxzz_xxxyzz_1, tg_xxxxxzz_xxxzz_1, tg_xxxxxzz_xxxzzz_0, tg_xxxxxzz_xxxzzz_1, \
                                         tg_xxxxxzz_xxyyy_1, tg_xxxxxzz_xxyyyy_0, tg_xxxxxzz_xxyyyy_1, tg_xxxxxzz_xxyyyz_0, \
                                         tg_xxxxxzz_xxyyyz_1, tg_xxxxxzz_xxyyz_1, tg_xxxxxzz_xxyyzz_0, tg_xxxxxzz_xxyyzz_1, \
                                         tg_xxxxxzz_xxyzz_1, tg_xxxxxzz_xxyzzz_0, tg_xxxxxzz_xxyzzz_1, tg_xxxxxzz_xxzzz_1, \
                                         tg_xxxxxzz_xxzzzz_0, tg_xxxxxzz_xxzzzz_1, tg_xxxxxzz_xyyyy_1, tg_xxxxxzz_xyyyyy_0, \
                                         tg_xxxxxzz_xyyyyy_1, tg_xxxxxzz_xyyyyz_0, tg_xxxxxzz_xyyyyz_1, tg_xxxxxzz_xyyyz_1, \
                                         tg_xxxxxzz_xyyyzz_0, tg_xxxxxzz_xyyyzz_1, tg_xxxxxzz_xyyzz_1, tg_xxxxxzz_xyyzzz_0, \
                                         tg_xxxxxzz_xyyzzz_1, tg_xxxxxzz_xyzzz_1, tg_xxxxxzz_xyzzzz_0, tg_xxxxxzz_xyzzzz_1, \
                                         tg_xxxxxzz_xzzzz_1, tg_xxxxxzz_xzzzzz_0, tg_xxxxxzz_xzzzzz_1, tg_xxxxxzz_yyyyy_1, \
                                         tg_xxxxxzz_yyyyyy_0, tg_xxxxxzz_yyyyyy_1, tg_xxxxxzz_yyyyyz_0, tg_xxxxxzz_yyyyyz_1, \
                                         tg_xxxxxzz_yyyyz_1, tg_xxxxxzz_yyyyzz_0, tg_xxxxxzz_yyyyzz_1, tg_xxxxxzz_yyyzz_1, \
                                         tg_xxxxxzz_yyyzzz_0, tg_xxxxxzz_yyyzzz_1, tg_xxxxxzz_yyzzz_1, tg_xxxxxzz_yyzzzz_0, \
                                         tg_xxxxxzz_yyzzzz_1, tg_xxxxxzz_yzzzz_1, tg_xxxxxzz_yzzzzz_0, tg_xxxxxzz_yzzzzz_1, \
                                         tg_xxxxxzz_zzzzz_1, tg_xxxxxzz_zzzzzz_0, tg_xxxxxzz_zzzzzz_1, tg_xxxxyy_xxyzzz_0, \
                                         tg_xxxxyy_xxyzzz_1, tg_xxxxyy_xxzzzz_0, tg_xxxxyy_xxzzzz_1, tg_xxxxyy_xyyyyy_0, \
                                         tg_xxxxyy_xyyyyy_1, tg_xxxxyy_xyyyyz_0, tg_xxxxyy_xyyyyz_1, tg_xxxxyy_xyyyzz_0, \
                                         tg_xxxxyy_xyyyzz_1, tg_xxxxyy_xyyzzz_0, tg_xxxxyy_xyyzzz_1, tg_xxxxyy_xyzzzz_0, \
                                         tg_xxxxyy_xyzzzz_1, tg_xxxxyy_xzzzzz_0, tg_xxxxyy_xzzzzz_1, tg_xxxxyy_yyyyyy_0, \
                                         tg_xxxxyy_yyyyyy_1, tg_xxxxyy_yyyyyz_0, tg_xxxxyy_yyyyyz_1, tg_xxxxyy_yyyyzz_0, \
                                         tg_xxxxyy_yyyyzz_1, tg_xxxxyy_yyyzzz_0, tg_xxxxyy_yyyzzz_1, tg_xxxxyy_yyzzzz_0, \
                                         tg_xxxxyy_yyzzzz_1, tg_xxxxyy_yzzzzz_0, tg_xxxxyy_yzzzzz_1, tg_xxxxyy_zzzzzz_0, \
                                         tg_xxxxyy_zzzzzz_1, tg_xxxxyyy_xxxxx_1, tg_xxxxyyy_xxxxxx_0, tg_xxxxyyy_xxxxxx_1, \
                                         tg_xxxxyyy_xxxxxy_0, tg_xxxxyyy_xxxxxy_1, tg_xxxxyyy_xxxxxz_0, tg_xxxxyyy_xxxxxz_1, \
                                         tg_xxxxyyy_xxxxy_1, tg_xxxxyyy_xxxxyy_0, tg_xxxxyyy_xxxxyy_1, tg_xxxxyyy_xxxxyz_0, \
                                         tg_xxxxyyy_xxxxyz_1, tg_xxxxyyy_xxxxz_1, tg_xxxxyyy_xxxxzz_0, tg_xxxxyyy_xxxxzz_1, \
                                         tg_xxxxyyy_xxxyy_1, tg_xxxxyyy_xxxyyy_0, tg_xxxxyyy_xxxyyy_1, tg_xxxxyyy_xxxyyz_0, \
                                         tg_xxxxyyy_xxxyyz_1, tg_xxxxyyy_xxxyz_1, tg_xxxxyyy_xxxyzz_0, tg_xxxxyyy_xxxyzz_1, \
                                         tg_xxxxyyy_xxxzz_1, tg_xxxxyyy_xxxzzz_0, tg_xxxxyyy_xxxzzz_1, tg_xxxxyyy_xxyyy_1, \
                                         tg_xxxxyyy_xxyyyy_0, tg_xxxxyyy_xxyyyy_1, tg_xxxxyyy_xxyyyz_0, tg_xxxxyyy_xxyyyz_1, \
                                         tg_xxxxyyy_xxyyz_1, tg_xxxxyyy_xxyyzz_0, tg_xxxxyyy_xxyyzz_1, tg_xxxxyyy_xxyzz_1, \
                                         tg_xxxxyyy_xxyzzz_0, tg_xxxxyyy_xxyzzz_1, tg_xxxxyyy_xxzzz_1, tg_xxxxyyy_xxzzzz_0, \
                                         tg_xxxxyyy_xxzzzz_1, tg_xxxxyyy_xyyyy_1, tg_xxxxyyy_xyyyyy_0, tg_xxxxyyy_xyyyyy_1, \
                                         tg_xxxxyyy_xyyyyz_0, tg_xxxxyyy_xyyyyz_1, tg_xxxxyyy_xyyyz_1, tg_xxxxyyy_xyyyzz_0, \
                                         tg_xxxxyyy_xyyyzz_1, tg_xxxxyyy_xyyzz_1, tg_xxxxyyy_xyyzzz_0, tg_xxxxyyy_xyyzzz_1, \
                                         tg_xxxxyyy_xyzzz_1, tg_xxxxyyy_xyzzzz_0, tg_xxxxyyy_xyzzzz_1, tg_xxxxyyy_xzzzz_1, \
                                         tg_xxxxyyy_xzzzzz_0, tg_xxxxyyy_xzzzzz_1, tg_xxxxyyy_yyyyy_1, tg_xxxxyyy_yyyyyy_0, \
                                         tg_xxxxyyy_yyyyyy_1, tg_xxxxyyy_yyyyyz_0, tg_xxxxyyy_yyyyyz_1, tg_xxxxyyy_yyyyz_1, \
                                         tg_xxxxyyy_yyyyzz_0, tg_xxxxyyy_yyyyzz_1, tg_xxxxyyy_yyyzz_1, tg_xxxxyyy_yyyzzz_0, \
                                         tg_xxxxyyy_yyyzzz_1, tg_xxxxyyy_yyzzz_1, tg_xxxxyyy_yyzzzz_0, tg_xxxxyyy_yyzzzz_1, \
                                         tg_xxxxyyy_yzzzz_1, tg_xxxxyyy_zzzzz_1, tg_xxxxyz_xxxxxx_0, tg_xxxxyz_xxxxxx_1, \
                                         tg_xxxxyz_xxxxxy_0, tg_xxxxyz_xxxxxy_1, tg_xxxxyz_xxxxxz_0, tg_xxxxyz_xxxxxz_1, \
                                         tg_xxxxyz_xxxxyy_0, tg_xxxxyz_xxxxyy_1, tg_xxxxyz_xxxxyz_0, tg_xxxxyz_xxxxyz_1, \
                                         tg_xxxxyz_xxxxzz_0, tg_xxxxyz_xxxxzz_1, tg_xxxxyz_xxxyyy_0, tg_xxxxyz_xxxyyy_1, \
                                         tg_xxxxyz_xxxyyz_0, tg_xxxxyz_xxxyyz_1, tg_xxxxyz_xxxyzz_0, tg_xxxxyz_xxxyzz_1, \
                                         tg_xxxxyz_xxxzzz_0, tg_xxxxyz_xxxzzz_1, tg_xxxxyz_xxyyyy_0, tg_xxxxyz_xxyyyy_1, \
                                         tg_xxxxyz_xxyyyz_0, tg_xxxxyz_xxyyyz_1, tg_xxxxyz_xxyyzz_0, tg_xxxxyz_xxyyzz_1, \
                                         tg_xxxxyz_xxyzzz_0, tg_xxxxyz_xxyzzz_1, tg_xxxxyz_xxzzzz_0, tg_xxxxyz_xxzzzz_1, \
                                         tg_xxxxyz_xyyyyy_0, tg_xxxxyz_xyyyyy_1, tg_xxxxyz_xyyyyz_0, tg_xxxxyz_xyyyyz_1, \
                                         tg_xxxxyz_xyyyzz_0, tg_xxxxyz_xyyyzz_1, tg_xxxxyz_xyyzzz_0, tg_xxxxyz_xyyzzz_1, \
                                         tg_xxxxyz_xyzzzz_0, tg_xxxxyz_xyzzzz_1, tg_xxxxyz_xzzzzz_0, tg_xxxxyz_xzzzzz_1, \
                                         tg_xxxxyz_yyyyyy_0, tg_xxxxyz_yyyyyy_1, tg_xxxxyz_yyyyyz_0, tg_xxxxyz_yyyyyz_1, \
                                         tg_xxxxyz_yyyyzz_0, tg_xxxxyz_yyyyzz_1, tg_xxxxyz_yyyzzz_0, tg_xxxxyz_yyyzzz_1, \
                                         tg_xxxxyz_yyzzzz_0, tg_xxxxyz_yyzzzz_1, tg_xxxxyz_yzzzzz_0, tg_xxxxyz_yzzzzz_1, \
                                         tg_xxxxyz_zzzzzz_0, tg_xxxxyz_zzzzzz_1, tg_xxxxzz_xxxxxx_0, tg_xxxxzz_xxxxxx_1, \
                                         tg_xxxxzz_xxxxxy_0, tg_xxxxzz_xxxxxy_1, tg_xxxxzz_xxxxxz_0, tg_xxxxzz_xxxxxz_1, \
                                         tg_xxxxzz_xxxxyy_0, tg_xxxxzz_xxxxyy_1, tg_xxxxzz_xxxxyz_0, tg_xxxxzz_xxxxyz_1, \
                                         tg_xxxxzz_xxxxzz_0, tg_xxxxzz_xxxxzz_1, tg_xxxxzz_xxxyyy_0, tg_xxxxzz_xxxyyy_1, \
                                         tg_xxxxzz_xxxyyz_0, tg_xxxxzz_xxxyyz_1, tg_xxxxzz_xxxyzz_0, tg_xxxxzz_xxxyzz_1, \
                                         tg_xxxxzz_xxxzzz_0, tg_xxxxzz_xxxzzz_1, tg_xxxxzz_xxyyyy_0, tg_xxxxzz_xxyyyy_1, \
                                         tg_xxxxzz_xxyyyz_0, tg_xxxxzz_xxyyyz_1, tg_xxxxzz_xxyyzz_0, tg_xxxxzz_xxyyzz_1, \
                                         tg_xxxxzz_xxyzzz_0, tg_xxxxzz_xxyzzz_1, tg_xxxxzz_xxzzzz_0, tg_xxxxzz_xxzzzz_1, \
                                         tg_xxxxzz_xyyyyy_0, tg_xxxxzz_xyyyyy_1, tg_xxxxzz_xyyyyz_0, tg_xxxxzz_xyyyyz_1, \
                                         tg_xxxxzz_xyyyzz_0, tg_xxxxzz_xyyyzz_1, tg_xxxxzz_xyyzzz_0, tg_xxxxzz_xyyzzz_1, \
                                         tg_xxxxzz_xyzzzz_0, tg_xxxxzz_xyzzzz_1, tg_xxxxzz_xzzzzz_0, tg_xxxxzz_xzzzzz_1, \
                                         tg_xxxxzz_yyyyyy_0, tg_xxxxzz_yyyyyy_1, tg_xxxxzz_yyyyyz_0, tg_xxxxzz_yyyyyz_1, \
                                         tg_xxxxzz_yyyyzz_0, tg_xxxxzz_yyyyzz_1, tg_xxxxzz_yyyzzz_0, tg_xxxxzz_yyyzzz_1, \
                                         tg_xxxxzz_yyzzzz_0, tg_xxxxzz_yyzzzz_1, tg_xxxxzz_yzzzzz_0, tg_xxxxzz_yzzzzz_1, \
                                         tg_xxxxzz_zzzzzz_0, tg_xxxxzz_zzzzzz_1, tg_xxxyyy_xxxxxx_0, tg_xxxyyy_xxxxxx_1, \
                                         tg_xxxyyy_xxxxxy_0, tg_xxxyyy_xxxxxy_1, tg_xxxyyy_xxxxxz_0, tg_xxxyyy_xxxxxz_1, \
                                         tg_xxxyyy_xxxxyy_0, tg_xxxyyy_xxxxyy_1, tg_xxxyyy_xxxxyz_0, tg_xxxyyy_xxxxyz_1, \
                                         tg_xxxyyy_xxxxzz_0, tg_xxxyyy_xxxxzz_1, tg_xxxyyy_xxxyyy_0, tg_xxxyyy_xxxyyy_1, \
                                         tg_xxxyyy_xxxyyz_0, tg_xxxyyy_xxxyyz_1, tg_xxxyyy_xxxyzz_0, tg_xxxyyy_xxxyzz_1, \
                                         tg_xxxyyy_xxxzzz_0, tg_xxxyyy_xxxzzz_1, tg_xxxyyy_xxyyyy_0, tg_xxxyyy_xxyyyy_1, \
                                         tg_xxxyyy_xxyyyz_0, tg_xxxyyy_xxyyyz_1, tg_xxxyyy_xxyyzz_0, tg_xxxyyy_xxyyzz_1, \
                                         tg_xxxyyy_xxyzzz_0, tg_xxxyyy_xxyzzz_1, tg_xxxyyy_xxzzzz_0, tg_xxxyyy_xxzzzz_1, \
                                         tg_xxxyyy_xyyyyy_0, tg_xxxyyy_xyyyyy_1, tg_xxxyyy_xyyyyz_0, tg_xxxyyy_xyyyyz_1, \
                                         tg_xxxyyy_xyyyzz_0, tg_xxxyyy_xyyyzz_1, tg_xxxyyy_xyyzzz_0, tg_xxxyyy_xyyzzz_1, \
                                         tg_xxxyyy_xyzzzz_0, tg_xxxyyy_xyzzzz_1, tg_xxxyyy_xzzzzz_0, tg_xxxyyy_xzzzzz_1, \
                                         tg_xxxyyy_yyyyyy_0, tg_xxxyyy_yyyyyy_1, tg_xxxyyy_yyyyyz_0, tg_xxxyyy_yyyyyz_1, \
                                         tg_xxxyyy_yyyyzz_0, tg_xxxyyy_yyyyzz_1, tg_xxxyyy_yyyzzz_0, tg_xxxyyy_yyyzzz_1, \
                                         tg_xxxyyy_yyzzzz_0, tg_xxxyyy_yyzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxxyy_xxyzzz_0[j] = pb_x * tg_xxxxxyy_xxyzzz_0[j] + fr * tg_xxxxxyy_xxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxyzzz_0[j] - tg_xxxxyy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_xyzzz_1[j];

                    tg_xxxxxxyy_xxzzzz_0[j] = pb_x * tg_xxxxxyy_xxzzzz_0[j] + fr * tg_xxxxxyy_xxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xxzzzz_0[j] - tg_xxxxyy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyy_xzzzz_1[j];

                    tg_xxxxxxyy_xyyyyy_0[j] = pb_x * tg_xxxxxyy_xyyyyy_0[j] + fr * tg_xxxxxyy_xyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xyyyyy_0[j] - tg_xxxxyy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_yyyyy_1[j];

                    tg_xxxxxxyy_xyyyyz_0[j] = pb_x * tg_xxxxxyy_xyyyyz_0[j] + fr * tg_xxxxxyy_xyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xyyyyz_0[j] - tg_xxxxyy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_yyyyz_1[j];

                    tg_xxxxxxyy_xyyyzz_0[j] = pb_x * tg_xxxxxyy_xyyyzz_0[j] + fr * tg_xxxxxyy_xyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xyyyzz_0[j] - tg_xxxxyy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_yyyzz_1[j];

                    tg_xxxxxxyy_xyyzzz_0[j] = pb_x * tg_xxxxxyy_xyyzzz_0[j] + fr * tg_xxxxxyy_xyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xyyzzz_0[j] - tg_xxxxyy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_yyzzz_1[j];

                    tg_xxxxxxyy_xyzzzz_0[j] = pb_x * tg_xxxxxyy_xyzzzz_0[j] + fr * tg_xxxxxyy_xyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xyzzzz_0[j] - tg_xxxxyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_yzzzz_1[j];

                    tg_xxxxxxyy_xzzzzz_0[j] = pb_x * tg_xxxxxyy_xzzzzz_0[j] + fr * tg_xxxxxyy_xzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_xzzzzz_0[j] - tg_xxxxyy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyy_zzzzz_1[j];

                    tg_xxxxxxyy_yyyyyy_0[j] = pb_x * tg_xxxxxyy_yyyyyy_0[j] + fr * tg_xxxxxyy_yyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yyyyyy_0[j] - tg_xxxxyy_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxyy_yyyyyz_0[j] = pb_x * tg_xxxxxyy_yyyyyz_0[j] + fr * tg_xxxxxyy_yyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yyyyyz_0[j] - tg_xxxxyy_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxyy_yyyyzz_0[j] = pb_x * tg_xxxxxyy_yyyyzz_0[j] + fr * tg_xxxxxyy_yyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yyyyzz_0[j] - tg_xxxxyy_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxyy_yyyzzz_0[j] = pb_x * tg_xxxxxyy_yyyzzz_0[j] + fr * tg_xxxxxyy_yyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yyyzzz_0[j] - tg_xxxxyy_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxyy_yyzzzz_0[j] = pb_x * tg_xxxxxyy_yyzzzz_0[j] + fr * tg_xxxxxyy_yyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yyzzzz_0[j] - tg_xxxxyy_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyy_yzzzzz_0[j] = pb_x * tg_xxxxxyy_yzzzzz_0[j] + fr * tg_xxxxxyy_yzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_yzzzzz_0[j] - tg_xxxxyy_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyy_zzzzzz_0[j] = pb_x * tg_xxxxxyy_zzzzzz_0[j] + fr * tg_xxxxxyy_zzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyy_zzzzzz_0[j] - tg_xxxxyy_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyz_xxxxxx_0[j] = pb_x * tg_xxxxxyz_xxxxxx_0[j] + fr * tg_xxxxxyz_xxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxxx_0[j] - tg_xxxxyz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxyz_xxxxx_1[j];

                    tg_xxxxxxyz_xxxxxy_0[j] = pb_x * tg_xxxxxyz_xxxxxy_0[j] + fr * tg_xxxxxyz_xxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxxy_0[j] - tg_xxxxyz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxyz_xxxxy_1[j];

                    tg_xxxxxxyz_xxxxxz_0[j] = pb_x * tg_xxxxxyz_xxxxxz_0[j] + fr * tg_xxxxxyz_xxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxxz_0[j] - tg_xxxxyz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxyz_xxxxz_1[j];

                    tg_xxxxxxyz_xxxxyy_0[j] = pb_x * tg_xxxxxyz_xxxxyy_0[j] + fr * tg_xxxxxyz_xxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxyy_0[j] - tg_xxxxyz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyz_xxxyy_1[j];

                    tg_xxxxxxyz_xxxxyz_0[j] = pb_x * tg_xxxxxyz_xxxxyz_0[j] + fr * tg_xxxxxyz_xxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxyz_0[j] - tg_xxxxyz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyz_xxxyz_1[j];

                    tg_xxxxxxyz_xxxxzz_0[j] = pb_x * tg_xxxxxyz_xxxxzz_0[j] + fr * tg_xxxxxyz_xxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxxzz_0[j] - tg_xxxxyz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxyz_xxxzz_1[j];

                    tg_xxxxxxyz_xxxyyy_0[j] = pb_x * tg_xxxxxyz_xxxyyy_0[j] + fr * tg_xxxxxyz_xxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxyyy_0[j] - tg_xxxxyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyz_xxyyy_1[j];

                    tg_xxxxxxyz_xxxyyz_0[j] = pb_x * tg_xxxxxyz_xxxyyz_0[j] + fr * tg_xxxxxyz_xxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxyyz_0[j] - tg_xxxxyz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyz_xxyyz_1[j];

                    tg_xxxxxxyz_xxxyzz_0[j] = pb_x * tg_xxxxxyz_xxxyzz_0[j] + fr * tg_xxxxxyz_xxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxyzz_0[j] - tg_xxxxyz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyz_xxyzz_1[j];

                    tg_xxxxxxyz_xxxzzz_0[j] = pb_x * tg_xxxxxyz_xxxzzz_0[j] + fr * tg_xxxxxyz_xxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxxzzz_0[j] - tg_xxxxyz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxyz_xxzzz_1[j];

                    tg_xxxxxxyz_xxyyyy_0[j] = pb_x * tg_xxxxxyz_xxyyyy_0[j] + fr * tg_xxxxxyz_xxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxyyyy_0[j] - tg_xxxxyz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_xyyyy_1[j];

                    tg_xxxxxxyz_xxyyyz_0[j] = pb_x * tg_xxxxxyz_xxyyyz_0[j] + fr * tg_xxxxxyz_xxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxyyyz_0[j] - tg_xxxxyz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_xyyyz_1[j];

                    tg_xxxxxxyz_xxyyzz_0[j] = pb_x * tg_xxxxxyz_xxyyzz_0[j] + fr * tg_xxxxxyz_xxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxyyzz_0[j] - tg_xxxxyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_xyyzz_1[j];

                    tg_xxxxxxyz_xxyzzz_0[j] = pb_x * tg_xxxxxyz_xxyzzz_0[j] + fr * tg_xxxxxyz_xxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxyzzz_0[j] - tg_xxxxyz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_xyzzz_1[j];

                    tg_xxxxxxyz_xxzzzz_0[j] = pb_x * tg_xxxxxyz_xxzzzz_0[j] + fr * tg_xxxxxyz_xxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xxzzzz_0[j] - tg_xxxxyz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxyz_xzzzz_1[j];

                    tg_xxxxxxyz_xyyyyy_0[j] = pb_x * tg_xxxxxyz_xyyyyy_0[j] + fr * tg_xxxxxyz_xyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xyyyyy_0[j] - tg_xxxxyz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_yyyyy_1[j];

                    tg_xxxxxxyz_xyyyyz_0[j] = pb_x * tg_xxxxxyz_xyyyyz_0[j] + fr * tg_xxxxxyz_xyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xyyyyz_0[j] - tg_xxxxyz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_yyyyz_1[j];

                    tg_xxxxxxyz_xyyyzz_0[j] = pb_x * tg_xxxxxyz_xyyyzz_0[j] + fr * tg_xxxxxyz_xyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xyyyzz_0[j] - tg_xxxxyz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_yyyzz_1[j];

                    tg_xxxxxxyz_xyyzzz_0[j] = pb_x * tg_xxxxxyz_xyyzzz_0[j] + fr * tg_xxxxxyz_xyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xyyzzz_0[j] - tg_xxxxyz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_yyzzz_1[j];

                    tg_xxxxxxyz_xyzzzz_0[j] = pb_x * tg_xxxxxyz_xyzzzz_0[j] + fr * tg_xxxxxyz_xyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xyzzzz_0[j] - tg_xxxxyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_yzzzz_1[j];

                    tg_xxxxxxyz_xzzzzz_0[j] = pb_x * tg_xxxxxyz_xzzzzz_0[j] + fr * tg_xxxxxyz_xzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_xzzzzz_0[j] - tg_xxxxyz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxyz_zzzzz_1[j];

                    tg_xxxxxxyz_yyyyyy_0[j] = pb_x * tg_xxxxxyz_yyyyyy_0[j] + fr * tg_xxxxxyz_yyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yyyyyy_0[j] - tg_xxxxyz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxyz_yyyyyz_0[j] = pb_x * tg_xxxxxyz_yyyyyz_0[j] + fr * tg_xxxxxyz_yyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yyyyyz_0[j] - tg_xxxxyz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxyz_yyyyzz_0[j] = pb_x * tg_xxxxxyz_yyyyzz_0[j] + fr * tg_xxxxxyz_yyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yyyyzz_0[j] - tg_xxxxyz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxyz_yyyzzz_0[j] = pb_x * tg_xxxxxyz_yyyzzz_0[j] + fr * tg_xxxxxyz_yyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yyyzzz_0[j] - tg_xxxxyz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxyz_yyzzzz_0[j] = pb_x * tg_xxxxxyz_yyzzzz_0[j] + fr * tg_xxxxxyz_yyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yyzzzz_0[j] - tg_xxxxyz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyz_yzzzzz_0[j] = pb_x * tg_xxxxxyz_yzzzzz_0[j] + fr * tg_xxxxxyz_yzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_yzzzzz_0[j] - tg_xxxxyz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxyz_zzzzzz_0[j] = pb_x * tg_xxxxxyz_zzzzzz_0[j] + fr * tg_xxxxxyz_zzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxyz_zzzzzz_0[j] - tg_xxxxyz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxzz_xxxxxx_0[j] = pb_x * tg_xxxxxzz_xxxxxx_0[j] + fr * tg_xxxxxzz_xxxxxx_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxxx_0[j] - tg_xxxxzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxxzz_xxxxx_1[j];

                    tg_xxxxxxzz_xxxxxy_0[j] = pb_x * tg_xxxxxzz_xxxxxy_0[j] + fr * tg_xxxxxzz_xxxxxy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxxy_0[j] - tg_xxxxzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxzz_xxxxy_1[j];

                    tg_xxxxxxzz_xxxxxz_0[j] = pb_x * tg_xxxxxzz_xxxxxz_0[j] + fr * tg_xxxxxzz_xxxxxz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxxz_0[j] - tg_xxxxzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxxzz_xxxxz_1[j];

                    tg_xxxxxxzz_xxxxyy_0[j] = pb_x * tg_xxxxxzz_xxxxyy_0[j] + fr * tg_xxxxxzz_xxxxyy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxyy_0[j] - tg_xxxxzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxzz_xxxyy_1[j];

                    tg_xxxxxxzz_xxxxyz_0[j] = pb_x * tg_xxxxxzz_xxxxyz_0[j] + fr * tg_xxxxxzz_xxxxyz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxyz_0[j] - tg_xxxxzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxzz_xxxyz_1[j];

                    tg_xxxxxxzz_xxxxzz_0[j] = pb_x * tg_xxxxxzz_xxxxzz_0[j] + fr * tg_xxxxxzz_xxxxzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxxzz_0[j] - tg_xxxxzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxxzz_xxxzz_1[j];

                    tg_xxxxxxzz_xxxyyy_0[j] = pb_x * tg_xxxxxzz_xxxyyy_0[j] + fr * tg_xxxxxzz_xxxyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxyyy_0[j] - tg_xxxxzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxzz_xxyyy_1[j];

                    tg_xxxxxxzz_xxxyyz_0[j] = pb_x * tg_xxxxxzz_xxxyyz_0[j] + fr * tg_xxxxxzz_xxxyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxyyz_0[j] - tg_xxxxzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxzz_xxyyz_1[j];

                    tg_xxxxxxzz_xxxyzz_0[j] = pb_x * tg_xxxxxzz_xxxyzz_0[j] + fr * tg_xxxxxzz_xxxyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxyzz_0[j] - tg_xxxxzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxzz_xxyzz_1[j];

                    tg_xxxxxxzz_xxxzzz_0[j] = pb_x * tg_xxxxxzz_xxxzzz_0[j] + fr * tg_xxxxxzz_xxxzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxxzzz_0[j] - tg_xxxxzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxxzz_xxzzz_1[j];

                    tg_xxxxxxzz_xxyyyy_0[j] = pb_x * tg_xxxxxzz_xxyyyy_0[j] + fr * tg_xxxxxzz_xxyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxyyyy_0[j] - tg_xxxxzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_xyyyy_1[j];

                    tg_xxxxxxzz_xxyyyz_0[j] = pb_x * tg_xxxxxzz_xxyyyz_0[j] + fr * tg_xxxxxzz_xxyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxyyyz_0[j] - tg_xxxxzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_xyyyz_1[j];

                    tg_xxxxxxzz_xxyyzz_0[j] = pb_x * tg_xxxxxzz_xxyyzz_0[j] + fr * tg_xxxxxzz_xxyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxyyzz_0[j] - tg_xxxxzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_xyyzz_1[j];

                    tg_xxxxxxzz_xxyzzz_0[j] = pb_x * tg_xxxxxzz_xxyzzz_0[j] + fr * tg_xxxxxzz_xxyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxyzzz_0[j] - tg_xxxxzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_xyzzz_1[j];

                    tg_xxxxxxzz_xxzzzz_0[j] = pb_x * tg_xxxxxzz_xxzzzz_0[j] + fr * tg_xxxxxzz_xxzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xxzzzz_0[j] - tg_xxxxzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxxzz_xzzzz_1[j];

                    tg_xxxxxxzz_xyyyyy_0[j] = pb_x * tg_xxxxxzz_xyyyyy_0[j] + fr * tg_xxxxxzz_xyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xyyyyy_0[j] - tg_xxxxzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_yyyyy_1[j];

                    tg_xxxxxxzz_xyyyyz_0[j] = pb_x * tg_xxxxxzz_xyyyyz_0[j] + fr * tg_xxxxxzz_xyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xyyyyz_0[j] - tg_xxxxzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_yyyyz_1[j];

                    tg_xxxxxxzz_xyyyzz_0[j] = pb_x * tg_xxxxxzz_xyyyzz_0[j] + fr * tg_xxxxxzz_xyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xyyyzz_0[j] - tg_xxxxzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_yyyzz_1[j];

                    tg_xxxxxxzz_xyyzzz_0[j] = pb_x * tg_xxxxxzz_xyyzzz_0[j] + fr * tg_xxxxxzz_xyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xyyzzz_0[j] - tg_xxxxzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_yyzzz_1[j];

                    tg_xxxxxxzz_xyzzzz_0[j] = pb_x * tg_xxxxxzz_xyzzzz_0[j] + fr * tg_xxxxxzz_xyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xyzzzz_0[j] - tg_xxxxzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_yzzzz_1[j];

                    tg_xxxxxxzz_xzzzzz_0[j] = pb_x * tg_xxxxxzz_xzzzzz_0[j] + fr * tg_xxxxxzz_xzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_xzzzzz_0[j] - tg_xxxxzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxxzz_zzzzz_1[j];

                    tg_xxxxxxzz_yyyyyy_0[j] = pb_x * tg_xxxxxzz_yyyyyy_0[j] + fr * tg_xxxxxzz_yyyyyy_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yyyyyy_0[j] - tg_xxxxzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxxzz_yyyyyz_0[j] = pb_x * tg_xxxxxzz_yyyyyz_0[j] + fr * tg_xxxxxzz_yyyyyz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yyyyyz_0[j] - tg_xxxxzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxxzz_yyyyzz_0[j] = pb_x * tg_xxxxxzz_yyyyzz_0[j] + fr * tg_xxxxxzz_yyyyzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yyyyzz_0[j] - tg_xxxxzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxxzz_yyyzzz_0[j] = pb_x * tg_xxxxxzz_yyyzzz_0[j] + fr * tg_xxxxxzz_yyyzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yyyzzz_0[j] - tg_xxxxzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxxzz_yyzzzz_0[j] = pb_x * tg_xxxxxzz_yyzzzz_0[j] + fr * tg_xxxxxzz_yyzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yyzzzz_0[j] - tg_xxxxzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxxzz_yzzzzz_0[j] = pb_x * tg_xxxxxzz_yzzzzz_0[j] + fr * tg_xxxxxzz_yzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_yzzzzz_0[j] - tg_xxxxzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxxzz_zzzzzz_0[j] = pb_x * tg_xxxxxzz_zzzzzz_0[j] + fr * tg_xxxxxzz_zzzzzz_1[j] + 2.5 * fl1_fx * (tg_xxxxzz_zzzzzz_0[j] - tg_xxxxzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyyy_xxxxxx_0[j] = pb_x * tg_xxxxyyy_xxxxxx_0[j] + fr * tg_xxxxyyy_xxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxxx_0[j] - tg_xxxyyy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyyy_xxxxx_1[j];

                    tg_xxxxxyyy_xxxxxy_0[j] = pb_x * tg_xxxxyyy_xxxxxy_0[j] + fr * tg_xxxxyyy_xxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxxy_0[j] - tg_xxxyyy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyyy_xxxxy_1[j];

                    tg_xxxxxyyy_xxxxxz_0[j] = pb_x * tg_xxxxyyy_xxxxxz_0[j] + fr * tg_xxxxyyy_xxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxxz_0[j] - tg_xxxyyy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyyy_xxxxz_1[j];

                    tg_xxxxxyyy_xxxxyy_0[j] = pb_x * tg_xxxxyyy_xxxxyy_0[j] + fr * tg_xxxxyyy_xxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxyy_0[j] - tg_xxxyyy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyy_xxxyy_1[j];

                    tg_xxxxxyyy_xxxxyz_0[j] = pb_x * tg_xxxxyyy_xxxxyz_0[j] + fr * tg_xxxxyyy_xxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxyz_0[j] - tg_xxxyyy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyy_xxxyz_1[j];

                    tg_xxxxxyyy_xxxxzz_0[j] = pb_x * tg_xxxxyyy_xxxxzz_0[j] + fr * tg_xxxxyyy_xxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxxzz_0[j] - tg_xxxyyy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyy_xxxzz_1[j];

                    tg_xxxxxyyy_xxxyyy_0[j] = pb_x * tg_xxxxyyy_xxxyyy_0[j] + fr * tg_xxxxyyy_xxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxyyy_0[j] - tg_xxxyyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyy_xxyyy_1[j];

                    tg_xxxxxyyy_xxxyyz_0[j] = pb_x * tg_xxxxyyy_xxxyyz_0[j] + fr * tg_xxxxyyy_xxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxyyz_0[j] - tg_xxxyyy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyy_xxyyz_1[j];

                    tg_xxxxxyyy_xxxyzz_0[j] = pb_x * tg_xxxxyyy_xxxyzz_0[j] + fr * tg_xxxxyyy_xxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxyzz_0[j] - tg_xxxyyy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyy_xxyzz_1[j];

                    tg_xxxxxyyy_xxxzzz_0[j] = pb_x * tg_xxxxyyy_xxxzzz_0[j] + fr * tg_xxxxyyy_xxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxxzzz_0[j] - tg_xxxyyy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyy_xxzzz_1[j];

                    tg_xxxxxyyy_xxyyyy_0[j] = pb_x * tg_xxxxyyy_xxyyyy_0[j] + fr * tg_xxxxyyy_xxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxyyyy_0[j] - tg_xxxyyy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_xyyyy_1[j];

                    tg_xxxxxyyy_xxyyyz_0[j] = pb_x * tg_xxxxyyy_xxyyyz_0[j] + fr * tg_xxxxyyy_xxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxyyyz_0[j] - tg_xxxyyy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_xyyyz_1[j];

                    tg_xxxxxyyy_xxyyzz_0[j] = pb_x * tg_xxxxyyy_xxyyzz_0[j] + fr * tg_xxxxyyy_xxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxyyzz_0[j] - tg_xxxyyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_xyyzz_1[j];

                    tg_xxxxxyyy_xxyzzz_0[j] = pb_x * tg_xxxxyyy_xxyzzz_0[j] + fr * tg_xxxxyyy_xxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxyzzz_0[j] - tg_xxxyyy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_xyzzz_1[j];

                    tg_xxxxxyyy_xxzzzz_0[j] = pb_x * tg_xxxxyyy_xxzzzz_0[j] + fr * tg_xxxxyyy_xxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xxzzzz_0[j] - tg_xxxyyy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyy_xzzzz_1[j];

                    tg_xxxxxyyy_xyyyyy_0[j] = pb_x * tg_xxxxyyy_xyyyyy_0[j] + fr * tg_xxxxyyy_xyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xyyyyy_0[j] - tg_xxxyyy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_yyyyy_1[j];

                    tg_xxxxxyyy_xyyyyz_0[j] = pb_x * tg_xxxxyyy_xyyyyz_0[j] + fr * tg_xxxxyyy_xyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xyyyyz_0[j] - tg_xxxyyy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_yyyyz_1[j];

                    tg_xxxxxyyy_xyyyzz_0[j] = pb_x * tg_xxxxyyy_xyyyzz_0[j] + fr * tg_xxxxyyy_xyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xyyyzz_0[j] - tg_xxxyyy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_yyyzz_1[j];

                    tg_xxxxxyyy_xyyzzz_0[j] = pb_x * tg_xxxxyyy_xyyzzz_0[j] + fr * tg_xxxxyyy_xyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xyyzzz_0[j] - tg_xxxyyy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_yyzzz_1[j];

                    tg_xxxxxyyy_xyzzzz_0[j] = pb_x * tg_xxxxyyy_xyzzzz_0[j] + fr * tg_xxxxyyy_xyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xyzzzz_0[j] - tg_xxxyyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_yzzzz_1[j];

                    tg_xxxxxyyy_xzzzzz_0[j] = pb_x * tg_xxxxyyy_xzzzzz_0[j] + fr * tg_xxxxyyy_xzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_xzzzzz_0[j] - tg_xxxyyy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyy_zzzzz_1[j];

                    tg_xxxxxyyy_yyyyyy_0[j] = pb_x * tg_xxxxyyy_yyyyyy_0[j] + fr * tg_xxxxyyy_yyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yyyyyy_0[j] - tg_xxxyyy_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxyyy_yyyyyz_0[j] = pb_x * tg_xxxxyyy_yyyyyz_0[j] + fr * tg_xxxxyyy_yyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yyyyyz_0[j] - tg_xxxyyy_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxyyy_yyyyzz_0[j] = pb_x * tg_xxxxyyy_yyyyzz_0[j] + fr * tg_xxxxyyy_yyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yyyyzz_0[j] - tg_xxxyyy_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxyyy_yyyzzz_0[j] = pb_x * tg_xxxxyyy_yyyzzz_0[j] + fr * tg_xxxxyyy_yyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yyyzzz_0[j] - tg_xxxyyy_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxyyy_yyzzzz_0[j] = pb_x * tg_xxxxyyy_yyzzzz_0[j] + fr * tg_xxxxyyy_yyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yyzzzz_0[j] - tg_xxxyyy_yyzzzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_194_291(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (194,291)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxxyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 194); 

                auto tg_xxxxyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 195); 

                auto tg_xxxxyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 196); 

                auto tg_xxxxyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 197); 

                auto tg_xxxxyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 198); 

                auto tg_xxxxyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 199); 

                auto tg_xxxxyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 200); 

                auto tg_xxxxyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 201); 

                auto tg_xxxxyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 202); 

                auto tg_xxxxyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 203); 

                auto tg_xxxxyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 204); 

                auto tg_xxxxyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 205); 

                auto tg_xxxxyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 206); 

                auto tg_xxxxyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 207); 

                auto tg_xxxxyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 208); 

                auto tg_xxxxyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 209); 

                auto tg_xxxxyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 210); 

                auto tg_xxxxyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 211); 

                auto tg_xxxxyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 212); 

                auto tg_xxxxyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 213); 

                auto tg_xxxxyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 214); 

                auto tg_xxxxyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 215); 

                auto tg_xxxxyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 216); 

                auto tg_xxxxyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 217); 

                auto tg_xxxxyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 218); 

                auto tg_xxxxyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 219); 

                auto tg_xxxxyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 220); 

                auto tg_xxxxyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 221); 

                auto tg_xxxxyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 222); 

                auto tg_xxxxyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 223); 

                auto tg_xxxxyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 224); 

                auto tg_xxxxyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 225); 

                auto tg_xxxxyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 226); 

                auto tg_xxxxyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 227); 

                auto tg_xxxxyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 228); 

                auto tg_xxxxyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 229); 

                auto tg_xxxxyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 230); 

                auto tg_xxxxyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 231); 

                auto tg_xxxxyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 232); 

                auto tg_xxxxyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 233); 

                auto tg_xxxxyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 234); 

                auto tg_xxxxyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 235); 

                auto tg_xxxxyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 236); 

                auto tg_xxxxyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 237); 

                auto tg_xxxxyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 238); 

                auto tg_xxxxyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 239); 

                auto tg_xxxxyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 240); 

                auto tg_xxxxyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 241); 

                auto tg_xxxxyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 242); 

                auto tg_xxxxyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 243); 

                auto tg_xxxxyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 244); 

                auto tg_xxxxyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 245); 

                auto tg_xxxxyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 246); 

                auto tg_xxxxyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 247); 

                auto tg_xxxxyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 248); 

                auto tg_xxxxyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 249); 

                auto tg_xxxxyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 250); 

                auto tg_xxxxyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 251); 

                auto tg_xxxxzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 252); 

                auto tg_xxxxzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 253); 

                auto tg_xxxxzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 254); 

                auto tg_xxxxzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 255); 

                auto tg_xxxxzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 256); 

                auto tg_xxxxzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 257); 

                auto tg_xxxxzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 258); 

                auto tg_xxxxzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 259); 

                auto tg_xxxxzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 260); 

                auto tg_xxxxzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 261); 

                auto tg_xxxxzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 262); 

                auto tg_xxxxzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 263); 

                auto tg_xxxxzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 264); 

                auto tg_xxxxzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 265); 

                auto tg_xxxxzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 266); 

                auto tg_xxxxzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 267); 

                auto tg_xxxxzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 268); 

                auto tg_xxxxzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 269); 

                auto tg_xxxxzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 270); 

                auto tg_xxxxzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 271); 

                auto tg_xxxxzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 272); 

                auto tg_xxxxzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 273); 

                auto tg_xxxxzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 274); 

                auto tg_xxxxzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 275); 

                auto tg_xxxxzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 276); 

                auto tg_xxxxzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 277); 

                auto tg_xxxxzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 278); 

                auto tg_xxxxzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 279); 

                auto tg_xxxyyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 280); 

                auto tg_xxxyyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 281); 

                auto tg_xxxyyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 282); 

                auto tg_xxxyyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 283); 

                auto tg_xxxyyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 284); 

                auto tg_xxxyyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 285); 

                auto tg_xxxyyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 286); 

                auto tg_xxxyyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 287); 

                auto tg_xxxyyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 288); 

                auto tg_xxxyyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 289); 

                auto tg_xxxyyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 290); 

                auto tg_xxxxyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 194); 

                auto tg_xxxxyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 195); 

                auto tg_xxxxyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 196); 

                auto tg_xxxxyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 197); 

                auto tg_xxxxyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 198); 

                auto tg_xxxxyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 199); 

                auto tg_xxxxyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 200); 

                auto tg_xxxxyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 201); 

                auto tg_xxxxyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 202); 

                auto tg_xxxxyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 203); 

                auto tg_xxxxyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 204); 

                auto tg_xxxxyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 205); 

                auto tg_xxxxyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 206); 

                auto tg_xxxxyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 207); 

                auto tg_xxxxyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 208); 

                auto tg_xxxxyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 209); 

                auto tg_xxxxyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 210); 

                auto tg_xxxxyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 211); 

                auto tg_xxxxyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 212); 

                auto tg_xxxxyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 213); 

                auto tg_xxxxyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 214); 

                auto tg_xxxxyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 215); 

                auto tg_xxxxyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 216); 

                auto tg_xxxxyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 217); 

                auto tg_xxxxyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 218); 

                auto tg_xxxxyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 219); 

                auto tg_xxxxyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 220); 

                auto tg_xxxxyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 221); 

                auto tg_xxxxyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 222); 

                auto tg_xxxxyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 223); 

                auto tg_xxxxyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 224); 

                auto tg_xxxxyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 225); 

                auto tg_xxxxyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 226); 

                auto tg_xxxxyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 227); 

                auto tg_xxxxyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 228); 

                auto tg_xxxxyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 229); 

                auto tg_xxxxyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 230); 

                auto tg_xxxxyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 231); 

                auto tg_xxxxyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 232); 

                auto tg_xxxxyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 233); 

                auto tg_xxxxyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 234); 

                auto tg_xxxxyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 235); 

                auto tg_xxxxyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 236); 

                auto tg_xxxxyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 237); 

                auto tg_xxxxyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 238); 

                auto tg_xxxxyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 239); 

                auto tg_xxxxyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 240); 

                auto tg_xxxxyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 241); 

                auto tg_xxxxyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 242); 

                auto tg_xxxxyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 243); 

                auto tg_xxxxyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 244); 

                auto tg_xxxxyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 245); 

                auto tg_xxxxyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 246); 

                auto tg_xxxxyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 247); 

                auto tg_xxxxyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 248); 

                auto tg_xxxxyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 249); 

                auto tg_xxxxyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 250); 

                auto tg_xxxxyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 251); 

                auto tg_xxxxzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 252); 

                auto tg_xxxxzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 253); 

                auto tg_xxxxzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 254); 

                auto tg_xxxxzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 255); 

                auto tg_xxxxzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 256); 

                auto tg_xxxxzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 257); 

                auto tg_xxxxzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 258); 

                auto tg_xxxxzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 259); 

                auto tg_xxxxzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 260); 

                auto tg_xxxxzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 261); 

                auto tg_xxxxzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 262); 

                auto tg_xxxxzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 263); 

                auto tg_xxxxzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 264); 

                auto tg_xxxxzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 265); 

                auto tg_xxxxzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 266); 

                auto tg_xxxxzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 267); 

                auto tg_xxxxzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 268); 

                auto tg_xxxxzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 269); 

                auto tg_xxxxzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 270); 

                auto tg_xxxxzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 271); 

                auto tg_xxxxzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 272); 

                auto tg_xxxxzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 273); 

                auto tg_xxxxzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 274); 

                auto tg_xxxxzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 275); 

                auto tg_xxxxzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 276); 

                auto tg_xxxxzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 277); 

                auto tg_xxxxzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 278); 

                auto tg_xxxxzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 279); 

                auto tg_xxxyyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 280); 

                auto tg_xxxyyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 281); 

                auto tg_xxxyyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 282); 

                auto tg_xxxyyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 283); 

                auto tg_xxxyyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 284); 

                auto tg_xxxyyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 285); 

                auto tg_xxxyyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 286); 

                auto tg_xxxyyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 287); 

                auto tg_xxxyyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 288); 

                auto tg_xxxyyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 289); 

                auto tg_xxxyyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 290); 

                auto tg_xxxyyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 194); 

                auto tg_xxxyyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 195); 

                auto tg_xxxyyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 196); 

                auto tg_xxxyyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 197); 

                auto tg_xxxyyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 198); 

                auto tg_xxxyyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 199); 

                auto tg_xxxyyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 200); 

                auto tg_xxxyyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 201); 

                auto tg_xxxyyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 202); 

                auto tg_xxxyyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 203); 

                auto tg_xxxyyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 204); 

                auto tg_xxxyyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 205); 

                auto tg_xxxyyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 206); 

                auto tg_xxxyyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 207); 

                auto tg_xxxyyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 208); 

                auto tg_xxxyyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 209); 

                auto tg_xxxyyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 210); 

                auto tg_xxxyyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 211); 

                auto tg_xxxyyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 212); 

                auto tg_xxxyyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 213); 

                auto tg_xxxyyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 214); 

                auto tg_xxxyyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 215); 

                auto tg_xxxyyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 216); 

                auto tg_xxxyyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 217); 

                auto tg_xxxyyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 218); 

                auto tg_xxxyyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 219); 

                auto tg_xxxyyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 220); 

                auto tg_xxxyyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 221); 

                auto tg_xxxyyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 222); 

                auto tg_xxxyyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 223); 

                auto tg_xxxyzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 224); 

                auto tg_xxxyzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 225); 

                auto tg_xxxyzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 226); 

                auto tg_xxxyzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 227); 

                auto tg_xxxyzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 228); 

                auto tg_xxxyzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 229); 

                auto tg_xxxyzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 230); 

                auto tg_xxxyzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 231); 

                auto tg_xxxyzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 232); 

                auto tg_xxxyzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 233); 

                auto tg_xxxyzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 234); 

                auto tg_xxxyzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 235); 

                auto tg_xxxyzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 236); 

                auto tg_xxxyzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 237); 

                auto tg_xxxyzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 238); 

                auto tg_xxxyzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 239); 

                auto tg_xxxyzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 240); 

                auto tg_xxxyzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 241); 

                auto tg_xxxyzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 242); 

                auto tg_xxxyzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 243); 

                auto tg_xxxyzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 244); 

                auto tg_xxxyzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 245); 

                auto tg_xxxyzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 246); 

                auto tg_xxxyzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 247); 

                auto tg_xxxyzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 248); 

                auto tg_xxxyzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 249); 

                auto tg_xxxyzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 250); 

                auto tg_xxxyzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 251); 

                auto tg_xxxzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 252); 

                auto tg_xxxzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 253); 

                auto tg_xxxzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 254); 

                auto tg_xxxzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 255); 

                auto tg_xxxzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 256); 

                auto tg_xxxzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 257); 

                auto tg_xxxzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 258); 

                auto tg_xxxzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 259); 

                auto tg_xxxzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 260); 

                auto tg_xxxzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 261); 

                auto tg_xxxzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 262); 

                auto tg_xxxzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 263); 

                auto tg_xxxzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 264); 

                auto tg_xxxzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 265); 

                auto tg_xxxzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 266); 

                auto tg_xxxzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 267); 

                auto tg_xxxzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 268); 

                auto tg_xxxzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 269); 

                auto tg_xxxzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 270); 

                auto tg_xxxzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 271); 

                auto tg_xxxzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 272); 

                auto tg_xxxzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 273); 

                auto tg_xxxzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 274); 

                auto tg_xxxzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 275); 

                auto tg_xxxzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 276); 

                auto tg_xxxzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 277); 

                auto tg_xxxzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 278); 

                auto tg_xxxzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 279); 

                auto tg_xxyyyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 280); 

                auto tg_xxyyyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 281); 

                auto tg_xxyyyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 282); 

                auto tg_xxyyyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 283); 

                auto tg_xxyyyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 284); 

                auto tg_xxyyyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 285); 

                auto tg_xxyyyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 286); 

                auto tg_xxyyyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 287); 

                auto tg_xxyyyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 288); 

                auto tg_xxyyyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 289); 

                auto tg_xxyyyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 290); 

                auto tg_xxxyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 194); 

                auto tg_xxxyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 195); 

                auto tg_xxxyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 196); 

                auto tg_xxxyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 197); 

                auto tg_xxxyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 198); 

                auto tg_xxxyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 199); 

                auto tg_xxxyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 200); 

                auto tg_xxxyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 201); 

                auto tg_xxxyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 202); 

                auto tg_xxxyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 203); 

                auto tg_xxxyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 204); 

                auto tg_xxxyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 205); 

                auto tg_xxxyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 206); 

                auto tg_xxxyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 207); 

                auto tg_xxxyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 208); 

                auto tg_xxxyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 209); 

                auto tg_xxxyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 210); 

                auto tg_xxxyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 211); 

                auto tg_xxxyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 212); 

                auto tg_xxxyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 213); 

                auto tg_xxxyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 214); 

                auto tg_xxxyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 215); 

                auto tg_xxxyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 216); 

                auto tg_xxxyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 217); 

                auto tg_xxxyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 218); 

                auto tg_xxxyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 219); 

                auto tg_xxxyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 220); 

                auto tg_xxxyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 221); 

                auto tg_xxxyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 222); 

                auto tg_xxxyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 223); 

                auto tg_xxxyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 224); 

                auto tg_xxxyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 225); 

                auto tg_xxxyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 226); 

                auto tg_xxxyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 227); 

                auto tg_xxxyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 228); 

                auto tg_xxxyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 229); 

                auto tg_xxxyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 230); 

                auto tg_xxxyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 231); 

                auto tg_xxxyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 232); 

                auto tg_xxxyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 233); 

                auto tg_xxxyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 234); 

                auto tg_xxxyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 235); 

                auto tg_xxxyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 236); 

                auto tg_xxxyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 237); 

                auto tg_xxxyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 238); 

                auto tg_xxxyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 239); 

                auto tg_xxxyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 240); 

                auto tg_xxxyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 241); 

                auto tg_xxxyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 242); 

                auto tg_xxxyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 243); 

                auto tg_xxxyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 244); 

                auto tg_xxxyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 245); 

                auto tg_xxxyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 246); 

                auto tg_xxxyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 247); 

                auto tg_xxxyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 248); 

                auto tg_xxxyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 249); 

                auto tg_xxxyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 250); 

                auto tg_xxxyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 251); 

                auto tg_xxxzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 252); 

                auto tg_xxxzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 253); 

                auto tg_xxxzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 254); 

                auto tg_xxxzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 255); 

                auto tg_xxxzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 256); 

                auto tg_xxxzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 257); 

                auto tg_xxxzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 258); 

                auto tg_xxxzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 259); 

                auto tg_xxxzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 260); 

                auto tg_xxxzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 261); 

                auto tg_xxxzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 262); 

                auto tg_xxxzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 263); 

                auto tg_xxxzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 264); 

                auto tg_xxxzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 265); 

                auto tg_xxxzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 266); 

                auto tg_xxxzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 267); 

                auto tg_xxxzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 268); 

                auto tg_xxxzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 269); 

                auto tg_xxxzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 270); 

                auto tg_xxxzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 271); 

                auto tg_xxxzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 272); 

                auto tg_xxxzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 273); 

                auto tg_xxxzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 274); 

                auto tg_xxxzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 275); 

                auto tg_xxxzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 276); 

                auto tg_xxxzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 277); 

                auto tg_xxxzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 278); 

                auto tg_xxxzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 279); 

                auto tg_xxyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 280); 

                auto tg_xxyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 281); 

                auto tg_xxyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 282); 

                auto tg_xxyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 283); 

                auto tg_xxyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 284); 

                auto tg_xxyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 285); 

                auto tg_xxyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 286); 

                auto tg_xxyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 287); 

                auto tg_xxyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 288); 

                auto tg_xxyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 289); 

                auto tg_xxyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 290); 

                auto tg_xxxxyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 147); 

                auto tg_xxxxyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 148); 

                auto tg_xxxxyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 149); 

                auto tg_xxxxyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 150); 

                auto tg_xxxxyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 151); 

                auto tg_xxxxyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 152); 

                auto tg_xxxxyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 153); 

                auto tg_xxxxyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 154); 

                auto tg_xxxxyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 155); 

                auto tg_xxxxyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 156); 

                auto tg_xxxxyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 157); 

                auto tg_xxxxyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 158); 

                auto tg_xxxxyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 159); 

                auto tg_xxxxyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 160); 

                auto tg_xxxxyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 161); 

                auto tg_xxxxyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 162); 

                auto tg_xxxxyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 163); 

                auto tg_xxxxyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 164); 

                auto tg_xxxxyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 165); 

                auto tg_xxxxyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 166); 

                auto tg_xxxxyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 167); 

                auto tg_xxxxyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 168); 

                auto tg_xxxxyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 169); 

                auto tg_xxxxyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 170); 

                auto tg_xxxxyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 171); 

                auto tg_xxxxyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 172); 

                auto tg_xxxxyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 173); 

                auto tg_xxxxyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 174); 

                auto tg_xxxxyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 175); 

                auto tg_xxxxyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 176); 

                auto tg_xxxxyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 177); 

                auto tg_xxxxyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 178); 

                auto tg_xxxxyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 179); 

                auto tg_xxxxyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 180); 

                auto tg_xxxxyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 181); 

                auto tg_xxxxyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 182); 

                auto tg_xxxxyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 183); 

                auto tg_xxxxyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 184); 

                auto tg_xxxxyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 185); 

                auto tg_xxxxyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 186); 

                auto tg_xxxxyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 187); 

                auto tg_xxxxyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 188); 

                auto tg_xxxxzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 189); 

                auto tg_xxxxzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 190); 

                auto tg_xxxxzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 191); 

                auto tg_xxxxzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 192); 

                auto tg_xxxxzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 193); 

                auto tg_xxxxzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 194); 

                auto tg_xxxxzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 195); 

                auto tg_xxxxzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 196); 

                auto tg_xxxxzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 197); 

                auto tg_xxxxzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 198); 

                auto tg_xxxxzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 199); 

                auto tg_xxxxzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 200); 

                auto tg_xxxxzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 201); 

                auto tg_xxxxzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 202); 

                auto tg_xxxxzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 203); 

                auto tg_xxxxzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 204); 

                auto tg_xxxxzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 205); 

                auto tg_xxxxzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 206); 

                auto tg_xxxxzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 207); 

                auto tg_xxxxzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 208); 

                auto tg_xxxxzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 209); 

                auto tg_xxxyyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 210); 

                auto tg_xxxyyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 211); 

                auto tg_xxxyyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 212); 

                auto tg_xxxyyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 213); 

                auto tg_xxxyyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 214); 

                auto tg_xxxyyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 215); 

                auto tg_xxxyyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 216); 

                auto tg_xxxyyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 217); 

                auto tg_xxxyyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 218); 

                auto tg_xxxyyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 219); 

                auto tg_xxxyyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 220); 

                // set up pointers to integrals

                auto tg_xxxxxyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 194); 

                auto tg_xxxxxyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 195); 

                auto tg_xxxxxyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 196); 

                auto tg_xxxxxyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 197); 

                auto tg_xxxxxyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 198); 

                auto tg_xxxxxyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 199); 

                auto tg_xxxxxyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 200); 

                auto tg_xxxxxyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 201); 

                auto tg_xxxxxyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 202); 

                auto tg_xxxxxyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 203); 

                auto tg_xxxxxyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 204); 

                auto tg_xxxxxyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 205); 

                auto tg_xxxxxyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 206); 

                auto tg_xxxxxyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 207); 

                auto tg_xxxxxyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 208); 

                auto tg_xxxxxyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 209); 

                auto tg_xxxxxyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 210); 

                auto tg_xxxxxyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 211); 

                auto tg_xxxxxyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 212); 

                auto tg_xxxxxyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 213); 

                auto tg_xxxxxyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 214); 

                auto tg_xxxxxyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 215); 

                auto tg_xxxxxyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 216); 

                auto tg_xxxxxyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 217); 

                auto tg_xxxxxyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 218); 

                auto tg_xxxxxyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 219); 

                auto tg_xxxxxyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 220); 

                auto tg_xxxxxyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 221); 

                auto tg_xxxxxyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 222); 

                auto tg_xxxxxyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 223); 

                auto tg_xxxxxyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 224); 

                auto tg_xxxxxyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 225); 

                auto tg_xxxxxyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 226); 

                auto tg_xxxxxyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 227); 

                auto tg_xxxxxyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 228); 

                auto tg_xxxxxyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 229); 

                auto tg_xxxxxyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 230); 

                auto tg_xxxxxyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 231); 

                auto tg_xxxxxyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 232); 

                auto tg_xxxxxyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 233); 

                auto tg_xxxxxyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 234); 

                auto tg_xxxxxyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 235); 

                auto tg_xxxxxyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 236); 

                auto tg_xxxxxyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 237); 

                auto tg_xxxxxyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 238); 

                auto tg_xxxxxyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 239); 

                auto tg_xxxxxyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 240); 

                auto tg_xxxxxyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 241); 

                auto tg_xxxxxyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 242); 

                auto tg_xxxxxyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 243); 

                auto tg_xxxxxyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 244); 

                auto tg_xxxxxyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 245); 

                auto tg_xxxxxyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 246); 

                auto tg_xxxxxyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 247); 

                auto tg_xxxxxyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 248); 

                auto tg_xxxxxyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 249); 

                auto tg_xxxxxyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 250); 

                auto tg_xxxxxyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 251); 

                auto tg_xxxxxzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 252); 

                auto tg_xxxxxzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 253); 

                auto tg_xxxxxzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 254); 

                auto tg_xxxxxzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 255); 

                auto tg_xxxxxzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 256); 

                auto tg_xxxxxzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 257); 

                auto tg_xxxxxzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 258); 

                auto tg_xxxxxzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 259); 

                auto tg_xxxxxzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 260); 

                auto tg_xxxxxzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 261); 

                auto tg_xxxxxzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 262); 

                auto tg_xxxxxzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 263); 

                auto tg_xxxxxzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 264); 

                auto tg_xxxxxzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 265); 

                auto tg_xxxxxzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 266); 

                auto tg_xxxxxzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 267); 

                auto tg_xxxxxzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 268); 

                auto tg_xxxxxzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 269); 

                auto tg_xxxxxzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 270); 

                auto tg_xxxxxzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 271); 

                auto tg_xxxxxzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 272); 

                auto tg_xxxxxzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 273); 

                auto tg_xxxxxzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 274); 

                auto tg_xxxxxzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 275); 

                auto tg_xxxxxzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 276); 

                auto tg_xxxxxzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 277); 

                auto tg_xxxxxzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 278); 

                auto tg_xxxxxzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 279); 

                auto tg_xxxxyyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 280); 

                auto tg_xxxxyyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 281); 

                auto tg_xxxxyyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 282); 

                auto tg_xxxxyyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 283); 

                auto tg_xxxxyyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 284); 

                auto tg_xxxxyyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 285); 

                auto tg_xxxxyyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 286); 

                auto tg_xxxxyyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 287); 

                auto tg_xxxxyyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 288); 

                auto tg_xxxxyyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 289); 

                auto tg_xxxxyyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 290); 

                // Batch of Integrals (194,291)

                #pragma omp simd aligned(fxn, fza, tg_xxxxxyyy_yzzzzz_0, tg_xxxxxyyy_zzzzzz_0, \
                                         tg_xxxxxyyz_xxxxxx_0, tg_xxxxxyyz_xxxxxy_0, tg_xxxxxyyz_xxxxxz_0, tg_xxxxxyyz_xxxxyy_0, \
                                         tg_xxxxxyyz_xxxxyz_0, tg_xxxxxyyz_xxxxzz_0, tg_xxxxxyyz_xxxyyy_0, tg_xxxxxyyz_xxxyyz_0, \
                                         tg_xxxxxyyz_xxxyzz_0, tg_xxxxxyyz_xxxzzz_0, tg_xxxxxyyz_xxyyyy_0, tg_xxxxxyyz_xxyyyz_0, \
                                         tg_xxxxxyyz_xxyyzz_0, tg_xxxxxyyz_xxyzzz_0, tg_xxxxxyyz_xxzzzz_0, tg_xxxxxyyz_xyyyyy_0, \
                                         tg_xxxxxyyz_xyyyyz_0, tg_xxxxxyyz_xyyyzz_0, tg_xxxxxyyz_xyyzzz_0, tg_xxxxxyyz_xyzzzz_0, \
                                         tg_xxxxxyyz_xzzzzz_0, tg_xxxxxyyz_yyyyyy_0, tg_xxxxxyyz_yyyyyz_0, tg_xxxxxyyz_yyyyzz_0, \
                                         tg_xxxxxyyz_yyyzzz_0, tg_xxxxxyyz_yyzzzz_0, tg_xxxxxyyz_yzzzzz_0, tg_xxxxxyyz_zzzzzz_0, \
                                         tg_xxxxxyzz_xxxxxx_0, tg_xxxxxyzz_xxxxxy_0, tg_xxxxxyzz_xxxxxz_0, tg_xxxxxyzz_xxxxyy_0, \
                                         tg_xxxxxyzz_xxxxyz_0, tg_xxxxxyzz_xxxxzz_0, tg_xxxxxyzz_xxxyyy_0, tg_xxxxxyzz_xxxyyz_0, \
                                         tg_xxxxxyzz_xxxyzz_0, tg_xxxxxyzz_xxxzzz_0, tg_xxxxxyzz_xxyyyy_0, tg_xxxxxyzz_xxyyyz_0, \
                                         tg_xxxxxyzz_xxyyzz_0, tg_xxxxxyzz_xxyzzz_0, tg_xxxxxyzz_xxzzzz_0, tg_xxxxxyzz_xyyyyy_0, \
                                         tg_xxxxxyzz_xyyyyz_0, tg_xxxxxyzz_xyyyzz_0, tg_xxxxxyzz_xyyzzz_0, tg_xxxxxyzz_xyzzzz_0, \
                                         tg_xxxxxyzz_xzzzzz_0, tg_xxxxxyzz_yyyyyy_0, tg_xxxxxyzz_yyyyyz_0, tg_xxxxxyzz_yyyyzz_0, \
                                         tg_xxxxxyzz_yyyzzz_0, tg_xxxxxyzz_yyzzzz_0, tg_xxxxxyzz_yzzzzz_0, tg_xxxxxyzz_zzzzzz_0, \
                                         tg_xxxxxzzz_xxxxxx_0, tg_xxxxxzzz_xxxxxy_0, tg_xxxxxzzz_xxxxxz_0, tg_xxxxxzzz_xxxxyy_0, \
                                         tg_xxxxxzzz_xxxxyz_0, tg_xxxxxzzz_xxxxzz_0, tg_xxxxxzzz_xxxyyy_0, tg_xxxxxzzz_xxxyyz_0, \
                                         tg_xxxxxzzz_xxxyzz_0, tg_xxxxxzzz_xxxzzz_0, tg_xxxxxzzz_xxyyyy_0, tg_xxxxxzzz_xxyyyz_0, \
                                         tg_xxxxxzzz_xxyyzz_0, tg_xxxxxzzz_xxyzzz_0, tg_xxxxxzzz_xxzzzz_0, tg_xxxxxzzz_xyyyyy_0, \
                                         tg_xxxxxzzz_xyyyyz_0, tg_xxxxxzzz_xyyyzz_0, tg_xxxxxzzz_xyyzzz_0, tg_xxxxxzzz_xyzzzz_0, \
                                         tg_xxxxxzzz_xzzzzz_0, tg_xxxxxzzz_yyyyyy_0, tg_xxxxxzzz_yyyyyz_0, tg_xxxxxzzz_yyyyzz_0, \
                                         tg_xxxxxzzz_yyyzzz_0, tg_xxxxxzzz_yyzzzz_0, tg_xxxxxzzz_yzzzzz_0, tg_xxxxxzzz_zzzzzz_0, \
                                         tg_xxxxyyy_yzzzzz_0, tg_xxxxyyy_yzzzzz_1, tg_xxxxyyy_zzzzzz_0, tg_xxxxyyy_zzzzzz_1, \
                                         tg_xxxxyyyy_xxxxxx_0, tg_xxxxyyyy_xxxxxy_0, tg_xxxxyyyy_xxxxxz_0, tg_xxxxyyyy_xxxxyy_0, \
                                         tg_xxxxyyyy_xxxxyz_0, tg_xxxxyyyy_xxxxzz_0, tg_xxxxyyyy_xxxyyy_0, tg_xxxxyyyy_xxxyyz_0, \
                                         tg_xxxxyyyy_xxxyzz_0, tg_xxxxyyyy_xxxzzz_0, tg_xxxxyyyy_xxyyyy_0, tg_xxxxyyz_xxxxx_1, \
                                         tg_xxxxyyz_xxxxxx_0, tg_xxxxyyz_xxxxxx_1, tg_xxxxyyz_xxxxxy_0, tg_xxxxyyz_xxxxxy_1, \
                                         tg_xxxxyyz_xxxxxz_0, tg_xxxxyyz_xxxxxz_1, tg_xxxxyyz_xxxxy_1, tg_xxxxyyz_xxxxyy_0, \
                                         tg_xxxxyyz_xxxxyy_1, tg_xxxxyyz_xxxxyz_0, tg_xxxxyyz_xxxxyz_1, tg_xxxxyyz_xxxxz_1, \
                                         tg_xxxxyyz_xxxxzz_0, tg_xxxxyyz_xxxxzz_1, tg_xxxxyyz_xxxyy_1, tg_xxxxyyz_xxxyyy_0, \
                                         tg_xxxxyyz_xxxyyy_1, tg_xxxxyyz_xxxyyz_0, tg_xxxxyyz_xxxyyz_1, tg_xxxxyyz_xxxyz_1, \
                                         tg_xxxxyyz_xxxyzz_0, tg_xxxxyyz_xxxyzz_1, tg_xxxxyyz_xxxzz_1, tg_xxxxyyz_xxxzzz_0, \
                                         tg_xxxxyyz_xxxzzz_1, tg_xxxxyyz_xxyyy_1, tg_xxxxyyz_xxyyyy_0, tg_xxxxyyz_xxyyyy_1, \
                                         tg_xxxxyyz_xxyyyz_0, tg_xxxxyyz_xxyyyz_1, tg_xxxxyyz_xxyyz_1, tg_xxxxyyz_xxyyzz_0, \
                                         tg_xxxxyyz_xxyyzz_1, tg_xxxxyyz_xxyzz_1, tg_xxxxyyz_xxyzzz_0, tg_xxxxyyz_xxyzzz_1, \
                                         tg_xxxxyyz_xxzzz_1, tg_xxxxyyz_xxzzzz_0, tg_xxxxyyz_xxzzzz_1, tg_xxxxyyz_xyyyy_1, \
                                         tg_xxxxyyz_xyyyyy_0, tg_xxxxyyz_xyyyyy_1, tg_xxxxyyz_xyyyyz_0, tg_xxxxyyz_xyyyyz_1, \
                                         tg_xxxxyyz_xyyyz_1, tg_xxxxyyz_xyyyzz_0, tg_xxxxyyz_xyyyzz_1, tg_xxxxyyz_xyyzz_1, \
                                         tg_xxxxyyz_xyyzzz_0, tg_xxxxyyz_xyyzzz_1, tg_xxxxyyz_xyzzz_1, tg_xxxxyyz_xyzzzz_0, \
                                         tg_xxxxyyz_xyzzzz_1, tg_xxxxyyz_xzzzz_1, tg_xxxxyyz_xzzzzz_0, tg_xxxxyyz_xzzzzz_1, \
                                         tg_xxxxyyz_yyyyy_1, tg_xxxxyyz_yyyyyy_0, tg_xxxxyyz_yyyyyy_1, tg_xxxxyyz_yyyyyz_0, \
                                         tg_xxxxyyz_yyyyyz_1, tg_xxxxyyz_yyyyz_1, tg_xxxxyyz_yyyyzz_0, tg_xxxxyyz_yyyyzz_1, \
                                         tg_xxxxyyz_yyyzz_1, tg_xxxxyyz_yyyzzz_0, tg_xxxxyyz_yyyzzz_1, tg_xxxxyyz_yyzzz_1, \
                                         tg_xxxxyyz_yyzzzz_0, tg_xxxxyyz_yyzzzz_1, tg_xxxxyyz_yzzzz_1, tg_xxxxyyz_yzzzzz_0, \
                                         tg_xxxxyyz_yzzzzz_1, tg_xxxxyyz_zzzzz_1, tg_xxxxyyz_zzzzzz_0, tg_xxxxyyz_zzzzzz_1, \
                                         tg_xxxxyzz_xxxxx_1, tg_xxxxyzz_xxxxxx_0, tg_xxxxyzz_xxxxxx_1, tg_xxxxyzz_xxxxxy_0, \
                                         tg_xxxxyzz_xxxxxy_1, tg_xxxxyzz_xxxxxz_0, tg_xxxxyzz_xxxxxz_1, tg_xxxxyzz_xxxxy_1, \
                                         tg_xxxxyzz_xxxxyy_0, tg_xxxxyzz_xxxxyy_1, tg_xxxxyzz_xxxxyz_0, tg_xxxxyzz_xxxxyz_1, \
                                         tg_xxxxyzz_xxxxz_1, tg_xxxxyzz_xxxxzz_0, tg_xxxxyzz_xxxxzz_1, tg_xxxxyzz_xxxyy_1, \
                                         tg_xxxxyzz_xxxyyy_0, tg_xxxxyzz_xxxyyy_1, tg_xxxxyzz_xxxyyz_0, tg_xxxxyzz_xxxyyz_1, \
                                         tg_xxxxyzz_xxxyz_1, tg_xxxxyzz_xxxyzz_0, tg_xxxxyzz_xxxyzz_1, tg_xxxxyzz_xxxzz_1, \
                                         tg_xxxxyzz_xxxzzz_0, tg_xxxxyzz_xxxzzz_1, tg_xxxxyzz_xxyyy_1, tg_xxxxyzz_xxyyyy_0, \
                                         tg_xxxxyzz_xxyyyy_1, tg_xxxxyzz_xxyyyz_0, tg_xxxxyzz_xxyyyz_1, tg_xxxxyzz_xxyyz_1, \
                                         tg_xxxxyzz_xxyyzz_0, tg_xxxxyzz_xxyyzz_1, tg_xxxxyzz_xxyzz_1, tg_xxxxyzz_xxyzzz_0, \
                                         tg_xxxxyzz_xxyzzz_1, tg_xxxxyzz_xxzzz_1, tg_xxxxyzz_xxzzzz_0, tg_xxxxyzz_xxzzzz_1, \
                                         tg_xxxxyzz_xyyyy_1, tg_xxxxyzz_xyyyyy_0, tg_xxxxyzz_xyyyyy_1, tg_xxxxyzz_xyyyyz_0, \
                                         tg_xxxxyzz_xyyyyz_1, tg_xxxxyzz_xyyyz_1, tg_xxxxyzz_xyyyzz_0, tg_xxxxyzz_xyyyzz_1, \
                                         tg_xxxxyzz_xyyzz_1, tg_xxxxyzz_xyyzzz_0, tg_xxxxyzz_xyyzzz_1, tg_xxxxyzz_xyzzz_1, \
                                         tg_xxxxyzz_xyzzzz_0, tg_xxxxyzz_xyzzzz_1, tg_xxxxyzz_xzzzz_1, tg_xxxxyzz_xzzzzz_0, \
                                         tg_xxxxyzz_xzzzzz_1, tg_xxxxyzz_yyyyy_1, tg_xxxxyzz_yyyyyy_0, tg_xxxxyzz_yyyyyy_1, \
                                         tg_xxxxyzz_yyyyyz_0, tg_xxxxyzz_yyyyyz_1, tg_xxxxyzz_yyyyz_1, tg_xxxxyzz_yyyyzz_0, \
                                         tg_xxxxyzz_yyyyzz_1, tg_xxxxyzz_yyyzz_1, tg_xxxxyzz_yyyzzz_0, tg_xxxxyzz_yyyzzz_1, \
                                         tg_xxxxyzz_yyzzz_1, tg_xxxxyzz_yyzzzz_0, tg_xxxxyzz_yyzzzz_1, tg_xxxxyzz_yzzzz_1, \
                                         tg_xxxxyzz_yzzzzz_0, tg_xxxxyzz_yzzzzz_1, tg_xxxxyzz_zzzzz_1, tg_xxxxyzz_zzzzzz_0, \
                                         tg_xxxxyzz_zzzzzz_1, tg_xxxxzzz_xxxxx_1, tg_xxxxzzz_xxxxxx_0, tg_xxxxzzz_xxxxxx_1, \
                                         tg_xxxxzzz_xxxxxy_0, tg_xxxxzzz_xxxxxy_1, tg_xxxxzzz_xxxxxz_0, tg_xxxxzzz_xxxxxz_1, \
                                         tg_xxxxzzz_xxxxy_1, tg_xxxxzzz_xxxxyy_0, tg_xxxxzzz_xxxxyy_1, tg_xxxxzzz_xxxxyz_0, \
                                         tg_xxxxzzz_xxxxyz_1, tg_xxxxzzz_xxxxz_1, tg_xxxxzzz_xxxxzz_0, tg_xxxxzzz_xxxxzz_1, \
                                         tg_xxxxzzz_xxxyy_1, tg_xxxxzzz_xxxyyy_0, tg_xxxxzzz_xxxyyy_1, tg_xxxxzzz_xxxyyz_0, \
                                         tg_xxxxzzz_xxxyyz_1, tg_xxxxzzz_xxxyz_1, tg_xxxxzzz_xxxyzz_0, tg_xxxxzzz_xxxyzz_1, \
                                         tg_xxxxzzz_xxxzz_1, tg_xxxxzzz_xxxzzz_0, tg_xxxxzzz_xxxzzz_1, tg_xxxxzzz_xxyyy_1, \
                                         tg_xxxxzzz_xxyyyy_0, tg_xxxxzzz_xxyyyy_1, tg_xxxxzzz_xxyyyz_0, tg_xxxxzzz_xxyyyz_1, \
                                         tg_xxxxzzz_xxyyz_1, tg_xxxxzzz_xxyyzz_0, tg_xxxxzzz_xxyyzz_1, tg_xxxxzzz_xxyzz_1, \
                                         tg_xxxxzzz_xxyzzz_0, tg_xxxxzzz_xxyzzz_1, tg_xxxxzzz_xxzzz_1, tg_xxxxzzz_xxzzzz_0, \
                                         tg_xxxxzzz_xxzzzz_1, tg_xxxxzzz_xyyyy_1, tg_xxxxzzz_xyyyyy_0, tg_xxxxzzz_xyyyyy_1, \
                                         tg_xxxxzzz_xyyyyz_0, tg_xxxxzzz_xyyyyz_1, tg_xxxxzzz_xyyyz_1, tg_xxxxzzz_xyyyzz_0, \
                                         tg_xxxxzzz_xyyyzz_1, tg_xxxxzzz_xyyzz_1, tg_xxxxzzz_xyyzzz_0, tg_xxxxzzz_xyyzzz_1, \
                                         tg_xxxxzzz_xyzzz_1, tg_xxxxzzz_xyzzzz_0, tg_xxxxzzz_xyzzzz_1, tg_xxxxzzz_xzzzz_1, \
                                         tg_xxxxzzz_xzzzzz_0, tg_xxxxzzz_xzzzzz_1, tg_xxxxzzz_yyyyy_1, tg_xxxxzzz_yyyyyy_0, \
                                         tg_xxxxzzz_yyyyyy_1, tg_xxxxzzz_yyyyyz_0, tg_xxxxzzz_yyyyyz_1, tg_xxxxzzz_yyyyz_1, \
                                         tg_xxxxzzz_yyyyzz_0, tg_xxxxzzz_yyyyzz_1, tg_xxxxzzz_yyyzz_1, tg_xxxxzzz_yyyzzz_0, \
                                         tg_xxxxzzz_yyyzzz_1, tg_xxxxzzz_yyzzz_1, tg_xxxxzzz_yyzzzz_0, tg_xxxxzzz_yyzzzz_1, \
                                         tg_xxxxzzz_yzzzz_1, tg_xxxxzzz_yzzzzz_0, tg_xxxxzzz_yzzzzz_1, tg_xxxxzzz_zzzzz_1, \
                                         tg_xxxxzzz_zzzzzz_0, tg_xxxxzzz_zzzzzz_1, tg_xxxyyy_yzzzzz_0, tg_xxxyyy_yzzzzz_1, \
                                         tg_xxxyyy_zzzzzz_0, tg_xxxyyy_zzzzzz_1, tg_xxxyyyy_xxxxx_1, tg_xxxyyyy_xxxxxx_0, \
                                         tg_xxxyyyy_xxxxxx_1, tg_xxxyyyy_xxxxxy_0, tg_xxxyyyy_xxxxxy_1, tg_xxxyyyy_xxxxxz_0, \
                                         tg_xxxyyyy_xxxxxz_1, tg_xxxyyyy_xxxxy_1, tg_xxxyyyy_xxxxyy_0, tg_xxxyyyy_xxxxyy_1, \
                                         tg_xxxyyyy_xxxxyz_0, tg_xxxyyyy_xxxxyz_1, tg_xxxyyyy_xxxxz_1, tg_xxxyyyy_xxxxzz_0, \
                                         tg_xxxyyyy_xxxxzz_1, tg_xxxyyyy_xxxyy_1, tg_xxxyyyy_xxxyyy_0, tg_xxxyyyy_xxxyyy_1, \
                                         tg_xxxyyyy_xxxyyz_0, tg_xxxyyyy_xxxyyz_1, tg_xxxyyyy_xxxyz_1, tg_xxxyyyy_xxxyzz_0, \
                                         tg_xxxyyyy_xxxyzz_1, tg_xxxyyyy_xxxzz_1, tg_xxxyyyy_xxxzzz_0, tg_xxxyyyy_xxxzzz_1, \
                                         tg_xxxyyyy_xxyyy_1, tg_xxxyyyy_xxyyyy_0, tg_xxxyyyy_xxyyyy_1, tg_xxxyyyy_xxyyz_1, \
                                         tg_xxxyyyy_xxyzz_1, tg_xxxyyyy_xxzzz_1, tg_xxxyyyy_xyyyy_1, tg_xxxyyz_xxxxxx_0, \
                                         tg_xxxyyz_xxxxxx_1, tg_xxxyyz_xxxxxy_0, tg_xxxyyz_xxxxxy_1, tg_xxxyyz_xxxxxz_0, \
                                         tg_xxxyyz_xxxxxz_1, tg_xxxyyz_xxxxyy_0, tg_xxxyyz_xxxxyy_1, tg_xxxyyz_xxxxyz_0, \
                                         tg_xxxyyz_xxxxyz_1, tg_xxxyyz_xxxxzz_0, tg_xxxyyz_xxxxzz_1, tg_xxxyyz_xxxyyy_0, \
                                         tg_xxxyyz_xxxyyy_1, tg_xxxyyz_xxxyyz_0, tg_xxxyyz_xxxyyz_1, tg_xxxyyz_xxxyzz_0, \
                                         tg_xxxyyz_xxxyzz_1, tg_xxxyyz_xxxzzz_0, tg_xxxyyz_xxxzzz_1, tg_xxxyyz_xxyyyy_0, \
                                         tg_xxxyyz_xxyyyy_1, tg_xxxyyz_xxyyyz_0, tg_xxxyyz_xxyyyz_1, tg_xxxyyz_xxyyzz_0, \
                                         tg_xxxyyz_xxyyzz_1, tg_xxxyyz_xxyzzz_0, tg_xxxyyz_xxyzzz_1, tg_xxxyyz_xxzzzz_0, \
                                         tg_xxxyyz_xxzzzz_1, tg_xxxyyz_xyyyyy_0, tg_xxxyyz_xyyyyy_1, tg_xxxyyz_xyyyyz_0, \
                                         tg_xxxyyz_xyyyyz_1, tg_xxxyyz_xyyyzz_0, tg_xxxyyz_xyyyzz_1, tg_xxxyyz_xyyzzz_0, \
                                         tg_xxxyyz_xyyzzz_1, tg_xxxyyz_xyzzzz_0, tg_xxxyyz_xyzzzz_1, tg_xxxyyz_xzzzzz_0, \
                                         tg_xxxyyz_xzzzzz_1, tg_xxxyyz_yyyyyy_0, tg_xxxyyz_yyyyyy_1, tg_xxxyyz_yyyyyz_0, \
                                         tg_xxxyyz_yyyyyz_1, tg_xxxyyz_yyyyzz_0, tg_xxxyyz_yyyyzz_1, tg_xxxyyz_yyyzzz_0, \
                                         tg_xxxyyz_yyyzzz_1, tg_xxxyyz_yyzzzz_0, tg_xxxyyz_yyzzzz_1, tg_xxxyyz_yzzzzz_0, \
                                         tg_xxxyyz_yzzzzz_1, tg_xxxyyz_zzzzzz_0, tg_xxxyyz_zzzzzz_1, tg_xxxyzz_xxxxxx_0, \
                                         tg_xxxyzz_xxxxxx_1, tg_xxxyzz_xxxxxy_0, tg_xxxyzz_xxxxxy_1, tg_xxxyzz_xxxxxz_0, \
                                         tg_xxxyzz_xxxxxz_1, tg_xxxyzz_xxxxyy_0, tg_xxxyzz_xxxxyy_1, tg_xxxyzz_xxxxyz_0, \
                                         tg_xxxyzz_xxxxyz_1, tg_xxxyzz_xxxxzz_0, tg_xxxyzz_xxxxzz_1, tg_xxxyzz_xxxyyy_0, \
                                         tg_xxxyzz_xxxyyy_1, tg_xxxyzz_xxxyyz_0, tg_xxxyzz_xxxyyz_1, tg_xxxyzz_xxxyzz_0, \
                                         tg_xxxyzz_xxxyzz_1, tg_xxxyzz_xxxzzz_0, tg_xxxyzz_xxxzzz_1, tg_xxxyzz_xxyyyy_0, \
                                         tg_xxxyzz_xxyyyy_1, tg_xxxyzz_xxyyyz_0, tg_xxxyzz_xxyyyz_1, tg_xxxyzz_xxyyzz_0, \
                                         tg_xxxyzz_xxyyzz_1, tg_xxxyzz_xxyzzz_0, tg_xxxyzz_xxyzzz_1, tg_xxxyzz_xxzzzz_0, \
                                         tg_xxxyzz_xxzzzz_1, tg_xxxyzz_xyyyyy_0, tg_xxxyzz_xyyyyy_1, tg_xxxyzz_xyyyyz_0, \
                                         tg_xxxyzz_xyyyyz_1, tg_xxxyzz_xyyyzz_0, tg_xxxyzz_xyyyzz_1, tg_xxxyzz_xyyzzz_0, \
                                         tg_xxxyzz_xyyzzz_1, tg_xxxyzz_xyzzzz_0, tg_xxxyzz_xyzzzz_1, tg_xxxyzz_xzzzzz_0, \
                                         tg_xxxyzz_xzzzzz_1, tg_xxxyzz_yyyyyy_0, tg_xxxyzz_yyyyyy_1, tg_xxxyzz_yyyyyz_0, \
                                         tg_xxxyzz_yyyyyz_1, tg_xxxyzz_yyyyzz_0, tg_xxxyzz_yyyyzz_1, tg_xxxyzz_yyyzzz_0, \
                                         tg_xxxyzz_yyyzzz_1, tg_xxxyzz_yyzzzz_0, tg_xxxyzz_yyzzzz_1, tg_xxxyzz_yzzzzz_0, \
                                         tg_xxxyzz_yzzzzz_1, tg_xxxyzz_zzzzzz_0, tg_xxxyzz_zzzzzz_1, tg_xxxzzz_xxxxxx_0, \
                                         tg_xxxzzz_xxxxxx_1, tg_xxxzzz_xxxxxy_0, tg_xxxzzz_xxxxxy_1, tg_xxxzzz_xxxxxz_0, \
                                         tg_xxxzzz_xxxxxz_1, tg_xxxzzz_xxxxyy_0, tg_xxxzzz_xxxxyy_1, tg_xxxzzz_xxxxyz_0, \
                                         tg_xxxzzz_xxxxyz_1, tg_xxxzzz_xxxxzz_0, tg_xxxzzz_xxxxzz_1, tg_xxxzzz_xxxyyy_0, \
                                         tg_xxxzzz_xxxyyy_1, tg_xxxzzz_xxxyyz_0, tg_xxxzzz_xxxyyz_1, tg_xxxzzz_xxxyzz_0, \
                                         tg_xxxzzz_xxxyzz_1, tg_xxxzzz_xxxzzz_0, tg_xxxzzz_xxxzzz_1, tg_xxxzzz_xxyyyy_0, \
                                         tg_xxxzzz_xxyyyy_1, tg_xxxzzz_xxyyyz_0, tg_xxxzzz_xxyyyz_1, tg_xxxzzz_xxyyzz_0, \
                                         tg_xxxzzz_xxyyzz_1, tg_xxxzzz_xxyzzz_0, tg_xxxzzz_xxyzzz_1, tg_xxxzzz_xxzzzz_0, \
                                         tg_xxxzzz_xxzzzz_1, tg_xxxzzz_xyyyyy_0, tg_xxxzzz_xyyyyy_1, tg_xxxzzz_xyyyyz_0, \
                                         tg_xxxzzz_xyyyyz_1, tg_xxxzzz_xyyyzz_0, tg_xxxzzz_xyyyzz_1, tg_xxxzzz_xyyzzz_0, \
                                         tg_xxxzzz_xyyzzz_1, tg_xxxzzz_xyzzzz_0, tg_xxxzzz_xyzzzz_1, tg_xxxzzz_xzzzzz_0, \
                                         tg_xxxzzz_xzzzzz_1, tg_xxxzzz_yyyyyy_0, tg_xxxzzz_yyyyyy_1, tg_xxxzzz_yyyyyz_0, \
                                         tg_xxxzzz_yyyyyz_1, tg_xxxzzz_yyyyzz_0, tg_xxxzzz_yyyyzz_1, tg_xxxzzz_yyyzzz_0, \
                                         tg_xxxzzz_yyyzzz_1, tg_xxxzzz_yyzzzz_0, tg_xxxzzz_yyzzzz_1, tg_xxxzzz_yzzzzz_0, \
                                         tg_xxxzzz_yzzzzz_1, tg_xxxzzz_zzzzzz_0, tg_xxxzzz_zzzzzz_1, tg_xxyyyy_xxxxxx_0, \
                                         tg_xxyyyy_xxxxxx_1, tg_xxyyyy_xxxxxy_0, tg_xxyyyy_xxxxxy_1, tg_xxyyyy_xxxxxz_0, \
                                         tg_xxyyyy_xxxxxz_1, tg_xxyyyy_xxxxyy_0, tg_xxyyyy_xxxxyy_1, tg_xxyyyy_xxxxyz_0, \
                                         tg_xxyyyy_xxxxyz_1, tg_xxyyyy_xxxxzz_0, tg_xxyyyy_xxxxzz_1, tg_xxyyyy_xxxyyy_0, \
                                         tg_xxyyyy_xxxyyy_1, tg_xxyyyy_xxxyyz_0, tg_xxyyyy_xxxyyz_1, tg_xxyyyy_xxxyzz_0, \
                                         tg_xxyyyy_xxxyzz_1, tg_xxyyyy_xxxzzz_0, tg_xxyyyy_xxxzzz_1, tg_xxyyyy_xxyyyy_0, \
                                         tg_xxyyyy_xxyyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxxyyy_yzzzzz_0[j] = pb_x * tg_xxxxyyy_yzzzzz_0[j] + fr * tg_xxxxyyy_yzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_yzzzzz_0[j] - tg_xxxyyy_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyyy_zzzzzz_0[j] = pb_x * tg_xxxxyyy_zzzzzz_0[j] + fr * tg_xxxxyyy_zzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyy_zzzzzz_0[j] - tg_xxxyyy_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyyz_xxxxxx_0[j] = pb_x * tg_xxxxyyz_xxxxxx_0[j] + fr * tg_xxxxyyz_xxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxxx_0[j] - tg_xxxyyz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyyz_xxxxx_1[j];

                    tg_xxxxxyyz_xxxxxy_0[j] = pb_x * tg_xxxxyyz_xxxxxy_0[j] + fr * tg_xxxxyyz_xxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxxy_0[j] - tg_xxxyyz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyyz_xxxxy_1[j];

                    tg_xxxxxyyz_xxxxxz_0[j] = pb_x * tg_xxxxyyz_xxxxxz_0[j] + fr * tg_xxxxyyz_xxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxxz_0[j] - tg_xxxyyz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyyz_xxxxz_1[j];

                    tg_xxxxxyyz_xxxxyy_0[j] = pb_x * tg_xxxxyyz_xxxxyy_0[j] + fr * tg_xxxxyyz_xxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxyy_0[j] - tg_xxxyyz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyz_xxxyy_1[j];

                    tg_xxxxxyyz_xxxxyz_0[j] = pb_x * tg_xxxxyyz_xxxxyz_0[j] + fr * tg_xxxxyyz_xxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxyz_0[j] - tg_xxxyyz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyz_xxxyz_1[j];

                    tg_xxxxxyyz_xxxxzz_0[j] = pb_x * tg_xxxxyyz_xxxxzz_0[j] + fr * tg_xxxxyyz_xxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxxzz_0[j] - tg_xxxyyz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyyz_xxxzz_1[j];

                    tg_xxxxxyyz_xxxyyy_0[j] = pb_x * tg_xxxxyyz_xxxyyy_0[j] + fr * tg_xxxxyyz_xxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxyyy_0[j] - tg_xxxyyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyz_xxyyy_1[j];

                    tg_xxxxxyyz_xxxyyz_0[j] = pb_x * tg_xxxxyyz_xxxyyz_0[j] + fr * tg_xxxxyyz_xxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxyyz_0[j] - tg_xxxyyz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyz_xxyyz_1[j];

                    tg_xxxxxyyz_xxxyzz_0[j] = pb_x * tg_xxxxyyz_xxxyzz_0[j] + fr * tg_xxxxyyz_xxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxyzz_0[j] - tg_xxxyyz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyz_xxyzz_1[j];

                    tg_xxxxxyyz_xxxzzz_0[j] = pb_x * tg_xxxxyyz_xxxzzz_0[j] + fr * tg_xxxxyyz_xxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxxzzz_0[j] - tg_xxxyyz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyyz_xxzzz_1[j];

                    tg_xxxxxyyz_xxyyyy_0[j] = pb_x * tg_xxxxyyz_xxyyyy_0[j] + fr * tg_xxxxyyz_xxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxyyyy_0[j] - tg_xxxyyz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_xyyyy_1[j];

                    tg_xxxxxyyz_xxyyyz_0[j] = pb_x * tg_xxxxyyz_xxyyyz_0[j] + fr * tg_xxxxyyz_xxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxyyyz_0[j] - tg_xxxyyz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_xyyyz_1[j];

                    tg_xxxxxyyz_xxyyzz_0[j] = pb_x * tg_xxxxyyz_xxyyzz_0[j] + fr * tg_xxxxyyz_xxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxyyzz_0[j] - tg_xxxyyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_xyyzz_1[j];

                    tg_xxxxxyyz_xxyzzz_0[j] = pb_x * tg_xxxxyyz_xxyzzz_0[j] + fr * tg_xxxxyyz_xxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxyzzz_0[j] - tg_xxxyyz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_xyzzz_1[j];

                    tg_xxxxxyyz_xxzzzz_0[j] = pb_x * tg_xxxxyyz_xxzzzz_0[j] + fr * tg_xxxxyyz_xxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xxzzzz_0[j] - tg_xxxyyz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyyz_xzzzz_1[j];

                    tg_xxxxxyyz_xyyyyy_0[j] = pb_x * tg_xxxxyyz_xyyyyy_0[j] + fr * tg_xxxxyyz_xyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xyyyyy_0[j] - tg_xxxyyz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_yyyyy_1[j];

                    tg_xxxxxyyz_xyyyyz_0[j] = pb_x * tg_xxxxyyz_xyyyyz_0[j] + fr * tg_xxxxyyz_xyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xyyyyz_0[j] - tg_xxxyyz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_yyyyz_1[j];

                    tg_xxxxxyyz_xyyyzz_0[j] = pb_x * tg_xxxxyyz_xyyyzz_0[j] + fr * tg_xxxxyyz_xyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xyyyzz_0[j] - tg_xxxyyz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_yyyzz_1[j];

                    tg_xxxxxyyz_xyyzzz_0[j] = pb_x * tg_xxxxyyz_xyyzzz_0[j] + fr * tg_xxxxyyz_xyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xyyzzz_0[j] - tg_xxxyyz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_yyzzz_1[j];

                    tg_xxxxxyyz_xyzzzz_0[j] = pb_x * tg_xxxxyyz_xyzzzz_0[j] + fr * tg_xxxxyyz_xyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xyzzzz_0[j] - tg_xxxyyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_yzzzz_1[j];

                    tg_xxxxxyyz_xzzzzz_0[j] = pb_x * tg_xxxxyyz_xzzzzz_0[j] + fr * tg_xxxxyyz_xzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_xzzzzz_0[j] - tg_xxxyyz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyyz_zzzzz_1[j];

                    tg_xxxxxyyz_yyyyyy_0[j] = pb_x * tg_xxxxyyz_yyyyyy_0[j] + fr * tg_xxxxyyz_yyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yyyyyy_0[j] - tg_xxxyyz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxyyz_yyyyyz_0[j] = pb_x * tg_xxxxyyz_yyyyyz_0[j] + fr * tg_xxxxyyz_yyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yyyyyz_0[j] - tg_xxxyyz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxyyz_yyyyzz_0[j] = pb_x * tg_xxxxyyz_yyyyzz_0[j] + fr * tg_xxxxyyz_yyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yyyyzz_0[j] - tg_xxxyyz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxyyz_yyyzzz_0[j] = pb_x * tg_xxxxyyz_yyyzzz_0[j] + fr * tg_xxxxyyz_yyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yyyzzz_0[j] - tg_xxxyyz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxyyz_yyzzzz_0[j] = pb_x * tg_xxxxyyz_yyzzzz_0[j] + fr * tg_xxxxyyz_yyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yyzzzz_0[j] - tg_xxxyyz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxyyz_yzzzzz_0[j] = pb_x * tg_xxxxyyz_yzzzzz_0[j] + fr * tg_xxxxyyz_yzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_yzzzzz_0[j] - tg_xxxyyz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyyz_zzzzzz_0[j] = pb_x * tg_xxxxyyz_zzzzzz_0[j] + fr * tg_xxxxyyz_zzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyyz_zzzzzz_0[j] - tg_xxxyyz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyzz_xxxxxx_0[j] = pb_x * tg_xxxxyzz_xxxxxx_0[j] + fr * tg_xxxxyzz_xxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxxx_0[j] - tg_xxxyzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxyzz_xxxxx_1[j];

                    tg_xxxxxyzz_xxxxxy_0[j] = pb_x * tg_xxxxyzz_xxxxxy_0[j] + fr * tg_xxxxyzz_xxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxxy_0[j] - tg_xxxyzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyzz_xxxxy_1[j];

                    tg_xxxxxyzz_xxxxxz_0[j] = pb_x * tg_xxxxyzz_xxxxxz_0[j] + fr * tg_xxxxyzz_xxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxxz_0[j] - tg_xxxyzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxyzz_xxxxz_1[j];

                    tg_xxxxxyzz_xxxxyy_0[j] = pb_x * tg_xxxxyzz_xxxxyy_0[j] + fr * tg_xxxxyzz_xxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxyy_0[j] - tg_xxxyzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyzz_xxxyy_1[j];

                    tg_xxxxxyzz_xxxxyz_0[j] = pb_x * tg_xxxxyzz_xxxxyz_0[j] + fr * tg_xxxxyzz_xxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxyz_0[j] - tg_xxxyzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyzz_xxxyz_1[j];

                    tg_xxxxxyzz_xxxxzz_0[j] = pb_x * tg_xxxxyzz_xxxxzz_0[j] + fr * tg_xxxxyzz_xxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxxzz_0[j] - tg_xxxyzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxyzz_xxxzz_1[j];

                    tg_xxxxxyzz_xxxyyy_0[j] = pb_x * tg_xxxxyzz_xxxyyy_0[j] + fr * tg_xxxxyzz_xxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxyyy_0[j] - tg_xxxyzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyzz_xxyyy_1[j];

                    tg_xxxxxyzz_xxxyyz_0[j] = pb_x * tg_xxxxyzz_xxxyyz_0[j] + fr * tg_xxxxyzz_xxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxyyz_0[j] - tg_xxxyzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyzz_xxyyz_1[j];

                    tg_xxxxxyzz_xxxyzz_0[j] = pb_x * tg_xxxxyzz_xxxyzz_0[j] + fr * tg_xxxxyzz_xxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxyzz_0[j] - tg_xxxyzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyzz_xxyzz_1[j];

                    tg_xxxxxyzz_xxxzzz_0[j] = pb_x * tg_xxxxyzz_xxxzzz_0[j] + fr * tg_xxxxyzz_xxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxxzzz_0[j] - tg_xxxyzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxyzz_xxzzz_1[j];

                    tg_xxxxxyzz_xxyyyy_0[j] = pb_x * tg_xxxxyzz_xxyyyy_0[j] + fr * tg_xxxxyzz_xxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxyyyy_0[j] - tg_xxxyzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_xyyyy_1[j];

                    tg_xxxxxyzz_xxyyyz_0[j] = pb_x * tg_xxxxyzz_xxyyyz_0[j] + fr * tg_xxxxyzz_xxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxyyyz_0[j] - tg_xxxyzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_xyyyz_1[j];

                    tg_xxxxxyzz_xxyyzz_0[j] = pb_x * tg_xxxxyzz_xxyyzz_0[j] + fr * tg_xxxxyzz_xxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxyyzz_0[j] - tg_xxxyzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_xyyzz_1[j];

                    tg_xxxxxyzz_xxyzzz_0[j] = pb_x * tg_xxxxyzz_xxyzzz_0[j] + fr * tg_xxxxyzz_xxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxyzzz_0[j] - tg_xxxyzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_xyzzz_1[j];

                    tg_xxxxxyzz_xxzzzz_0[j] = pb_x * tg_xxxxyzz_xxzzzz_0[j] + fr * tg_xxxxyzz_xxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xxzzzz_0[j] - tg_xxxyzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxyzz_xzzzz_1[j];

                    tg_xxxxxyzz_xyyyyy_0[j] = pb_x * tg_xxxxyzz_xyyyyy_0[j] + fr * tg_xxxxyzz_xyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xyyyyy_0[j] - tg_xxxyzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_yyyyy_1[j];

                    tg_xxxxxyzz_xyyyyz_0[j] = pb_x * tg_xxxxyzz_xyyyyz_0[j] + fr * tg_xxxxyzz_xyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xyyyyz_0[j] - tg_xxxyzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_yyyyz_1[j];

                    tg_xxxxxyzz_xyyyzz_0[j] = pb_x * tg_xxxxyzz_xyyyzz_0[j] + fr * tg_xxxxyzz_xyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xyyyzz_0[j] - tg_xxxyzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_yyyzz_1[j];

                    tg_xxxxxyzz_xyyzzz_0[j] = pb_x * tg_xxxxyzz_xyyzzz_0[j] + fr * tg_xxxxyzz_xyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xyyzzz_0[j] - tg_xxxyzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_yyzzz_1[j];

                    tg_xxxxxyzz_xyzzzz_0[j] = pb_x * tg_xxxxyzz_xyzzzz_0[j] + fr * tg_xxxxyzz_xyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xyzzzz_0[j] - tg_xxxyzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_yzzzz_1[j];

                    tg_xxxxxyzz_xzzzzz_0[j] = pb_x * tg_xxxxyzz_xzzzzz_0[j] + fr * tg_xxxxyzz_xzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_xzzzzz_0[j] - tg_xxxyzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxyzz_zzzzz_1[j];

                    tg_xxxxxyzz_yyyyyy_0[j] = pb_x * tg_xxxxyzz_yyyyyy_0[j] + fr * tg_xxxxyzz_yyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yyyyyy_0[j] - tg_xxxyzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxyzz_yyyyyz_0[j] = pb_x * tg_xxxxyzz_yyyyyz_0[j] + fr * tg_xxxxyzz_yyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yyyyyz_0[j] - tg_xxxyzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxyzz_yyyyzz_0[j] = pb_x * tg_xxxxyzz_yyyyzz_0[j] + fr * tg_xxxxyzz_yyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yyyyzz_0[j] - tg_xxxyzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxyzz_yyyzzz_0[j] = pb_x * tg_xxxxyzz_yyyzzz_0[j] + fr * tg_xxxxyzz_yyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yyyzzz_0[j] - tg_xxxyzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxyzz_yyzzzz_0[j] = pb_x * tg_xxxxyzz_yyzzzz_0[j] + fr * tg_xxxxyzz_yyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yyzzzz_0[j] - tg_xxxyzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxyzz_yzzzzz_0[j] = pb_x * tg_xxxxyzz_yzzzzz_0[j] + fr * tg_xxxxyzz_yzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_yzzzzz_0[j] - tg_xxxyzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxyzz_zzzzzz_0[j] = pb_x * tg_xxxxyzz_zzzzzz_0[j] + fr * tg_xxxxyzz_zzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxyzz_zzzzzz_0[j] - tg_xxxyzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxxzzz_xxxxxx_0[j] = pb_x * tg_xxxxzzz_xxxxxx_0[j] + fr * tg_xxxxzzz_xxxxxx_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxxx_0[j] - tg_xxxzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxxzzz_xxxxx_1[j];

                    tg_xxxxxzzz_xxxxxy_0[j] = pb_x * tg_xxxxzzz_xxxxxy_0[j] + fr * tg_xxxxzzz_xxxxxy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxxy_0[j] - tg_xxxzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxzzz_xxxxy_1[j];

                    tg_xxxxxzzz_xxxxxz_0[j] = pb_x * tg_xxxxzzz_xxxxxz_0[j] + fr * tg_xxxxzzz_xxxxxz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxxz_0[j] - tg_xxxzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxxzzz_xxxxz_1[j];

                    tg_xxxxxzzz_xxxxyy_0[j] = pb_x * tg_xxxxzzz_xxxxyy_0[j] + fr * tg_xxxxzzz_xxxxyy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxyy_0[j] - tg_xxxzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzzz_xxxyy_1[j];

                    tg_xxxxxzzz_xxxxyz_0[j] = pb_x * tg_xxxxzzz_xxxxyz_0[j] + fr * tg_xxxxzzz_xxxxyz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxyz_0[j] - tg_xxxzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzzz_xxxyz_1[j];

                    tg_xxxxxzzz_xxxxzz_0[j] = pb_x * tg_xxxxzzz_xxxxzz_0[j] + fr * tg_xxxxzzz_xxxxzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxxzz_0[j] - tg_xxxzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxxzzz_xxxzz_1[j];

                    tg_xxxxxzzz_xxxyyy_0[j] = pb_x * tg_xxxxzzz_xxxyyy_0[j] + fr * tg_xxxxzzz_xxxyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxyyy_0[j] - tg_xxxzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzzz_xxyyy_1[j];

                    tg_xxxxxzzz_xxxyyz_0[j] = pb_x * tg_xxxxzzz_xxxyyz_0[j] + fr * tg_xxxxzzz_xxxyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxyyz_0[j] - tg_xxxzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzzz_xxyyz_1[j];

                    tg_xxxxxzzz_xxxyzz_0[j] = pb_x * tg_xxxxzzz_xxxyzz_0[j] + fr * tg_xxxxzzz_xxxyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxyzz_0[j] - tg_xxxzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzzz_xxyzz_1[j];

                    tg_xxxxxzzz_xxxzzz_0[j] = pb_x * tg_xxxxzzz_xxxzzz_0[j] + fr * tg_xxxxzzz_xxxzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxxzzz_0[j] - tg_xxxzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxxzzz_xxzzz_1[j];

                    tg_xxxxxzzz_xxyyyy_0[j] = pb_x * tg_xxxxzzz_xxyyyy_0[j] + fr * tg_xxxxzzz_xxyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxyyyy_0[j] - tg_xxxzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_xyyyy_1[j];

                    tg_xxxxxzzz_xxyyyz_0[j] = pb_x * tg_xxxxzzz_xxyyyz_0[j] + fr * tg_xxxxzzz_xxyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxyyyz_0[j] - tg_xxxzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_xyyyz_1[j];

                    tg_xxxxxzzz_xxyyzz_0[j] = pb_x * tg_xxxxzzz_xxyyzz_0[j] + fr * tg_xxxxzzz_xxyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxyyzz_0[j] - tg_xxxzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_xyyzz_1[j];

                    tg_xxxxxzzz_xxyzzz_0[j] = pb_x * tg_xxxxzzz_xxyzzz_0[j] + fr * tg_xxxxzzz_xxyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxyzzz_0[j] - tg_xxxzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_xyzzz_1[j];

                    tg_xxxxxzzz_xxzzzz_0[j] = pb_x * tg_xxxxzzz_xxzzzz_0[j] + fr * tg_xxxxzzz_xxzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xxzzzz_0[j] - tg_xxxzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxxzzz_xzzzz_1[j];

                    tg_xxxxxzzz_xyyyyy_0[j] = pb_x * tg_xxxxzzz_xyyyyy_0[j] + fr * tg_xxxxzzz_xyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xyyyyy_0[j] - tg_xxxzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_yyyyy_1[j];

                    tg_xxxxxzzz_xyyyyz_0[j] = pb_x * tg_xxxxzzz_xyyyyz_0[j] + fr * tg_xxxxzzz_xyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xyyyyz_0[j] - tg_xxxzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_yyyyz_1[j];

                    tg_xxxxxzzz_xyyyzz_0[j] = pb_x * tg_xxxxzzz_xyyyzz_0[j] + fr * tg_xxxxzzz_xyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xyyyzz_0[j] - tg_xxxzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_yyyzz_1[j];

                    tg_xxxxxzzz_xyyzzz_0[j] = pb_x * tg_xxxxzzz_xyyzzz_0[j] + fr * tg_xxxxzzz_xyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xyyzzz_0[j] - tg_xxxzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_yyzzz_1[j];

                    tg_xxxxxzzz_xyzzzz_0[j] = pb_x * tg_xxxxzzz_xyzzzz_0[j] + fr * tg_xxxxzzz_xyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xyzzzz_0[j] - tg_xxxzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_yzzzz_1[j];

                    tg_xxxxxzzz_xzzzzz_0[j] = pb_x * tg_xxxxzzz_xzzzzz_0[j] + fr * tg_xxxxzzz_xzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_xzzzzz_0[j] - tg_xxxzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxxzzz_zzzzz_1[j];

                    tg_xxxxxzzz_yyyyyy_0[j] = pb_x * tg_xxxxzzz_yyyyyy_0[j] + fr * tg_xxxxzzz_yyyyyy_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yyyyyy_0[j] - tg_xxxzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxxzzz_yyyyyz_0[j] = pb_x * tg_xxxxzzz_yyyyyz_0[j] + fr * tg_xxxxzzz_yyyyyz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yyyyyz_0[j] - tg_xxxzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxxzzz_yyyyzz_0[j] = pb_x * tg_xxxxzzz_yyyyzz_0[j] + fr * tg_xxxxzzz_yyyyzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yyyyzz_0[j] - tg_xxxzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxxzzz_yyyzzz_0[j] = pb_x * tg_xxxxzzz_yyyzzz_0[j] + fr * tg_xxxxzzz_yyyzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yyyzzz_0[j] - tg_xxxzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxxzzz_yyzzzz_0[j] = pb_x * tg_xxxxzzz_yyzzzz_0[j] + fr * tg_xxxxzzz_yyzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yyzzzz_0[j] - tg_xxxzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxxzzz_yzzzzz_0[j] = pb_x * tg_xxxxzzz_yzzzzz_0[j] + fr * tg_xxxxzzz_yzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_yzzzzz_0[j] - tg_xxxzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxxzzz_zzzzzz_0[j] = pb_x * tg_xxxxzzz_zzzzzz_0[j] + fr * tg_xxxxzzz_zzzzzz_1[j] + 2.0 * fl1_fx * (tg_xxxzzz_zzzzzz_0[j] - tg_xxxzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyy_xxxxxx_0[j] = pb_x * tg_xxxyyyy_xxxxxx_0[j] + fr * tg_xxxyyyy_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxxx_0[j] - tg_xxyyyy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyyy_xxxxx_1[j];

                    tg_xxxxyyyy_xxxxxy_0[j] = pb_x * tg_xxxyyyy_xxxxxy_0[j] + fr * tg_xxxyyyy_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxxy_0[j] - tg_xxyyyy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyyy_xxxxy_1[j];

                    tg_xxxxyyyy_xxxxxz_0[j] = pb_x * tg_xxxyyyy_xxxxxz_0[j] + fr * tg_xxxyyyy_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxxz_0[j] - tg_xxyyyy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyyy_xxxxz_1[j];

                    tg_xxxxyyyy_xxxxyy_0[j] = pb_x * tg_xxxyyyy_xxxxyy_0[j] + fr * tg_xxxyyyy_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxyy_0[j] - tg_xxyyyy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyy_xxxyy_1[j];

                    tg_xxxxyyyy_xxxxyz_0[j] = pb_x * tg_xxxyyyy_xxxxyz_0[j] + fr * tg_xxxyyyy_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxyz_0[j] - tg_xxyyyy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyy_xxxyz_1[j];

                    tg_xxxxyyyy_xxxxzz_0[j] = pb_x * tg_xxxyyyy_xxxxzz_0[j] + fr * tg_xxxyyyy_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxxzz_0[j] - tg_xxyyyy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyy_xxxzz_1[j];

                    tg_xxxxyyyy_xxxyyy_0[j] = pb_x * tg_xxxyyyy_xxxyyy_0[j] + fr * tg_xxxyyyy_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxyyy_0[j] - tg_xxyyyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyy_xxyyy_1[j];

                    tg_xxxxyyyy_xxxyyz_0[j] = pb_x * tg_xxxyyyy_xxxyyz_0[j] + fr * tg_xxxyyyy_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxyyz_0[j] - tg_xxyyyy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyy_xxyyz_1[j];

                    tg_xxxxyyyy_xxxyzz_0[j] = pb_x * tg_xxxyyyy_xxxyzz_0[j] + fr * tg_xxxyyyy_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxyzz_0[j] - tg_xxyyyy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyy_xxyzz_1[j];

                    tg_xxxxyyyy_xxxzzz_0[j] = pb_x * tg_xxxyyyy_xxxzzz_0[j] + fr * tg_xxxyyyy_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxxzzz_0[j] - tg_xxyyyy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyy_xxzzz_1[j];

                    tg_xxxxyyyy_xxyyyy_0[j] = pb_x * tg_xxxyyyy_xxyyyy_0[j] + fr * tg_xxxyyyy_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxyyyy_0[j] - tg_xxyyyy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_xyyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_291_388(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (291,388)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxyyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 291); 

                auto tg_xxxyyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 292); 

                auto tg_xxxyyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 293); 

                auto tg_xxxyyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 294); 

                auto tg_xxxyyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 295); 

                auto tg_xxxyyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 296); 

                auto tg_xxxyyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 297); 

                auto tg_xxxyyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 298); 

                auto tg_xxxyyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 299); 

                auto tg_xxxyyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 300); 

                auto tg_xxxyyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 301); 

                auto tg_xxxyyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 302); 

                auto tg_xxxyyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 303); 

                auto tg_xxxyyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 304); 

                auto tg_xxxyyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 305); 

                auto tg_xxxyyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 306); 

                auto tg_xxxyyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 307); 

                auto tg_xxxyyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 308); 

                auto tg_xxxyyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 309); 

                auto tg_xxxyyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 310); 

                auto tg_xxxyyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 311); 

                auto tg_xxxyyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 312); 

                auto tg_xxxyyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 313); 

                auto tg_xxxyyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 314); 

                auto tg_xxxyyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 315); 

                auto tg_xxxyyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 316); 

                auto tg_xxxyyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 317); 

                auto tg_xxxyyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 318); 

                auto tg_xxxyyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 319); 

                auto tg_xxxyyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 320); 

                auto tg_xxxyyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 321); 

                auto tg_xxxyyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 322); 

                auto tg_xxxyyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 323); 

                auto tg_xxxyyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 324); 

                auto tg_xxxyyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 325); 

                auto tg_xxxyyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 326); 

                auto tg_xxxyyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 327); 

                auto tg_xxxyyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 328); 

                auto tg_xxxyyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 329); 

                auto tg_xxxyyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 330); 

                auto tg_xxxyyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 331); 

                auto tg_xxxyyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 332); 

                auto tg_xxxyyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 333); 

                auto tg_xxxyyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 334); 

                auto tg_xxxyyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 335); 

                auto tg_xxxyyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 336); 

                auto tg_xxxyyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 337); 

                auto tg_xxxyyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 338); 

                auto tg_xxxyyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 339); 

                auto tg_xxxyyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 340); 

                auto tg_xxxyyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 341); 

                auto tg_xxxyyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 342); 

                auto tg_xxxyyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 343); 

                auto tg_xxxyyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 344); 

                auto tg_xxxyyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 345); 

                auto tg_xxxyyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 346); 

                auto tg_xxxyyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 347); 

                auto tg_xxxyyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 348); 

                auto tg_xxxyyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 349); 

                auto tg_xxxyyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 350); 

                auto tg_xxxyyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 351); 

                auto tg_xxxyyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 352); 

                auto tg_xxxyyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 353); 

                auto tg_xxxyyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 354); 

                auto tg_xxxyyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 355); 

                auto tg_xxxyyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 356); 

                auto tg_xxxyyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 357); 

                auto tg_xxxyyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 358); 

                auto tg_xxxyyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 359); 

                auto tg_xxxyyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 360); 

                auto tg_xxxyyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 361); 

                auto tg_xxxyyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 362); 

                auto tg_xxxyyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 363); 

                auto tg_xxxyzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 364); 

                auto tg_xxxyzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 365); 

                auto tg_xxxyzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 366); 

                auto tg_xxxyzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 367); 

                auto tg_xxxyzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 368); 

                auto tg_xxxyzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 369); 

                auto tg_xxxyzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 370); 

                auto tg_xxxyzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 371); 

                auto tg_xxxyzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 372); 

                auto tg_xxxyzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 373); 

                auto tg_xxxyzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 374); 

                auto tg_xxxyzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 375); 

                auto tg_xxxyzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 376); 

                auto tg_xxxyzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 377); 

                auto tg_xxxyzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 378); 

                auto tg_xxxyzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 379); 

                auto tg_xxxyzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 380); 

                auto tg_xxxyzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 381); 

                auto tg_xxxyzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 382); 

                auto tg_xxxyzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 383); 

                auto tg_xxxyzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 384); 

                auto tg_xxxyzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 385); 

                auto tg_xxxyzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 386); 

                auto tg_xxxyzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 387); 

                auto tg_xxxyyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 291); 

                auto tg_xxxyyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 292); 

                auto tg_xxxyyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 293); 

                auto tg_xxxyyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 294); 

                auto tg_xxxyyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 295); 

                auto tg_xxxyyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 296); 

                auto tg_xxxyyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 297); 

                auto tg_xxxyyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 298); 

                auto tg_xxxyyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 299); 

                auto tg_xxxyyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 300); 

                auto tg_xxxyyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 301); 

                auto tg_xxxyyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 302); 

                auto tg_xxxyyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 303); 

                auto tg_xxxyyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 304); 

                auto tg_xxxyyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 305); 

                auto tg_xxxyyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 306); 

                auto tg_xxxyyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 307); 

                auto tg_xxxyyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 308); 

                auto tg_xxxyyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 309); 

                auto tg_xxxyyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 310); 

                auto tg_xxxyyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 311); 

                auto tg_xxxyyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 312); 

                auto tg_xxxyyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 313); 

                auto tg_xxxyyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 314); 

                auto tg_xxxyyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 315); 

                auto tg_xxxyyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 316); 

                auto tg_xxxyyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 317); 

                auto tg_xxxyyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 318); 

                auto tg_xxxyyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 319); 

                auto tg_xxxyyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 320); 

                auto tg_xxxyyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 321); 

                auto tg_xxxyyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 322); 

                auto tg_xxxyyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 323); 

                auto tg_xxxyyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 324); 

                auto tg_xxxyyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 325); 

                auto tg_xxxyyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 326); 

                auto tg_xxxyyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 327); 

                auto tg_xxxyyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 328); 

                auto tg_xxxyyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 329); 

                auto tg_xxxyyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 330); 

                auto tg_xxxyyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 331); 

                auto tg_xxxyyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 332); 

                auto tg_xxxyyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 333); 

                auto tg_xxxyyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 334); 

                auto tg_xxxyyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 335); 

                auto tg_xxxyyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 336); 

                auto tg_xxxyyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 337); 

                auto tg_xxxyyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 338); 

                auto tg_xxxyyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 339); 

                auto tg_xxxyyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 340); 

                auto tg_xxxyyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 341); 

                auto tg_xxxyyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 342); 

                auto tg_xxxyyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 343); 

                auto tg_xxxyyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 344); 

                auto tg_xxxyyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 345); 

                auto tg_xxxyyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 346); 

                auto tg_xxxyyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 347); 

                auto tg_xxxyyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 348); 

                auto tg_xxxyyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 349); 

                auto tg_xxxyyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 350); 

                auto tg_xxxyyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 351); 

                auto tg_xxxyyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 352); 

                auto tg_xxxyyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 353); 

                auto tg_xxxyyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 354); 

                auto tg_xxxyyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 355); 

                auto tg_xxxyyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 356); 

                auto tg_xxxyyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 357); 

                auto tg_xxxyyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 358); 

                auto tg_xxxyyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 359); 

                auto tg_xxxyyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 360); 

                auto tg_xxxyyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 361); 

                auto tg_xxxyyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 362); 

                auto tg_xxxyyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 363); 

                auto tg_xxxyzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 364); 

                auto tg_xxxyzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 365); 

                auto tg_xxxyzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 366); 

                auto tg_xxxyzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 367); 

                auto tg_xxxyzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 368); 

                auto tg_xxxyzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 369); 

                auto tg_xxxyzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 370); 

                auto tg_xxxyzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 371); 

                auto tg_xxxyzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 372); 

                auto tg_xxxyzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 373); 

                auto tg_xxxyzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 374); 

                auto tg_xxxyzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 375); 

                auto tg_xxxyzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 376); 

                auto tg_xxxyzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 377); 

                auto tg_xxxyzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 378); 

                auto tg_xxxyzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 379); 

                auto tg_xxxyzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 380); 

                auto tg_xxxyzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 381); 

                auto tg_xxxyzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 382); 

                auto tg_xxxyzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 383); 

                auto tg_xxxyzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 384); 

                auto tg_xxxyzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 385); 

                auto tg_xxxyzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 386); 

                auto tg_xxxyzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 387); 

                auto tg_xxyyyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 291); 

                auto tg_xxyyyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 292); 

                auto tg_xxyyyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 293); 

                auto tg_xxyyyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 294); 

                auto tg_xxyyyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 295); 

                auto tg_xxyyyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 296); 

                auto tg_xxyyyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 297); 

                auto tg_xxyyyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 298); 

                auto tg_xxyyyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 299); 

                auto tg_xxyyyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 300); 

                auto tg_xxyyyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 301); 

                auto tg_xxyyyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 302); 

                auto tg_xxyyyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 303); 

                auto tg_xxyyyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 304); 

                auto tg_xxyyyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 305); 

                auto tg_xxyyyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 306); 

                auto tg_xxyyyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 307); 

                auto tg_xxyyyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 308); 

                auto tg_xxyyyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 309); 

                auto tg_xxyyyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 310); 

                auto tg_xxyyyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 311); 

                auto tg_xxyyyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 312); 

                auto tg_xxyyyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 313); 

                auto tg_xxyyyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 314); 

                auto tg_xxyyyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 315); 

                auto tg_xxyyyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 316); 

                auto tg_xxyyyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 317); 

                auto tg_xxyyyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 318); 

                auto tg_xxyyyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 319); 

                auto tg_xxyyyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 320); 

                auto tg_xxyyyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 321); 

                auto tg_xxyyyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 322); 

                auto tg_xxyyyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 323); 

                auto tg_xxyyyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 324); 

                auto tg_xxyyyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 325); 

                auto tg_xxyyyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 326); 

                auto tg_xxyyyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 327); 

                auto tg_xxyyyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 328); 

                auto tg_xxyyyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 329); 

                auto tg_xxyyyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 330); 

                auto tg_xxyyyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 331); 

                auto tg_xxyyyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 332); 

                auto tg_xxyyyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 333); 

                auto tg_xxyyyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 334); 

                auto tg_xxyyyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 335); 

                auto tg_xxyyzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 336); 

                auto tg_xxyyzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 337); 

                auto tg_xxyyzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 338); 

                auto tg_xxyyzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 339); 

                auto tg_xxyyzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 340); 

                auto tg_xxyyzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 341); 

                auto tg_xxyyzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 342); 

                auto tg_xxyyzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 343); 

                auto tg_xxyyzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 344); 

                auto tg_xxyyzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 345); 

                auto tg_xxyyzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 346); 

                auto tg_xxyyzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 347); 

                auto tg_xxyyzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 348); 

                auto tg_xxyyzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 349); 

                auto tg_xxyyzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 350); 

                auto tg_xxyyzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 351); 

                auto tg_xxyyzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 352); 

                auto tg_xxyyzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 353); 

                auto tg_xxyyzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 354); 

                auto tg_xxyyzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 355); 

                auto tg_xxyyzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 356); 

                auto tg_xxyyzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 357); 

                auto tg_xxyyzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 358); 

                auto tg_xxyyzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 359); 

                auto tg_xxyyzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 360); 

                auto tg_xxyyzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 361); 

                auto tg_xxyyzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 362); 

                auto tg_xxyyzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 363); 

                auto tg_xxyzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 364); 

                auto tg_xxyzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 365); 

                auto tg_xxyzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 366); 

                auto tg_xxyzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 367); 

                auto tg_xxyzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 368); 

                auto tg_xxyzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 369); 

                auto tg_xxyzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 370); 

                auto tg_xxyzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 371); 

                auto tg_xxyzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 372); 

                auto tg_xxyzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 373); 

                auto tg_xxyzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 374); 

                auto tg_xxyzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 375); 

                auto tg_xxyzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 376); 

                auto tg_xxyzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 377); 

                auto tg_xxyzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 378); 

                auto tg_xxyzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 379); 

                auto tg_xxyzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 380); 

                auto tg_xxyzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 381); 

                auto tg_xxyzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 382); 

                auto tg_xxyzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 383); 

                auto tg_xxyzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 384); 

                auto tg_xxyzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 385); 

                auto tg_xxyzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 386); 

                auto tg_xxyzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 387); 

                auto tg_xxyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 291); 

                auto tg_xxyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 292); 

                auto tg_xxyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 293); 

                auto tg_xxyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 294); 

                auto tg_xxyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 295); 

                auto tg_xxyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 296); 

                auto tg_xxyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 297); 

                auto tg_xxyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 298); 

                auto tg_xxyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 299); 

                auto tg_xxyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 300); 

                auto tg_xxyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 301); 

                auto tg_xxyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 302); 

                auto tg_xxyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 303); 

                auto tg_xxyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 304); 

                auto tg_xxyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 305); 

                auto tg_xxyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 306); 

                auto tg_xxyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 307); 

                auto tg_xxyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 308); 

                auto tg_xxyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 309); 

                auto tg_xxyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 310); 

                auto tg_xxyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 311); 

                auto tg_xxyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 312); 

                auto tg_xxyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 313); 

                auto tg_xxyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 314); 

                auto tg_xxyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 315); 

                auto tg_xxyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 316); 

                auto tg_xxyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 317); 

                auto tg_xxyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 318); 

                auto tg_xxyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 319); 

                auto tg_xxyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 320); 

                auto tg_xxyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 321); 

                auto tg_xxyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 322); 

                auto tg_xxyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 323); 

                auto tg_xxyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 324); 

                auto tg_xxyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 325); 

                auto tg_xxyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 326); 

                auto tg_xxyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 327); 

                auto tg_xxyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 328); 

                auto tg_xxyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 329); 

                auto tg_xxyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 330); 

                auto tg_xxyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 331); 

                auto tg_xxyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 332); 

                auto tg_xxyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 333); 

                auto tg_xxyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 334); 

                auto tg_xxyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 335); 

                auto tg_xxyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 336); 

                auto tg_xxyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 337); 

                auto tg_xxyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 338); 

                auto tg_xxyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 339); 

                auto tg_xxyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 340); 

                auto tg_xxyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 341); 

                auto tg_xxyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 342); 

                auto tg_xxyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 343); 

                auto tg_xxyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 344); 

                auto tg_xxyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 345); 

                auto tg_xxyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 346); 

                auto tg_xxyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 347); 

                auto tg_xxyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 348); 

                auto tg_xxyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 349); 

                auto tg_xxyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 350); 

                auto tg_xxyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 351); 

                auto tg_xxyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 352); 

                auto tg_xxyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 353); 

                auto tg_xxyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 354); 

                auto tg_xxyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 355); 

                auto tg_xxyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 356); 

                auto tg_xxyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 357); 

                auto tg_xxyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 358); 

                auto tg_xxyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 359); 

                auto tg_xxyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 360); 

                auto tg_xxyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 361); 

                auto tg_xxyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 362); 

                auto tg_xxyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 363); 

                auto tg_xxyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 364); 

                auto tg_xxyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 365); 

                auto tg_xxyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 366); 

                auto tg_xxyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 367); 

                auto tg_xxyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 368); 

                auto tg_xxyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 369); 

                auto tg_xxyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 370); 

                auto tg_xxyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 371); 

                auto tg_xxyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 372); 

                auto tg_xxyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 373); 

                auto tg_xxyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 374); 

                auto tg_xxyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 375); 

                auto tg_xxyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 376); 

                auto tg_xxyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 377); 

                auto tg_xxyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 378); 

                auto tg_xxyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 379); 

                auto tg_xxyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 380); 

                auto tg_xxyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 381); 

                auto tg_xxyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 382); 

                auto tg_xxyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 383); 

                auto tg_xxyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 384); 

                auto tg_xxyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 385); 

                auto tg_xxyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 386); 

                auto tg_xxyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 387); 

                auto tg_xxxyyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 221); 

                auto tg_xxxyyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 222); 

                auto tg_xxxyyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 223); 

                auto tg_xxxyyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 224); 

                auto tg_xxxyyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 225); 

                auto tg_xxxyyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 226); 

                auto tg_xxxyyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 227); 

                auto tg_xxxyyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 228); 

                auto tg_xxxyyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 229); 

                auto tg_xxxyyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 230); 

                auto tg_xxxyyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 231); 

                auto tg_xxxyyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 232); 

                auto tg_xxxyyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 233); 

                auto tg_xxxyyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 234); 

                auto tg_xxxyyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 235); 

                auto tg_xxxyyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 236); 

                auto tg_xxxyyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 237); 

                auto tg_xxxyyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 238); 

                auto tg_xxxyyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 239); 

                auto tg_xxxyyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 240); 

                auto tg_xxxyyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 241); 

                auto tg_xxxyyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 242); 

                auto tg_xxxyyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 243); 

                auto tg_xxxyyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 244); 

                auto tg_xxxyyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 245); 

                auto tg_xxxyyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 246); 

                auto tg_xxxyyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 247); 

                auto tg_xxxyyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 248); 

                auto tg_xxxyyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 249); 

                auto tg_xxxyyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 250); 

                auto tg_xxxyyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 251); 

                auto tg_xxxyyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 252); 

                auto tg_xxxyyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 253); 

                auto tg_xxxyyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 254); 

                auto tg_xxxyyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 255); 

                auto tg_xxxyyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 256); 

                auto tg_xxxyyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 257); 

                auto tg_xxxyyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 258); 

                auto tg_xxxyyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 259); 

                auto tg_xxxyyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 260); 

                auto tg_xxxyyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 261); 

                auto tg_xxxyyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 262); 

                auto tg_xxxyyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 263); 

                auto tg_xxxyyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 264); 

                auto tg_xxxyyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 265); 

                auto tg_xxxyyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 266); 

                auto tg_xxxyyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 267); 

                auto tg_xxxyyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 268); 

                auto tg_xxxyyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 269); 

                auto tg_xxxyyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 270); 

                auto tg_xxxyyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 271); 

                auto tg_xxxyyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 272); 

                auto tg_xxxyzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 273); 

                auto tg_xxxyzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 274); 

                auto tg_xxxyzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 275); 

                auto tg_xxxyzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 276); 

                auto tg_xxxyzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 277); 

                auto tg_xxxyzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 278); 

                auto tg_xxxyzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 279); 

                auto tg_xxxyzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 280); 

                auto tg_xxxyzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 281); 

                auto tg_xxxyzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 282); 

                auto tg_xxxyzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 283); 

                auto tg_xxxyzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 284); 

                auto tg_xxxyzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 285); 

                auto tg_xxxyzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 286); 

                auto tg_xxxyzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 287); 

                auto tg_xxxyzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 288); 

                auto tg_xxxyzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 289); 

                auto tg_xxxyzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 290); 

                auto tg_xxxyzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 291); 

                auto tg_xxxyzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 292); 

                auto tg_xxxyzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 293); 

                // set up pointers to integrals

                auto tg_xxxxyyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 291); 

                auto tg_xxxxyyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 292); 

                auto tg_xxxxyyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 293); 

                auto tg_xxxxyyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 294); 

                auto tg_xxxxyyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 295); 

                auto tg_xxxxyyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 296); 

                auto tg_xxxxyyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 297); 

                auto tg_xxxxyyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 298); 

                auto tg_xxxxyyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 299); 

                auto tg_xxxxyyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 300); 

                auto tg_xxxxyyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 301); 

                auto tg_xxxxyyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 302); 

                auto tg_xxxxyyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 303); 

                auto tg_xxxxyyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 304); 

                auto tg_xxxxyyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 305); 

                auto tg_xxxxyyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 306); 

                auto tg_xxxxyyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 307); 

                auto tg_xxxxyyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 308); 

                auto tg_xxxxyyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 309); 

                auto tg_xxxxyyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 310); 

                auto tg_xxxxyyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 311); 

                auto tg_xxxxyyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 312); 

                auto tg_xxxxyyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 313); 

                auto tg_xxxxyyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 314); 

                auto tg_xxxxyyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 315); 

                auto tg_xxxxyyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 316); 

                auto tg_xxxxyyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 317); 

                auto tg_xxxxyyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 318); 

                auto tg_xxxxyyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 319); 

                auto tg_xxxxyyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 320); 

                auto tg_xxxxyyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 321); 

                auto tg_xxxxyyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 322); 

                auto tg_xxxxyyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 323); 

                auto tg_xxxxyyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 324); 

                auto tg_xxxxyyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 325); 

                auto tg_xxxxyyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 326); 

                auto tg_xxxxyyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 327); 

                auto tg_xxxxyyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 328); 

                auto tg_xxxxyyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 329); 

                auto tg_xxxxyyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 330); 

                auto tg_xxxxyyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 331); 

                auto tg_xxxxyyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 332); 

                auto tg_xxxxyyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 333); 

                auto tg_xxxxyyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 334); 

                auto tg_xxxxyyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 335); 

                auto tg_xxxxyyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 336); 

                auto tg_xxxxyyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 337); 

                auto tg_xxxxyyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 338); 

                auto tg_xxxxyyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 339); 

                auto tg_xxxxyyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 340); 

                auto tg_xxxxyyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 341); 

                auto tg_xxxxyyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 342); 

                auto tg_xxxxyyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 343); 

                auto tg_xxxxyyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 344); 

                auto tg_xxxxyyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 345); 

                auto tg_xxxxyyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 346); 

                auto tg_xxxxyyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 347); 

                auto tg_xxxxyyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 348); 

                auto tg_xxxxyyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 349); 

                auto tg_xxxxyyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 350); 

                auto tg_xxxxyyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 351); 

                auto tg_xxxxyyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 352); 

                auto tg_xxxxyyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 353); 

                auto tg_xxxxyyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 354); 

                auto tg_xxxxyyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 355); 

                auto tg_xxxxyyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 356); 

                auto tg_xxxxyyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 357); 

                auto tg_xxxxyyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 358); 

                auto tg_xxxxyyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 359); 

                auto tg_xxxxyyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 360); 

                auto tg_xxxxyyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 361); 

                auto tg_xxxxyyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 362); 

                auto tg_xxxxyyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 363); 

                auto tg_xxxxyzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 364); 

                auto tg_xxxxyzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 365); 

                auto tg_xxxxyzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 366); 

                auto tg_xxxxyzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 367); 

                auto tg_xxxxyzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 368); 

                auto tg_xxxxyzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 369); 

                auto tg_xxxxyzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 370); 

                auto tg_xxxxyzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 371); 

                auto tg_xxxxyzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 372); 

                auto tg_xxxxyzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 373); 

                auto tg_xxxxyzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 374); 

                auto tg_xxxxyzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 375); 

                auto tg_xxxxyzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 376); 

                auto tg_xxxxyzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 377); 

                auto tg_xxxxyzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 378); 

                auto tg_xxxxyzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 379); 

                auto tg_xxxxyzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 380); 

                auto tg_xxxxyzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 381); 

                auto tg_xxxxyzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 382); 

                auto tg_xxxxyzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 383); 

                auto tg_xxxxyzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 384); 

                auto tg_xxxxyzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 385); 

                auto tg_xxxxyzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 386); 

                auto tg_xxxxyzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 387); 

                // Batch of Integrals (291,388)

                #pragma omp simd aligned(fxn, fza, tg_xxxxyyyy_xxyyyz_0, tg_xxxxyyyy_xxyyzz_0, \
                                         tg_xxxxyyyy_xxyzzz_0, tg_xxxxyyyy_xxzzzz_0, tg_xxxxyyyy_xyyyyy_0, tg_xxxxyyyy_xyyyyz_0, \
                                         tg_xxxxyyyy_xyyyzz_0, tg_xxxxyyyy_xyyzzz_0, tg_xxxxyyyy_xyzzzz_0, tg_xxxxyyyy_xzzzzz_0, \
                                         tg_xxxxyyyy_yyyyyy_0, tg_xxxxyyyy_yyyyyz_0, tg_xxxxyyyy_yyyyzz_0, tg_xxxxyyyy_yyyzzz_0, \
                                         tg_xxxxyyyy_yyzzzz_0, tg_xxxxyyyy_yzzzzz_0, tg_xxxxyyyy_zzzzzz_0, tg_xxxxyyyz_xxxxxx_0, \
                                         tg_xxxxyyyz_xxxxxy_0, tg_xxxxyyyz_xxxxxz_0, tg_xxxxyyyz_xxxxyy_0, tg_xxxxyyyz_xxxxyz_0, \
                                         tg_xxxxyyyz_xxxxzz_0, tg_xxxxyyyz_xxxyyy_0, tg_xxxxyyyz_xxxyyz_0, tg_xxxxyyyz_xxxyzz_0, \
                                         tg_xxxxyyyz_xxxzzz_0, tg_xxxxyyyz_xxyyyy_0, tg_xxxxyyyz_xxyyyz_0, tg_xxxxyyyz_xxyyzz_0, \
                                         tg_xxxxyyyz_xxyzzz_0, tg_xxxxyyyz_xxzzzz_0, tg_xxxxyyyz_xyyyyy_0, tg_xxxxyyyz_xyyyyz_0, \
                                         tg_xxxxyyyz_xyyyzz_0, tg_xxxxyyyz_xyyzzz_0, tg_xxxxyyyz_xyzzzz_0, tg_xxxxyyyz_xzzzzz_0, \
                                         tg_xxxxyyyz_yyyyyy_0, tg_xxxxyyyz_yyyyyz_0, tg_xxxxyyyz_yyyyzz_0, tg_xxxxyyyz_yyyzzz_0, \
                                         tg_xxxxyyyz_yyzzzz_0, tg_xxxxyyyz_yzzzzz_0, tg_xxxxyyyz_zzzzzz_0, tg_xxxxyyzz_xxxxxx_0, \
                                         tg_xxxxyyzz_xxxxxy_0, tg_xxxxyyzz_xxxxxz_0, tg_xxxxyyzz_xxxxyy_0, tg_xxxxyyzz_xxxxyz_0, \
                                         tg_xxxxyyzz_xxxxzz_0, tg_xxxxyyzz_xxxyyy_0, tg_xxxxyyzz_xxxyyz_0, tg_xxxxyyzz_xxxyzz_0, \
                                         tg_xxxxyyzz_xxxzzz_0, tg_xxxxyyzz_xxyyyy_0, tg_xxxxyyzz_xxyyyz_0, tg_xxxxyyzz_xxyyzz_0, \
                                         tg_xxxxyyzz_xxyzzz_0, tg_xxxxyyzz_xxzzzz_0, tg_xxxxyyzz_xyyyyy_0, tg_xxxxyyzz_xyyyyz_0, \
                                         tg_xxxxyyzz_xyyyzz_0, tg_xxxxyyzz_xyyzzz_0, tg_xxxxyyzz_xyzzzz_0, tg_xxxxyyzz_xzzzzz_0, \
                                         tg_xxxxyyzz_yyyyyy_0, tg_xxxxyyzz_yyyyyz_0, tg_xxxxyyzz_yyyyzz_0, tg_xxxxyyzz_yyyzzz_0, \
                                         tg_xxxxyyzz_yyzzzz_0, tg_xxxxyyzz_yzzzzz_0, tg_xxxxyyzz_zzzzzz_0, tg_xxxxyzzz_xxxxxx_0, \
                                         tg_xxxxyzzz_xxxxxy_0, tg_xxxxyzzz_xxxxxz_0, tg_xxxxyzzz_xxxxyy_0, tg_xxxxyzzz_xxxxyz_0, \
                                         tg_xxxxyzzz_xxxxzz_0, tg_xxxxyzzz_xxxyyy_0, tg_xxxxyzzz_xxxyyz_0, tg_xxxxyzzz_xxxyzz_0, \
                                         tg_xxxxyzzz_xxxzzz_0, tg_xxxxyzzz_xxyyyy_0, tg_xxxxyzzz_xxyyyz_0, tg_xxxxyzzz_xxyyzz_0, \
                                         tg_xxxxyzzz_xxyzzz_0, tg_xxxxyzzz_xxzzzz_0, tg_xxxxyzzz_xyyyyy_0, tg_xxxxyzzz_xyyyyz_0, \
                                         tg_xxxxyzzz_xyyyzz_0, tg_xxxxyzzz_xyyzzz_0, tg_xxxxyzzz_xyzzzz_0, tg_xxxxyzzz_xzzzzz_0, \
                                         tg_xxxxyzzz_yyyyyy_0, tg_xxxxyzzz_yyyyyz_0, tg_xxxxyzzz_yyyyzz_0, tg_xxxyyyy_xxyyyz_0, \
                                         tg_xxxyyyy_xxyyyz_1, tg_xxxyyyy_xxyyzz_0, tg_xxxyyyy_xxyyzz_1, tg_xxxyyyy_xxyzzz_0, \
                                         tg_xxxyyyy_xxyzzz_1, tg_xxxyyyy_xxzzzz_0, tg_xxxyyyy_xxzzzz_1, tg_xxxyyyy_xyyyyy_0, \
                                         tg_xxxyyyy_xyyyyy_1, tg_xxxyyyy_xyyyyz_0, tg_xxxyyyy_xyyyyz_1, tg_xxxyyyy_xyyyz_1, \
                                         tg_xxxyyyy_xyyyzz_0, tg_xxxyyyy_xyyyzz_1, tg_xxxyyyy_xyyzz_1, tg_xxxyyyy_xyyzzz_0, \
                                         tg_xxxyyyy_xyyzzz_1, tg_xxxyyyy_xyzzz_1, tg_xxxyyyy_xyzzzz_0, tg_xxxyyyy_xyzzzz_1, \
                                         tg_xxxyyyy_xzzzz_1, tg_xxxyyyy_xzzzzz_0, tg_xxxyyyy_xzzzzz_1, tg_xxxyyyy_yyyyy_1, \
                                         tg_xxxyyyy_yyyyyy_0, tg_xxxyyyy_yyyyyy_1, tg_xxxyyyy_yyyyyz_0, tg_xxxyyyy_yyyyyz_1, \
                                         tg_xxxyyyy_yyyyz_1, tg_xxxyyyy_yyyyzz_0, tg_xxxyyyy_yyyyzz_1, tg_xxxyyyy_yyyzz_1, \
                                         tg_xxxyyyy_yyyzzz_0, tg_xxxyyyy_yyyzzz_1, tg_xxxyyyy_yyzzz_1, tg_xxxyyyy_yyzzzz_0, \
                                         tg_xxxyyyy_yyzzzz_1, tg_xxxyyyy_yzzzz_1, tg_xxxyyyy_yzzzzz_0, tg_xxxyyyy_yzzzzz_1, \
                                         tg_xxxyyyy_zzzzz_1, tg_xxxyyyy_zzzzzz_0, tg_xxxyyyy_zzzzzz_1, tg_xxxyyyz_xxxxx_1, \
                                         tg_xxxyyyz_xxxxxx_0, tg_xxxyyyz_xxxxxx_1, tg_xxxyyyz_xxxxxy_0, tg_xxxyyyz_xxxxxy_1, \
                                         tg_xxxyyyz_xxxxxz_0, tg_xxxyyyz_xxxxxz_1, tg_xxxyyyz_xxxxy_1, tg_xxxyyyz_xxxxyy_0, \
                                         tg_xxxyyyz_xxxxyy_1, tg_xxxyyyz_xxxxyz_0, tg_xxxyyyz_xxxxyz_1, tg_xxxyyyz_xxxxz_1, \
                                         tg_xxxyyyz_xxxxzz_0, tg_xxxyyyz_xxxxzz_1, tg_xxxyyyz_xxxyy_1, tg_xxxyyyz_xxxyyy_0, \
                                         tg_xxxyyyz_xxxyyy_1, tg_xxxyyyz_xxxyyz_0, tg_xxxyyyz_xxxyyz_1, tg_xxxyyyz_xxxyz_1, \
                                         tg_xxxyyyz_xxxyzz_0, tg_xxxyyyz_xxxyzz_1, tg_xxxyyyz_xxxzz_1, tg_xxxyyyz_xxxzzz_0, \
                                         tg_xxxyyyz_xxxzzz_1, tg_xxxyyyz_xxyyy_1, tg_xxxyyyz_xxyyyy_0, tg_xxxyyyz_xxyyyy_1, \
                                         tg_xxxyyyz_xxyyyz_0, tg_xxxyyyz_xxyyyz_1, tg_xxxyyyz_xxyyz_1, tg_xxxyyyz_xxyyzz_0, \
                                         tg_xxxyyyz_xxyyzz_1, tg_xxxyyyz_xxyzz_1, tg_xxxyyyz_xxyzzz_0, tg_xxxyyyz_xxyzzz_1, \
                                         tg_xxxyyyz_xxzzz_1, tg_xxxyyyz_xxzzzz_0, tg_xxxyyyz_xxzzzz_1, tg_xxxyyyz_xyyyy_1, \
                                         tg_xxxyyyz_xyyyyy_0, tg_xxxyyyz_xyyyyy_1, tg_xxxyyyz_xyyyyz_0, tg_xxxyyyz_xyyyyz_1, \
                                         tg_xxxyyyz_xyyyz_1, tg_xxxyyyz_xyyyzz_0, tg_xxxyyyz_xyyyzz_1, tg_xxxyyyz_xyyzz_1, \
                                         tg_xxxyyyz_xyyzzz_0, tg_xxxyyyz_xyyzzz_1, tg_xxxyyyz_xyzzz_1, tg_xxxyyyz_xyzzzz_0, \
                                         tg_xxxyyyz_xyzzzz_1, tg_xxxyyyz_xzzzz_1, tg_xxxyyyz_xzzzzz_0, tg_xxxyyyz_xzzzzz_1, \
                                         tg_xxxyyyz_yyyyy_1, tg_xxxyyyz_yyyyyy_0, tg_xxxyyyz_yyyyyy_1, tg_xxxyyyz_yyyyyz_0, \
                                         tg_xxxyyyz_yyyyyz_1, tg_xxxyyyz_yyyyz_1, tg_xxxyyyz_yyyyzz_0, tg_xxxyyyz_yyyyzz_1, \
                                         tg_xxxyyyz_yyyzz_1, tg_xxxyyyz_yyyzzz_0, tg_xxxyyyz_yyyzzz_1, tg_xxxyyyz_yyzzz_1, \
                                         tg_xxxyyyz_yyzzzz_0, tg_xxxyyyz_yyzzzz_1, tg_xxxyyyz_yzzzz_1, tg_xxxyyyz_yzzzzz_0, \
                                         tg_xxxyyyz_yzzzzz_1, tg_xxxyyyz_zzzzz_1, tg_xxxyyyz_zzzzzz_0, tg_xxxyyyz_zzzzzz_1, \
                                         tg_xxxyyzz_xxxxx_1, tg_xxxyyzz_xxxxxx_0, tg_xxxyyzz_xxxxxx_1, tg_xxxyyzz_xxxxxy_0, \
                                         tg_xxxyyzz_xxxxxy_1, tg_xxxyyzz_xxxxxz_0, tg_xxxyyzz_xxxxxz_1, tg_xxxyyzz_xxxxy_1, \
                                         tg_xxxyyzz_xxxxyy_0, tg_xxxyyzz_xxxxyy_1, tg_xxxyyzz_xxxxyz_0, tg_xxxyyzz_xxxxyz_1, \
                                         tg_xxxyyzz_xxxxz_1, tg_xxxyyzz_xxxxzz_0, tg_xxxyyzz_xxxxzz_1, tg_xxxyyzz_xxxyy_1, \
                                         tg_xxxyyzz_xxxyyy_0, tg_xxxyyzz_xxxyyy_1, tg_xxxyyzz_xxxyyz_0, tg_xxxyyzz_xxxyyz_1, \
                                         tg_xxxyyzz_xxxyz_1, tg_xxxyyzz_xxxyzz_0, tg_xxxyyzz_xxxyzz_1, tg_xxxyyzz_xxxzz_1, \
                                         tg_xxxyyzz_xxxzzz_0, tg_xxxyyzz_xxxzzz_1, tg_xxxyyzz_xxyyy_1, tg_xxxyyzz_xxyyyy_0, \
                                         tg_xxxyyzz_xxyyyy_1, tg_xxxyyzz_xxyyyz_0, tg_xxxyyzz_xxyyyz_1, tg_xxxyyzz_xxyyz_1, \
                                         tg_xxxyyzz_xxyyzz_0, tg_xxxyyzz_xxyyzz_1, tg_xxxyyzz_xxyzz_1, tg_xxxyyzz_xxyzzz_0, \
                                         tg_xxxyyzz_xxyzzz_1, tg_xxxyyzz_xxzzz_1, tg_xxxyyzz_xxzzzz_0, tg_xxxyyzz_xxzzzz_1, \
                                         tg_xxxyyzz_xyyyy_1, tg_xxxyyzz_xyyyyy_0, tg_xxxyyzz_xyyyyy_1, tg_xxxyyzz_xyyyyz_0, \
                                         tg_xxxyyzz_xyyyyz_1, tg_xxxyyzz_xyyyz_1, tg_xxxyyzz_xyyyzz_0, tg_xxxyyzz_xyyyzz_1, \
                                         tg_xxxyyzz_xyyzz_1, tg_xxxyyzz_xyyzzz_0, tg_xxxyyzz_xyyzzz_1, tg_xxxyyzz_xyzzz_1, \
                                         tg_xxxyyzz_xyzzzz_0, tg_xxxyyzz_xyzzzz_1, tg_xxxyyzz_xzzzz_1, tg_xxxyyzz_xzzzzz_0, \
                                         tg_xxxyyzz_xzzzzz_1, tg_xxxyyzz_yyyyy_1, tg_xxxyyzz_yyyyyy_0, tg_xxxyyzz_yyyyyy_1, \
                                         tg_xxxyyzz_yyyyyz_0, tg_xxxyyzz_yyyyyz_1, tg_xxxyyzz_yyyyz_1, tg_xxxyyzz_yyyyzz_0, \
                                         tg_xxxyyzz_yyyyzz_1, tg_xxxyyzz_yyyzz_1, tg_xxxyyzz_yyyzzz_0, tg_xxxyyzz_yyyzzz_1, \
                                         tg_xxxyyzz_yyzzz_1, tg_xxxyyzz_yyzzzz_0, tg_xxxyyzz_yyzzzz_1, tg_xxxyyzz_yzzzz_1, \
                                         tg_xxxyyzz_yzzzzz_0, tg_xxxyyzz_yzzzzz_1, tg_xxxyyzz_zzzzz_1, tg_xxxyyzz_zzzzzz_0, \
                                         tg_xxxyyzz_zzzzzz_1, tg_xxxyzzz_xxxxx_1, tg_xxxyzzz_xxxxxx_0, tg_xxxyzzz_xxxxxx_1, \
                                         tg_xxxyzzz_xxxxxy_0, tg_xxxyzzz_xxxxxy_1, tg_xxxyzzz_xxxxxz_0, tg_xxxyzzz_xxxxxz_1, \
                                         tg_xxxyzzz_xxxxy_1, tg_xxxyzzz_xxxxyy_0, tg_xxxyzzz_xxxxyy_1, tg_xxxyzzz_xxxxyz_0, \
                                         tg_xxxyzzz_xxxxyz_1, tg_xxxyzzz_xxxxz_1, tg_xxxyzzz_xxxxzz_0, tg_xxxyzzz_xxxxzz_1, \
                                         tg_xxxyzzz_xxxyy_1, tg_xxxyzzz_xxxyyy_0, tg_xxxyzzz_xxxyyy_1, tg_xxxyzzz_xxxyyz_0, \
                                         tg_xxxyzzz_xxxyyz_1, tg_xxxyzzz_xxxyz_1, tg_xxxyzzz_xxxyzz_0, tg_xxxyzzz_xxxyzz_1, \
                                         tg_xxxyzzz_xxxzz_1, tg_xxxyzzz_xxxzzz_0, tg_xxxyzzz_xxxzzz_1, tg_xxxyzzz_xxyyy_1, \
                                         tg_xxxyzzz_xxyyyy_0, tg_xxxyzzz_xxyyyy_1, tg_xxxyzzz_xxyyyz_0, tg_xxxyzzz_xxyyyz_1, \
                                         tg_xxxyzzz_xxyyz_1, tg_xxxyzzz_xxyyzz_0, tg_xxxyzzz_xxyyzz_1, tg_xxxyzzz_xxyzz_1, \
                                         tg_xxxyzzz_xxyzzz_0, tg_xxxyzzz_xxyzzz_1, tg_xxxyzzz_xxzzz_1, tg_xxxyzzz_xxzzzz_0, \
                                         tg_xxxyzzz_xxzzzz_1, tg_xxxyzzz_xyyyy_1, tg_xxxyzzz_xyyyyy_0, tg_xxxyzzz_xyyyyy_1, \
                                         tg_xxxyzzz_xyyyyz_0, tg_xxxyzzz_xyyyyz_1, tg_xxxyzzz_xyyyz_1, tg_xxxyzzz_xyyyzz_0, \
                                         tg_xxxyzzz_xyyyzz_1, tg_xxxyzzz_xyyzz_1, tg_xxxyzzz_xyyzzz_0, tg_xxxyzzz_xyyzzz_1, \
                                         tg_xxxyzzz_xyzzz_1, tg_xxxyzzz_xyzzzz_0, tg_xxxyzzz_xyzzzz_1, tg_xxxyzzz_xzzzz_1, \
                                         tg_xxxyzzz_xzzzzz_0, tg_xxxyzzz_xzzzzz_1, tg_xxxyzzz_yyyyy_1, tg_xxxyzzz_yyyyyy_0, \
                                         tg_xxxyzzz_yyyyyy_1, tg_xxxyzzz_yyyyyz_0, tg_xxxyzzz_yyyyyz_1, tg_xxxyzzz_yyyyz_1, \
                                         tg_xxxyzzz_yyyyzz_0, tg_xxxyzzz_yyyyzz_1, tg_xxxyzzz_yyyzz_1, tg_xxxyzzz_yyzzz_1, \
                                         tg_xxxyzzz_yzzzz_1, tg_xxxyzzz_zzzzz_1, tg_xxyyyy_xxyyyz_0, tg_xxyyyy_xxyyyz_1, \
                                         tg_xxyyyy_xxyyzz_0, tg_xxyyyy_xxyyzz_1, tg_xxyyyy_xxyzzz_0, tg_xxyyyy_xxyzzz_1, \
                                         tg_xxyyyy_xxzzzz_0, tg_xxyyyy_xxzzzz_1, tg_xxyyyy_xyyyyy_0, tg_xxyyyy_xyyyyy_1, \
                                         tg_xxyyyy_xyyyyz_0, tg_xxyyyy_xyyyyz_1, tg_xxyyyy_xyyyzz_0, tg_xxyyyy_xyyyzz_1, \
                                         tg_xxyyyy_xyyzzz_0, tg_xxyyyy_xyyzzz_1, tg_xxyyyy_xyzzzz_0, tg_xxyyyy_xyzzzz_1, \
                                         tg_xxyyyy_xzzzzz_0, tg_xxyyyy_xzzzzz_1, tg_xxyyyy_yyyyyy_0, tg_xxyyyy_yyyyyy_1, \
                                         tg_xxyyyy_yyyyyz_0, tg_xxyyyy_yyyyyz_1, tg_xxyyyy_yyyyzz_0, tg_xxyyyy_yyyyzz_1, \
                                         tg_xxyyyy_yyyzzz_0, tg_xxyyyy_yyyzzz_1, tg_xxyyyy_yyzzzz_0, tg_xxyyyy_yyzzzz_1, \
                                         tg_xxyyyy_yzzzzz_0, tg_xxyyyy_yzzzzz_1, tg_xxyyyy_zzzzzz_0, tg_xxyyyy_zzzzzz_1, \
                                         tg_xxyyyz_xxxxxx_0, tg_xxyyyz_xxxxxx_1, tg_xxyyyz_xxxxxy_0, tg_xxyyyz_xxxxxy_1, \
                                         tg_xxyyyz_xxxxxz_0, tg_xxyyyz_xxxxxz_1, tg_xxyyyz_xxxxyy_0, tg_xxyyyz_xxxxyy_1, \
                                         tg_xxyyyz_xxxxyz_0, tg_xxyyyz_xxxxyz_1, tg_xxyyyz_xxxxzz_0, tg_xxyyyz_xxxxzz_1, \
                                         tg_xxyyyz_xxxyyy_0, tg_xxyyyz_xxxyyy_1, tg_xxyyyz_xxxyyz_0, tg_xxyyyz_xxxyyz_1, \
                                         tg_xxyyyz_xxxyzz_0, tg_xxyyyz_xxxyzz_1, tg_xxyyyz_xxxzzz_0, tg_xxyyyz_xxxzzz_1, \
                                         tg_xxyyyz_xxyyyy_0, tg_xxyyyz_xxyyyy_1, tg_xxyyyz_xxyyyz_0, tg_xxyyyz_xxyyyz_1, \
                                         tg_xxyyyz_xxyyzz_0, tg_xxyyyz_xxyyzz_1, tg_xxyyyz_xxyzzz_0, tg_xxyyyz_xxyzzz_1, \
                                         tg_xxyyyz_xxzzzz_0, tg_xxyyyz_xxzzzz_1, tg_xxyyyz_xyyyyy_0, tg_xxyyyz_xyyyyy_1, \
                                         tg_xxyyyz_xyyyyz_0, tg_xxyyyz_xyyyyz_1, tg_xxyyyz_xyyyzz_0, tg_xxyyyz_xyyyzz_1, \
                                         tg_xxyyyz_xyyzzz_0, tg_xxyyyz_xyyzzz_1, tg_xxyyyz_xyzzzz_0, tg_xxyyyz_xyzzzz_1, \
                                         tg_xxyyyz_xzzzzz_0, tg_xxyyyz_xzzzzz_1, tg_xxyyyz_yyyyyy_0, tg_xxyyyz_yyyyyy_1, \
                                         tg_xxyyyz_yyyyyz_0, tg_xxyyyz_yyyyyz_1, tg_xxyyyz_yyyyzz_0, tg_xxyyyz_yyyyzz_1, \
                                         tg_xxyyyz_yyyzzz_0, tg_xxyyyz_yyyzzz_1, tg_xxyyyz_yyzzzz_0, tg_xxyyyz_yyzzzz_1, \
                                         tg_xxyyyz_yzzzzz_0, tg_xxyyyz_yzzzzz_1, tg_xxyyyz_zzzzzz_0, tg_xxyyyz_zzzzzz_1, \
                                         tg_xxyyzz_xxxxxx_0, tg_xxyyzz_xxxxxx_1, tg_xxyyzz_xxxxxy_0, tg_xxyyzz_xxxxxy_1, \
                                         tg_xxyyzz_xxxxxz_0, tg_xxyyzz_xxxxxz_1, tg_xxyyzz_xxxxyy_0, tg_xxyyzz_xxxxyy_1, \
                                         tg_xxyyzz_xxxxyz_0, tg_xxyyzz_xxxxyz_1, tg_xxyyzz_xxxxzz_0, tg_xxyyzz_xxxxzz_1, \
                                         tg_xxyyzz_xxxyyy_0, tg_xxyyzz_xxxyyy_1, tg_xxyyzz_xxxyyz_0, tg_xxyyzz_xxxyyz_1, \
                                         tg_xxyyzz_xxxyzz_0, tg_xxyyzz_xxxyzz_1, tg_xxyyzz_xxxzzz_0, tg_xxyyzz_xxxzzz_1, \
                                         tg_xxyyzz_xxyyyy_0, tg_xxyyzz_xxyyyy_1, tg_xxyyzz_xxyyyz_0, tg_xxyyzz_xxyyyz_1, \
                                         tg_xxyyzz_xxyyzz_0, tg_xxyyzz_xxyyzz_1, tg_xxyyzz_xxyzzz_0, tg_xxyyzz_xxyzzz_1, \
                                         tg_xxyyzz_xxzzzz_0, tg_xxyyzz_xxzzzz_1, tg_xxyyzz_xyyyyy_0, tg_xxyyzz_xyyyyy_1, \
                                         tg_xxyyzz_xyyyyz_0, tg_xxyyzz_xyyyyz_1, tg_xxyyzz_xyyyzz_0, tg_xxyyzz_xyyyzz_1, \
                                         tg_xxyyzz_xyyzzz_0, tg_xxyyzz_xyyzzz_1, tg_xxyyzz_xyzzzz_0, tg_xxyyzz_xyzzzz_1, \
                                         tg_xxyyzz_xzzzzz_0, tg_xxyyzz_xzzzzz_1, tg_xxyyzz_yyyyyy_0, tg_xxyyzz_yyyyyy_1, \
                                         tg_xxyyzz_yyyyyz_0, tg_xxyyzz_yyyyyz_1, tg_xxyyzz_yyyyzz_0, tg_xxyyzz_yyyyzz_1, \
                                         tg_xxyyzz_yyyzzz_0, tg_xxyyzz_yyyzzz_1, tg_xxyyzz_yyzzzz_0, tg_xxyyzz_yyzzzz_1, \
                                         tg_xxyyzz_yzzzzz_0, tg_xxyyzz_yzzzzz_1, tg_xxyyzz_zzzzzz_0, tg_xxyyzz_zzzzzz_1, \
                                         tg_xxyzzz_xxxxxx_0, tg_xxyzzz_xxxxxx_1, tg_xxyzzz_xxxxxy_0, tg_xxyzzz_xxxxxy_1, \
                                         tg_xxyzzz_xxxxxz_0, tg_xxyzzz_xxxxxz_1, tg_xxyzzz_xxxxyy_0, tg_xxyzzz_xxxxyy_1, \
                                         tg_xxyzzz_xxxxyz_0, tg_xxyzzz_xxxxyz_1, tg_xxyzzz_xxxxzz_0, tg_xxyzzz_xxxxzz_1, \
                                         tg_xxyzzz_xxxyyy_0, tg_xxyzzz_xxxyyy_1, tg_xxyzzz_xxxyyz_0, tg_xxyzzz_xxxyyz_1, \
                                         tg_xxyzzz_xxxyzz_0, tg_xxyzzz_xxxyzz_1, tg_xxyzzz_xxxzzz_0, tg_xxyzzz_xxxzzz_1, \
                                         tg_xxyzzz_xxyyyy_0, tg_xxyzzz_xxyyyy_1, tg_xxyzzz_xxyyyz_0, tg_xxyzzz_xxyyyz_1, \
                                         tg_xxyzzz_xxyyzz_0, tg_xxyzzz_xxyyzz_1, tg_xxyzzz_xxyzzz_0, tg_xxyzzz_xxyzzz_1, \
                                         tg_xxyzzz_xxzzzz_0, tg_xxyzzz_xxzzzz_1, tg_xxyzzz_xyyyyy_0, tg_xxyzzz_xyyyyy_1, \
                                         tg_xxyzzz_xyyyyz_0, tg_xxyzzz_xyyyyz_1, tg_xxyzzz_xyyyzz_0, tg_xxyzzz_xyyyzz_1, \
                                         tg_xxyzzz_xyyzzz_0, tg_xxyzzz_xyyzzz_1, tg_xxyzzz_xyzzzz_0, tg_xxyzzz_xyzzzz_1, \
                                         tg_xxyzzz_xzzzzz_0, tg_xxyzzz_xzzzzz_1, tg_xxyzzz_yyyyyy_0, tg_xxyzzz_yyyyyy_1, \
                                         tg_xxyzzz_yyyyyz_0, tg_xxyzzz_yyyyyz_1, tg_xxyzzz_yyyyzz_0, tg_xxyzzz_yyyyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxyyyy_xxyyyz_0[j] = pb_x * tg_xxxyyyy_xxyyyz_0[j] + fr * tg_xxxyyyy_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxyyyz_0[j] - tg_xxyyyy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_xyyyz_1[j];

                    tg_xxxxyyyy_xxyyzz_0[j] = pb_x * tg_xxxyyyy_xxyyzz_0[j] + fr * tg_xxxyyyy_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxyyzz_0[j] - tg_xxyyyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_xyyzz_1[j];

                    tg_xxxxyyyy_xxyzzz_0[j] = pb_x * tg_xxxyyyy_xxyzzz_0[j] + fr * tg_xxxyyyy_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxyzzz_0[j] - tg_xxyyyy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_xyzzz_1[j];

                    tg_xxxxyyyy_xxzzzz_0[j] = pb_x * tg_xxxyyyy_xxzzzz_0[j] + fr * tg_xxxyyyy_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xxzzzz_0[j] - tg_xxyyyy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyy_xzzzz_1[j];

                    tg_xxxxyyyy_xyyyyy_0[j] = pb_x * tg_xxxyyyy_xyyyyy_0[j] + fr * tg_xxxyyyy_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xyyyyy_0[j] - tg_xxyyyy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_yyyyy_1[j];

                    tg_xxxxyyyy_xyyyyz_0[j] = pb_x * tg_xxxyyyy_xyyyyz_0[j] + fr * tg_xxxyyyy_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xyyyyz_0[j] - tg_xxyyyy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_yyyyz_1[j];

                    tg_xxxxyyyy_xyyyzz_0[j] = pb_x * tg_xxxyyyy_xyyyzz_0[j] + fr * tg_xxxyyyy_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xyyyzz_0[j] - tg_xxyyyy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_yyyzz_1[j];

                    tg_xxxxyyyy_xyyzzz_0[j] = pb_x * tg_xxxyyyy_xyyzzz_0[j] + fr * tg_xxxyyyy_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xyyzzz_0[j] - tg_xxyyyy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_yyzzz_1[j];

                    tg_xxxxyyyy_xyzzzz_0[j] = pb_x * tg_xxxyyyy_xyzzzz_0[j] + fr * tg_xxxyyyy_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xyzzzz_0[j] - tg_xxyyyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_yzzzz_1[j];

                    tg_xxxxyyyy_xzzzzz_0[j] = pb_x * tg_xxxyyyy_xzzzzz_0[j] + fr * tg_xxxyyyy_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_xzzzzz_0[j] - tg_xxyyyy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyy_zzzzz_1[j];

                    tg_xxxxyyyy_yyyyyy_0[j] = pb_x * tg_xxxyyyy_yyyyyy_0[j] + fr * tg_xxxyyyy_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yyyyyy_0[j] - tg_xxyyyy_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxyyyy_yyyyyz_0[j] = pb_x * tg_xxxyyyy_yyyyyz_0[j] + fr * tg_xxxyyyy_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yyyyyz_0[j] - tg_xxyyyy_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxyyyy_yyyyzz_0[j] = pb_x * tg_xxxyyyy_yyyyzz_0[j] + fr * tg_xxxyyyy_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yyyyzz_0[j] - tg_xxyyyy_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxyyyy_yyyzzz_0[j] = pb_x * tg_xxxyyyy_yyyzzz_0[j] + fr * tg_xxxyyyy_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yyyzzz_0[j] - tg_xxyyyy_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxyyyy_yyzzzz_0[j] = pb_x * tg_xxxyyyy_yyzzzz_0[j] + fr * tg_xxxyyyy_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yyzzzz_0[j] - tg_xxyyyy_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyy_yzzzzz_0[j] = pb_x * tg_xxxyyyy_yzzzzz_0[j] + fr * tg_xxxyyyy_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_yzzzzz_0[j] - tg_xxyyyy_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyy_zzzzzz_0[j] = pb_x * tg_xxxyyyy_zzzzzz_0[j] + fr * tg_xxxyyyy_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyy_zzzzzz_0[j] - tg_xxyyyy_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyz_xxxxxx_0[j] = pb_x * tg_xxxyyyz_xxxxxx_0[j] + fr * tg_xxxyyyz_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxxx_0[j] - tg_xxyyyz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyyz_xxxxx_1[j];

                    tg_xxxxyyyz_xxxxxy_0[j] = pb_x * tg_xxxyyyz_xxxxxy_0[j] + fr * tg_xxxyyyz_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxxy_0[j] - tg_xxyyyz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyyz_xxxxy_1[j];

                    tg_xxxxyyyz_xxxxxz_0[j] = pb_x * tg_xxxyyyz_xxxxxz_0[j] + fr * tg_xxxyyyz_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxxz_0[j] - tg_xxyyyz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyyz_xxxxz_1[j];

                    tg_xxxxyyyz_xxxxyy_0[j] = pb_x * tg_xxxyyyz_xxxxyy_0[j] + fr * tg_xxxyyyz_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxyy_0[j] - tg_xxyyyz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyz_xxxyy_1[j];

                    tg_xxxxyyyz_xxxxyz_0[j] = pb_x * tg_xxxyyyz_xxxxyz_0[j] + fr * tg_xxxyyyz_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxyz_0[j] - tg_xxyyyz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyz_xxxyz_1[j];

                    tg_xxxxyyyz_xxxxzz_0[j] = pb_x * tg_xxxyyyz_xxxxzz_0[j] + fr * tg_xxxyyyz_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxxzz_0[j] - tg_xxyyyz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyyz_xxxzz_1[j];

                    tg_xxxxyyyz_xxxyyy_0[j] = pb_x * tg_xxxyyyz_xxxyyy_0[j] + fr * tg_xxxyyyz_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxyyy_0[j] - tg_xxyyyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyz_xxyyy_1[j];

                    tg_xxxxyyyz_xxxyyz_0[j] = pb_x * tg_xxxyyyz_xxxyyz_0[j] + fr * tg_xxxyyyz_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxyyz_0[j] - tg_xxyyyz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyz_xxyyz_1[j];

                    tg_xxxxyyyz_xxxyzz_0[j] = pb_x * tg_xxxyyyz_xxxyzz_0[j] + fr * tg_xxxyyyz_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxyzz_0[j] - tg_xxyyyz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyz_xxyzz_1[j];

                    tg_xxxxyyyz_xxxzzz_0[j] = pb_x * tg_xxxyyyz_xxxzzz_0[j] + fr * tg_xxxyyyz_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxxzzz_0[j] - tg_xxyyyz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyyz_xxzzz_1[j];

                    tg_xxxxyyyz_xxyyyy_0[j] = pb_x * tg_xxxyyyz_xxyyyy_0[j] + fr * tg_xxxyyyz_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxyyyy_0[j] - tg_xxyyyz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_xyyyy_1[j];

                    tg_xxxxyyyz_xxyyyz_0[j] = pb_x * tg_xxxyyyz_xxyyyz_0[j] + fr * tg_xxxyyyz_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxyyyz_0[j] - tg_xxyyyz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_xyyyz_1[j];

                    tg_xxxxyyyz_xxyyzz_0[j] = pb_x * tg_xxxyyyz_xxyyzz_0[j] + fr * tg_xxxyyyz_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxyyzz_0[j] - tg_xxyyyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_xyyzz_1[j];

                    tg_xxxxyyyz_xxyzzz_0[j] = pb_x * tg_xxxyyyz_xxyzzz_0[j] + fr * tg_xxxyyyz_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxyzzz_0[j] - tg_xxyyyz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_xyzzz_1[j];

                    tg_xxxxyyyz_xxzzzz_0[j] = pb_x * tg_xxxyyyz_xxzzzz_0[j] + fr * tg_xxxyyyz_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xxzzzz_0[j] - tg_xxyyyz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyyz_xzzzz_1[j];

                    tg_xxxxyyyz_xyyyyy_0[j] = pb_x * tg_xxxyyyz_xyyyyy_0[j] + fr * tg_xxxyyyz_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xyyyyy_0[j] - tg_xxyyyz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_yyyyy_1[j];

                    tg_xxxxyyyz_xyyyyz_0[j] = pb_x * tg_xxxyyyz_xyyyyz_0[j] + fr * tg_xxxyyyz_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xyyyyz_0[j] - tg_xxyyyz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_yyyyz_1[j];

                    tg_xxxxyyyz_xyyyzz_0[j] = pb_x * tg_xxxyyyz_xyyyzz_0[j] + fr * tg_xxxyyyz_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xyyyzz_0[j] - tg_xxyyyz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_yyyzz_1[j];

                    tg_xxxxyyyz_xyyzzz_0[j] = pb_x * tg_xxxyyyz_xyyzzz_0[j] + fr * tg_xxxyyyz_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xyyzzz_0[j] - tg_xxyyyz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_yyzzz_1[j];

                    tg_xxxxyyyz_xyzzzz_0[j] = pb_x * tg_xxxyyyz_xyzzzz_0[j] + fr * tg_xxxyyyz_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xyzzzz_0[j] - tg_xxyyyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_yzzzz_1[j];

                    tg_xxxxyyyz_xzzzzz_0[j] = pb_x * tg_xxxyyyz_xzzzzz_0[j] + fr * tg_xxxyyyz_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_xzzzzz_0[j] - tg_xxyyyz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyyz_zzzzz_1[j];

                    tg_xxxxyyyz_yyyyyy_0[j] = pb_x * tg_xxxyyyz_yyyyyy_0[j] + fr * tg_xxxyyyz_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yyyyyy_0[j] - tg_xxyyyz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxyyyz_yyyyyz_0[j] = pb_x * tg_xxxyyyz_yyyyyz_0[j] + fr * tg_xxxyyyz_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yyyyyz_0[j] - tg_xxyyyz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxyyyz_yyyyzz_0[j] = pb_x * tg_xxxyyyz_yyyyzz_0[j] + fr * tg_xxxyyyz_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yyyyzz_0[j] - tg_xxyyyz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxyyyz_yyyzzz_0[j] = pb_x * tg_xxxyyyz_yyyzzz_0[j] + fr * tg_xxxyyyz_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yyyzzz_0[j] - tg_xxyyyz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxyyyz_yyzzzz_0[j] = pb_x * tg_xxxyyyz_yyzzzz_0[j] + fr * tg_xxxyyyz_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yyzzzz_0[j] - tg_xxyyyz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyz_yzzzzz_0[j] = pb_x * tg_xxxyyyz_yzzzzz_0[j] + fr * tg_xxxyyyz_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_yzzzzz_0[j] - tg_xxyyyz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyyz_zzzzzz_0[j] = pb_x * tg_xxxyyyz_zzzzzz_0[j] + fr * tg_xxxyyyz_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyyz_zzzzzz_0[j] - tg_xxyyyz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyzz_xxxxxx_0[j] = pb_x * tg_xxxyyzz_xxxxxx_0[j] + fr * tg_xxxyyzz_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxxx_0[j] - tg_xxyyzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyyzz_xxxxx_1[j];

                    tg_xxxxyyzz_xxxxxy_0[j] = pb_x * tg_xxxyyzz_xxxxxy_0[j] + fr * tg_xxxyyzz_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxxy_0[j] - tg_xxyyzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyzz_xxxxy_1[j];

                    tg_xxxxyyzz_xxxxxz_0[j] = pb_x * tg_xxxyyzz_xxxxxz_0[j] + fr * tg_xxxyyzz_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxxz_0[j] - tg_xxyyzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyyzz_xxxxz_1[j];

                    tg_xxxxyyzz_xxxxyy_0[j] = pb_x * tg_xxxyyzz_xxxxyy_0[j] + fr * tg_xxxyyzz_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxyy_0[j] - tg_xxyyzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyzz_xxxyy_1[j];

                    tg_xxxxyyzz_xxxxyz_0[j] = pb_x * tg_xxxyyzz_xxxxyz_0[j] + fr * tg_xxxyyzz_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxyz_0[j] - tg_xxyyzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyzz_xxxyz_1[j];

                    tg_xxxxyyzz_xxxxzz_0[j] = pb_x * tg_xxxyyzz_xxxxzz_0[j] + fr * tg_xxxyyzz_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxxzz_0[j] - tg_xxyyzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyyzz_xxxzz_1[j];

                    tg_xxxxyyzz_xxxyyy_0[j] = pb_x * tg_xxxyyzz_xxxyyy_0[j] + fr * tg_xxxyyzz_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxyyy_0[j] - tg_xxyyzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyzz_xxyyy_1[j];

                    tg_xxxxyyzz_xxxyyz_0[j] = pb_x * tg_xxxyyzz_xxxyyz_0[j] + fr * tg_xxxyyzz_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxyyz_0[j] - tg_xxyyzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyzz_xxyyz_1[j];

                    tg_xxxxyyzz_xxxyzz_0[j] = pb_x * tg_xxxyyzz_xxxyzz_0[j] + fr * tg_xxxyyzz_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxyzz_0[j] - tg_xxyyzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyzz_xxyzz_1[j];

                    tg_xxxxyyzz_xxxzzz_0[j] = pb_x * tg_xxxyyzz_xxxzzz_0[j] + fr * tg_xxxyyzz_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxxzzz_0[j] - tg_xxyyzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyyzz_xxzzz_1[j];

                    tg_xxxxyyzz_xxyyyy_0[j] = pb_x * tg_xxxyyzz_xxyyyy_0[j] + fr * tg_xxxyyzz_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxyyyy_0[j] - tg_xxyyzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_xyyyy_1[j];

                    tg_xxxxyyzz_xxyyyz_0[j] = pb_x * tg_xxxyyzz_xxyyyz_0[j] + fr * tg_xxxyyzz_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxyyyz_0[j] - tg_xxyyzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_xyyyz_1[j];

                    tg_xxxxyyzz_xxyyzz_0[j] = pb_x * tg_xxxyyzz_xxyyzz_0[j] + fr * tg_xxxyyzz_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxyyzz_0[j] - tg_xxyyzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_xyyzz_1[j];

                    tg_xxxxyyzz_xxyzzz_0[j] = pb_x * tg_xxxyyzz_xxyzzz_0[j] + fr * tg_xxxyyzz_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxyzzz_0[j] - tg_xxyyzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_xyzzz_1[j];

                    tg_xxxxyyzz_xxzzzz_0[j] = pb_x * tg_xxxyyzz_xxzzzz_0[j] + fr * tg_xxxyyzz_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xxzzzz_0[j] - tg_xxyyzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyyzz_xzzzz_1[j];

                    tg_xxxxyyzz_xyyyyy_0[j] = pb_x * tg_xxxyyzz_xyyyyy_0[j] + fr * tg_xxxyyzz_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xyyyyy_0[j] - tg_xxyyzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_yyyyy_1[j];

                    tg_xxxxyyzz_xyyyyz_0[j] = pb_x * tg_xxxyyzz_xyyyyz_0[j] + fr * tg_xxxyyzz_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xyyyyz_0[j] - tg_xxyyzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_yyyyz_1[j];

                    tg_xxxxyyzz_xyyyzz_0[j] = pb_x * tg_xxxyyzz_xyyyzz_0[j] + fr * tg_xxxyyzz_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xyyyzz_0[j] - tg_xxyyzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_yyyzz_1[j];

                    tg_xxxxyyzz_xyyzzz_0[j] = pb_x * tg_xxxyyzz_xyyzzz_0[j] + fr * tg_xxxyyzz_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xyyzzz_0[j] - tg_xxyyzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_yyzzz_1[j];

                    tg_xxxxyyzz_xyzzzz_0[j] = pb_x * tg_xxxyyzz_xyzzzz_0[j] + fr * tg_xxxyyzz_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xyzzzz_0[j] - tg_xxyyzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_yzzzz_1[j];

                    tg_xxxxyyzz_xzzzzz_0[j] = pb_x * tg_xxxyyzz_xzzzzz_0[j] + fr * tg_xxxyyzz_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_xzzzzz_0[j] - tg_xxyyzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyyzz_zzzzz_1[j];

                    tg_xxxxyyzz_yyyyyy_0[j] = pb_x * tg_xxxyyzz_yyyyyy_0[j] + fr * tg_xxxyyzz_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yyyyyy_0[j] - tg_xxyyzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxyyzz_yyyyyz_0[j] = pb_x * tg_xxxyyzz_yyyyyz_0[j] + fr * tg_xxxyyzz_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yyyyyz_0[j] - tg_xxyyzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxyyzz_yyyyzz_0[j] = pb_x * tg_xxxyyzz_yyyyzz_0[j] + fr * tg_xxxyyzz_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yyyyzz_0[j] - tg_xxyyzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxyyzz_yyyzzz_0[j] = pb_x * tg_xxxyyzz_yyyzzz_0[j] + fr * tg_xxxyyzz_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yyyzzz_0[j] - tg_xxyyzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxyyzz_yyzzzz_0[j] = pb_x * tg_xxxyyzz_yyzzzz_0[j] + fr * tg_xxxyyzz_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yyzzzz_0[j] - tg_xxyyzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxyyzz_yzzzzz_0[j] = pb_x * tg_xxxyyzz_yzzzzz_0[j] + fr * tg_xxxyyzz_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_yzzzzz_0[j] - tg_xxyyzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxyyzz_zzzzzz_0[j] = pb_x * tg_xxxyyzz_zzzzzz_0[j] + fr * tg_xxxyyzz_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyyzz_zzzzzz_0[j] - tg_xxyyzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxyzzz_xxxxxx_0[j] = pb_x * tg_xxxyzzz_xxxxxx_0[j] + fr * tg_xxxyzzz_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxxx_0[j] - tg_xxyzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxyzzz_xxxxx_1[j];

                    tg_xxxxyzzz_xxxxxy_0[j] = pb_x * tg_xxxyzzz_xxxxxy_0[j] + fr * tg_xxxyzzz_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxxy_0[j] - tg_xxyzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyzzz_xxxxy_1[j];

                    tg_xxxxyzzz_xxxxxz_0[j] = pb_x * tg_xxxyzzz_xxxxxz_0[j] + fr * tg_xxxyzzz_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxxz_0[j] - tg_xxyzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxyzzz_xxxxz_1[j];

                    tg_xxxxyzzz_xxxxyy_0[j] = pb_x * tg_xxxyzzz_xxxxyy_0[j] + fr * tg_xxxyzzz_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxyy_0[j] - tg_xxyzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzzz_xxxyy_1[j];

                    tg_xxxxyzzz_xxxxyz_0[j] = pb_x * tg_xxxyzzz_xxxxyz_0[j] + fr * tg_xxxyzzz_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxyz_0[j] - tg_xxyzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzzz_xxxyz_1[j];

                    tg_xxxxyzzz_xxxxzz_0[j] = pb_x * tg_xxxyzzz_xxxxzz_0[j] + fr * tg_xxxyzzz_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxxzz_0[j] - tg_xxyzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxyzzz_xxxzz_1[j];

                    tg_xxxxyzzz_xxxyyy_0[j] = pb_x * tg_xxxyzzz_xxxyyy_0[j] + fr * tg_xxxyzzz_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxyyy_0[j] - tg_xxyzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzzz_xxyyy_1[j];

                    tg_xxxxyzzz_xxxyyz_0[j] = pb_x * tg_xxxyzzz_xxxyyz_0[j] + fr * tg_xxxyzzz_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxyyz_0[j] - tg_xxyzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzzz_xxyyz_1[j];

                    tg_xxxxyzzz_xxxyzz_0[j] = pb_x * tg_xxxyzzz_xxxyzz_0[j] + fr * tg_xxxyzzz_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxyzz_0[j] - tg_xxyzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzzz_xxyzz_1[j];

                    tg_xxxxyzzz_xxxzzz_0[j] = pb_x * tg_xxxyzzz_xxxzzz_0[j] + fr * tg_xxxyzzz_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxxzzz_0[j] - tg_xxyzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxyzzz_xxzzz_1[j];

                    tg_xxxxyzzz_xxyyyy_0[j] = pb_x * tg_xxxyzzz_xxyyyy_0[j] + fr * tg_xxxyzzz_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxyyyy_0[j] - tg_xxyzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_xyyyy_1[j];

                    tg_xxxxyzzz_xxyyyz_0[j] = pb_x * tg_xxxyzzz_xxyyyz_0[j] + fr * tg_xxxyzzz_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxyyyz_0[j] - tg_xxyzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_xyyyz_1[j];

                    tg_xxxxyzzz_xxyyzz_0[j] = pb_x * tg_xxxyzzz_xxyyzz_0[j] + fr * tg_xxxyzzz_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxyyzz_0[j] - tg_xxyzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_xyyzz_1[j];

                    tg_xxxxyzzz_xxyzzz_0[j] = pb_x * tg_xxxyzzz_xxyzzz_0[j] + fr * tg_xxxyzzz_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxyzzz_0[j] - tg_xxyzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_xyzzz_1[j];

                    tg_xxxxyzzz_xxzzzz_0[j] = pb_x * tg_xxxyzzz_xxzzzz_0[j] + fr * tg_xxxyzzz_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xxzzzz_0[j] - tg_xxyzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxyzzz_xzzzz_1[j];

                    tg_xxxxyzzz_xyyyyy_0[j] = pb_x * tg_xxxyzzz_xyyyyy_0[j] + fr * tg_xxxyzzz_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xyyyyy_0[j] - tg_xxyzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_yyyyy_1[j];

                    tg_xxxxyzzz_xyyyyz_0[j] = pb_x * tg_xxxyzzz_xyyyyz_0[j] + fr * tg_xxxyzzz_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xyyyyz_0[j] - tg_xxyzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_yyyyz_1[j];

                    tg_xxxxyzzz_xyyyzz_0[j] = pb_x * tg_xxxyzzz_xyyyzz_0[j] + fr * tg_xxxyzzz_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xyyyzz_0[j] - tg_xxyzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_yyyzz_1[j];

                    tg_xxxxyzzz_xyyzzz_0[j] = pb_x * tg_xxxyzzz_xyyzzz_0[j] + fr * tg_xxxyzzz_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xyyzzz_0[j] - tg_xxyzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_yyzzz_1[j];

                    tg_xxxxyzzz_xyzzzz_0[j] = pb_x * tg_xxxyzzz_xyzzzz_0[j] + fr * tg_xxxyzzz_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xyzzzz_0[j] - tg_xxyzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_yzzzz_1[j];

                    tg_xxxxyzzz_xzzzzz_0[j] = pb_x * tg_xxxyzzz_xzzzzz_0[j] + fr * tg_xxxyzzz_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_xzzzzz_0[j] - tg_xxyzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxyzzz_zzzzz_1[j];

                    tg_xxxxyzzz_yyyyyy_0[j] = pb_x * tg_xxxyzzz_yyyyyy_0[j] + fr * tg_xxxyzzz_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yyyyyy_0[j] - tg_xxyzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxyzzz_yyyyyz_0[j] = pb_x * tg_xxxyzzz_yyyyyz_0[j] + fr * tg_xxxyzzz_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yyyyyz_0[j] - tg_xxyzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxyzzz_yyyyzz_0[j] = pb_x * tg_xxxyzzz_yyyyzz_0[j] + fr * tg_xxxyzzz_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yyyyzz_0[j] - tg_xxyzzz_yyyyzz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_388_485(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (388,485)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxxyzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 388); 

                auto tg_xxxyzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 389); 

                auto tg_xxxyzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 390); 

                auto tg_xxxyzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 391); 

                auto tg_xxxzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 392); 

                auto tg_xxxzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 393); 

                auto tg_xxxzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 394); 

                auto tg_xxxzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 395); 

                auto tg_xxxzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 396); 

                auto tg_xxxzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 397); 

                auto tg_xxxzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 398); 

                auto tg_xxxzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 399); 

                auto tg_xxxzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 400); 

                auto tg_xxxzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 401); 

                auto tg_xxxzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 402); 

                auto tg_xxxzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 403); 

                auto tg_xxxzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 404); 

                auto tg_xxxzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 405); 

                auto tg_xxxzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 406); 

                auto tg_xxxzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 407); 

                auto tg_xxxzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 408); 

                auto tg_xxxzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 409); 

                auto tg_xxxzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 410); 

                auto tg_xxxzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 411); 

                auto tg_xxxzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 412); 

                auto tg_xxxzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 413); 

                auto tg_xxxzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 414); 

                auto tg_xxxzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 415); 

                auto tg_xxxzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 416); 

                auto tg_xxxzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 417); 

                auto tg_xxxzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 418); 

                auto tg_xxxzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 419); 

                auto tg_xxyyyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 420); 

                auto tg_xxyyyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 421); 

                auto tg_xxyyyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 422); 

                auto tg_xxyyyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 423); 

                auto tg_xxyyyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 424); 

                auto tg_xxyyyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 425); 

                auto tg_xxyyyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 426); 

                auto tg_xxyyyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 427); 

                auto tg_xxyyyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 428); 

                auto tg_xxyyyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 429); 

                auto tg_xxyyyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 430); 

                auto tg_xxyyyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 431); 

                auto tg_xxyyyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 432); 

                auto tg_xxyyyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 433); 

                auto tg_xxyyyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 434); 

                auto tg_xxyyyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 435); 

                auto tg_xxyyyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 436); 

                auto tg_xxyyyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 437); 

                auto tg_xxyyyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 438); 

                auto tg_xxyyyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 439); 

                auto tg_xxyyyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 440); 

                auto tg_xxyyyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 441); 

                auto tg_xxyyyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 442); 

                auto tg_xxyyyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 443); 

                auto tg_xxyyyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 444); 

                auto tg_xxyyyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 445); 

                auto tg_xxyyyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 446); 

                auto tg_xxyyyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 447); 

                auto tg_xxyyyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 448); 

                auto tg_xxyyyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 449); 

                auto tg_xxyyyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 450); 

                auto tg_xxyyyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 451); 

                auto tg_xxyyyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 452); 

                auto tg_xxyyyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 453); 

                auto tg_xxyyyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 454); 

                auto tg_xxyyyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 455); 

                auto tg_xxyyyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 456); 

                auto tg_xxyyyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 457); 

                auto tg_xxyyyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 458); 

                auto tg_xxyyyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 459); 

                auto tg_xxyyyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 460); 

                auto tg_xxyyyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 461); 

                auto tg_xxyyyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 462); 

                auto tg_xxyyyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 463); 

                auto tg_xxyyyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 464); 

                auto tg_xxyyyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 465); 

                auto tg_xxyyyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 466); 

                auto tg_xxyyyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 467); 

                auto tg_xxyyyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 468); 

                auto tg_xxyyyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 469); 

                auto tg_xxyyyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 470); 

                auto tg_xxyyyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 471); 

                auto tg_xxyyyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 472); 

                auto tg_xxyyyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 473); 

                auto tg_xxyyyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 474); 

                auto tg_xxyyyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 475); 

                auto tg_xxyyyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 476); 

                auto tg_xxyyyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 477); 

                auto tg_xxyyyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 478); 

                auto tg_xxyyyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 479); 

                auto tg_xxyyyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 480); 

                auto tg_xxyyyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 481); 

                auto tg_xxyyyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 482); 

                auto tg_xxyyyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 483); 

                auto tg_xxyyyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 484); 

                auto tg_xxxyzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 388); 

                auto tg_xxxyzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 389); 

                auto tg_xxxyzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 390); 

                auto tg_xxxyzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 391); 

                auto tg_xxxzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 392); 

                auto tg_xxxzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 393); 

                auto tg_xxxzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 394); 

                auto tg_xxxzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 395); 

                auto tg_xxxzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 396); 

                auto tg_xxxzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 397); 

                auto tg_xxxzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 398); 

                auto tg_xxxzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 399); 

                auto tg_xxxzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 400); 

                auto tg_xxxzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 401); 

                auto tg_xxxzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 402); 

                auto tg_xxxzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 403); 

                auto tg_xxxzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 404); 

                auto tg_xxxzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 405); 

                auto tg_xxxzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 406); 

                auto tg_xxxzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 407); 

                auto tg_xxxzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 408); 

                auto tg_xxxzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 409); 

                auto tg_xxxzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 410); 

                auto tg_xxxzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 411); 

                auto tg_xxxzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 412); 

                auto tg_xxxzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 413); 

                auto tg_xxxzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 414); 

                auto tg_xxxzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 415); 

                auto tg_xxxzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 416); 

                auto tg_xxxzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 417); 

                auto tg_xxxzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 418); 

                auto tg_xxxzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 419); 

                auto tg_xxyyyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 420); 

                auto tg_xxyyyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 421); 

                auto tg_xxyyyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 422); 

                auto tg_xxyyyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 423); 

                auto tg_xxyyyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 424); 

                auto tg_xxyyyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 425); 

                auto tg_xxyyyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 426); 

                auto tg_xxyyyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 427); 

                auto tg_xxyyyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 428); 

                auto tg_xxyyyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 429); 

                auto tg_xxyyyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 430); 

                auto tg_xxyyyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 431); 

                auto tg_xxyyyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 432); 

                auto tg_xxyyyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 433); 

                auto tg_xxyyyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 434); 

                auto tg_xxyyyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 435); 

                auto tg_xxyyyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 436); 

                auto tg_xxyyyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 437); 

                auto tg_xxyyyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 438); 

                auto tg_xxyyyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 439); 

                auto tg_xxyyyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 440); 

                auto tg_xxyyyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 441); 

                auto tg_xxyyyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 442); 

                auto tg_xxyyyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 443); 

                auto tg_xxyyyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 444); 

                auto tg_xxyyyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 445); 

                auto tg_xxyyyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 446); 

                auto tg_xxyyyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 447); 

                auto tg_xxyyyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 448); 

                auto tg_xxyyyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 449); 

                auto tg_xxyyyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 450); 

                auto tg_xxyyyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 451); 

                auto tg_xxyyyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 452); 

                auto tg_xxyyyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 453); 

                auto tg_xxyyyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 454); 

                auto tg_xxyyyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 455); 

                auto tg_xxyyyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 456); 

                auto tg_xxyyyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 457); 

                auto tg_xxyyyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 458); 

                auto tg_xxyyyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 459); 

                auto tg_xxyyyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 460); 

                auto tg_xxyyyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 461); 

                auto tg_xxyyyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 462); 

                auto tg_xxyyyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 463); 

                auto tg_xxyyyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 464); 

                auto tg_xxyyyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 465); 

                auto tg_xxyyyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 466); 

                auto tg_xxyyyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 467); 

                auto tg_xxyyyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 468); 

                auto tg_xxyyyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 469); 

                auto tg_xxyyyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 470); 

                auto tg_xxyyyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 471); 

                auto tg_xxyyyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 472); 

                auto tg_xxyyyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 473); 

                auto tg_xxyyyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 474); 

                auto tg_xxyyyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 475); 

                auto tg_xxyyyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 476); 

                auto tg_xxyyyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 477); 

                auto tg_xxyyyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 478); 

                auto tg_xxyyyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 479); 

                auto tg_xxyyyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 480); 

                auto tg_xxyyyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 481); 

                auto tg_xxyyyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 482); 

                auto tg_xxyyyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 483); 

                auto tg_xxyyyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 484); 

                auto tg_xxyzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 388); 

                auto tg_xxyzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 389); 

                auto tg_xxyzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 390); 

                auto tg_xxyzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 391); 

                auto tg_xxzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 392); 

                auto tg_xxzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 393); 

                auto tg_xxzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 394); 

                auto tg_xxzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 395); 

                auto tg_xxzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 396); 

                auto tg_xxzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 397); 

                auto tg_xxzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 398); 

                auto tg_xxzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 399); 

                auto tg_xxzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 400); 

                auto tg_xxzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 401); 

                auto tg_xxzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 402); 

                auto tg_xxzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 403); 

                auto tg_xxzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 404); 

                auto tg_xxzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 405); 

                auto tg_xxzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 406); 

                auto tg_xxzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 407); 

                auto tg_xxzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 408); 

                auto tg_xxzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 409); 

                auto tg_xxzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 410); 

                auto tg_xxzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 411); 

                auto tg_xxzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 412); 

                auto tg_xxzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 413); 

                auto tg_xxzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 414); 

                auto tg_xxzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 415); 

                auto tg_xxzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 416); 

                auto tg_xxzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 417); 

                auto tg_xxzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 418); 

                auto tg_xxzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 419); 

                auto tg_xyyyyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 420); 

                auto tg_xyyyyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 421); 

                auto tg_xyyyyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 422); 

                auto tg_xyyyyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 423); 

                auto tg_xyyyyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 424); 

                auto tg_xyyyyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 425); 

                auto tg_xyyyyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 426); 

                auto tg_xyyyyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 427); 

                auto tg_xyyyyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 428); 

                auto tg_xyyyyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 429); 

                auto tg_xyyyyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 430); 

                auto tg_xyyyyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 431); 

                auto tg_xyyyyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 432); 

                auto tg_xyyyyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 433); 

                auto tg_xyyyyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 434); 

                auto tg_xyyyyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 435); 

                auto tg_xyyyyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 436); 

                auto tg_xyyyyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 437); 

                auto tg_xyyyyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 438); 

                auto tg_xyyyyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 439); 

                auto tg_xyyyyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 440); 

                auto tg_xyyyyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 441); 

                auto tg_xyyyyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 442); 

                auto tg_xyyyyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 443); 

                auto tg_xyyyyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 444); 

                auto tg_xyyyyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 445); 

                auto tg_xyyyyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 446); 

                auto tg_xyyyyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 447); 

                auto tg_xyyyyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 448); 

                auto tg_xyyyyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 449); 

                auto tg_xyyyyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 450); 

                auto tg_xyyyyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 451); 

                auto tg_xyyyyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 452); 

                auto tg_xyyyyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 453); 

                auto tg_xyyyyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 454); 

                auto tg_xyyyyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 455); 

                auto tg_xyyyyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 456); 

                auto tg_xyyyyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 457); 

                auto tg_xyyyyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 458); 

                auto tg_xyyyyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 459); 

                auto tg_xyyyyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 460); 

                auto tg_xyyyyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 461); 

                auto tg_xyyyyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 462); 

                auto tg_xyyyyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 463); 

                auto tg_xyyyyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 464); 

                auto tg_xyyyyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 465); 

                auto tg_xyyyyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 466); 

                auto tg_xyyyyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 467); 

                auto tg_xyyyyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 468); 

                auto tg_xyyyyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 469); 

                auto tg_xyyyyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 470); 

                auto tg_xyyyyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 471); 

                auto tg_xyyyyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 472); 

                auto tg_xyyyyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 473); 

                auto tg_xyyyyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 474); 

                auto tg_xyyyyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 475); 

                auto tg_xyyyzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 476); 

                auto tg_xyyyzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 477); 

                auto tg_xyyyzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 478); 

                auto tg_xyyyzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 479); 

                auto tg_xyyyzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 480); 

                auto tg_xyyyzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 481); 

                auto tg_xyyyzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 482); 

                auto tg_xyyyzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 483); 

                auto tg_xyyyzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 484); 

                auto tg_xxyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 388); 

                auto tg_xxyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 389); 

                auto tg_xxyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 390); 

                auto tg_xxyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 391); 

                auto tg_xxzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 392); 

                auto tg_xxzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 393); 

                auto tg_xxzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 394); 

                auto tg_xxzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 395); 

                auto tg_xxzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 396); 

                auto tg_xxzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 397); 

                auto tg_xxzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 398); 

                auto tg_xxzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 399); 

                auto tg_xxzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 400); 

                auto tg_xxzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 401); 

                auto tg_xxzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 402); 

                auto tg_xxzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 403); 

                auto tg_xxzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 404); 

                auto tg_xxzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 405); 

                auto tg_xxzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 406); 

                auto tg_xxzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 407); 

                auto tg_xxzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 408); 

                auto tg_xxzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 409); 

                auto tg_xxzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 410); 

                auto tg_xxzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 411); 

                auto tg_xxzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 412); 

                auto tg_xxzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 413); 

                auto tg_xxzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 414); 

                auto tg_xxzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 415); 

                auto tg_xxzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 416); 

                auto tg_xxzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 417); 

                auto tg_xxzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 418); 

                auto tg_xxzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 419); 

                auto tg_xyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 420); 

                auto tg_xyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 421); 

                auto tg_xyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 422); 

                auto tg_xyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 423); 

                auto tg_xyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 424); 

                auto tg_xyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 425); 

                auto tg_xyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 426); 

                auto tg_xyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 427); 

                auto tg_xyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 428); 

                auto tg_xyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 429); 

                auto tg_xyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 430); 

                auto tg_xyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 431); 

                auto tg_xyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 432); 

                auto tg_xyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 433); 

                auto tg_xyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 434); 

                auto tg_xyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 435); 

                auto tg_xyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 436); 

                auto tg_xyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 437); 

                auto tg_xyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 438); 

                auto tg_xyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 439); 

                auto tg_xyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 440); 

                auto tg_xyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 441); 

                auto tg_xyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 442); 

                auto tg_xyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 443); 

                auto tg_xyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 444); 

                auto tg_xyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 445); 

                auto tg_xyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 446); 

                auto tg_xyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 447); 

                auto tg_xyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 448); 

                auto tg_xyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 449); 

                auto tg_xyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 450); 

                auto tg_xyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 451); 

                auto tg_xyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 452); 

                auto tg_xyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 453); 

                auto tg_xyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 454); 

                auto tg_xyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 455); 

                auto tg_xyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 456); 

                auto tg_xyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 457); 

                auto tg_xyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 458); 

                auto tg_xyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 459); 

                auto tg_xyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 460); 

                auto tg_xyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 461); 

                auto tg_xyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 462); 

                auto tg_xyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 463); 

                auto tg_xyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 464); 

                auto tg_xyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 465); 

                auto tg_xyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 466); 

                auto tg_xyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 467); 

                auto tg_xyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 468); 

                auto tg_xyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 469); 

                auto tg_xyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 470); 

                auto tg_xyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 471); 

                auto tg_xyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 472); 

                auto tg_xyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 473); 

                auto tg_xyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 474); 

                auto tg_xyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 475); 

                auto tg_xyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 476); 

                auto tg_xyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 477); 

                auto tg_xyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 478); 

                auto tg_xyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 479); 

                auto tg_xyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 480); 

                auto tg_xyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 481); 

                auto tg_xyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 482); 

                auto tg_xyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 483); 

                auto tg_xyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 484); 

                auto tg_xxxzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 294); 

                auto tg_xxxzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 295); 

                auto tg_xxxzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 296); 

                auto tg_xxxzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 297); 

                auto tg_xxxzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 298); 

                auto tg_xxxzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 299); 

                auto tg_xxxzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 300); 

                auto tg_xxxzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 301); 

                auto tg_xxxzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 302); 

                auto tg_xxxzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 303); 

                auto tg_xxxzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 304); 

                auto tg_xxxzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 305); 

                auto tg_xxxzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 306); 

                auto tg_xxxzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 307); 

                auto tg_xxxzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 308); 

                auto tg_xxxzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 309); 

                auto tg_xxxzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 310); 

                auto tg_xxxzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 311); 

                auto tg_xxxzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 312); 

                auto tg_xxxzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 313); 

                auto tg_xxxzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 314); 

                auto tg_xxyyyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 315); 

                auto tg_xxyyyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 316); 

                auto tg_xxyyyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 317); 

                auto tg_xxyyyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 318); 

                auto tg_xxyyyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 319); 

                auto tg_xxyyyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 320); 

                auto tg_xxyyyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 321); 

                auto tg_xxyyyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 322); 

                auto tg_xxyyyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 323); 

                auto tg_xxyyyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 324); 

                auto tg_xxyyyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 325); 

                auto tg_xxyyyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 326); 

                auto tg_xxyyyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 327); 

                auto tg_xxyyyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 328); 

                auto tg_xxyyyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 329); 

                auto tg_xxyyyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 330); 

                auto tg_xxyyyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 331); 

                auto tg_xxyyyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 332); 

                auto tg_xxyyyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 333); 

                auto tg_xxyyyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 334); 

                auto tg_xxyyyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 335); 

                auto tg_xxyyyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 336); 

                auto tg_xxyyyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 337); 

                auto tg_xxyyyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 338); 

                auto tg_xxyyyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 339); 

                auto tg_xxyyyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 340); 

                auto tg_xxyyyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 341); 

                auto tg_xxyyyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 342); 

                auto tg_xxyyyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 343); 

                auto tg_xxyyyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 344); 

                auto tg_xxyyyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 345); 

                auto tg_xxyyyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 346); 

                auto tg_xxyyyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 347); 

                auto tg_xxyyyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 348); 

                auto tg_xxyyyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 349); 

                auto tg_xxyyyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 350); 

                auto tg_xxyyyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 351); 

                auto tg_xxyyyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 352); 

                auto tg_xxyyyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 353); 

                auto tg_xxyyyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 354); 

                auto tg_xxyyyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 355); 

                auto tg_xxyyyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 356); 

                auto tg_xxyyyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 357); 

                auto tg_xxyyyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 358); 

                auto tg_xxyyyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 359); 

                auto tg_xxyyyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 360); 

                auto tg_xxyyyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 361); 

                auto tg_xxyyyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 362); 

                auto tg_xxyyyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 363); 

                auto tg_xxyyyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 364); 

                auto tg_xxyyyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 365); 

                // set up pointers to integrals

                auto tg_xxxxyzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 388); 

                auto tg_xxxxyzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 389); 

                auto tg_xxxxyzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 390); 

                auto tg_xxxxyzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 391); 

                auto tg_xxxxzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 392); 

                auto tg_xxxxzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 393); 

                auto tg_xxxxzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 394); 

                auto tg_xxxxzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 395); 

                auto tg_xxxxzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 396); 

                auto tg_xxxxzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 397); 

                auto tg_xxxxzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 398); 

                auto tg_xxxxzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 399); 

                auto tg_xxxxzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 400); 

                auto tg_xxxxzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 401); 

                auto tg_xxxxzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 402); 

                auto tg_xxxxzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 403); 

                auto tg_xxxxzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 404); 

                auto tg_xxxxzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 405); 

                auto tg_xxxxzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 406); 

                auto tg_xxxxzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 407); 

                auto tg_xxxxzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 408); 

                auto tg_xxxxzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 409); 

                auto tg_xxxxzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 410); 

                auto tg_xxxxzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 411); 

                auto tg_xxxxzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 412); 

                auto tg_xxxxzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 413); 

                auto tg_xxxxzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 414); 

                auto tg_xxxxzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 415); 

                auto tg_xxxxzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 416); 

                auto tg_xxxxzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 417); 

                auto tg_xxxxzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 418); 

                auto tg_xxxxzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 419); 

                auto tg_xxxyyyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 420); 

                auto tg_xxxyyyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 421); 

                auto tg_xxxyyyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 422); 

                auto tg_xxxyyyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 423); 

                auto tg_xxxyyyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 424); 

                auto tg_xxxyyyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 425); 

                auto tg_xxxyyyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 426); 

                auto tg_xxxyyyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 427); 

                auto tg_xxxyyyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 428); 

                auto tg_xxxyyyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 429); 

                auto tg_xxxyyyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 430); 

                auto tg_xxxyyyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 431); 

                auto tg_xxxyyyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 432); 

                auto tg_xxxyyyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 433); 

                auto tg_xxxyyyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 434); 

                auto tg_xxxyyyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 435); 

                auto tg_xxxyyyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 436); 

                auto tg_xxxyyyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 437); 

                auto tg_xxxyyyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 438); 

                auto tg_xxxyyyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 439); 

                auto tg_xxxyyyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 440); 

                auto tg_xxxyyyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 441); 

                auto tg_xxxyyyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 442); 

                auto tg_xxxyyyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 443); 

                auto tg_xxxyyyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 444); 

                auto tg_xxxyyyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 445); 

                auto tg_xxxyyyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 446); 

                auto tg_xxxyyyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 447); 

                auto tg_xxxyyyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 448); 

                auto tg_xxxyyyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 449); 

                auto tg_xxxyyyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 450); 

                auto tg_xxxyyyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 451); 

                auto tg_xxxyyyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 452); 

                auto tg_xxxyyyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 453); 

                auto tg_xxxyyyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 454); 

                auto tg_xxxyyyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 455); 

                auto tg_xxxyyyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 456); 

                auto tg_xxxyyyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 457); 

                auto tg_xxxyyyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 458); 

                auto tg_xxxyyyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 459); 

                auto tg_xxxyyyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 460); 

                auto tg_xxxyyyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 461); 

                auto tg_xxxyyyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 462); 

                auto tg_xxxyyyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 463); 

                auto tg_xxxyyyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 464); 

                auto tg_xxxyyyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 465); 

                auto tg_xxxyyyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 466); 

                auto tg_xxxyyyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 467); 

                auto tg_xxxyyyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 468); 

                auto tg_xxxyyyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 469); 

                auto tg_xxxyyyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 470); 

                auto tg_xxxyyyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 471); 

                auto tg_xxxyyyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 472); 

                auto tg_xxxyyyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 473); 

                auto tg_xxxyyyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 474); 

                auto tg_xxxyyyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 475); 

                auto tg_xxxyyyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 476); 

                auto tg_xxxyyyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 477); 

                auto tg_xxxyyyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 478); 

                auto tg_xxxyyyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 479); 

                auto tg_xxxyyyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 480); 

                auto tg_xxxyyyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 481); 

                auto tg_xxxyyyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 482); 

                auto tg_xxxyyyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 483); 

                auto tg_xxxyyyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 484); 

                // Batch of Integrals (388,485)

                #pragma omp simd aligned(fxn, fza, tg_xxxxyzzz_yyyzzz_0, tg_xxxxyzzz_yyzzzz_0, \
                                         tg_xxxxyzzz_yzzzzz_0, tg_xxxxyzzz_zzzzzz_0, tg_xxxxzzzz_xxxxxx_0, tg_xxxxzzzz_xxxxxy_0, \
                                         tg_xxxxzzzz_xxxxxz_0, tg_xxxxzzzz_xxxxyy_0, tg_xxxxzzzz_xxxxyz_0, tg_xxxxzzzz_xxxxzz_0, \
                                         tg_xxxxzzzz_xxxyyy_0, tg_xxxxzzzz_xxxyyz_0, tg_xxxxzzzz_xxxyzz_0, tg_xxxxzzzz_xxxzzz_0, \
                                         tg_xxxxzzzz_xxyyyy_0, tg_xxxxzzzz_xxyyyz_0, tg_xxxxzzzz_xxyyzz_0, tg_xxxxzzzz_xxyzzz_0, \
                                         tg_xxxxzzzz_xxzzzz_0, tg_xxxxzzzz_xyyyyy_0, tg_xxxxzzzz_xyyyyz_0, tg_xxxxzzzz_xyyyzz_0, \
                                         tg_xxxxzzzz_xyyzzz_0, tg_xxxxzzzz_xyzzzz_0, tg_xxxxzzzz_xzzzzz_0, tg_xxxxzzzz_yyyyyy_0, \
                                         tg_xxxxzzzz_yyyyyz_0, tg_xxxxzzzz_yyyyzz_0, tg_xxxxzzzz_yyyzzz_0, tg_xxxxzzzz_yyzzzz_0, \
                                         tg_xxxxzzzz_yzzzzz_0, tg_xxxxzzzz_zzzzzz_0, tg_xxxyyyyy_xxxxxx_0, tg_xxxyyyyy_xxxxxy_0, \
                                         tg_xxxyyyyy_xxxxxz_0, tg_xxxyyyyy_xxxxyy_0, tg_xxxyyyyy_xxxxyz_0, tg_xxxyyyyy_xxxxzz_0, \
                                         tg_xxxyyyyy_xxxyyy_0, tg_xxxyyyyy_xxxyyz_0, tg_xxxyyyyy_xxxyzz_0, tg_xxxyyyyy_xxxzzz_0, \
                                         tg_xxxyyyyy_xxyyyy_0, tg_xxxyyyyy_xxyyyz_0, tg_xxxyyyyy_xxyyzz_0, tg_xxxyyyyy_xxyzzz_0, \
                                         tg_xxxyyyyy_xxzzzz_0, tg_xxxyyyyy_xyyyyy_0, tg_xxxyyyyy_xyyyyz_0, tg_xxxyyyyy_xyyyzz_0, \
                                         tg_xxxyyyyy_xyyzzz_0, tg_xxxyyyyy_xyzzzz_0, tg_xxxyyyyy_xzzzzz_0, tg_xxxyyyyy_yyyyyy_0, \
                                         tg_xxxyyyyy_yyyyyz_0, tg_xxxyyyyy_yyyyzz_0, tg_xxxyyyyy_yyyzzz_0, tg_xxxyyyyy_yyzzzz_0, \
                                         tg_xxxyyyyy_yzzzzz_0, tg_xxxyyyyy_zzzzzz_0, tg_xxxyyyyz_xxxxxx_0, tg_xxxyyyyz_xxxxxy_0, \
                                         tg_xxxyyyyz_xxxxxz_0, tg_xxxyyyyz_xxxxyy_0, tg_xxxyyyyz_xxxxyz_0, tg_xxxyyyyz_xxxxzz_0, \
                                         tg_xxxyyyyz_xxxyyy_0, tg_xxxyyyyz_xxxyyz_0, tg_xxxyyyyz_xxxyzz_0, tg_xxxyyyyz_xxxzzz_0, \
                                         tg_xxxyyyyz_xxyyyy_0, tg_xxxyyyyz_xxyyyz_0, tg_xxxyyyyz_xxyyzz_0, tg_xxxyyyyz_xxyzzz_0, \
                                         tg_xxxyyyyz_xxzzzz_0, tg_xxxyyyyz_xyyyyy_0, tg_xxxyyyyz_xyyyyz_0, tg_xxxyyyyz_xyyyzz_0, \
                                         tg_xxxyyyyz_xyyzzz_0, tg_xxxyyyyz_xyzzzz_0, tg_xxxyyyyz_xzzzzz_0, tg_xxxyyyyz_yyyyyy_0, \
                                         tg_xxxyyyyz_yyyyyz_0, tg_xxxyyyyz_yyyyzz_0, tg_xxxyyyyz_yyyzzz_0, tg_xxxyyyyz_yyzzzz_0, \
                                         tg_xxxyyyyz_yzzzzz_0, tg_xxxyyyyz_zzzzzz_0, tg_xxxyyyzz_xxxxxx_0, tg_xxxyyyzz_xxxxxy_0, \
                                         tg_xxxyyyzz_xxxxxz_0, tg_xxxyyyzz_xxxxyy_0, tg_xxxyyyzz_xxxxyz_0, tg_xxxyyyzz_xxxxzz_0, \
                                         tg_xxxyyyzz_xxxyyy_0, tg_xxxyyyzz_xxxyyz_0, tg_xxxyyyzz_xxxyzz_0, tg_xxxyzzz_yyyzzz_0, \
                                         tg_xxxyzzz_yyyzzz_1, tg_xxxyzzz_yyzzzz_0, tg_xxxyzzz_yyzzzz_1, tg_xxxyzzz_yzzzzz_0, \
                                         tg_xxxyzzz_yzzzzz_1, tg_xxxyzzz_zzzzzz_0, tg_xxxyzzz_zzzzzz_1, tg_xxxzzzz_xxxxx_1, \
                                         tg_xxxzzzz_xxxxxx_0, tg_xxxzzzz_xxxxxx_1, tg_xxxzzzz_xxxxxy_0, tg_xxxzzzz_xxxxxy_1, \
                                         tg_xxxzzzz_xxxxxz_0, tg_xxxzzzz_xxxxxz_1, tg_xxxzzzz_xxxxy_1, tg_xxxzzzz_xxxxyy_0, \
                                         tg_xxxzzzz_xxxxyy_1, tg_xxxzzzz_xxxxyz_0, tg_xxxzzzz_xxxxyz_1, tg_xxxzzzz_xxxxz_1, \
                                         tg_xxxzzzz_xxxxzz_0, tg_xxxzzzz_xxxxzz_1, tg_xxxzzzz_xxxyy_1, tg_xxxzzzz_xxxyyy_0, \
                                         tg_xxxzzzz_xxxyyy_1, tg_xxxzzzz_xxxyyz_0, tg_xxxzzzz_xxxyyz_1, tg_xxxzzzz_xxxyz_1, \
                                         tg_xxxzzzz_xxxyzz_0, tg_xxxzzzz_xxxyzz_1, tg_xxxzzzz_xxxzz_1, tg_xxxzzzz_xxxzzz_0, \
                                         tg_xxxzzzz_xxxzzz_1, tg_xxxzzzz_xxyyy_1, tg_xxxzzzz_xxyyyy_0, tg_xxxzzzz_xxyyyy_1, \
                                         tg_xxxzzzz_xxyyyz_0, tg_xxxzzzz_xxyyyz_1, tg_xxxzzzz_xxyyz_1, tg_xxxzzzz_xxyyzz_0, \
                                         tg_xxxzzzz_xxyyzz_1, tg_xxxzzzz_xxyzz_1, tg_xxxzzzz_xxyzzz_0, tg_xxxzzzz_xxyzzz_1, \
                                         tg_xxxzzzz_xxzzz_1, tg_xxxzzzz_xxzzzz_0, tg_xxxzzzz_xxzzzz_1, tg_xxxzzzz_xyyyy_1, \
                                         tg_xxxzzzz_xyyyyy_0, tg_xxxzzzz_xyyyyy_1, tg_xxxzzzz_xyyyyz_0, tg_xxxzzzz_xyyyyz_1, \
                                         tg_xxxzzzz_xyyyz_1, tg_xxxzzzz_xyyyzz_0, tg_xxxzzzz_xyyyzz_1, tg_xxxzzzz_xyyzz_1, \
                                         tg_xxxzzzz_xyyzzz_0, tg_xxxzzzz_xyyzzz_1, tg_xxxzzzz_xyzzz_1, tg_xxxzzzz_xyzzzz_0, \
                                         tg_xxxzzzz_xyzzzz_1, tg_xxxzzzz_xzzzz_1, tg_xxxzzzz_xzzzzz_0, tg_xxxzzzz_xzzzzz_1, \
                                         tg_xxxzzzz_yyyyy_1, tg_xxxzzzz_yyyyyy_0, tg_xxxzzzz_yyyyyy_1, tg_xxxzzzz_yyyyyz_0, \
                                         tg_xxxzzzz_yyyyyz_1, tg_xxxzzzz_yyyyz_1, tg_xxxzzzz_yyyyzz_0, tg_xxxzzzz_yyyyzz_1, \
                                         tg_xxxzzzz_yyyzz_1, tg_xxxzzzz_yyyzzz_0, tg_xxxzzzz_yyyzzz_1, tg_xxxzzzz_yyzzz_1, \
                                         tg_xxxzzzz_yyzzzz_0, tg_xxxzzzz_yyzzzz_1, tg_xxxzzzz_yzzzz_1, tg_xxxzzzz_yzzzzz_0, \
                                         tg_xxxzzzz_yzzzzz_1, tg_xxxzzzz_zzzzz_1, tg_xxxzzzz_zzzzzz_0, tg_xxxzzzz_zzzzzz_1, \
                                         tg_xxyyyyy_xxxxx_1, tg_xxyyyyy_xxxxxx_0, tg_xxyyyyy_xxxxxx_1, tg_xxyyyyy_xxxxxy_0, \
                                         tg_xxyyyyy_xxxxxy_1, tg_xxyyyyy_xxxxxz_0, tg_xxyyyyy_xxxxxz_1, tg_xxyyyyy_xxxxy_1, \
                                         tg_xxyyyyy_xxxxyy_0, tg_xxyyyyy_xxxxyy_1, tg_xxyyyyy_xxxxyz_0, tg_xxyyyyy_xxxxyz_1, \
                                         tg_xxyyyyy_xxxxz_1, tg_xxyyyyy_xxxxzz_0, tg_xxyyyyy_xxxxzz_1, tg_xxyyyyy_xxxyy_1, \
                                         tg_xxyyyyy_xxxyyy_0, tg_xxyyyyy_xxxyyy_1, tg_xxyyyyy_xxxyyz_0, tg_xxyyyyy_xxxyyz_1, \
                                         tg_xxyyyyy_xxxyz_1, tg_xxyyyyy_xxxyzz_0, tg_xxyyyyy_xxxyzz_1, tg_xxyyyyy_xxxzz_1, \
                                         tg_xxyyyyy_xxxzzz_0, tg_xxyyyyy_xxxzzz_1, tg_xxyyyyy_xxyyy_1, tg_xxyyyyy_xxyyyy_0, \
                                         tg_xxyyyyy_xxyyyy_1, tg_xxyyyyy_xxyyyz_0, tg_xxyyyyy_xxyyyz_1, tg_xxyyyyy_xxyyz_1, \
                                         tg_xxyyyyy_xxyyzz_0, tg_xxyyyyy_xxyyzz_1, tg_xxyyyyy_xxyzz_1, tg_xxyyyyy_xxyzzz_0, \
                                         tg_xxyyyyy_xxyzzz_1, tg_xxyyyyy_xxzzz_1, tg_xxyyyyy_xxzzzz_0, tg_xxyyyyy_xxzzzz_1, \
                                         tg_xxyyyyy_xyyyy_1, tg_xxyyyyy_xyyyyy_0, tg_xxyyyyy_xyyyyy_1, tg_xxyyyyy_xyyyyz_0, \
                                         tg_xxyyyyy_xyyyyz_1, tg_xxyyyyy_xyyyz_1, tg_xxyyyyy_xyyyzz_0, tg_xxyyyyy_xyyyzz_1, \
                                         tg_xxyyyyy_xyyzz_1, tg_xxyyyyy_xyyzzz_0, tg_xxyyyyy_xyyzzz_1, tg_xxyyyyy_xyzzz_1, \
                                         tg_xxyyyyy_xyzzzz_0, tg_xxyyyyy_xyzzzz_1, tg_xxyyyyy_xzzzz_1, tg_xxyyyyy_xzzzzz_0, \
                                         tg_xxyyyyy_xzzzzz_1, tg_xxyyyyy_yyyyy_1, tg_xxyyyyy_yyyyyy_0, tg_xxyyyyy_yyyyyy_1, \
                                         tg_xxyyyyy_yyyyyz_0, tg_xxyyyyy_yyyyyz_1, tg_xxyyyyy_yyyyz_1, tg_xxyyyyy_yyyyzz_0, \
                                         tg_xxyyyyy_yyyyzz_1, tg_xxyyyyy_yyyzz_1, tg_xxyyyyy_yyyzzz_0, tg_xxyyyyy_yyyzzz_1, \
                                         tg_xxyyyyy_yyzzz_1, tg_xxyyyyy_yyzzzz_0, tg_xxyyyyy_yyzzzz_1, tg_xxyyyyy_yzzzz_1, \
                                         tg_xxyyyyy_yzzzzz_0, tg_xxyyyyy_yzzzzz_1, tg_xxyyyyy_zzzzz_1, tg_xxyyyyy_zzzzzz_0, \
                                         tg_xxyyyyy_zzzzzz_1, tg_xxyyyyz_xxxxx_1, tg_xxyyyyz_xxxxxx_0, tg_xxyyyyz_xxxxxx_1, \
                                         tg_xxyyyyz_xxxxxy_0, tg_xxyyyyz_xxxxxy_1, tg_xxyyyyz_xxxxxz_0, tg_xxyyyyz_xxxxxz_1, \
                                         tg_xxyyyyz_xxxxy_1, tg_xxyyyyz_xxxxyy_0, tg_xxyyyyz_xxxxyy_1, tg_xxyyyyz_xxxxyz_0, \
                                         tg_xxyyyyz_xxxxyz_1, tg_xxyyyyz_xxxxz_1, tg_xxyyyyz_xxxxzz_0, tg_xxyyyyz_xxxxzz_1, \
                                         tg_xxyyyyz_xxxyy_1, tg_xxyyyyz_xxxyyy_0, tg_xxyyyyz_xxxyyy_1, tg_xxyyyyz_xxxyyz_0, \
                                         tg_xxyyyyz_xxxyyz_1, tg_xxyyyyz_xxxyz_1, tg_xxyyyyz_xxxyzz_0, tg_xxyyyyz_xxxyzz_1, \
                                         tg_xxyyyyz_xxxzz_1, tg_xxyyyyz_xxxzzz_0, tg_xxyyyyz_xxxzzz_1, tg_xxyyyyz_xxyyy_1, \
                                         tg_xxyyyyz_xxyyyy_0, tg_xxyyyyz_xxyyyy_1, tg_xxyyyyz_xxyyyz_0, tg_xxyyyyz_xxyyyz_1, \
                                         tg_xxyyyyz_xxyyz_1, tg_xxyyyyz_xxyyzz_0, tg_xxyyyyz_xxyyzz_1, tg_xxyyyyz_xxyzz_1, \
                                         tg_xxyyyyz_xxyzzz_0, tg_xxyyyyz_xxyzzz_1, tg_xxyyyyz_xxzzz_1, tg_xxyyyyz_xxzzzz_0, \
                                         tg_xxyyyyz_xxzzzz_1, tg_xxyyyyz_xyyyy_1, tg_xxyyyyz_xyyyyy_0, tg_xxyyyyz_xyyyyy_1, \
                                         tg_xxyyyyz_xyyyyz_0, tg_xxyyyyz_xyyyyz_1, tg_xxyyyyz_xyyyz_1, tg_xxyyyyz_xyyyzz_0, \
                                         tg_xxyyyyz_xyyyzz_1, tg_xxyyyyz_xyyzz_1, tg_xxyyyyz_xyyzzz_0, tg_xxyyyyz_xyyzzz_1, \
                                         tg_xxyyyyz_xyzzz_1, tg_xxyyyyz_xyzzzz_0, tg_xxyyyyz_xyzzzz_1, tg_xxyyyyz_xzzzz_1, \
                                         tg_xxyyyyz_xzzzzz_0, tg_xxyyyyz_xzzzzz_1, tg_xxyyyyz_yyyyy_1, tg_xxyyyyz_yyyyyy_0, \
                                         tg_xxyyyyz_yyyyyy_1, tg_xxyyyyz_yyyyyz_0, tg_xxyyyyz_yyyyyz_1, tg_xxyyyyz_yyyyz_1, \
                                         tg_xxyyyyz_yyyyzz_0, tg_xxyyyyz_yyyyzz_1, tg_xxyyyyz_yyyzz_1, tg_xxyyyyz_yyyzzz_0, \
                                         tg_xxyyyyz_yyyzzz_1, tg_xxyyyyz_yyzzz_1, tg_xxyyyyz_yyzzzz_0, tg_xxyyyyz_yyzzzz_1, \
                                         tg_xxyyyyz_yzzzz_1, tg_xxyyyyz_yzzzzz_0, tg_xxyyyyz_yzzzzz_1, tg_xxyyyyz_zzzzz_1, \
                                         tg_xxyyyyz_zzzzzz_0, tg_xxyyyyz_zzzzzz_1, tg_xxyyyzz_xxxxx_1, tg_xxyyyzz_xxxxxx_0, \
                                         tg_xxyyyzz_xxxxxx_1, tg_xxyyyzz_xxxxxy_0, tg_xxyyyzz_xxxxxy_1, tg_xxyyyzz_xxxxxz_0, \
                                         tg_xxyyyzz_xxxxxz_1, tg_xxyyyzz_xxxxy_1, tg_xxyyyzz_xxxxyy_0, tg_xxyyyzz_xxxxyy_1, \
                                         tg_xxyyyzz_xxxxyz_0, tg_xxyyyzz_xxxxyz_1, tg_xxyyyzz_xxxxz_1, tg_xxyyyzz_xxxxzz_0, \
                                         tg_xxyyyzz_xxxxzz_1, tg_xxyyyzz_xxxyy_1, tg_xxyyyzz_xxxyyy_0, tg_xxyyyzz_xxxyyy_1, \
                                         tg_xxyyyzz_xxxyyz_0, tg_xxyyyzz_xxxyyz_1, tg_xxyyyzz_xxxyz_1, tg_xxyyyzz_xxxyzz_0, \
                                         tg_xxyyyzz_xxxyzz_1, tg_xxyyyzz_xxxzz_1, tg_xxyyyzz_xxyyy_1, tg_xxyyyzz_xxyyz_1, \
                                         tg_xxyyyzz_xxyzz_1, tg_xxyzzz_yyyzzz_0, tg_xxyzzz_yyyzzz_1, tg_xxyzzz_yyzzzz_0, \
                                         tg_xxyzzz_yyzzzz_1, tg_xxyzzz_yzzzzz_0, tg_xxyzzz_yzzzzz_1, tg_xxyzzz_zzzzzz_0, \
                                         tg_xxyzzz_zzzzzz_1, tg_xxzzzz_xxxxxx_0, tg_xxzzzz_xxxxxx_1, tg_xxzzzz_xxxxxy_0, \
                                         tg_xxzzzz_xxxxxy_1, tg_xxzzzz_xxxxxz_0, tg_xxzzzz_xxxxxz_1, tg_xxzzzz_xxxxyy_0, \
                                         tg_xxzzzz_xxxxyy_1, tg_xxzzzz_xxxxyz_0, tg_xxzzzz_xxxxyz_1, tg_xxzzzz_xxxxzz_0, \
                                         tg_xxzzzz_xxxxzz_1, tg_xxzzzz_xxxyyy_0, tg_xxzzzz_xxxyyy_1, tg_xxzzzz_xxxyyz_0, \
                                         tg_xxzzzz_xxxyyz_1, tg_xxzzzz_xxxyzz_0, tg_xxzzzz_xxxyzz_1, tg_xxzzzz_xxxzzz_0, \
                                         tg_xxzzzz_xxxzzz_1, tg_xxzzzz_xxyyyy_0, tg_xxzzzz_xxyyyy_1, tg_xxzzzz_xxyyyz_0, \
                                         tg_xxzzzz_xxyyyz_1, tg_xxzzzz_xxyyzz_0, tg_xxzzzz_xxyyzz_1, tg_xxzzzz_xxyzzz_0, \
                                         tg_xxzzzz_xxyzzz_1, tg_xxzzzz_xxzzzz_0, tg_xxzzzz_xxzzzz_1, tg_xxzzzz_xyyyyy_0, \
                                         tg_xxzzzz_xyyyyy_1, tg_xxzzzz_xyyyyz_0, tg_xxzzzz_xyyyyz_1, tg_xxzzzz_xyyyzz_0, \
                                         tg_xxzzzz_xyyyzz_1, tg_xxzzzz_xyyzzz_0, tg_xxzzzz_xyyzzz_1, tg_xxzzzz_xyzzzz_0, \
                                         tg_xxzzzz_xyzzzz_1, tg_xxzzzz_xzzzzz_0, tg_xxzzzz_xzzzzz_1, tg_xxzzzz_yyyyyy_0, \
                                         tg_xxzzzz_yyyyyy_1, tg_xxzzzz_yyyyyz_0, tg_xxzzzz_yyyyyz_1, tg_xxzzzz_yyyyzz_0, \
                                         tg_xxzzzz_yyyyzz_1, tg_xxzzzz_yyyzzz_0, tg_xxzzzz_yyyzzz_1, tg_xxzzzz_yyzzzz_0, \
                                         tg_xxzzzz_yyzzzz_1, tg_xxzzzz_yzzzzz_0, tg_xxzzzz_yzzzzz_1, tg_xxzzzz_zzzzzz_0, \
                                         tg_xxzzzz_zzzzzz_1, tg_xyyyyy_xxxxxx_0, tg_xyyyyy_xxxxxx_1, tg_xyyyyy_xxxxxy_0, \
                                         tg_xyyyyy_xxxxxy_1, tg_xyyyyy_xxxxxz_0, tg_xyyyyy_xxxxxz_1, tg_xyyyyy_xxxxyy_0, \
                                         tg_xyyyyy_xxxxyy_1, tg_xyyyyy_xxxxyz_0, tg_xyyyyy_xxxxyz_1, tg_xyyyyy_xxxxzz_0, \
                                         tg_xyyyyy_xxxxzz_1, tg_xyyyyy_xxxyyy_0, tg_xyyyyy_xxxyyy_1, tg_xyyyyy_xxxyyz_0, \
                                         tg_xyyyyy_xxxyyz_1, tg_xyyyyy_xxxyzz_0, tg_xyyyyy_xxxyzz_1, tg_xyyyyy_xxxzzz_0, \
                                         tg_xyyyyy_xxxzzz_1, tg_xyyyyy_xxyyyy_0, tg_xyyyyy_xxyyyy_1, tg_xyyyyy_xxyyyz_0, \
                                         tg_xyyyyy_xxyyyz_1, tg_xyyyyy_xxyyzz_0, tg_xyyyyy_xxyyzz_1, tg_xyyyyy_xxyzzz_0, \
                                         tg_xyyyyy_xxyzzz_1, tg_xyyyyy_xxzzzz_0, tg_xyyyyy_xxzzzz_1, tg_xyyyyy_xyyyyy_0, \
                                         tg_xyyyyy_xyyyyy_1, tg_xyyyyy_xyyyyz_0, tg_xyyyyy_xyyyyz_1, tg_xyyyyy_xyyyzz_0, \
                                         tg_xyyyyy_xyyyzz_1, tg_xyyyyy_xyyzzz_0, tg_xyyyyy_xyyzzz_1, tg_xyyyyy_xyzzzz_0, \
                                         tg_xyyyyy_xyzzzz_1, tg_xyyyyy_xzzzzz_0, tg_xyyyyy_xzzzzz_1, tg_xyyyyy_yyyyyy_0, \
                                         tg_xyyyyy_yyyyyy_1, tg_xyyyyy_yyyyyz_0, tg_xyyyyy_yyyyyz_1, tg_xyyyyy_yyyyzz_0, \
                                         tg_xyyyyy_yyyyzz_1, tg_xyyyyy_yyyzzz_0, tg_xyyyyy_yyyzzz_1, tg_xyyyyy_yyzzzz_0, \
                                         tg_xyyyyy_yyzzzz_1, tg_xyyyyy_yzzzzz_0, tg_xyyyyy_yzzzzz_1, tg_xyyyyy_zzzzzz_0, \
                                         tg_xyyyyy_zzzzzz_1, tg_xyyyyz_xxxxxx_0, tg_xyyyyz_xxxxxx_1, tg_xyyyyz_xxxxxy_0, \
                                         tg_xyyyyz_xxxxxy_1, tg_xyyyyz_xxxxxz_0, tg_xyyyyz_xxxxxz_1, tg_xyyyyz_xxxxyy_0, \
                                         tg_xyyyyz_xxxxyy_1, tg_xyyyyz_xxxxyz_0, tg_xyyyyz_xxxxyz_1, tg_xyyyyz_xxxxzz_0, \
                                         tg_xyyyyz_xxxxzz_1, tg_xyyyyz_xxxyyy_0, tg_xyyyyz_xxxyyy_1, tg_xyyyyz_xxxyyz_0, \
                                         tg_xyyyyz_xxxyyz_1, tg_xyyyyz_xxxyzz_0, tg_xyyyyz_xxxyzz_1, tg_xyyyyz_xxxzzz_0, \
                                         tg_xyyyyz_xxxzzz_1, tg_xyyyyz_xxyyyy_0, tg_xyyyyz_xxyyyy_1, tg_xyyyyz_xxyyyz_0, \
                                         tg_xyyyyz_xxyyyz_1, tg_xyyyyz_xxyyzz_0, tg_xyyyyz_xxyyzz_1, tg_xyyyyz_xxyzzz_0, \
                                         tg_xyyyyz_xxyzzz_1, tg_xyyyyz_xxzzzz_0, tg_xyyyyz_xxzzzz_1, tg_xyyyyz_xyyyyy_0, \
                                         tg_xyyyyz_xyyyyy_1, tg_xyyyyz_xyyyyz_0, tg_xyyyyz_xyyyyz_1, tg_xyyyyz_xyyyzz_0, \
                                         tg_xyyyyz_xyyyzz_1, tg_xyyyyz_xyyzzz_0, tg_xyyyyz_xyyzzz_1, tg_xyyyyz_xyzzzz_0, \
                                         tg_xyyyyz_xyzzzz_1, tg_xyyyyz_xzzzzz_0, tg_xyyyyz_xzzzzz_1, tg_xyyyyz_yyyyyy_0, \
                                         tg_xyyyyz_yyyyyy_1, tg_xyyyyz_yyyyyz_0, tg_xyyyyz_yyyyyz_1, tg_xyyyyz_yyyyzz_0, \
                                         tg_xyyyyz_yyyyzz_1, tg_xyyyyz_yyyzzz_0, tg_xyyyyz_yyyzzz_1, tg_xyyyyz_yyzzzz_0, \
                                         tg_xyyyyz_yyzzzz_1, tg_xyyyyz_yzzzzz_0, tg_xyyyyz_yzzzzz_1, tg_xyyyyz_zzzzzz_0, \
                                         tg_xyyyyz_zzzzzz_1, tg_xyyyzz_xxxxxx_0, tg_xyyyzz_xxxxxx_1, tg_xyyyzz_xxxxxy_0, \
                                         tg_xyyyzz_xxxxxy_1, tg_xyyyzz_xxxxxz_0, tg_xyyyzz_xxxxxz_1, tg_xyyyzz_xxxxyy_0, \
                                         tg_xyyyzz_xxxxyy_1, tg_xyyyzz_xxxxyz_0, tg_xyyyzz_xxxxyz_1, tg_xyyyzz_xxxxzz_0, \
                                         tg_xyyyzz_xxxxzz_1, tg_xyyyzz_xxxyyy_0, tg_xyyyzz_xxxyyy_1, tg_xyyyzz_xxxyyz_0, \
                                         tg_xyyyzz_xxxyyz_1, tg_xyyyzz_xxxyzz_0, tg_xyyyzz_xxxyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxxyzzz_yyyzzz_0[j] = pb_x * tg_xxxyzzz_yyyzzz_0[j] + fr * tg_xxxyzzz_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yyyzzz_0[j] - tg_xxyzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxyzzz_yyzzzz_0[j] = pb_x * tg_xxxyzzz_yyzzzz_0[j] + fr * tg_xxxyzzz_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yyzzzz_0[j] - tg_xxyzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxyzzz_yzzzzz_0[j] = pb_x * tg_xxxyzzz_yzzzzz_0[j] + fr * tg_xxxyzzz_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_yzzzzz_0[j] - tg_xxyzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxyzzz_zzzzzz_0[j] = pb_x * tg_xxxyzzz_zzzzzz_0[j] + fr * tg_xxxyzzz_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxyzzz_zzzzzz_0[j] - tg_xxyzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxxzzzz_xxxxxx_0[j] = pb_x * tg_xxxzzzz_xxxxxx_0[j] + fr * tg_xxxzzzz_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxxx_0[j] - tg_xxzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxxzzzz_xxxxx_1[j];

                    tg_xxxxzzzz_xxxxxy_0[j] = pb_x * tg_xxxzzzz_xxxxxy_0[j] + fr * tg_xxxzzzz_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxxy_0[j] - tg_xxzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzzzz_xxxxy_1[j];

                    tg_xxxxzzzz_xxxxxz_0[j] = pb_x * tg_xxxzzzz_xxxxxz_0[j] + fr * tg_xxxzzzz_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxxz_0[j] - tg_xxzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxxzzzz_xxxxz_1[j];

                    tg_xxxxzzzz_xxxxyy_0[j] = pb_x * tg_xxxzzzz_xxxxyy_0[j] + fr * tg_xxxzzzz_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxyy_0[j] - tg_xxzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzzz_xxxyy_1[j];

                    tg_xxxxzzzz_xxxxyz_0[j] = pb_x * tg_xxxzzzz_xxxxyz_0[j] + fr * tg_xxxzzzz_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxyz_0[j] - tg_xxzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzzz_xxxyz_1[j];

                    tg_xxxxzzzz_xxxxzz_0[j] = pb_x * tg_xxxzzzz_xxxxzz_0[j] + fr * tg_xxxzzzz_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxxzz_0[j] - tg_xxzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxxzzzz_xxxzz_1[j];

                    tg_xxxxzzzz_xxxyyy_0[j] = pb_x * tg_xxxzzzz_xxxyyy_0[j] + fr * tg_xxxzzzz_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxyyy_0[j] - tg_xxzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzzz_xxyyy_1[j];

                    tg_xxxxzzzz_xxxyyz_0[j] = pb_x * tg_xxxzzzz_xxxyyz_0[j] + fr * tg_xxxzzzz_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxyyz_0[j] - tg_xxzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzzz_xxyyz_1[j];

                    tg_xxxxzzzz_xxxyzz_0[j] = pb_x * tg_xxxzzzz_xxxyzz_0[j] + fr * tg_xxxzzzz_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxyzz_0[j] - tg_xxzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzzz_xxyzz_1[j];

                    tg_xxxxzzzz_xxxzzz_0[j] = pb_x * tg_xxxzzzz_xxxzzz_0[j] + fr * tg_xxxzzzz_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxxzzz_0[j] - tg_xxzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxxzzzz_xxzzz_1[j];

                    tg_xxxxzzzz_xxyyyy_0[j] = pb_x * tg_xxxzzzz_xxyyyy_0[j] + fr * tg_xxxzzzz_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxyyyy_0[j] - tg_xxzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_xyyyy_1[j];

                    tg_xxxxzzzz_xxyyyz_0[j] = pb_x * tg_xxxzzzz_xxyyyz_0[j] + fr * tg_xxxzzzz_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxyyyz_0[j] - tg_xxzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_xyyyz_1[j];

                    tg_xxxxzzzz_xxyyzz_0[j] = pb_x * tg_xxxzzzz_xxyyzz_0[j] + fr * tg_xxxzzzz_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxyyzz_0[j] - tg_xxzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_xyyzz_1[j];

                    tg_xxxxzzzz_xxyzzz_0[j] = pb_x * tg_xxxzzzz_xxyzzz_0[j] + fr * tg_xxxzzzz_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxyzzz_0[j] - tg_xxzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_xyzzz_1[j];

                    tg_xxxxzzzz_xxzzzz_0[j] = pb_x * tg_xxxzzzz_xxzzzz_0[j] + fr * tg_xxxzzzz_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xxzzzz_0[j] - tg_xxzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxxzzzz_xzzzz_1[j];

                    tg_xxxxzzzz_xyyyyy_0[j] = pb_x * tg_xxxzzzz_xyyyyy_0[j] + fr * tg_xxxzzzz_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xyyyyy_0[j] - tg_xxzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_yyyyy_1[j];

                    tg_xxxxzzzz_xyyyyz_0[j] = pb_x * tg_xxxzzzz_xyyyyz_0[j] + fr * tg_xxxzzzz_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xyyyyz_0[j] - tg_xxzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_yyyyz_1[j];

                    tg_xxxxzzzz_xyyyzz_0[j] = pb_x * tg_xxxzzzz_xyyyzz_0[j] + fr * tg_xxxzzzz_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xyyyzz_0[j] - tg_xxzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_yyyzz_1[j];

                    tg_xxxxzzzz_xyyzzz_0[j] = pb_x * tg_xxxzzzz_xyyzzz_0[j] + fr * tg_xxxzzzz_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xyyzzz_0[j] - tg_xxzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_yyzzz_1[j];

                    tg_xxxxzzzz_xyzzzz_0[j] = pb_x * tg_xxxzzzz_xyzzzz_0[j] + fr * tg_xxxzzzz_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xyzzzz_0[j] - tg_xxzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_yzzzz_1[j];

                    tg_xxxxzzzz_xzzzzz_0[j] = pb_x * tg_xxxzzzz_xzzzzz_0[j] + fr * tg_xxxzzzz_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_xzzzzz_0[j] - tg_xxzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxxzzzz_zzzzz_1[j];

                    tg_xxxxzzzz_yyyyyy_0[j] = pb_x * tg_xxxzzzz_yyyyyy_0[j] + fr * tg_xxxzzzz_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yyyyyy_0[j] - tg_xxzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxxzzzz_yyyyyz_0[j] = pb_x * tg_xxxzzzz_yyyyyz_0[j] + fr * tg_xxxzzzz_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yyyyyz_0[j] - tg_xxzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxxzzzz_yyyyzz_0[j] = pb_x * tg_xxxzzzz_yyyyzz_0[j] + fr * tg_xxxzzzz_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yyyyzz_0[j] - tg_xxzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxxzzzz_yyyzzz_0[j] = pb_x * tg_xxxzzzz_yyyzzz_0[j] + fr * tg_xxxzzzz_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yyyzzz_0[j] - tg_xxzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxxzzzz_yyzzzz_0[j] = pb_x * tg_xxxzzzz_yyzzzz_0[j] + fr * tg_xxxzzzz_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yyzzzz_0[j] - tg_xxzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxxzzzz_yzzzzz_0[j] = pb_x * tg_xxxzzzz_yzzzzz_0[j] + fr * tg_xxxzzzz_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_yzzzzz_0[j] - tg_xxzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxxzzzz_zzzzzz_0[j] = pb_x * tg_xxxzzzz_zzzzzz_0[j] + fr * tg_xxxzzzz_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_xxzzzz_zzzzzz_0[j] - tg_xxzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyy_xxxxxx_0[j] = pb_x * tg_xxyyyyy_xxxxxx_0[j] + fr * tg_xxyyyyy_xxxxxx_1[j] + fl1_fx * (tg_xyyyyy_xxxxxx_0[j] - tg_xyyyyy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyyy_xxxxx_1[j];

                    tg_xxxyyyyy_xxxxxy_0[j] = pb_x * tg_xxyyyyy_xxxxxy_0[j] + fr * tg_xxyyyyy_xxxxxy_1[j] + fl1_fx * (tg_xyyyyy_xxxxxy_0[j] - tg_xyyyyy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyyy_xxxxy_1[j];

                    tg_xxxyyyyy_xxxxxz_0[j] = pb_x * tg_xxyyyyy_xxxxxz_0[j] + fr * tg_xxyyyyy_xxxxxz_1[j] + fl1_fx * (tg_xyyyyy_xxxxxz_0[j] - tg_xyyyyy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyyy_xxxxz_1[j];

                    tg_xxxyyyyy_xxxxyy_0[j] = pb_x * tg_xxyyyyy_xxxxyy_0[j] + fr * tg_xxyyyyy_xxxxyy_1[j] + fl1_fx * (tg_xyyyyy_xxxxyy_0[j] - tg_xyyyyy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyy_xxxyy_1[j];

                    tg_xxxyyyyy_xxxxyz_0[j] = pb_x * tg_xxyyyyy_xxxxyz_0[j] + fr * tg_xxyyyyy_xxxxyz_1[j] + fl1_fx * (tg_xyyyyy_xxxxyz_0[j] - tg_xyyyyy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyy_xxxyz_1[j];

                    tg_xxxyyyyy_xxxxzz_0[j] = pb_x * tg_xxyyyyy_xxxxzz_0[j] + fr * tg_xxyyyyy_xxxxzz_1[j] + fl1_fx * (tg_xyyyyy_xxxxzz_0[j] - tg_xyyyyy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyy_xxxzz_1[j];

                    tg_xxxyyyyy_xxxyyy_0[j] = pb_x * tg_xxyyyyy_xxxyyy_0[j] + fr * tg_xxyyyyy_xxxyyy_1[j] + fl1_fx * (tg_xyyyyy_xxxyyy_0[j] - tg_xyyyyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyy_xxyyy_1[j];

                    tg_xxxyyyyy_xxxyyz_0[j] = pb_x * tg_xxyyyyy_xxxyyz_0[j] + fr * tg_xxyyyyy_xxxyyz_1[j] + fl1_fx * (tg_xyyyyy_xxxyyz_0[j] - tg_xyyyyy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyy_xxyyz_1[j];

                    tg_xxxyyyyy_xxxyzz_0[j] = pb_x * tg_xxyyyyy_xxxyzz_0[j] + fr * tg_xxyyyyy_xxxyzz_1[j] + fl1_fx * (tg_xyyyyy_xxxyzz_0[j] - tg_xyyyyy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyy_xxyzz_1[j];

                    tg_xxxyyyyy_xxxzzz_0[j] = pb_x * tg_xxyyyyy_xxxzzz_0[j] + fr * tg_xxyyyyy_xxxzzz_1[j] + fl1_fx * (tg_xyyyyy_xxxzzz_0[j] - tg_xyyyyy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyy_xxzzz_1[j];

                    tg_xxxyyyyy_xxyyyy_0[j] = pb_x * tg_xxyyyyy_xxyyyy_0[j] + fr * tg_xxyyyyy_xxyyyy_1[j] + fl1_fx * (tg_xyyyyy_xxyyyy_0[j] - tg_xyyyyy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_xyyyy_1[j];

                    tg_xxxyyyyy_xxyyyz_0[j] = pb_x * tg_xxyyyyy_xxyyyz_0[j] + fr * tg_xxyyyyy_xxyyyz_1[j] + fl1_fx * (tg_xyyyyy_xxyyyz_0[j] - tg_xyyyyy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_xyyyz_1[j];

                    tg_xxxyyyyy_xxyyzz_0[j] = pb_x * tg_xxyyyyy_xxyyzz_0[j] + fr * tg_xxyyyyy_xxyyzz_1[j] + fl1_fx * (tg_xyyyyy_xxyyzz_0[j] - tg_xyyyyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_xyyzz_1[j];

                    tg_xxxyyyyy_xxyzzz_0[j] = pb_x * tg_xxyyyyy_xxyzzz_0[j] + fr * tg_xxyyyyy_xxyzzz_1[j] + fl1_fx * (tg_xyyyyy_xxyzzz_0[j] - tg_xyyyyy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_xyzzz_1[j];

                    tg_xxxyyyyy_xxzzzz_0[j] = pb_x * tg_xxyyyyy_xxzzzz_0[j] + fr * tg_xxyyyyy_xxzzzz_1[j] + fl1_fx * (tg_xyyyyy_xxzzzz_0[j] - tg_xyyyyy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyy_xzzzz_1[j];

                    tg_xxxyyyyy_xyyyyy_0[j] = pb_x * tg_xxyyyyy_xyyyyy_0[j] + fr * tg_xxyyyyy_xyyyyy_1[j] + fl1_fx * (tg_xyyyyy_xyyyyy_0[j] - tg_xyyyyy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_yyyyy_1[j];

                    tg_xxxyyyyy_xyyyyz_0[j] = pb_x * tg_xxyyyyy_xyyyyz_0[j] + fr * tg_xxyyyyy_xyyyyz_1[j] + fl1_fx * (tg_xyyyyy_xyyyyz_0[j] - tg_xyyyyy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_yyyyz_1[j];

                    tg_xxxyyyyy_xyyyzz_0[j] = pb_x * tg_xxyyyyy_xyyyzz_0[j] + fr * tg_xxyyyyy_xyyyzz_1[j] + fl1_fx * (tg_xyyyyy_xyyyzz_0[j] - tg_xyyyyy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_yyyzz_1[j];

                    tg_xxxyyyyy_xyyzzz_0[j] = pb_x * tg_xxyyyyy_xyyzzz_0[j] + fr * tg_xxyyyyy_xyyzzz_1[j] + fl1_fx * (tg_xyyyyy_xyyzzz_0[j] - tg_xyyyyy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_yyzzz_1[j];

                    tg_xxxyyyyy_xyzzzz_0[j] = pb_x * tg_xxyyyyy_xyzzzz_0[j] + fr * tg_xxyyyyy_xyzzzz_1[j] + fl1_fx * (tg_xyyyyy_xyzzzz_0[j] - tg_xyyyyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_yzzzz_1[j];

                    tg_xxxyyyyy_xzzzzz_0[j] = pb_x * tg_xxyyyyy_xzzzzz_0[j] + fr * tg_xxyyyyy_xzzzzz_1[j] + fl1_fx * (tg_xyyyyy_xzzzzz_0[j] - tg_xyyyyy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyy_zzzzz_1[j];

                    tg_xxxyyyyy_yyyyyy_0[j] = pb_x * tg_xxyyyyy_yyyyyy_0[j] + fr * tg_xxyyyyy_yyyyyy_1[j] + fl1_fx * (tg_xyyyyy_yyyyyy_0[j] - tg_xyyyyy_yyyyyy_1[j] * fl1_fza);

                    tg_xxxyyyyy_yyyyyz_0[j] = pb_x * tg_xxyyyyy_yyyyyz_0[j] + fr * tg_xxyyyyy_yyyyyz_1[j] + fl1_fx * (tg_xyyyyy_yyyyyz_0[j] - tg_xyyyyy_yyyyyz_1[j] * fl1_fza);

                    tg_xxxyyyyy_yyyyzz_0[j] = pb_x * tg_xxyyyyy_yyyyzz_0[j] + fr * tg_xxyyyyy_yyyyzz_1[j] + fl1_fx * (tg_xyyyyy_yyyyzz_0[j] - tg_xyyyyy_yyyyzz_1[j] * fl1_fza);

                    tg_xxxyyyyy_yyyzzz_0[j] = pb_x * tg_xxyyyyy_yyyzzz_0[j] + fr * tg_xxyyyyy_yyyzzz_1[j] + fl1_fx * (tg_xyyyyy_yyyzzz_0[j] - tg_xyyyyy_yyyzzz_1[j] * fl1_fza);

                    tg_xxxyyyyy_yyzzzz_0[j] = pb_x * tg_xxyyyyy_yyzzzz_0[j] + fr * tg_xxyyyyy_yyzzzz_1[j] + fl1_fx * (tg_xyyyyy_yyzzzz_0[j] - tg_xyyyyy_yyzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyy_yzzzzz_0[j] = pb_x * tg_xxyyyyy_yzzzzz_0[j] + fr * tg_xxyyyyy_yzzzzz_1[j] + fl1_fx * (tg_xyyyyy_yzzzzz_0[j] - tg_xyyyyy_yzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyy_zzzzzz_0[j] = pb_x * tg_xxyyyyy_zzzzzz_0[j] + fr * tg_xxyyyyy_zzzzzz_1[j] + fl1_fx * (tg_xyyyyy_zzzzzz_0[j] - tg_xyyyyy_zzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyz_xxxxxx_0[j] = pb_x * tg_xxyyyyz_xxxxxx_0[j] + fr * tg_xxyyyyz_xxxxxx_1[j] + fl1_fx * (tg_xyyyyz_xxxxxx_0[j] - tg_xyyyyz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyyz_xxxxx_1[j];

                    tg_xxxyyyyz_xxxxxy_0[j] = pb_x * tg_xxyyyyz_xxxxxy_0[j] + fr * tg_xxyyyyz_xxxxxy_1[j] + fl1_fx * (tg_xyyyyz_xxxxxy_0[j] - tg_xyyyyz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyyz_xxxxy_1[j];

                    tg_xxxyyyyz_xxxxxz_0[j] = pb_x * tg_xxyyyyz_xxxxxz_0[j] + fr * tg_xxyyyyz_xxxxxz_1[j] + fl1_fx * (tg_xyyyyz_xxxxxz_0[j] - tg_xyyyyz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyyz_xxxxz_1[j];

                    tg_xxxyyyyz_xxxxyy_0[j] = pb_x * tg_xxyyyyz_xxxxyy_0[j] + fr * tg_xxyyyyz_xxxxyy_1[j] + fl1_fx * (tg_xyyyyz_xxxxyy_0[j] - tg_xyyyyz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyz_xxxyy_1[j];

                    tg_xxxyyyyz_xxxxyz_0[j] = pb_x * tg_xxyyyyz_xxxxyz_0[j] + fr * tg_xxyyyyz_xxxxyz_1[j] + fl1_fx * (tg_xyyyyz_xxxxyz_0[j] - tg_xyyyyz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyz_xxxyz_1[j];

                    tg_xxxyyyyz_xxxxzz_0[j] = pb_x * tg_xxyyyyz_xxxxzz_0[j] + fr * tg_xxyyyyz_xxxxzz_1[j] + fl1_fx * (tg_xyyyyz_xxxxzz_0[j] - tg_xyyyyz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyyz_xxxzz_1[j];

                    tg_xxxyyyyz_xxxyyy_0[j] = pb_x * tg_xxyyyyz_xxxyyy_0[j] + fr * tg_xxyyyyz_xxxyyy_1[j] + fl1_fx * (tg_xyyyyz_xxxyyy_0[j] - tg_xyyyyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyz_xxyyy_1[j];

                    tg_xxxyyyyz_xxxyyz_0[j] = pb_x * tg_xxyyyyz_xxxyyz_0[j] + fr * tg_xxyyyyz_xxxyyz_1[j] + fl1_fx * (tg_xyyyyz_xxxyyz_0[j] - tg_xyyyyz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyz_xxyyz_1[j];

                    tg_xxxyyyyz_xxxyzz_0[j] = pb_x * tg_xxyyyyz_xxxyzz_0[j] + fr * tg_xxyyyyz_xxxyzz_1[j] + fl1_fx * (tg_xyyyyz_xxxyzz_0[j] - tg_xyyyyz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyz_xxyzz_1[j];

                    tg_xxxyyyyz_xxxzzz_0[j] = pb_x * tg_xxyyyyz_xxxzzz_0[j] + fr * tg_xxyyyyz_xxxzzz_1[j] + fl1_fx * (tg_xyyyyz_xxxzzz_0[j] - tg_xyyyyz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyyz_xxzzz_1[j];

                    tg_xxxyyyyz_xxyyyy_0[j] = pb_x * tg_xxyyyyz_xxyyyy_0[j] + fr * tg_xxyyyyz_xxyyyy_1[j] + fl1_fx * (tg_xyyyyz_xxyyyy_0[j] - tg_xyyyyz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_xyyyy_1[j];

                    tg_xxxyyyyz_xxyyyz_0[j] = pb_x * tg_xxyyyyz_xxyyyz_0[j] + fr * tg_xxyyyyz_xxyyyz_1[j] + fl1_fx * (tg_xyyyyz_xxyyyz_0[j] - tg_xyyyyz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_xyyyz_1[j];

                    tg_xxxyyyyz_xxyyzz_0[j] = pb_x * tg_xxyyyyz_xxyyzz_0[j] + fr * tg_xxyyyyz_xxyyzz_1[j] + fl1_fx * (tg_xyyyyz_xxyyzz_0[j] - tg_xyyyyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_xyyzz_1[j];

                    tg_xxxyyyyz_xxyzzz_0[j] = pb_x * tg_xxyyyyz_xxyzzz_0[j] + fr * tg_xxyyyyz_xxyzzz_1[j] + fl1_fx * (tg_xyyyyz_xxyzzz_0[j] - tg_xyyyyz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_xyzzz_1[j];

                    tg_xxxyyyyz_xxzzzz_0[j] = pb_x * tg_xxyyyyz_xxzzzz_0[j] + fr * tg_xxyyyyz_xxzzzz_1[j] + fl1_fx * (tg_xyyyyz_xxzzzz_0[j] - tg_xyyyyz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyyz_xzzzz_1[j];

                    tg_xxxyyyyz_xyyyyy_0[j] = pb_x * tg_xxyyyyz_xyyyyy_0[j] + fr * tg_xxyyyyz_xyyyyy_1[j] + fl1_fx * (tg_xyyyyz_xyyyyy_0[j] - tg_xyyyyz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_yyyyy_1[j];

                    tg_xxxyyyyz_xyyyyz_0[j] = pb_x * tg_xxyyyyz_xyyyyz_0[j] + fr * tg_xxyyyyz_xyyyyz_1[j] + fl1_fx * (tg_xyyyyz_xyyyyz_0[j] - tg_xyyyyz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_yyyyz_1[j];

                    tg_xxxyyyyz_xyyyzz_0[j] = pb_x * tg_xxyyyyz_xyyyzz_0[j] + fr * tg_xxyyyyz_xyyyzz_1[j] + fl1_fx * (tg_xyyyyz_xyyyzz_0[j] - tg_xyyyyz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_yyyzz_1[j];

                    tg_xxxyyyyz_xyyzzz_0[j] = pb_x * tg_xxyyyyz_xyyzzz_0[j] + fr * tg_xxyyyyz_xyyzzz_1[j] + fl1_fx * (tg_xyyyyz_xyyzzz_0[j] - tg_xyyyyz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_yyzzz_1[j];

                    tg_xxxyyyyz_xyzzzz_0[j] = pb_x * tg_xxyyyyz_xyzzzz_0[j] + fr * tg_xxyyyyz_xyzzzz_1[j] + fl1_fx * (tg_xyyyyz_xyzzzz_0[j] - tg_xyyyyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_yzzzz_1[j];

                    tg_xxxyyyyz_xzzzzz_0[j] = pb_x * tg_xxyyyyz_xzzzzz_0[j] + fr * tg_xxyyyyz_xzzzzz_1[j] + fl1_fx * (tg_xyyyyz_xzzzzz_0[j] - tg_xyyyyz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyyz_zzzzz_1[j];

                    tg_xxxyyyyz_yyyyyy_0[j] = pb_x * tg_xxyyyyz_yyyyyy_0[j] + fr * tg_xxyyyyz_yyyyyy_1[j] + fl1_fx * (tg_xyyyyz_yyyyyy_0[j] - tg_xyyyyz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxyyyyz_yyyyyz_0[j] = pb_x * tg_xxyyyyz_yyyyyz_0[j] + fr * tg_xxyyyyz_yyyyyz_1[j] + fl1_fx * (tg_xyyyyz_yyyyyz_0[j] - tg_xyyyyz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxyyyyz_yyyyzz_0[j] = pb_x * tg_xxyyyyz_yyyyzz_0[j] + fr * tg_xxyyyyz_yyyyzz_1[j] + fl1_fx * (tg_xyyyyz_yyyyzz_0[j] - tg_xyyyyz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxyyyyz_yyyzzz_0[j] = pb_x * tg_xxyyyyz_yyyzzz_0[j] + fr * tg_xxyyyyz_yyyzzz_1[j] + fl1_fx * (tg_xyyyyz_yyyzzz_0[j] - tg_xyyyyz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxyyyyz_yyzzzz_0[j] = pb_x * tg_xxyyyyz_yyzzzz_0[j] + fr * tg_xxyyyyz_yyzzzz_1[j] + fl1_fx * (tg_xyyyyz_yyzzzz_0[j] - tg_xyyyyz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyz_yzzzzz_0[j] = pb_x * tg_xxyyyyz_yzzzzz_0[j] + fr * tg_xxyyyyz_yzzzzz_1[j] + fl1_fx * (tg_xyyyyz_yzzzzz_0[j] - tg_xyyyyz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyyz_zzzzzz_0[j] = pb_x * tg_xxyyyyz_zzzzzz_0[j] + fr * tg_xxyyyyz_zzzzzz_1[j] + fl1_fx * (tg_xyyyyz_zzzzzz_0[j] - tg_xyyyyz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyzz_xxxxxx_0[j] = pb_x * tg_xxyyyzz_xxxxxx_0[j] + fr * tg_xxyyyzz_xxxxxx_1[j] + fl1_fx * (tg_xyyyzz_xxxxxx_0[j] - tg_xyyyzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyyzz_xxxxx_1[j];

                    tg_xxxyyyzz_xxxxxy_0[j] = pb_x * tg_xxyyyzz_xxxxxy_0[j] + fr * tg_xxyyyzz_xxxxxy_1[j] + fl1_fx * (tg_xyyyzz_xxxxxy_0[j] - tg_xyyyzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyzz_xxxxy_1[j];

                    tg_xxxyyyzz_xxxxxz_0[j] = pb_x * tg_xxyyyzz_xxxxxz_0[j] + fr * tg_xxyyyzz_xxxxxz_1[j] + fl1_fx * (tg_xyyyzz_xxxxxz_0[j] - tg_xyyyzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyyzz_xxxxz_1[j];

                    tg_xxxyyyzz_xxxxyy_0[j] = pb_x * tg_xxyyyzz_xxxxyy_0[j] + fr * tg_xxyyyzz_xxxxyy_1[j] + fl1_fx * (tg_xyyyzz_xxxxyy_0[j] - tg_xyyyzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyzz_xxxyy_1[j];

                    tg_xxxyyyzz_xxxxyz_0[j] = pb_x * tg_xxyyyzz_xxxxyz_0[j] + fr * tg_xxyyyzz_xxxxyz_1[j] + fl1_fx * (tg_xyyyzz_xxxxyz_0[j] - tg_xyyyzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyzz_xxxyz_1[j];

                    tg_xxxyyyzz_xxxxzz_0[j] = pb_x * tg_xxyyyzz_xxxxzz_0[j] + fr * tg_xxyyyzz_xxxxzz_1[j] + fl1_fx * (tg_xyyyzz_xxxxzz_0[j] - tg_xyyyzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyyzz_xxxzz_1[j];

                    tg_xxxyyyzz_xxxyyy_0[j] = pb_x * tg_xxyyyzz_xxxyyy_0[j] + fr * tg_xxyyyzz_xxxyyy_1[j] + fl1_fx * (tg_xyyyzz_xxxyyy_0[j] - tg_xyyyzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyzz_xxyyy_1[j];

                    tg_xxxyyyzz_xxxyyz_0[j] = pb_x * tg_xxyyyzz_xxxyyz_0[j] + fr * tg_xxyyyzz_xxxyyz_1[j] + fl1_fx * (tg_xyyyzz_xxxyyz_0[j] - tg_xyyyzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyzz_xxyyz_1[j];

                    tg_xxxyyyzz_xxxyzz_0[j] = pb_x * tg_xxyyyzz_xxxyzz_0[j] + fr * tg_xxyyyzz_xxxyzz_1[j] + fl1_fx * (tg_xyyyzz_xxxyzz_0[j] - tg_xyyyzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyzz_xxyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_485_582(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (485,582)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxyyyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 485); 

                auto tg_xxyyyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 486); 

                auto tg_xxyyyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 487); 

                auto tg_xxyyyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 488); 

                auto tg_xxyyyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 489); 

                auto tg_xxyyyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 490); 

                auto tg_xxyyyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 491); 

                auto tg_xxyyyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 492); 

                auto tg_xxyyyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 493); 

                auto tg_xxyyyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 494); 

                auto tg_xxyyyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 495); 

                auto tg_xxyyyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 496); 

                auto tg_xxyyyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 497); 

                auto tg_xxyyyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 498); 

                auto tg_xxyyyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 499); 

                auto tg_xxyyyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 500); 

                auto tg_xxyyyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 501); 

                auto tg_xxyyyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 502); 

                auto tg_xxyyyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 503); 

                auto tg_xxyyzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 504); 

                auto tg_xxyyzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 505); 

                auto tg_xxyyzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 506); 

                auto tg_xxyyzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 507); 

                auto tg_xxyyzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 508); 

                auto tg_xxyyzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 509); 

                auto tg_xxyyzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 510); 

                auto tg_xxyyzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 511); 

                auto tg_xxyyzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 512); 

                auto tg_xxyyzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 513); 

                auto tg_xxyyzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 514); 

                auto tg_xxyyzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 515); 

                auto tg_xxyyzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 516); 

                auto tg_xxyyzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 517); 

                auto tg_xxyyzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 518); 

                auto tg_xxyyzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 519); 

                auto tg_xxyyzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 520); 

                auto tg_xxyyzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 521); 

                auto tg_xxyyzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 522); 

                auto tg_xxyyzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 523); 

                auto tg_xxyyzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 524); 

                auto tg_xxyyzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 525); 

                auto tg_xxyyzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 526); 

                auto tg_xxyyzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 527); 

                auto tg_xxyyzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 528); 

                auto tg_xxyyzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 529); 

                auto tg_xxyyzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 530); 

                auto tg_xxyyzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 531); 

                auto tg_xxyzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 532); 

                auto tg_xxyzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 533); 

                auto tg_xxyzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 534); 

                auto tg_xxyzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 535); 

                auto tg_xxyzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 536); 

                auto tg_xxyzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 537); 

                auto tg_xxyzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 538); 

                auto tg_xxyzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 539); 

                auto tg_xxyzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 540); 

                auto tg_xxyzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 541); 

                auto tg_xxyzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 542); 

                auto tg_xxyzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 543); 

                auto tg_xxyzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 544); 

                auto tg_xxyzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 545); 

                auto tg_xxyzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 546); 

                auto tg_xxyzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 547); 

                auto tg_xxyzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 548); 

                auto tg_xxyzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 549); 

                auto tg_xxyzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 550); 

                auto tg_xxyzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 551); 

                auto tg_xxyzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 552); 

                auto tg_xxyzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 553); 

                auto tg_xxyzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 554); 

                auto tg_xxyzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 555); 

                auto tg_xxyzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 556); 

                auto tg_xxyzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 557); 

                auto tg_xxyzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 558); 

                auto tg_xxyzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 559); 

                auto tg_xxzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 560); 

                auto tg_xxzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 561); 

                auto tg_xxzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 562); 

                auto tg_xxzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 563); 

                auto tg_xxzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 564); 

                auto tg_xxzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 565); 

                auto tg_xxzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 566); 

                auto tg_xxzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 567); 

                auto tg_xxzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 568); 

                auto tg_xxzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 569); 

                auto tg_xxzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 570); 

                auto tg_xxzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 571); 

                auto tg_xxzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 572); 

                auto tg_xxzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 573); 

                auto tg_xxzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 574); 

                auto tg_xxzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 575); 

                auto tg_xxzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 576); 

                auto tg_xxzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 577); 

                auto tg_xxzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 578); 

                auto tg_xxzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 579); 

                auto tg_xxzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 580); 

                auto tg_xxzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 581); 

                auto tg_xxyyyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 485); 

                auto tg_xxyyyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 486); 

                auto tg_xxyyyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 487); 

                auto tg_xxyyyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 488); 

                auto tg_xxyyyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 489); 

                auto tg_xxyyyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 490); 

                auto tg_xxyyyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 491); 

                auto tg_xxyyyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 492); 

                auto tg_xxyyyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 493); 

                auto tg_xxyyyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 494); 

                auto tg_xxyyyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 495); 

                auto tg_xxyyyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 496); 

                auto tg_xxyyyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 497); 

                auto tg_xxyyyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 498); 

                auto tg_xxyyyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 499); 

                auto tg_xxyyyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 500); 

                auto tg_xxyyyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 501); 

                auto tg_xxyyyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 502); 

                auto tg_xxyyyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 503); 

                auto tg_xxyyzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 504); 

                auto tg_xxyyzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 505); 

                auto tg_xxyyzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 506); 

                auto tg_xxyyzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 507); 

                auto tg_xxyyzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 508); 

                auto tg_xxyyzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 509); 

                auto tg_xxyyzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 510); 

                auto tg_xxyyzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 511); 

                auto tg_xxyyzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 512); 

                auto tg_xxyyzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 513); 

                auto tg_xxyyzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 514); 

                auto tg_xxyyzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 515); 

                auto tg_xxyyzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 516); 

                auto tg_xxyyzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 517); 

                auto tg_xxyyzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 518); 

                auto tg_xxyyzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 519); 

                auto tg_xxyyzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 520); 

                auto tg_xxyyzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 521); 

                auto tg_xxyyzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 522); 

                auto tg_xxyyzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 523); 

                auto tg_xxyyzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 524); 

                auto tg_xxyyzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 525); 

                auto tg_xxyyzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 526); 

                auto tg_xxyyzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 527); 

                auto tg_xxyyzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 528); 

                auto tg_xxyyzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 529); 

                auto tg_xxyyzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 530); 

                auto tg_xxyyzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 531); 

                auto tg_xxyzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 532); 

                auto tg_xxyzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 533); 

                auto tg_xxyzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 534); 

                auto tg_xxyzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 535); 

                auto tg_xxyzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 536); 

                auto tg_xxyzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 537); 

                auto tg_xxyzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 538); 

                auto tg_xxyzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 539); 

                auto tg_xxyzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 540); 

                auto tg_xxyzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 541); 

                auto tg_xxyzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 542); 

                auto tg_xxyzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 543); 

                auto tg_xxyzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 544); 

                auto tg_xxyzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 545); 

                auto tg_xxyzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 546); 

                auto tg_xxyzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 547); 

                auto tg_xxyzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 548); 

                auto tg_xxyzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 549); 

                auto tg_xxyzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 550); 

                auto tg_xxyzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 551); 

                auto tg_xxyzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 552); 

                auto tg_xxyzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 553); 

                auto tg_xxyzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 554); 

                auto tg_xxyzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 555); 

                auto tg_xxyzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 556); 

                auto tg_xxyzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 557); 

                auto tg_xxyzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 558); 

                auto tg_xxyzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 559); 

                auto tg_xxzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 560); 

                auto tg_xxzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 561); 

                auto tg_xxzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 562); 

                auto tg_xxzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 563); 

                auto tg_xxzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 564); 

                auto tg_xxzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 565); 

                auto tg_xxzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 566); 

                auto tg_xxzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 567); 

                auto tg_xxzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 568); 

                auto tg_xxzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 569); 

                auto tg_xxzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 570); 

                auto tg_xxzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 571); 

                auto tg_xxzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 572); 

                auto tg_xxzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 573); 

                auto tg_xxzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 574); 

                auto tg_xxzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 575); 

                auto tg_xxzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 576); 

                auto tg_xxzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 577); 

                auto tg_xxzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 578); 

                auto tg_xxzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 579); 

                auto tg_xxzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 580); 

                auto tg_xxzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 581); 

                auto tg_xyyyzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 485); 

                auto tg_xyyyzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 486); 

                auto tg_xyyyzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 487); 

                auto tg_xyyyzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 488); 

                auto tg_xyyyzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 489); 

                auto tg_xyyyzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 490); 

                auto tg_xyyyzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 491); 

                auto tg_xyyyzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 492); 

                auto tg_xyyyzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 493); 

                auto tg_xyyyzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 494); 

                auto tg_xyyyzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 495); 

                auto tg_xyyyzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 496); 

                auto tg_xyyyzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 497); 

                auto tg_xyyyzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 498); 

                auto tg_xyyyzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 499); 

                auto tg_xyyyzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 500); 

                auto tg_xyyyzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 501); 

                auto tg_xyyyzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 502); 

                auto tg_xyyyzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 503); 

                auto tg_xyyzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 504); 

                auto tg_xyyzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 505); 

                auto tg_xyyzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 506); 

                auto tg_xyyzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 507); 

                auto tg_xyyzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 508); 

                auto tg_xyyzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 509); 

                auto tg_xyyzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 510); 

                auto tg_xyyzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 511); 

                auto tg_xyyzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 512); 

                auto tg_xyyzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 513); 

                auto tg_xyyzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 514); 

                auto tg_xyyzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 515); 

                auto tg_xyyzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 516); 

                auto tg_xyyzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 517); 

                auto tg_xyyzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 518); 

                auto tg_xyyzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 519); 

                auto tg_xyyzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 520); 

                auto tg_xyyzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 521); 

                auto tg_xyyzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 522); 

                auto tg_xyyzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 523); 

                auto tg_xyyzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 524); 

                auto tg_xyyzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 525); 

                auto tg_xyyzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 526); 

                auto tg_xyyzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 527); 

                auto tg_xyyzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 528); 

                auto tg_xyyzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 529); 

                auto tg_xyyzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 530); 

                auto tg_xyyzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 531); 

                auto tg_xyzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 532); 

                auto tg_xyzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 533); 

                auto tg_xyzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 534); 

                auto tg_xyzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 535); 

                auto tg_xyzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 536); 

                auto tg_xyzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 537); 

                auto tg_xyzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 538); 

                auto tg_xyzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 539); 

                auto tg_xyzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 540); 

                auto tg_xyzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 541); 

                auto tg_xyzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 542); 

                auto tg_xyzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 543); 

                auto tg_xyzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 544); 

                auto tg_xyzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 545); 

                auto tg_xyzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 546); 

                auto tg_xyzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 547); 

                auto tg_xyzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 548); 

                auto tg_xyzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 549); 

                auto tg_xyzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 550); 

                auto tg_xyzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 551); 

                auto tg_xyzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 552); 

                auto tg_xyzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 553); 

                auto tg_xyzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 554); 

                auto tg_xyzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 555); 

                auto tg_xyzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 556); 

                auto tg_xyzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 557); 

                auto tg_xyzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 558); 

                auto tg_xyzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 559); 

                auto tg_xzzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 560); 

                auto tg_xzzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 561); 

                auto tg_xzzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 562); 

                auto tg_xzzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 563); 

                auto tg_xzzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 564); 

                auto tg_xzzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 565); 

                auto tg_xzzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 566); 

                auto tg_xzzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 567); 

                auto tg_xzzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 568); 

                auto tg_xzzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 569); 

                auto tg_xzzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 570); 

                auto tg_xzzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 571); 

                auto tg_xzzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 572); 

                auto tg_xzzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 573); 

                auto tg_xzzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 574); 

                auto tg_xzzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 575); 

                auto tg_xzzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 576); 

                auto tg_xzzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 577); 

                auto tg_xzzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 578); 

                auto tg_xzzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 579); 

                auto tg_xzzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 580); 

                auto tg_xzzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 581); 

                auto tg_xyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 485); 

                auto tg_xyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 486); 

                auto tg_xyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 487); 

                auto tg_xyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 488); 

                auto tg_xyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 489); 

                auto tg_xyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 490); 

                auto tg_xyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 491); 

                auto tg_xyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 492); 

                auto tg_xyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 493); 

                auto tg_xyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 494); 

                auto tg_xyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 495); 

                auto tg_xyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 496); 

                auto tg_xyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 497); 

                auto tg_xyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 498); 

                auto tg_xyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 499); 

                auto tg_xyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 500); 

                auto tg_xyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 501); 

                auto tg_xyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 502); 

                auto tg_xyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 503); 

                auto tg_xyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 504); 

                auto tg_xyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 505); 

                auto tg_xyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 506); 

                auto tg_xyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 507); 

                auto tg_xyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 508); 

                auto tg_xyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 509); 

                auto tg_xyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 510); 

                auto tg_xyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 511); 

                auto tg_xyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 512); 

                auto tg_xyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 513); 

                auto tg_xyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 514); 

                auto tg_xyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 515); 

                auto tg_xyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 516); 

                auto tg_xyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 517); 

                auto tg_xyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 518); 

                auto tg_xyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 519); 

                auto tg_xyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 520); 

                auto tg_xyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 521); 

                auto tg_xyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 522); 

                auto tg_xyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 523); 

                auto tg_xyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 524); 

                auto tg_xyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 525); 

                auto tg_xyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 526); 

                auto tg_xyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 527); 

                auto tg_xyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 528); 

                auto tg_xyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 529); 

                auto tg_xyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 530); 

                auto tg_xyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 531); 

                auto tg_xyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 532); 

                auto tg_xyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 533); 

                auto tg_xyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 534); 

                auto tg_xyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 535); 

                auto tg_xyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 536); 

                auto tg_xyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 537); 

                auto tg_xyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 538); 

                auto tg_xyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 539); 

                auto tg_xyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 540); 

                auto tg_xyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 541); 

                auto tg_xyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 542); 

                auto tg_xyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 543); 

                auto tg_xyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 544); 

                auto tg_xyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 545); 

                auto tg_xyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 546); 

                auto tg_xyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 547); 

                auto tg_xyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 548); 

                auto tg_xyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 549); 

                auto tg_xyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 550); 

                auto tg_xyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 551); 

                auto tg_xyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 552); 

                auto tg_xyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 553); 

                auto tg_xyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 554); 

                auto tg_xyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 555); 

                auto tg_xyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 556); 

                auto tg_xyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 557); 

                auto tg_xyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 558); 

                auto tg_xyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 559); 

                auto tg_xzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 560); 

                auto tg_xzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 561); 

                auto tg_xzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 562); 

                auto tg_xzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 563); 

                auto tg_xzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 564); 

                auto tg_xzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 565); 

                auto tg_xzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 566); 

                auto tg_xzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 567); 

                auto tg_xzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 568); 

                auto tg_xzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 569); 

                auto tg_xzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 570); 

                auto tg_xzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 571); 

                auto tg_xzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 572); 

                auto tg_xzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 573); 

                auto tg_xzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 574); 

                auto tg_xzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 575); 

                auto tg_xzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 576); 

                auto tg_xzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 577); 

                auto tg_xzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 578); 

                auto tg_xzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 579); 

                auto tg_xzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 580); 

                auto tg_xzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 581); 

                auto tg_xxyyyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 366); 

                auto tg_xxyyyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 367); 

                auto tg_xxyyyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 368); 

                auto tg_xxyyyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 369); 

                auto tg_xxyyyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 370); 

                auto tg_xxyyyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 371); 

                auto tg_xxyyyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 372); 

                auto tg_xxyyyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 373); 

                auto tg_xxyyyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 374); 

                auto tg_xxyyyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 375); 

                auto tg_xxyyyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 376); 

                auto tg_xxyyyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 377); 

                auto tg_xxyyzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 378); 

                auto tg_xxyyzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 379); 

                auto tg_xxyyzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 380); 

                auto tg_xxyyzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 381); 

                auto tg_xxyyzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 382); 

                auto tg_xxyyzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 383); 

                auto tg_xxyyzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 384); 

                auto tg_xxyyzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 385); 

                auto tg_xxyyzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 386); 

                auto tg_xxyyzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 387); 

                auto tg_xxyyzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 388); 

                auto tg_xxyyzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 389); 

                auto tg_xxyyzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 390); 

                auto tg_xxyyzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 391); 

                auto tg_xxyyzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 392); 

                auto tg_xxyyzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 393); 

                auto tg_xxyyzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 394); 

                auto tg_xxyyzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 395); 

                auto tg_xxyyzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 396); 

                auto tg_xxyyzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 397); 

                auto tg_xxyyzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 398); 

                auto tg_xxyzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 399); 

                auto tg_xxyzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 400); 

                auto tg_xxyzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 401); 

                auto tg_xxyzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 402); 

                auto tg_xxyzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 403); 

                auto tg_xxyzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 404); 

                auto tg_xxyzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 405); 

                auto tg_xxyzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 406); 

                auto tg_xxyzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 407); 

                auto tg_xxyzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 408); 

                auto tg_xxyzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 409); 

                auto tg_xxyzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 410); 

                auto tg_xxyzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 411); 

                auto tg_xxyzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 412); 

                auto tg_xxyzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 413); 

                auto tg_xxyzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 414); 

                auto tg_xxyzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 415); 

                auto tg_xxyzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 416); 

                auto tg_xxyzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 417); 

                auto tg_xxyzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 418); 

                auto tg_xxyzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 419); 

                auto tg_xxzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 420); 

                auto tg_xxzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 421); 

                auto tg_xxzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 422); 

                auto tg_xxzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 423); 

                auto tg_xxzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 424); 

                auto tg_xxzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 425); 

                auto tg_xxzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 426); 

                auto tg_xxzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 427); 

                auto tg_xxzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 428); 

                auto tg_xxzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 429); 

                auto tg_xxzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 430); 

                auto tg_xxzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 431); 

                auto tg_xxzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 432); 

                auto tg_xxzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 433); 

                auto tg_xxzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 434); 

                auto tg_xxzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 435); 

                auto tg_xxzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 436); 

                auto tg_xxzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 437); 

                auto tg_xxzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 438); 

                auto tg_xxzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 439); 

                auto tg_xxzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 440); 

                // set up pointers to integrals

                auto tg_xxxyyyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 485); 

                auto tg_xxxyyyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 486); 

                auto tg_xxxyyyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 487); 

                auto tg_xxxyyyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 488); 

                auto tg_xxxyyyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 489); 

                auto tg_xxxyyyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 490); 

                auto tg_xxxyyyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 491); 

                auto tg_xxxyyyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 492); 

                auto tg_xxxyyyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 493); 

                auto tg_xxxyyyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 494); 

                auto tg_xxxyyyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 495); 

                auto tg_xxxyyyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 496); 

                auto tg_xxxyyyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 497); 

                auto tg_xxxyyyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 498); 

                auto tg_xxxyyyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 499); 

                auto tg_xxxyyyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 500); 

                auto tg_xxxyyyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 501); 

                auto tg_xxxyyyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 502); 

                auto tg_xxxyyyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 503); 

                auto tg_xxxyyzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 504); 

                auto tg_xxxyyzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 505); 

                auto tg_xxxyyzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 506); 

                auto tg_xxxyyzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 507); 

                auto tg_xxxyyzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 508); 

                auto tg_xxxyyzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 509); 

                auto tg_xxxyyzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 510); 

                auto tg_xxxyyzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 511); 

                auto tg_xxxyyzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 512); 

                auto tg_xxxyyzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 513); 

                auto tg_xxxyyzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 514); 

                auto tg_xxxyyzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 515); 

                auto tg_xxxyyzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 516); 

                auto tg_xxxyyzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 517); 

                auto tg_xxxyyzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 518); 

                auto tg_xxxyyzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 519); 

                auto tg_xxxyyzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 520); 

                auto tg_xxxyyzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 521); 

                auto tg_xxxyyzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 522); 

                auto tg_xxxyyzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 523); 

                auto tg_xxxyyzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 524); 

                auto tg_xxxyyzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 525); 

                auto tg_xxxyyzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 526); 

                auto tg_xxxyyzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 527); 

                auto tg_xxxyyzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 528); 

                auto tg_xxxyyzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 529); 

                auto tg_xxxyyzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 530); 

                auto tg_xxxyyzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 531); 

                auto tg_xxxyzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 532); 

                auto tg_xxxyzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 533); 

                auto tg_xxxyzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 534); 

                auto tg_xxxyzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 535); 

                auto tg_xxxyzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 536); 

                auto tg_xxxyzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 537); 

                auto tg_xxxyzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 538); 

                auto tg_xxxyzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 539); 

                auto tg_xxxyzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 540); 

                auto tg_xxxyzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 541); 

                auto tg_xxxyzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 542); 

                auto tg_xxxyzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 543); 

                auto tg_xxxyzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 544); 

                auto tg_xxxyzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 545); 

                auto tg_xxxyzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 546); 

                auto tg_xxxyzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 547); 

                auto tg_xxxyzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 548); 

                auto tg_xxxyzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 549); 

                auto tg_xxxyzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 550); 

                auto tg_xxxyzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 551); 

                auto tg_xxxyzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 552); 

                auto tg_xxxyzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 553); 

                auto tg_xxxyzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 554); 

                auto tg_xxxyzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 555); 

                auto tg_xxxyzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 556); 

                auto tg_xxxyzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 557); 

                auto tg_xxxyzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 558); 

                auto tg_xxxyzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 559); 

                auto tg_xxxzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 560); 

                auto tg_xxxzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 561); 

                auto tg_xxxzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 562); 

                auto tg_xxxzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 563); 

                auto tg_xxxzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 564); 

                auto tg_xxxzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 565); 

                auto tg_xxxzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 566); 

                auto tg_xxxzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 567); 

                auto tg_xxxzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 568); 

                auto tg_xxxzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 569); 

                auto tg_xxxzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 570); 

                auto tg_xxxzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 571); 

                auto tg_xxxzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 572); 

                auto tg_xxxzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 573); 

                auto tg_xxxzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 574); 

                auto tg_xxxzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 575); 

                auto tg_xxxzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 576); 

                auto tg_xxxzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 577); 

                auto tg_xxxzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 578); 

                auto tg_xxxzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 579); 

                auto tg_xxxzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 580); 

                auto tg_xxxzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 581); 

                // Batch of Integrals (485,582)

                #pragma omp simd aligned(fxn, fza, tg_xxxyyyzz_xxxzzz_0, tg_xxxyyyzz_xxyyyy_0, \
                                         tg_xxxyyyzz_xxyyyz_0, tg_xxxyyyzz_xxyyzz_0, tg_xxxyyyzz_xxyzzz_0, tg_xxxyyyzz_xxzzzz_0, \
                                         tg_xxxyyyzz_xyyyyy_0, tg_xxxyyyzz_xyyyyz_0, tg_xxxyyyzz_xyyyzz_0, tg_xxxyyyzz_xyyzzz_0, \
                                         tg_xxxyyyzz_xyzzzz_0, tg_xxxyyyzz_xzzzzz_0, tg_xxxyyyzz_yyyyyy_0, tg_xxxyyyzz_yyyyyz_0, \
                                         tg_xxxyyyzz_yyyyzz_0, tg_xxxyyyzz_yyyzzz_0, tg_xxxyyyzz_yyzzzz_0, tg_xxxyyyzz_yzzzzz_0, \
                                         tg_xxxyyyzz_zzzzzz_0, tg_xxxyyzzz_xxxxxx_0, tg_xxxyyzzz_xxxxxy_0, tg_xxxyyzzz_xxxxxz_0, \
                                         tg_xxxyyzzz_xxxxyy_0, tg_xxxyyzzz_xxxxyz_0, tg_xxxyyzzz_xxxxzz_0, tg_xxxyyzzz_xxxyyy_0, \
                                         tg_xxxyyzzz_xxxyyz_0, tg_xxxyyzzz_xxxyzz_0, tg_xxxyyzzz_xxxzzz_0, tg_xxxyyzzz_xxyyyy_0, \
                                         tg_xxxyyzzz_xxyyyz_0, tg_xxxyyzzz_xxyyzz_0, tg_xxxyyzzz_xxyzzz_0, tg_xxxyyzzz_xxzzzz_0, \
                                         tg_xxxyyzzz_xyyyyy_0, tg_xxxyyzzz_xyyyyz_0, tg_xxxyyzzz_xyyyzz_0, tg_xxxyyzzz_xyyzzz_0, \
                                         tg_xxxyyzzz_xyzzzz_0, tg_xxxyyzzz_xzzzzz_0, tg_xxxyyzzz_yyyyyy_0, tg_xxxyyzzz_yyyyyz_0, \
                                         tg_xxxyyzzz_yyyyzz_0, tg_xxxyyzzz_yyyzzz_0, tg_xxxyyzzz_yyzzzz_0, tg_xxxyyzzz_yzzzzz_0, \
                                         tg_xxxyyzzz_zzzzzz_0, tg_xxxyzzzz_xxxxxx_0, tg_xxxyzzzz_xxxxxy_0, tg_xxxyzzzz_xxxxxz_0, \
                                         tg_xxxyzzzz_xxxxyy_0, tg_xxxyzzzz_xxxxyz_0, tg_xxxyzzzz_xxxxzz_0, tg_xxxyzzzz_xxxyyy_0, \
                                         tg_xxxyzzzz_xxxyyz_0, tg_xxxyzzzz_xxxyzz_0, tg_xxxyzzzz_xxxzzz_0, tg_xxxyzzzz_xxyyyy_0, \
                                         tg_xxxyzzzz_xxyyyz_0, tg_xxxyzzzz_xxyyzz_0, tg_xxxyzzzz_xxyzzz_0, tg_xxxyzzzz_xxzzzz_0, \
                                         tg_xxxyzzzz_xyyyyy_0, tg_xxxyzzzz_xyyyyz_0, tg_xxxyzzzz_xyyyzz_0, tg_xxxyzzzz_xyyzzz_0, \
                                         tg_xxxyzzzz_xyzzzz_0, tg_xxxyzzzz_xzzzzz_0, tg_xxxyzzzz_yyyyyy_0, tg_xxxyzzzz_yyyyyz_0, \
                                         tg_xxxyzzzz_yyyyzz_0, tg_xxxyzzzz_yyyzzz_0, tg_xxxyzzzz_yyzzzz_0, tg_xxxyzzzz_yzzzzz_0, \
                                         tg_xxxyzzzz_zzzzzz_0, tg_xxxzzzzz_xxxxxx_0, tg_xxxzzzzz_xxxxxy_0, tg_xxxzzzzz_xxxxxz_0, \
                                         tg_xxxzzzzz_xxxxyy_0, tg_xxxzzzzz_xxxxyz_0, tg_xxxzzzzz_xxxxzz_0, tg_xxxzzzzz_xxxyyy_0, \
                                         tg_xxxzzzzz_xxxyyz_0, tg_xxxzzzzz_xxxyzz_0, tg_xxxzzzzz_xxxzzz_0, tg_xxxzzzzz_xxyyyy_0, \
                                         tg_xxxzzzzz_xxyyyz_0, tg_xxxzzzzz_xxyyzz_0, tg_xxxzzzzz_xxyzzz_0, tg_xxxzzzzz_xxzzzz_0, \
                                         tg_xxxzzzzz_xyyyyy_0, tg_xxxzzzzz_xyyyyz_0, tg_xxxzzzzz_xyyyzz_0, tg_xxxzzzzz_xyyzzz_0, \
                                         tg_xxxzzzzz_xyzzzz_0, tg_xxxzzzzz_xzzzzz_0, tg_xxxzzzzz_yyyyyy_0, tg_xxyyyzz_xxxzzz_0, \
                                         tg_xxyyyzz_xxxzzz_1, tg_xxyyyzz_xxyyyy_0, tg_xxyyyzz_xxyyyy_1, tg_xxyyyzz_xxyyyz_0, \
                                         tg_xxyyyzz_xxyyyz_1, tg_xxyyyzz_xxyyzz_0, tg_xxyyyzz_xxyyzz_1, tg_xxyyyzz_xxyzzz_0, \
                                         tg_xxyyyzz_xxyzzz_1, tg_xxyyyzz_xxzzz_1, tg_xxyyyzz_xxzzzz_0, tg_xxyyyzz_xxzzzz_1, \
                                         tg_xxyyyzz_xyyyy_1, tg_xxyyyzz_xyyyyy_0, tg_xxyyyzz_xyyyyy_1, tg_xxyyyzz_xyyyyz_0, \
                                         tg_xxyyyzz_xyyyyz_1, tg_xxyyyzz_xyyyz_1, tg_xxyyyzz_xyyyzz_0, tg_xxyyyzz_xyyyzz_1, \
                                         tg_xxyyyzz_xyyzz_1, tg_xxyyyzz_xyyzzz_0, tg_xxyyyzz_xyyzzz_1, tg_xxyyyzz_xyzzz_1, \
                                         tg_xxyyyzz_xyzzzz_0, tg_xxyyyzz_xyzzzz_1, tg_xxyyyzz_xzzzz_1, tg_xxyyyzz_xzzzzz_0, \
                                         tg_xxyyyzz_xzzzzz_1, tg_xxyyyzz_yyyyy_1, tg_xxyyyzz_yyyyyy_0, tg_xxyyyzz_yyyyyy_1, \
                                         tg_xxyyyzz_yyyyyz_0, tg_xxyyyzz_yyyyyz_1, tg_xxyyyzz_yyyyz_1, tg_xxyyyzz_yyyyzz_0, \
                                         tg_xxyyyzz_yyyyzz_1, tg_xxyyyzz_yyyzz_1, tg_xxyyyzz_yyyzzz_0, tg_xxyyyzz_yyyzzz_1, \
                                         tg_xxyyyzz_yyzzz_1, tg_xxyyyzz_yyzzzz_0, tg_xxyyyzz_yyzzzz_1, tg_xxyyyzz_yzzzz_1, \
                                         tg_xxyyyzz_yzzzzz_0, tg_xxyyyzz_yzzzzz_1, tg_xxyyyzz_zzzzz_1, tg_xxyyyzz_zzzzzz_0, \
                                         tg_xxyyyzz_zzzzzz_1, tg_xxyyzzz_xxxxx_1, tg_xxyyzzz_xxxxxx_0, tg_xxyyzzz_xxxxxx_1, \
                                         tg_xxyyzzz_xxxxxy_0, tg_xxyyzzz_xxxxxy_1, tg_xxyyzzz_xxxxxz_0, tg_xxyyzzz_xxxxxz_1, \
                                         tg_xxyyzzz_xxxxy_1, tg_xxyyzzz_xxxxyy_0, tg_xxyyzzz_xxxxyy_1, tg_xxyyzzz_xxxxyz_0, \
                                         tg_xxyyzzz_xxxxyz_1, tg_xxyyzzz_xxxxz_1, tg_xxyyzzz_xxxxzz_0, tg_xxyyzzz_xxxxzz_1, \
                                         tg_xxyyzzz_xxxyy_1, tg_xxyyzzz_xxxyyy_0, tg_xxyyzzz_xxxyyy_1, tg_xxyyzzz_xxxyyz_0, \
                                         tg_xxyyzzz_xxxyyz_1, tg_xxyyzzz_xxxyz_1, tg_xxyyzzz_xxxyzz_0, tg_xxyyzzz_xxxyzz_1, \
                                         tg_xxyyzzz_xxxzz_1, tg_xxyyzzz_xxxzzz_0, tg_xxyyzzz_xxxzzz_1, tg_xxyyzzz_xxyyy_1, \
                                         tg_xxyyzzz_xxyyyy_0, tg_xxyyzzz_xxyyyy_1, tg_xxyyzzz_xxyyyz_0, tg_xxyyzzz_xxyyyz_1, \
                                         tg_xxyyzzz_xxyyz_1, tg_xxyyzzz_xxyyzz_0, tg_xxyyzzz_xxyyzz_1, tg_xxyyzzz_xxyzz_1, \
                                         tg_xxyyzzz_xxyzzz_0, tg_xxyyzzz_xxyzzz_1, tg_xxyyzzz_xxzzz_1, tg_xxyyzzz_xxzzzz_0, \
                                         tg_xxyyzzz_xxzzzz_1, tg_xxyyzzz_xyyyy_1, tg_xxyyzzz_xyyyyy_0, tg_xxyyzzz_xyyyyy_1, \
                                         tg_xxyyzzz_xyyyyz_0, tg_xxyyzzz_xyyyyz_1, tg_xxyyzzz_xyyyz_1, tg_xxyyzzz_xyyyzz_0, \
                                         tg_xxyyzzz_xyyyzz_1, tg_xxyyzzz_xyyzz_1, tg_xxyyzzz_xyyzzz_0, tg_xxyyzzz_xyyzzz_1, \
                                         tg_xxyyzzz_xyzzz_1, tg_xxyyzzz_xyzzzz_0, tg_xxyyzzz_xyzzzz_1, tg_xxyyzzz_xzzzz_1, \
                                         tg_xxyyzzz_xzzzzz_0, tg_xxyyzzz_xzzzzz_1, tg_xxyyzzz_yyyyy_1, tg_xxyyzzz_yyyyyy_0, \
                                         tg_xxyyzzz_yyyyyy_1, tg_xxyyzzz_yyyyyz_0, tg_xxyyzzz_yyyyyz_1, tg_xxyyzzz_yyyyz_1, \
                                         tg_xxyyzzz_yyyyzz_0, tg_xxyyzzz_yyyyzz_1, tg_xxyyzzz_yyyzz_1, tg_xxyyzzz_yyyzzz_0, \
                                         tg_xxyyzzz_yyyzzz_1, tg_xxyyzzz_yyzzz_1, tg_xxyyzzz_yyzzzz_0, tg_xxyyzzz_yyzzzz_1, \
                                         tg_xxyyzzz_yzzzz_1, tg_xxyyzzz_yzzzzz_0, tg_xxyyzzz_yzzzzz_1, tg_xxyyzzz_zzzzz_1, \
                                         tg_xxyyzzz_zzzzzz_0, tg_xxyyzzz_zzzzzz_1, tg_xxyzzzz_xxxxx_1, tg_xxyzzzz_xxxxxx_0, \
                                         tg_xxyzzzz_xxxxxx_1, tg_xxyzzzz_xxxxxy_0, tg_xxyzzzz_xxxxxy_1, tg_xxyzzzz_xxxxxz_0, \
                                         tg_xxyzzzz_xxxxxz_1, tg_xxyzzzz_xxxxy_1, tg_xxyzzzz_xxxxyy_0, tg_xxyzzzz_xxxxyy_1, \
                                         tg_xxyzzzz_xxxxyz_0, tg_xxyzzzz_xxxxyz_1, tg_xxyzzzz_xxxxz_1, tg_xxyzzzz_xxxxzz_0, \
                                         tg_xxyzzzz_xxxxzz_1, tg_xxyzzzz_xxxyy_1, tg_xxyzzzz_xxxyyy_0, tg_xxyzzzz_xxxyyy_1, \
                                         tg_xxyzzzz_xxxyyz_0, tg_xxyzzzz_xxxyyz_1, tg_xxyzzzz_xxxyz_1, tg_xxyzzzz_xxxyzz_0, \
                                         tg_xxyzzzz_xxxyzz_1, tg_xxyzzzz_xxxzz_1, tg_xxyzzzz_xxxzzz_0, tg_xxyzzzz_xxxzzz_1, \
                                         tg_xxyzzzz_xxyyy_1, tg_xxyzzzz_xxyyyy_0, tg_xxyzzzz_xxyyyy_1, tg_xxyzzzz_xxyyyz_0, \
                                         tg_xxyzzzz_xxyyyz_1, tg_xxyzzzz_xxyyz_1, tg_xxyzzzz_xxyyzz_0, tg_xxyzzzz_xxyyzz_1, \
                                         tg_xxyzzzz_xxyzz_1, tg_xxyzzzz_xxyzzz_0, tg_xxyzzzz_xxyzzz_1, tg_xxyzzzz_xxzzz_1, \
                                         tg_xxyzzzz_xxzzzz_0, tg_xxyzzzz_xxzzzz_1, tg_xxyzzzz_xyyyy_1, tg_xxyzzzz_xyyyyy_0, \
                                         tg_xxyzzzz_xyyyyy_1, tg_xxyzzzz_xyyyyz_0, tg_xxyzzzz_xyyyyz_1, tg_xxyzzzz_xyyyz_1, \
                                         tg_xxyzzzz_xyyyzz_0, tg_xxyzzzz_xyyyzz_1, tg_xxyzzzz_xyyzz_1, tg_xxyzzzz_xyyzzz_0, \
                                         tg_xxyzzzz_xyyzzz_1, tg_xxyzzzz_xyzzz_1, tg_xxyzzzz_xyzzzz_0, tg_xxyzzzz_xyzzzz_1, \
                                         tg_xxyzzzz_xzzzz_1, tg_xxyzzzz_xzzzzz_0, tg_xxyzzzz_xzzzzz_1, tg_xxyzzzz_yyyyy_1, \
                                         tg_xxyzzzz_yyyyyy_0, tg_xxyzzzz_yyyyyy_1, tg_xxyzzzz_yyyyyz_0, tg_xxyzzzz_yyyyyz_1, \
                                         tg_xxyzzzz_yyyyz_1, tg_xxyzzzz_yyyyzz_0, tg_xxyzzzz_yyyyzz_1, tg_xxyzzzz_yyyzz_1, \
                                         tg_xxyzzzz_yyyzzz_0, tg_xxyzzzz_yyyzzz_1, tg_xxyzzzz_yyzzz_1, tg_xxyzzzz_yyzzzz_0, \
                                         tg_xxyzzzz_yyzzzz_1, tg_xxyzzzz_yzzzz_1, tg_xxyzzzz_yzzzzz_0, tg_xxyzzzz_yzzzzz_1, \
                                         tg_xxyzzzz_zzzzz_1, tg_xxyzzzz_zzzzzz_0, tg_xxyzzzz_zzzzzz_1, tg_xxzzzzz_xxxxx_1, \
                                         tg_xxzzzzz_xxxxxx_0, tg_xxzzzzz_xxxxxx_1, tg_xxzzzzz_xxxxxy_0, tg_xxzzzzz_xxxxxy_1, \
                                         tg_xxzzzzz_xxxxxz_0, tg_xxzzzzz_xxxxxz_1, tg_xxzzzzz_xxxxy_1, tg_xxzzzzz_xxxxyy_0, \
                                         tg_xxzzzzz_xxxxyy_1, tg_xxzzzzz_xxxxyz_0, tg_xxzzzzz_xxxxyz_1, tg_xxzzzzz_xxxxz_1, \
                                         tg_xxzzzzz_xxxxzz_0, tg_xxzzzzz_xxxxzz_1, tg_xxzzzzz_xxxyy_1, tg_xxzzzzz_xxxyyy_0, \
                                         tg_xxzzzzz_xxxyyy_1, tg_xxzzzzz_xxxyyz_0, tg_xxzzzzz_xxxyyz_1, tg_xxzzzzz_xxxyz_1, \
                                         tg_xxzzzzz_xxxyzz_0, tg_xxzzzzz_xxxyzz_1, tg_xxzzzzz_xxxzz_1, tg_xxzzzzz_xxxzzz_0, \
                                         tg_xxzzzzz_xxxzzz_1, tg_xxzzzzz_xxyyy_1, tg_xxzzzzz_xxyyyy_0, tg_xxzzzzz_xxyyyy_1, \
                                         tg_xxzzzzz_xxyyyz_0, tg_xxzzzzz_xxyyyz_1, tg_xxzzzzz_xxyyz_1, tg_xxzzzzz_xxyyzz_0, \
                                         tg_xxzzzzz_xxyyzz_1, tg_xxzzzzz_xxyzz_1, tg_xxzzzzz_xxyzzz_0, tg_xxzzzzz_xxyzzz_1, \
                                         tg_xxzzzzz_xxzzz_1, tg_xxzzzzz_xxzzzz_0, tg_xxzzzzz_xxzzzz_1, tg_xxzzzzz_xyyyy_1, \
                                         tg_xxzzzzz_xyyyyy_0, tg_xxzzzzz_xyyyyy_1, tg_xxzzzzz_xyyyyz_0, tg_xxzzzzz_xyyyyz_1, \
                                         tg_xxzzzzz_xyyyz_1, tg_xxzzzzz_xyyyzz_0, tg_xxzzzzz_xyyyzz_1, tg_xxzzzzz_xyyzz_1, \
                                         tg_xxzzzzz_xyyzzz_0, tg_xxzzzzz_xyyzzz_1, tg_xxzzzzz_xyzzz_1, tg_xxzzzzz_xyzzzz_0, \
                                         tg_xxzzzzz_xyzzzz_1, tg_xxzzzzz_xzzzz_1, tg_xxzzzzz_xzzzzz_0, tg_xxzzzzz_xzzzzz_1, \
                                         tg_xxzzzzz_yyyyy_1, tg_xxzzzzz_yyyyyy_0, tg_xxzzzzz_yyyyyy_1, tg_xxzzzzz_yyyyz_1, \
                                         tg_xxzzzzz_yyyzz_1, tg_xxzzzzz_yyzzz_1, tg_xxzzzzz_yzzzz_1, tg_xxzzzzz_zzzzz_1, \
                                         tg_xyyyzz_xxxzzz_0, tg_xyyyzz_xxxzzz_1, tg_xyyyzz_xxyyyy_0, tg_xyyyzz_xxyyyy_1, \
                                         tg_xyyyzz_xxyyyz_0, tg_xyyyzz_xxyyyz_1, tg_xyyyzz_xxyyzz_0, tg_xyyyzz_xxyyzz_1, \
                                         tg_xyyyzz_xxyzzz_0, tg_xyyyzz_xxyzzz_1, tg_xyyyzz_xxzzzz_0, tg_xyyyzz_xxzzzz_1, \
                                         tg_xyyyzz_xyyyyy_0, tg_xyyyzz_xyyyyy_1, tg_xyyyzz_xyyyyz_0, tg_xyyyzz_xyyyyz_1, \
                                         tg_xyyyzz_xyyyzz_0, tg_xyyyzz_xyyyzz_1, tg_xyyyzz_xyyzzz_0, tg_xyyyzz_xyyzzz_1, \
                                         tg_xyyyzz_xyzzzz_0, tg_xyyyzz_xyzzzz_1, tg_xyyyzz_xzzzzz_0, tg_xyyyzz_xzzzzz_1, \
                                         tg_xyyyzz_yyyyyy_0, tg_xyyyzz_yyyyyy_1, tg_xyyyzz_yyyyyz_0, tg_xyyyzz_yyyyyz_1, \
                                         tg_xyyyzz_yyyyzz_0, tg_xyyyzz_yyyyzz_1, tg_xyyyzz_yyyzzz_0, tg_xyyyzz_yyyzzz_1, \
                                         tg_xyyyzz_yyzzzz_0, tg_xyyyzz_yyzzzz_1, tg_xyyyzz_yzzzzz_0, tg_xyyyzz_yzzzzz_1, \
                                         tg_xyyyzz_zzzzzz_0, tg_xyyyzz_zzzzzz_1, tg_xyyzzz_xxxxxx_0, tg_xyyzzz_xxxxxx_1, \
                                         tg_xyyzzz_xxxxxy_0, tg_xyyzzz_xxxxxy_1, tg_xyyzzz_xxxxxz_0, tg_xyyzzz_xxxxxz_1, \
                                         tg_xyyzzz_xxxxyy_0, tg_xyyzzz_xxxxyy_1, tg_xyyzzz_xxxxyz_0, tg_xyyzzz_xxxxyz_1, \
                                         tg_xyyzzz_xxxxzz_0, tg_xyyzzz_xxxxzz_1, tg_xyyzzz_xxxyyy_0, tg_xyyzzz_xxxyyy_1, \
                                         tg_xyyzzz_xxxyyz_0, tg_xyyzzz_xxxyyz_1, tg_xyyzzz_xxxyzz_0, tg_xyyzzz_xxxyzz_1, \
                                         tg_xyyzzz_xxxzzz_0, tg_xyyzzz_xxxzzz_1, tg_xyyzzz_xxyyyy_0, tg_xyyzzz_xxyyyy_1, \
                                         tg_xyyzzz_xxyyyz_0, tg_xyyzzz_xxyyyz_1, tg_xyyzzz_xxyyzz_0, tg_xyyzzz_xxyyzz_1, \
                                         tg_xyyzzz_xxyzzz_0, tg_xyyzzz_xxyzzz_1, tg_xyyzzz_xxzzzz_0, tg_xyyzzz_xxzzzz_1, \
                                         tg_xyyzzz_xyyyyy_0, tg_xyyzzz_xyyyyy_1, tg_xyyzzz_xyyyyz_0, tg_xyyzzz_xyyyyz_1, \
                                         tg_xyyzzz_xyyyzz_0, tg_xyyzzz_xyyyzz_1, tg_xyyzzz_xyyzzz_0, tg_xyyzzz_xyyzzz_1, \
                                         tg_xyyzzz_xyzzzz_0, tg_xyyzzz_xyzzzz_1, tg_xyyzzz_xzzzzz_0, tg_xyyzzz_xzzzzz_1, \
                                         tg_xyyzzz_yyyyyy_0, tg_xyyzzz_yyyyyy_1, tg_xyyzzz_yyyyyz_0, tg_xyyzzz_yyyyyz_1, \
                                         tg_xyyzzz_yyyyzz_0, tg_xyyzzz_yyyyzz_1, tg_xyyzzz_yyyzzz_0, tg_xyyzzz_yyyzzz_1, \
                                         tg_xyyzzz_yyzzzz_0, tg_xyyzzz_yyzzzz_1, tg_xyyzzz_yzzzzz_0, tg_xyyzzz_yzzzzz_1, \
                                         tg_xyyzzz_zzzzzz_0, tg_xyyzzz_zzzzzz_1, tg_xyzzzz_xxxxxx_0, tg_xyzzzz_xxxxxx_1, \
                                         tg_xyzzzz_xxxxxy_0, tg_xyzzzz_xxxxxy_1, tg_xyzzzz_xxxxxz_0, tg_xyzzzz_xxxxxz_1, \
                                         tg_xyzzzz_xxxxyy_0, tg_xyzzzz_xxxxyy_1, tg_xyzzzz_xxxxyz_0, tg_xyzzzz_xxxxyz_1, \
                                         tg_xyzzzz_xxxxzz_0, tg_xyzzzz_xxxxzz_1, tg_xyzzzz_xxxyyy_0, tg_xyzzzz_xxxyyy_1, \
                                         tg_xyzzzz_xxxyyz_0, tg_xyzzzz_xxxyyz_1, tg_xyzzzz_xxxyzz_0, tg_xyzzzz_xxxyzz_1, \
                                         tg_xyzzzz_xxxzzz_0, tg_xyzzzz_xxxzzz_1, tg_xyzzzz_xxyyyy_0, tg_xyzzzz_xxyyyy_1, \
                                         tg_xyzzzz_xxyyyz_0, tg_xyzzzz_xxyyyz_1, tg_xyzzzz_xxyyzz_0, tg_xyzzzz_xxyyzz_1, \
                                         tg_xyzzzz_xxyzzz_0, tg_xyzzzz_xxyzzz_1, tg_xyzzzz_xxzzzz_0, tg_xyzzzz_xxzzzz_1, \
                                         tg_xyzzzz_xyyyyy_0, tg_xyzzzz_xyyyyy_1, tg_xyzzzz_xyyyyz_0, tg_xyzzzz_xyyyyz_1, \
                                         tg_xyzzzz_xyyyzz_0, tg_xyzzzz_xyyyzz_1, tg_xyzzzz_xyyzzz_0, tg_xyzzzz_xyyzzz_1, \
                                         tg_xyzzzz_xyzzzz_0, tg_xyzzzz_xyzzzz_1, tg_xyzzzz_xzzzzz_0, tg_xyzzzz_xzzzzz_1, \
                                         tg_xyzzzz_yyyyyy_0, tg_xyzzzz_yyyyyy_1, tg_xyzzzz_yyyyyz_0, tg_xyzzzz_yyyyyz_1, \
                                         tg_xyzzzz_yyyyzz_0, tg_xyzzzz_yyyyzz_1, tg_xyzzzz_yyyzzz_0, tg_xyzzzz_yyyzzz_1, \
                                         tg_xyzzzz_yyzzzz_0, tg_xyzzzz_yyzzzz_1, tg_xyzzzz_yzzzzz_0, tg_xyzzzz_yzzzzz_1, \
                                         tg_xyzzzz_zzzzzz_0, tg_xyzzzz_zzzzzz_1, tg_xzzzzz_xxxxxx_0, tg_xzzzzz_xxxxxx_1, \
                                         tg_xzzzzz_xxxxxy_0, tg_xzzzzz_xxxxxy_1, tg_xzzzzz_xxxxxz_0, tg_xzzzzz_xxxxxz_1, \
                                         tg_xzzzzz_xxxxyy_0, tg_xzzzzz_xxxxyy_1, tg_xzzzzz_xxxxyz_0, tg_xzzzzz_xxxxyz_1, \
                                         tg_xzzzzz_xxxxzz_0, tg_xzzzzz_xxxxzz_1, tg_xzzzzz_xxxyyy_0, tg_xzzzzz_xxxyyy_1, \
                                         tg_xzzzzz_xxxyyz_0, tg_xzzzzz_xxxyyz_1, tg_xzzzzz_xxxyzz_0, tg_xzzzzz_xxxyzz_1, \
                                         tg_xzzzzz_xxxzzz_0, tg_xzzzzz_xxxzzz_1, tg_xzzzzz_xxyyyy_0, tg_xzzzzz_xxyyyy_1, \
                                         tg_xzzzzz_xxyyyz_0, tg_xzzzzz_xxyyyz_1, tg_xzzzzz_xxyyzz_0, tg_xzzzzz_xxyyzz_1, \
                                         tg_xzzzzz_xxyzzz_0, tg_xzzzzz_xxyzzz_1, tg_xzzzzz_xxzzzz_0, tg_xzzzzz_xxzzzz_1, \
                                         tg_xzzzzz_xyyyyy_0, tg_xzzzzz_xyyyyy_1, tg_xzzzzz_xyyyyz_0, tg_xzzzzz_xyyyyz_1, \
                                         tg_xzzzzz_xyyyzz_0, tg_xzzzzz_xyyyzz_1, tg_xzzzzz_xyyzzz_0, tg_xzzzzz_xyyzzz_1, \
                                         tg_xzzzzz_xyzzzz_0, tg_xzzzzz_xyzzzz_1, tg_xzzzzz_xzzzzz_0, tg_xzzzzz_xzzzzz_1, \
                                         tg_xzzzzz_yyyyyy_0, tg_xzzzzz_yyyyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxyyyzz_xxxzzz_0[j] = pb_x * tg_xxyyyzz_xxxzzz_0[j] + fr * tg_xxyyyzz_xxxzzz_1[j] + fl1_fx * (tg_xyyyzz_xxxzzz_0[j] - tg_xyyyzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyyzz_xxzzz_1[j];

                    tg_xxxyyyzz_xxyyyy_0[j] = pb_x * tg_xxyyyzz_xxyyyy_0[j] + fr * tg_xxyyyzz_xxyyyy_1[j] + fl1_fx * (tg_xyyyzz_xxyyyy_0[j] - tg_xyyyzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_xyyyy_1[j];

                    tg_xxxyyyzz_xxyyyz_0[j] = pb_x * tg_xxyyyzz_xxyyyz_0[j] + fr * tg_xxyyyzz_xxyyyz_1[j] + fl1_fx * (tg_xyyyzz_xxyyyz_0[j] - tg_xyyyzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_xyyyz_1[j];

                    tg_xxxyyyzz_xxyyzz_0[j] = pb_x * tg_xxyyyzz_xxyyzz_0[j] + fr * tg_xxyyyzz_xxyyzz_1[j] + fl1_fx * (tg_xyyyzz_xxyyzz_0[j] - tg_xyyyzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_xyyzz_1[j];

                    tg_xxxyyyzz_xxyzzz_0[j] = pb_x * tg_xxyyyzz_xxyzzz_0[j] + fr * tg_xxyyyzz_xxyzzz_1[j] + fl1_fx * (tg_xyyyzz_xxyzzz_0[j] - tg_xyyyzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_xyzzz_1[j];

                    tg_xxxyyyzz_xxzzzz_0[j] = pb_x * tg_xxyyyzz_xxzzzz_0[j] + fr * tg_xxyyyzz_xxzzzz_1[j] + fl1_fx * (tg_xyyyzz_xxzzzz_0[j] - tg_xyyyzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyyzz_xzzzz_1[j];

                    tg_xxxyyyzz_xyyyyy_0[j] = pb_x * tg_xxyyyzz_xyyyyy_0[j] + fr * tg_xxyyyzz_xyyyyy_1[j] + fl1_fx * (tg_xyyyzz_xyyyyy_0[j] - tg_xyyyzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_yyyyy_1[j];

                    tg_xxxyyyzz_xyyyyz_0[j] = pb_x * tg_xxyyyzz_xyyyyz_0[j] + fr * tg_xxyyyzz_xyyyyz_1[j] + fl1_fx * (tg_xyyyzz_xyyyyz_0[j] - tg_xyyyzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_yyyyz_1[j];

                    tg_xxxyyyzz_xyyyzz_0[j] = pb_x * tg_xxyyyzz_xyyyzz_0[j] + fr * tg_xxyyyzz_xyyyzz_1[j] + fl1_fx * (tg_xyyyzz_xyyyzz_0[j] - tg_xyyyzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_yyyzz_1[j];

                    tg_xxxyyyzz_xyyzzz_0[j] = pb_x * tg_xxyyyzz_xyyzzz_0[j] + fr * tg_xxyyyzz_xyyzzz_1[j] + fl1_fx * (tg_xyyyzz_xyyzzz_0[j] - tg_xyyyzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_yyzzz_1[j];

                    tg_xxxyyyzz_xyzzzz_0[j] = pb_x * tg_xxyyyzz_xyzzzz_0[j] + fr * tg_xxyyyzz_xyzzzz_1[j] + fl1_fx * (tg_xyyyzz_xyzzzz_0[j] - tg_xyyyzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_yzzzz_1[j];

                    tg_xxxyyyzz_xzzzzz_0[j] = pb_x * tg_xxyyyzz_xzzzzz_0[j] + fr * tg_xxyyyzz_xzzzzz_1[j] + fl1_fx * (tg_xyyyzz_xzzzzz_0[j] - tg_xyyyzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyyzz_zzzzz_1[j];

                    tg_xxxyyyzz_yyyyyy_0[j] = pb_x * tg_xxyyyzz_yyyyyy_0[j] + fr * tg_xxyyyzz_yyyyyy_1[j] + fl1_fx * (tg_xyyyzz_yyyyyy_0[j] - tg_xyyyzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxyyyzz_yyyyyz_0[j] = pb_x * tg_xxyyyzz_yyyyyz_0[j] + fr * tg_xxyyyzz_yyyyyz_1[j] + fl1_fx * (tg_xyyyzz_yyyyyz_0[j] - tg_xyyyzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxyyyzz_yyyyzz_0[j] = pb_x * tg_xxyyyzz_yyyyzz_0[j] + fr * tg_xxyyyzz_yyyyzz_1[j] + fl1_fx * (tg_xyyyzz_yyyyzz_0[j] - tg_xyyyzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxyyyzz_yyyzzz_0[j] = pb_x * tg_xxyyyzz_yyyzzz_0[j] + fr * tg_xxyyyzz_yyyzzz_1[j] + fl1_fx * (tg_xyyyzz_yyyzzz_0[j] - tg_xyyyzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxyyyzz_yyzzzz_0[j] = pb_x * tg_xxyyyzz_yyzzzz_0[j] + fr * tg_xxyyyzz_yyzzzz_1[j] + fl1_fx * (tg_xyyyzz_yyzzzz_0[j] - tg_xyyyzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxyyyzz_yzzzzz_0[j] = pb_x * tg_xxyyyzz_yzzzzz_0[j] + fr * tg_xxyyyzz_yzzzzz_1[j] + fl1_fx * (tg_xyyyzz_yzzzzz_0[j] - tg_xyyyzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxyyyzz_zzzzzz_0[j] = pb_x * tg_xxyyyzz_zzzzzz_0[j] + fr * tg_xxyyyzz_zzzzzz_1[j] + fl1_fx * (tg_xyyyzz_zzzzzz_0[j] - tg_xyyyzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxyyzzz_xxxxxx_0[j] = pb_x * tg_xxyyzzz_xxxxxx_0[j] + fr * tg_xxyyzzz_xxxxxx_1[j] + fl1_fx * (tg_xyyzzz_xxxxxx_0[j] - tg_xyyzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyyzzz_xxxxx_1[j];

                    tg_xxxyyzzz_xxxxxy_0[j] = pb_x * tg_xxyyzzz_xxxxxy_0[j] + fr * tg_xxyyzzz_xxxxxy_1[j] + fl1_fx * (tg_xyyzzz_xxxxxy_0[j] - tg_xyyzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyzzz_xxxxy_1[j];

                    tg_xxxyyzzz_xxxxxz_0[j] = pb_x * tg_xxyyzzz_xxxxxz_0[j] + fr * tg_xxyyzzz_xxxxxz_1[j] + fl1_fx * (tg_xyyzzz_xxxxxz_0[j] - tg_xyyzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyyzzz_xxxxz_1[j];

                    tg_xxxyyzzz_xxxxyy_0[j] = pb_x * tg_xxyyzzz_xxxxyy_0[j] + fr * tg_xxyyzzz_xxxxyy_1[j] + fl1_fx * (tg_xyyzzz_xxxxyy_0[j] - tg_xyyzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzzz_xxxyy_1[j];

                    tg_xxxyyzzz_xxxxyz_0[j] = pb_x * tg_xxyyzzz_xxxxyz_0[j] + fr * tg_xxyyzzz_xxxxyz_1[j] + fl1_fx * (tg_xyyzzz_xxxxyz_0[j] - tg_xyyzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzzz_xxxyz_1[j];

                    tg_xxxyyzzz_xxxxzz_0[j] = pb_x * tg_xxyyzzz_xxxxzz_0[j] + fr * tg_xxyyzzz_xxxxzz_1[j] + fl1_fx * (tg_xyyzzz_xxxxzz_0[j] - tg_xyyzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyyzzz_xxxzz_1[j];

                    tg_xxxyyzzz_xxxyyy_0[j] = pb_x * tg_xxyyzzz_xxxyyy_0[j] + fr * tg_xxyyzzz_xxxyyy_1[j] + fl1_fx * (tg_xyyzzz_xxxyyy_0[j] - tg_xyyzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzzz_xxyyy_1[j];

                    tg_xxxyyzzz_xxxyyz_0[j] = pb_x * tg_xxyyzzz_xxxyyz_0[j] + fr * tg_xxyyzzz_xxxyyz_1[j] + fl1_fx * (tg_xyyzzz_xxxyyz_0[j] - tg_xyyzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzzz_xxyyz_1[j];

                    tg_xxxyyzzz_xxxyzz_0[j] = pb_x * tg_xxyyzzz_xxxyzz_0[j] + fr * tg_xxyyzzz_xxxyzz_1[j] + fl1_fx * (tg_xyyzzz_xxxyzz_0[j] - tg_xyyzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzzz_xxyzz_1[j];

                    tg_xxxyyzzz_xxxzzz_0[j] = pb_x * tg_xxyyzzz_xxxzzz_0[j] + fr * tg_xxyyzzz_xxxzzz_1[j] + fl1_fx * (tg_xyyzzz_xxxzzz_0[j] - tg_xyyzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyyzzz_xxzzz_1[j];

                    tg_xxxyyzzz_xxyyyy_0[j] = pb_x * tg_xxyyzzz_xxyyyy_0[j] + fr * tg_xxyyzzz_xxyyyy_1[j] + fl1_fx * (tg_xyyzzz_xxyyyy_0[j] - tg_xyyzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_xyyyy_1[j];

                    tg_xxxyyzzz_xxyyyz_0[j] = pb_x * tg_xxyyzzz_xxyyyz_0[j] + fr * tg_xxyyzzz_xxyyyz_1[j] + fl1_fx * (tg_xyyzzz_xxyyyz_0[j] - tg_xyyzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_xyyyz_1[j];

                    tg_xxxyyzzz_xxyyzz_0[j] = pb_x * tg_xxyyzzz_xxyyzz_0[j] + fr * tg_xxyyzzz_xxyyzz_1[j] + fl1_fx * (tg_xyyzzz_xxyyzz_0[j] - tg_xyyzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_xyyzz_1[j];

                    tg_xxxyyzzz_xxyzzz_0[j] = pb_x * tg_xxyyzzz_xxyzzz_0[j] + fr * tg_xxyyzzz_xxyzzz_1[j] + fl1_fx * (tg_xyyzzz_xxyzzz_0[j] - tg_xyyzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_xyzzz_1[j];

                    tg_xxxyyzzz_xxzzzz_0[j] = pb_x * tg_xxyyzzz_xxzzzz_0[j] + fr * tg_xxyyzzz_xxzzzz_1[j] + fl1_fx * (tg_xyyzzz_xxzzzz_0[j] - tg_xyyzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyyzzz_xzzzz_1[j];

                    tg_xxxyyzzz_xyyyyy_0[j] = pb_x * tg_xxyyzzz_xyyyyy_0[j] + fr * tg_xxyyzzz_xyyyyy_1[j] + fl1_fx * (tg_xyyzzz_xyyyyy_0[j] - tg_xyyzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_yyyyy_1[j];

                    tg_xxxyyzzz_xyyyyz_0[j] = pb_x * tg_xxyyzzz_xyyyyz_0[j] + fr * tg_xxyyzzz_xyyyyz_1[j] + fl1_fx * (tg_xyyzzz_xyyyyz_0[j] - tg_xyyzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_yyyyz_1[j];

                    tg_xxxyyzzz_xyyyzz_0[j] = pb_x * tg_xxyyzzz_xyyyzz_0[j] + fr * tg_xxyyzzz_xyyyzz_1[j] + fl1_fx * (tg_xyyzzz_xyyyzz_0[j] - tg_xyyzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_yyyzz_1[j];

                    tg_xxxyyzzz_xyyzzz_0[j] = pb_x * tg_xxyyzzz_xyyzzz_0[j] + fr * tg_xxyyzzz_xyyzzz_1[j] + fl1_fx * (tg_xyyzzz_xyyzzz_0[j] - tg_xyyzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_yyzzz_1[j];

                    tg_xxxyyzzz_xyzzzz_0[j] = pb_x * tg_xxyyzzz_xyzzzz_0[j] + fr * tg_xxyyzzz_xyzzzz_1[j] + fl1_fx * (tg_xyyzzz_xyzzzz_0[j] - tg_xyyzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_yzzzz_1[j];

                    tg_xxxyyzzz_xzzzzz_0[j] = pb_x * tg_xxyyzzz_xzzzzz_0[j] + fr * tg_xxyyzzz_xzzzzz_1[j] + fl1_fx * (tg_xyyzzz_xzzzzz_0[j] - tg_xyyzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyyzzz_zzzzz_1[j];

                    tg_xxxyyzzz_yyyyyy_0[j] = pb_x * tg_xxyyzzz_yyyyyy_0[j] + fr * tg_xxyyzzz_yyyyyy_1[j] + fl1_fx * (tg_xyyzzz_yyyyyy_0[j] - tg_xyyzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxyyzzz_yyyyyz_0[j] = pb_x * tg_xxyyzzz_yyyyyz_0[j] + fr * tg_xxyyzzz_yyyyyz_1[j] + fl1_fx * (tg_xyyzzz_yyyyyz_0[j] - tg_xyyzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxyyzzz_yyyyzz_0[j] = pb_x * tg_xxyyzzz_yyyyzz_0[j] + fr * tg_xxyyzzz_yyyyzz_1[j] + fl1_fx * (tg_xyyzzz_yyyyzz_0[j] - tg_xyyzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxyyzzz_yyyzzz_0[j] = pb_x * tg_xxyyzzz_yyyzzz_0[j] + fr * tg_xxyyzzz_yyyzzz_1[j] + fl1_fx * (tg_xyyzzz_yyyzzz_0[j] - tg_xyyzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxyyzzz_yyzzzz_0[j] = pb_x * tg_xxyyzzz_yyzzzz_0[j] + fr * tg_xxyyzzz_yyzzzz_1[j] + fl1_fx * (tg_xyyzzz_yyzzzz_0[j] - tg_xyyzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxyyzzz_yzzzzz_0[j] = pb_x * tg_xxyyzzz_yzzzzz_0[j] + fr * tg_xxyyzzz_yzzzzz_1[j] + fl1_fx * (tg_xyyzzz_yzzzzz_0[j] - tg_xyyzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxyyzzz_zzzzzz_0[j] = pb_x * tg_xxyyzzz_zzzzzz_0[j] + fr * tg_xxyyzzz_zzzzzz_1[j] + fl1_fx * (tg_xyyzzz_zzzzzz_0[j] - tg_xyyzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxyzzzz_xxxxxx_0[j] = pb_x * tg_xxyzzzz_xxxxxx_0[j] + fr * tg_xxyzzzz_xxxxxx_1[j] + fl1_fx * (tg_xyzzzz_xxxxxx_0[j] - tg_xyzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxyzzzz_xxxxx_1[j];

                    tg_xxxyzzzz_xxxxxy_0[j] = pb_x * tg_xxyzzzz_xxxxxy_0[j] + fr * tg_xxyzzzz_xxxxxy_1[j] + fl1_fx * (tg_xyzzzz_xxxxxy_0[j] - tg_xyzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzzzz_xxxxy_1[j];

                    tg_xxxyzzzz_xxxxxz_0[j] = pb_x * tg_xxyzzzz_xxxxxz_0[j] + fr * tg_xxyzzzz_xxxxxz_1[j] + fl1_fx * (tg_xyzzzz_xxxxxz_0[j] - tg_xyzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxyzzzz_xxxxz_1[j];

                    tg_xxxyzzzz_xxxxyy_0[j] = pb_x * tg_xxyzzzz_xxxxyy_0[j] + fr * tg_xxyzzzz_xxxxyy_1[j] + fl1_fx * (tg_xyzzzz_xxxxyy_0[j] - tg_xyzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzzz_xxxyy_1[j];

                    tg_xxxyzzzz_xxxxyz_0[j] = pb_x * tg_xxyzzzz_xxxxyz_0[j] + fr * tg_xxyzzzz_xxxxyz_1[j] + fl1_fx * (tg_xyzzzz_xxxxyz_0[j] - tg_xyzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzzz_xxxyz_1[j];

                    tg_xxxyzzzz_xxxxzz_0[j] = pb_x * tg_xxyzzzz_xxxxzz_0[j] + fr * tg_xxyzzzz_xxxxzz_1[j] + fl1_fx * (tg_xyzzzz_xxxxzz_0[j] - tg_xyzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxyzzzz_xxxzz_1[j];

                    tg_xxxyzzzz_xxxyyy_0[j] = pb_x * tg_xxyzzzz_xxxyyy_0[j] + fr * tg_xxyzzzz_xxxyyy_1[j] + fl1_fx * (tg_xyzzzz_xxxyyy_0[j] - tg_xyzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzzz_xxyyy_1[j];

                    tg_xxxyzzzz_xxxyyz_0[j] = pb_x * tg_xxyzzzz_xxxyyz_0[j] + fr * tg_xxyzzzz_xxxyyz_1[j] + fl1_fx * (tg_xyzzzz_xxxyyz_0[j] - tg_xyzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzzz_xxyyz_1[j];

                    tg_xxxyzzzz_xxxyzz_0[j] = pb_x * tg_xxyzzzz_xxxyzz_0[j] + fr * tg_xxyzzzz_xxxyzz_1[j] + fl1_fx * (tg_xyzzzz_xxxyzz_0[j] - tg_xyzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzzz_xxyzz_1[j];

                    tg_xxxyzzzz_xxxzzz_0[j] = pb_x * tg_xxyzzzz_xxxzzz_0[j] + fr * tg_xxyzzzz_xxxzzz_1[j] + fl1_fx * (tg_xyzzzz_xxxzzz_0[j] - tg_xyzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxyzzzz_xxzzz_1[j];

                    tg_xxxyzzzz_xxyyyy_0[j] = pb_x * tg_xxyzzzz_xxyyyy_0[j] + fr * tg_xxyzzzz_xxyyyy_1[j] + fl1_fx * (tg_xyzzzz_xxyyyy_0[j] - tg_xyzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_xyyyy_1[j];

                    tg_xxxyzzzz_xxyyyz_0[j] = pb_x * tg_xxyzzzz_xxyyyz_0[j] + fr * tg_xxyzzzz_xxyyyz_1[j] + fl1_fx * (tg_xyzzzz_xxyyyz_0[j] - tg_xyzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_xyyyz_1[j];

                    tg_xxxyzzzz_xxyyzz_0[j] = pb_x * tg_xxyzzzz_xxyyzz_0[j] + fr * tg_xxyzzzz_xxyyzz_1[j] + fl1_fx * (tg_xyzzzz_xxyyzz_0[j] - tg_xyzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_xyyzz_1[j];

                    tg_xxxyzzzz_xxyzzz_0[j] = pb_x * tg_xxyzzzz_xxyzzz_0[j] + fr * tg_xxyzzzz_xxyzzz_1[j] + fl1_fx * (tg_xyzzzz_xxyzzz_0[j] - tg_xyzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_xyzzz_1[j];

                    tg_xxxyzzzz_xxzzzz_0[j] = pb_x * tg_xxyzzzz_xxzzzz_0[j] + fr * tg_xxyzzzz_xxzzzz_1[j] + fl1_fx * (tg_xyzzzz_xxzzzz_0[j] - tg_xyzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxyzzzz_xzzzz_1[j];

                    tg_xxxyzzzz_xyyyyy_0[j] = pb_x * tg_xxyzzzz_xyyyyy_0[j] + fr * tg_xxyzzzz_xyyyyy_1[j] + fl1_fx * (tg_xyzzzz_xyyyyy_0[j] - tg_xyzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_yyyyy_1[j];

                    tg_xxxyzzzz_xyyyyz_0[j] = pb_x * tg_xxyzzzz_xyyyyz_0[j] + fr * tg_xxyzzzz_xyyyyz_1[j] + fl1_fx * (tg_xyzzzz_xyyyyz_0[j] - tg_xyzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_yyyyz_1[j];

                    tg_xxxyzzzz_xyyyzz_0[j] = pb_x * tg_xxyzzzz_xyyyzz_0[j] + fr * tg_xxyzzzz_xyyyzz_1[j] + fl1_fx * (tg_xyzzzz_xyyyzz_0[j] - tg_xyzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_yyyzz_1[j];

                    tg_xxxyzzzz_xyyzzz_0[j] = pb_x * tg_xxyzzzz_xyyzzz_0[j] + fr * tg_xxyzzzz_xyyzzz_1[j] + fl1_fx * (tg_xyzzzz_xyyzzz_0[j] - tg_xyzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_yyzzz_1[j];

                    tg_xxxyzzzz_xyzzzz_0[j] = pb_x * tg_xxyzzzz_xyzzzz_0[j] + fr * tg_xxyzzzz_xyzzzz_1[j] + fl1_fx * (tg_xyzzzz_xyzzzz_0[j] - tg_xyzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_yzzzz_1[j];

                    tg_xxxyzzzz_xzzzzz_0[j] = pb_x * tg_xxyzzzz_xzzzzz_0[j] + fr * tg_xxyzzzz_xzzzzz_1[j] + fl1_fx * (tg_xyzzzz_xzzzzz_0[j] - tg_xyzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxyzzzz_zzzzz_1[j];

                    tg_xxxyzzzz_yyyyyy_0[j] = pb_x * tg_xxyzzzz_yyyyyy_0[j] + fr * tg_xxyzzzz_yyyyyy_1[j] + fl1_fx * (tg_xyzzzz_yyyyyy_0[j] - tg_xyzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxxyzzzz_yyyyyz_0[j] = pb_x * tg_xxyzzzz_yyyyyz_0[j] + fr * tg_xxyzzzz_yyyyyz_1[j] + fl1_fx * (tg_xyzzzz_yyyyyz_0[j] - tg_xyzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxyzzzz_yyyyzz_0[j] = pb_x * tg_xxyzzzz_yyyyzz_0[j] + fr * tg_xxyzzzz_yyyyzz_1[j] + fl1_fx * (tg_xyzzzz_yyyyzz_0[j] - tg_xyzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxyzzzz_yyyzzz_0[j] = pb_x * tg_xxyzzzz_yyyzzz_0[j] + fr * tg_xxyzzzz_yyyzzz_1[j] + fl1_fx * (tg_xyzzzz_yyyzzz_0[j] - tg_xyzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxyzzzz_yyzzzz_0[j] = pb_x * tg_xxyzzzz_yyzzzz_0[j] + fr * tg_xxyzzzz_yyzzzz_1[j] + fl1_fx * (tg_xyzzzz_yyzzzz_0[j] - tg_xyzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxyzzzz_yzzzzz_0[j] = pb_x * tg_xxyzzzz_yzzzzz_0[j] + fr * tg_xxyzzzz_yzzzzz_1[j] + fl1_fx * (tg_xyzzzz_yzzzzz_0[j] - tg_xyzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxyzzzz_zzzzzz_0[j] = pb_x * tg_xxyzzzz_zzzzzz_0[j] + fr * tg_xxyzzzz_zzzzzz_1[j] + fl1_fx * (tg_xyzzzz_zzzzzz_0[j] - tg_xyzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxxzzzzz_xxxxxx_0[j] = pb_x * tg_xxzzzzz_xxxxxx_0[j] + fr * tg_xxzzzzz_xxxxxx_1[j] + fl1_fx * (tg_xzzzzz_xxxxxx_0[j] - tg_xzzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xxzzzzz_xxxxx_1[j];

                    tg_xxxzzzzz_xxxxxy_0[j] = pb_x * tg_xxzzzzz_xxxxxy_0[j] + fr * tg_xxzzzzz_xxxxxy_1[j] + fl1_fx * (tg_xzzzzz_xxxxxy_0[j] - tg_xzzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzzzz_xxxxy_1[j];

                    tg_xxxzzzzz_xxxxxz_0[j] = pb_x * tg_xxzzzzz_xxxxxz_0[j] + fr * tg_xxzzzzz_xxxxxz_1[j] + fl1_fx * (tg_xzzzzz_xxxxxz_0[j] - tg_xzzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xxzzzzz_xxxxz_1[j];

                    tg_xxxzzzzz_xxxxyy_0[j] = pb_x * tg_xxzzzzz_xxxxyy_0[j] + fr * tg_xxzzzzz_xxxxyy_1[j] + fl1_fx * (tg_xzzzzz_xxxxyy_0[j] - tg_xzzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzzz_xxxyy_1[j];

                    tg_xxxzzzzz_xxxxyz_0[j] = pb_x * tg_xxzzzzz_xxxxyz_0[j] + fr * tg_xxzzzzz_xxxxyz_1[j] + fl1_fx * (tg_xzzzzz_xxxxyz_0[j] - tg_xzzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzzz_xxxyz_1[j];

                    tg_xxxzzzzz_xxxxzz_0[j] = pb_x * tg_xxzzzzz_xxxxzz_0[j] + fr * tg_xxzzzzz_xxxxzz_1[j] + fl1_fx * (tg_xzzzzz_xxxxzz_0[j] - tg_xzzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xxzzzzz_xxxzz_1[j];

                    tg_xxxzzzzz_xxxyyy_0[j] = pb_x * tg_xxzzzzz_xxxyyy_0[j] + fr * tg_xxzzzzz_xxxyyy_1[j] + fl1_fx * (tg_xzzzzz_xxxyyy_0[j] - tg_xzzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzzz_xxyyy_1[j];

                    tg_xxxzzzzz_xxxyyz_0[j] = pb_x * tg_xxzzzzz_xxxyyz_0[j] + fr * tg_xxzzzzz_xxxyyz_1[j] + fl1_fx * (tg_xzzzzz_xxxyyz_0[j] - tg_xzzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzzz_xxyyz_1[j];

                    tg_xxxzzzzz_xxxyzz_0[j] = pb_x * tg_xxzzzzz_xxxyzz_0[j] + fr * tg_xxzzzzz_xxxyzz_1[j] + fl1_fx * (tg_xzzzzz_xxxyzz_0[j] - tg_xzzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzzz_xxyzz_1[j];

                    tg_xxxzzzzz_xxxzzz_0[j] = pb_x * tg_xxzzzzz_xxxzzz_0[j] + fr * tg_xxzzzzz_xxxzzz_1[j] + fl1_fx * (tg_xzzzzz_xxxzzz_0[j] - tg_xzzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xxzzzzz_xxzzz_1[j];

                    tg_xxxzzzzz_xxyyyy_0[j] = pb_x * tg_xxzzzzz_xxyyyy_0[j] + fr * tg_xxzzzzz_xxyyyy_1[j] + fl1_fx * (tg_xzzzzz_xxyyyy_0[j] - tg_xzzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_xyyyy_1[j];

                    tg_xxxzzzzz_xxyyyz_0[j] = pb_x * tg_xxzzzzz_xxyyyz_0[j] + fr * tg_xxzzzzz_xxyyyz_1[j] + fl1_fx * (tg_xzzzzz_xxyyyz_0[j] - tg_xzzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_xyyyz_1[j];

                    tg_xxxzzzzz_xxyyzz_0[j] = pb_x * tg_xxzzzzz_xxyyzz_0[j] + fr * tg_xxzzzzz_xxyyzz_1[j] + fl1_fx * (tg_xzzzzz_xxyyzz_0[j] - tg_xzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_xyyzz_1[j];

                    tg_xxxzzzzz_xxyzzz_0[j] = pb_x * tg_xxzzzzz_xxyzzz_0[j] + fr * tg_xxzzzzz_xxyzzz_1[j] + fl1_fx * (tg_xzzzzz_xxyzzz_0[j] - tg_xzzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_xyzzz_1[j];

                    tg_xxxzzzzz_xxzzzz_0[j] = pb_x * tg_xxzzzzz_xxzzzz_0[j] + fr * tg_xxzzzzz_xxzzzz_1[j] + fl1_fx * (tg_xzzzzz_xxzzzz_0[j] - tg_xzzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xxzzzzz_xzzzz_1[j];

                    tg_xxxzzzzz_xyyyyy_0[j] = pb_x * tg_xxzzzzz_xyyyyy_0[j] + fr * tg_xxzzzzz_xyyyyy_1[j] + fl1_fx * (tg_xzzzzz_xyyyyy_0[j] - tg_xzzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_yyyyy_1[j];

                    tg_xxxzzzzz_xyyyyz_0[j] = pb_x * tg_xxzzzzz_xyyyyz_0[j] + fr * tg_xxzzzzz_xyyyyz_1[j] + fl1_fx * (tg_xzzzzz_xyyyyz_0[j] - tg_xzzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_yyyyz_1[j];

                    tg_xxxzzzzz_xyyyzz_0[j] = pb_x * tg_xxzzzzz_xyyyzz_0[j] + fr * tg_xxzzzzz_xyyyzz_1[j] + fl1_fx * (tg_xzzzzz_xyyyzz_0[j] - tg_xzzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_yyyzz_1[j];

                    tg_xxxzzzzz_xyyzzz_0[j] = pb_x * tg_xxzzzzz_xyyzzz_0[j] + fr * tg_xxzzzzz_xyyzzz_1[j] + fl1_fx * (tg_xzzzzz_xyyzzz_0[j] - tg_xzzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_yyzzz_1[j];

                    tg_xxxzzzzz_xyzzzz_0[j] = pb_x * tg_xxzzzzz_xyzzzz_0[j] + fr * tg_xxzzzzz_xyzzzz_1[j] + fl1_fx * (tg_xzzzzz_xyzzzz_0[j] - tg_xzzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_yzzzz_1[j];

                    tg_xxxzzzzz_xzzzzz_0[j] = pb_x * tg_xxzzzzz_xzzzzz_0[j] + fr * tg_xxzzzzz_xzzzzz_1[j] + fl1_fx * (tg_xzzzzz_xzzzzz_0[j] - tg_xzzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xxzzzzz_zzzzz_1[j];

                    tg_xxxzzzzz_yyyyyy_0[j] = pb_x * tg_xxzzzzz_yyyyyy_0[j] + fr * tg_xxzzzzz_yyyyyy_1[j] + fl1_fx * (tg_xzzzzz_yyyyyy_0[j] - tg_xzzzzz_yyyyyy_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_582_679(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (582,679)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xxzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 582); 

                auto tg_xxzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 583); 

                auto tg_xxzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 584); 

                auto tg_xxzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 585); 

                auto tg_xxzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 586); 

                auto tg_xxzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 587); 

                auto tg_xyyyyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 588); 

                auto tg_xyyyyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 589); 

                auto tg_xyyyyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 590); 

                auto tg_xyyyyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 591); 

                auto tg_xyyyyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 592); 

                auto tg_xyyyyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 593); 

                auto tg_xyyyyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 594); 

                auto tg_xyyyyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 595); 

                auto tg_xyyyyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 596); 

                auto tg_xyyyyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 597); 

                auto tg_xyyyyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 598); 

                auto tg_xyyyyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 599); 

                auto tg_xyyyyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 600); 

                auto tg_xyyyyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 601); 

                auto tg_xyyyyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 602); 

                auto tg_xyyyyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 603); 

                auto tg_xyyyyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 604); 

                auto tg_xyyyyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 605); 

                auto tg_xyyyyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 606); 

                auto tg_xyyyyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 607); 

                auto tg_xyyyyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 608); 

                auto tg_xyyyyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 609); 

                auto tg_xyyyyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 610); 

                auto tg_xyyyyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 611); 

                auto tg_xyyyyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 612); 

                auto tg_xyyyyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 613); 

                auto tg_xyyyyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 614); 

                auto tg_xyyyyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 615); 

                auto tg_xyyyyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 616); 

                auto tg_xyyyyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 617); 

                auto tg_xyyyyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 618); 

                auto tg_xyyyyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 619); 

                auto tg_xyyyyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 620); 

                auto tg_xyyyyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 621); 

                auto tg_xyyyyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 622); 

                auto tg_xyyyyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 623); 

                auto tg_xyyyyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 624); 

                auto tg_xyyyyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 625); 

                auto tg_xyyyyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 626); 

                auto tg_xyyyyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 627); 

                auto tg_xyyyyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 628); 

                auto tg_xyyyyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 629); 

                auto tg_xyyyyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 630); 

                auto tg_xyyyyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 631); 

                auto tg_xyyyyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 632); 

                auto tg_xyyyyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 633); 

                auto tg_xyyyyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 634); 

                auto tg_xyyyyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 635); 

                auto tg_xyyyyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 636); 

                auto tg_xyyyyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 637); 

                auto tg_xyyyyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 638); 

                auto tg_xyyyyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 639); 

                auto tg_xyyyyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 640); 

                auto tg_xyyyyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 641); 

                auto tg_xyyyyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 642); 

                auto tg_xyyyyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 643); 

                auto tg_xyyyyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 644); 

                auto tg_xyyyyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 645); 

                auto tg_xyyyyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 646); 

                auto tg_xyyyyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 647); 

                auto tg_xyyyyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 648); 

                auto tg_xyyyyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 649); 

                auto tg_xyyyyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 650); 

                auto tg_xyyyyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 651); 

                auto tg_xyyyyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 652); 

                auto tg_xyyyyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 653); 

                auto tg_xyyyyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 654); 

                auto tg_xyyyyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 655); 

                auto tg_xyyyyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 656); 

                auto tg_xyyyyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 657); 

                auto tg_xyyyyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 658); 

                auto tg_xyyyyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 659); 

                auto tg_xyyyyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 660); 

                auto tg_xyyyyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 661); 

                auto tg_xyyyyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 662); 

                auto tg_xyyyyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 663); 

                auto tg_xyyyyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 664); 

                auto tg_xyyyyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 665); 

                auto tg_xyyyyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 666); 

                auto tg_xyyyyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 667); 

                auto tg_xyyyyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 668); 

                auto tg_xyyyyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 669); 

                auto tg_xyyyyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 670); 

                auto tg_xyyyyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 671); 

                auto tg_xyyyzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 672); 

                auto tg_xyyyzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 673); 

                auto tg_xyyyzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 674); 

                auto tg_xyyyzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 675); 

                auto tg_xyyyzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 676); 

                auto tg_xyyyzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 677); 

                auto tg_xyyyzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 678); 

                auto tg_xxzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 582); 

                auto tg_xxzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 583); 

                auto tg_xxzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 584); 

                auto tg_xxzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 585); 

                auto tg_xxzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 586); 

                auto tg_xxzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 587); 

                auto tg_xyyyyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 588); 

                auto tg_xyyyyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 589); 

                auto tg_xyyyyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 590); 

                auto tg_xyyyyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 591); 

                auto tg_xyyyyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 592); 

                auto tg_xyyyyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 593); 

                auto tg_xyyyyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 594); 

                auto tg_xyyyyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 595); 

                auto tg_xyyyyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 596); 

                auto tg_xyyyyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 597); 

                auto tg_xyyyyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 598); 

                auto tg_xyyyyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 599); 

                auto tg_xyyyyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 600); 

                auto tg_xyyyyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 601); 

                auto tg_xyyyyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 602); 

                auto tg_xyyyyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 603); 

                auto tg_xyyyyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 604); 

                auto tg_xyyyyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 605); 

                auto tg_xyyyyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 606); 

                auto tg_xyyyyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 607); 

                auto tg_xyyyyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 608); 

                auto tg_xyyyyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 609); 

                auto tg_xyyyyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 610); 

                auto tg_xyyyyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 611); 

                auto tg_xyyyyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 612); 

                auto tg_xyyyyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 613); 

                auto tg_xyyyyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 614); 

                auto tg_xyyyyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 615); 

                auto tg_xyyyyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 616); 

                auto tg_xyyyyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 617); 

                auto tg_xyyyyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 618); 

                auto tg_xyyyyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 619); 

                auto tg_xyyyyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 620); 

                auto tg_xyyyyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 621); 

                auto tg_xyyyyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 622); 

                auto tg_xyyyyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 623); 

                auto tg_xyyyyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 624); 

                auto tg_xyyyyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 625); 

                auto tg_xyyyyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 626); 

                auto tg_xyyyyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 627); 

                auto tg_xyyyyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 628); 

                auto tg_xyyyyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 629); 

                auto tg_xyyyyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 630); 

                auto tg_xyyyyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 631); 

                auto tg_xyyyyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 632); 

                auto tg_xyyyyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 633); 

                auto tg_xyyyyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 634); 

                auto tg_xyyyyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 635); 

                auto tg_xyyyyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 636); 

                auto tg_xyyyyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 637); 

                auto tg_xyyyyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 638); 

                auto tg_xyyyyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 639); 

                auto tg_xyyyyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 640); 

                auto tg_xyyyyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 641); 

                auto tg_xyyyyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 642); 

                auto tg_xyyyyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 643); 

                auto tg_xyyyyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 644); 

                auto tg_xyyyyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 645); 

                auto tg_xyyyyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 646); 

                auto tg_xyyyyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 647); 

                auto tg_xyyyyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 648); 

                auto tg_xyyyyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 649); 

                auto tg_xyyyyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 650); 

                auto tg_xyyyyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 651); 

                auto tg_xyyyyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 652); 

                auto tg_xyyyyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 653); 

                auto tg_xyyyyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 654); 

                auto tg_xyyyyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 655); 

                auto tg_xyyyyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 656); 

                auto tg_xyyyyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 657); 

                auto tg_xyyyyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 658); 

                auto tg_xyyyyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 659); 

                auto tg_xyyyyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 660); 

                auto tg_xyyyyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 661); 

                auto tg_xyyyyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 662); 

                auto tg_xyyyyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 663); 

                auto tg_xyyyyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 664); 

                auto tg_xyyyyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 665); 

                auto tg_xyyyyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 666); 

                auto tg_xyyyyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 667); 

                auto tg_xyyyyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 668); 

                auto tg_xyyyyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 669); 

                auto tg_xyyyyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 670); 

                auto tg_xyyyyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 671); 

                auto tg_xyyyzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 672); 

                auto tg_xyyyzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 673); 

                auto tg_xyyyzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 674); 

                auto tg_xyyyzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 675); 

                auto tg_xyyyzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 676); 

                auto tg_xyyyzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 677); 

                auto tg_xyyyzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 678); 

                auto tg_xzzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 582); 

                auto tg_xzzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 583); 

                auto tg_xzzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 584); 

                auto tg_xzzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 585); 

                auto tg_xzzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 586); 

                auto tg_xzzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 587); 

                auto tg_yyyyyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 623); 

                auto tg_yyyyyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 646); 

                auto tg_yyyyzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 656); 

                auto tg_yyyyzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 678); 

                auto tg_xzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 582); 

                auto tg_xzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 583); 

                auto tg_xzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 584); 

                auto tg_xzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 585); 

                auto tg_xzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 586); 

                auto tg_xzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 587); 

                auto tg_yyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 623); 

                auto tg_yyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 646); 

                auto tg_yyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 656); 

                auto tg_yyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 678); 

                auto tg_xyyyyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 441); 

                auto tg_xyyyyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 442); 

                auto tg_xyyyyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 443); 

                auto tg_xyyyyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 444); 

                auto tg_xyyyyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 445); 

                auto tg_xyyyyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 446); 

                auto tg_xyyyyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 447); 

                auto tg_xyyyyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 448); 

                auto tg_xyyyyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 449); 

                auto tg_xyyyyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 450); 

                auto tg_xyyyyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 451); 

                auto tg_xyyyyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 452); 

                auto tg_xyyyyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 453); 

                auto tg_xyyyyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 454); 

                auto tg_xyyyyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 455); 

                auto tg_xyyyyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 456); 

                auto tg_xyyyyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 457); 

                auto tg_xyyyyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 458); 

                auto tg_xyyyyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 459); 

                auto tg_xyyyyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 460); 

                auto tg_xyyyyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 461); 

                auto tg_xyyyyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 462); 

                auto tg_xyyyyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 463); 

                auto tg_xyyyyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 464); 

                auto tg_xyyyyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 465); 

                auto tg_xyyyyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 466); 

                auto tg_xyyyyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 467); 

                auto tg_xyyyyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 468); 

                auto tg_xyyyyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 469); 

                auto tg_xyyyyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 470); 

                auto tg_xyyyyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 471); 

                auto tg_xyyyyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 472); 

                auto tg_xyyyyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 473); 

                auto tg_xyyyyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 474); 

                auto tg_xyyyyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 475); 

                auto tg_xyyyyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 476); 

                auto tg_xyyyyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 477); 

                auto tg_xyyyyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 478); 

                auto tg_xyyyyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 479); 

                auto tg_xyyyyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 480); 

                auto tg_xyyyyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 481); 

                auto tg_xyyyyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 482); 

                auto tg_xyyyyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 483); 

                auto tg_xyyyyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 484); 

                auto tg_xyyyyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 485); 

                auto tg_xyyyyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 486); 

                auto tg_xyyyyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 487); 

                auto tg_xyyyyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 488); 

                auto tg_xyyyyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 489); 

                auto tg_xyyyyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 490); 

                auto tg_xyyyyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 491); 

                auto tg_xyyyyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 492); 

                auto tg_xyyyyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 493); 

                auto tg_xyyyyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 494); 

                auto tg_xyyyyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 495); 

                auto tg_xyyyyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 496); 

                auto tg_xyyyyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 497); 

                auto tg_xyyyyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 498); 

                auto tg_xyyyyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 499); 

                auto tg_xyyyyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 500); 

                auto tg_xyyyyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 501); 

                auto tg_xyyyyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 502); 

                auto tg_xyyyyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 503); 

                auto tg_xyyyzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 504); 

                auto tg_xyyyzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 505); 

                auto tg_xyyyzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 506); 

                auto tg_xyyyzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 507); 

                auto tg_xyyyzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 508); 

                auto tg_xyyyzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 509); 

                auto tg_xyyyzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 510); 

                // set up pointers to integrals

                auto tg_xxxzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 582); 

                auto tg_xxxzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 583); 

                auto tg_xxxzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 584); 

                auto tg_xxxzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 585); 

                auto tg_xxxzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 586); 

                auto tg_xxxzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 587); 

                auto tg_xxyyyyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 588); 

                auto tg_xxyyyyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 589); 

                auto tg_xxyyyyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 590); 

                auto tg_xxyyyyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 591); 

                auto tg_xxyyyyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 592); 

                auto tg_xxyyyyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 593); 

                auto tg_xxyyyyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 594); 

                auto tg_xxyyyyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 595); 

                auto tg_xxyyyyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 596); 

                auto tg_xxyyyyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 597); 

                auto tg_xxyyyyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 598); 

                auto tg_xxyyyyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 599); 

                auto tg_xxyyyyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 600); 

                auto tg_xxyyyyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 601); 

                auto tg_xxyyyyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 602); 

                auto tg_xxyyyyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 603); 

                auto tg_xxyyyyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 604); 

                auto tg_xxyyyyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 605); 

                auto tg_xxyyyyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 606); 

                auto tg_xxyyyyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 607); 

                auto tg_xxyyyyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 608); 

                auto tg_xxyyyyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 609); 

                auto tg_xxyyyyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 610); 

                auto tg_xxyyyyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 611); 

                auto tg_xxyyyyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 612); 

                auto tg_xxyyyyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 613); 

                auto tg_xxyyyyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 614); 

                auto tg_xxyyyyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 615); 

                auto tg_xxyyyyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 616); 

                auto tg_xxyyyyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 617); 

                auto tg_xxyyyyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 618); 

                auto tg_xxyyyyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 619); 

                auto tg_xxyyyyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 620); 

                auto tg_xxyyyyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 621); 

                auto tg_xxyyyyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 622); 

                auto tg_xxyyyyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 623); 

                auto tg_xxyyyyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 624); 

                auto tg_xxyyyyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 625); 

                auto tg_xxyyyyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 626); 

                auto tg_xxyyyyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 627); 

                auto tg_xxyyyyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 628); 

                auto tg_xxyyyyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 629); 

                auto tg_xxyyyyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 630); 

                auto tg_xxyyyyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 631); 

                auto tg_xxyyyyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 632); 

                auto tg_xxyyyyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 633); 

                auto tg_xxyyyyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 634); 

                auto tg_xxyyyyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 635); 

                auto tg_xxyyyyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 636); 

                auto tg_xxyyyyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 637); 

                auto tg_xxyyyyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 638); 

                auto tg_xxyyyyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 639); 

                auto tg_xxyyyyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 640); 

                auto tg_xxyyyyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 641); 

                auto tg_xxyyyyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 642); 

                auto tg_xxyyyyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 643); 

                auto tg_xxyyyyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 644); 

                auto tg_xxyyyyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 645); 

                auto tg_xxyyyyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 646); 

                auto tg_xxyyyyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 647); 

                auto tg_xxyyyyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 648); 

                auto tg_xxyyyyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 649); 

                auto tg_xxyyyyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 650); 

                auto tg_xxyyyyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 651); 

                auto tg_xxyyyyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 652); 

                auto tg_xxyyyyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 653); 

                auto tg_xxyyyyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 654); 

                auto tg_xxyyyyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 655); 

                auto tg_xxyyyyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 656); 

                auto tg_xxyyyyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 657); 

                auto tg_xxyyyyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 658); 

                auto tg_xxyyyyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 659); 

                auto tg_xxyyyyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 660); 

                auto tg_xxyyyyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 661); 

                auto tg_xxyyyyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 662); 

                auto tg_xxyyyyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 663); 

                auto tg_xxyyyyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 664); 

                auto tg_xxyyyyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 665); 

                auto tg_xxyyyyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 666); 

                auto tg_xxyyyyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 667); 

                auto tg_xxyyyyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 668); 

                auto tg_xxyyyyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 669); 

                auto tg_xxyyyyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 670); 

                auto tg_xxyyyyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 671); 

                auto tg_xxyyyzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 672); 

                auto tg_xxyyyzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 673); 

                auto tg_xxyyyzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 674); 

                auto tg_xxyyyzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 675); 

                auto tg_xxyyyzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 676); 

                auto tg_xxyyyzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 677); 

                auto tg_xxyyyzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 678); 

                // Batch of Integrals (582,679)

                #pragma omp simd aligned(fxn, fza, tg_xxxzzzzz_yyyyyz_0, tg_xxxzzzzz_yyyyzz_0, \
                                         tg_xxxzzzzz_yyyzzz_0, tg_xxxzzzzz_yyzzzz_0, tg_xxxzzzzz_yzzzzz_0, tg_xxxzzzzz_zzzzzz_0, \
                                         tg_xxyyyyyy_xxxxxx_0, tg_xxyyyyyy_xxxxxy_0, tg_xxyyyyyy_xxxxxz_0, tg_xxyyyyyy_xxxxyy_0, \
                                         tg_xxyyyyyy_xxxxyz_0, tg_xxyyyyyy_xxxxzz_0, tg_xxyyyyyy_xxxyyy_0, tg_xxyyyyyy_xxxyyz_0, \
                                         tg_xxyyyyyy_xxxyzz_0, tg_xxyyyyyy_xxxzzz_0, tg_xxyyyyyy_xxyyyy_0, tg_xxyyyyyy_xxyyyz_0, \
                                         tg_xxyyyyyy_xxyyzz_0, tg_xxyyyyyy_xxyzzz_0, tg_xxyyyyyy_xxzzzz_0, tg_xxyyyyyy_xyyyyy_0, \
                                         tg_xxyyyyyy_xyyyyz_0, tg_xxyyyyyy_xyyyzz_0, tg_xxyyyyyy_xyyzzz_0, tg_xxyyyyyy_xyzzzz_0, \
                                         tg_xxyyyyyy_xzzzzz_0, tg_xxyyyyyy_yyyyyy_0, tg_xxyyyyyy_yyyyyz_0, tg_xxyyyyyy_yyyyzz_0, \
                                         tg_xxyyyyyy_yyyzzz_0, tg_xxyyyyyy_yyzzzz_0, tg_xxyyyyyy_yzzzzz_0, tg_xxyyyyyy_zzzzzz_0, \
                                         tg_xxyyyyyz_xxxxxx_0, tg_xxyyyyyz_xxxxxy_0, tg_xxyyyyyz_xxxxxz_0, tg_xxyyyyyz_xxxxyy_0, \
                                         tg_xxyyyyyz_xxxxyz_0, tg_xxyyyyyz_xxxxzz_0, tg_xxyyyyyz_xxxyyy_0, tg_xxyyyyyz_xxxyyz_0, \
                                         tg_xxyyyyyz_xxxyzz_0, tg_xxyyyyyz_xxxzzz_0, tg_xxyyyyyz_xxyyyy_0, tg_xxyyyyyz_xxyyyz_0, \
                                         tg_xxyyyyyz_xxyyzz_0, tg_xxyyyyyz_xxyzzz_0, tg_xxyyyyyz_xxzzzz_0, tg_xxyyyyyz_xyyyyy_0, \
                                         tg_xxyyyyyz_xyyyyz_0, tg_xxyyyyyz_xyyyzz_0, tg_xxyyyyyz_xyyzzz_0, tg_xxyyyyyz_xyzzzz_0, \
                                         tg_xxyyyyyz_xzzzzz_0, tg_xxyyyyyz_yyyyyy_0, tg_xxyyyyyz_yyyyyz_0, tg_xxyyyyyz_yyyyzz_0, \
                                         tg_xxyyyyyz_yyyzzz_0, tg_xxyyyyyz_yyzzzz_0, tg_xxyyyyyz_yzzzzz_0, tg_xxyyyyyz_zzzzzz_0, \
                                         tg_xxyyyyzz_xxxxxx_0, tg_xxyyyyzz_xxxxxy_0, tg_xxyyyyzz_xxxxxz_0, tg_xxyyyyzz_xxxxyy_0, \
                                         tg_xxyyyyzz_xxxxyz_0, tg_xxyyyyzz_xxxxzz_0, tg_xxyyyyzz_xxxyyy_0, tg_xxyyyyzz_xxxyyz_0, \
                                         tg_xxyyyyzz_xxxyzz_0, tg_xxyyyyzz_xxxzzz_0, tg_xxyyyyzz_xxyyyy_0, tg_xxyyyyzz_xxyyyz_0, \
                                         tg_xxyyyyzz_xxyyzz_0, tg_xxyyyyzz_xxyzzz_0, tg_xxyyyyzz_xxzzzz_0, tg_xxyyyyzz_xyyyyy_0, \
                                         tg_xxyyyyzz_xyyyyz_0, tg_xxyyyyzz_xyyyzz_0, tg_xxyyyyzz_xyyzzz_0, tg_xxyyyyzz_xyzzzz_0, \
                                         tg_xxyyyyzz_xzzzzz_0, tg_xxyyyyzz_yyyyyy_0, tg_xxyyyyzz_yyyyyz_0, tg_xxyyyyzz_yyyyzz_0, \
                                         tg_xxyyyyzz_yyyzzz_0, tg_xxyyyyzz_yyzzzz_0, tg_xxyyyyzz_yzzzzz_0, tg_xxyyyyzz_zzzzzz_0, \
                                         tg_xxyyyzzz_xxxxxx_0, tg_xxyyyzzz_xxxxxy_0, tg_xxyyyzzz_xxxxxz_0, tg_xxyyyzzz_xxxxyy_0, \
                                         tg_xxyyyzzz_xxxxyz_0, tg_xxyyyzzz_xxxxzz_0, tg_xxyyyzzz_xxxyyy_0, tg_xxzzzzz_yyyyyz_0, \
                                         tg_xxzzzzz_yyyyyz_1, tg_xxzzzzz_yyyyzz_0, tg_xxzzzzz_yyyyzz_1, tg_xxzzzzz_yyyzzz_0, \
                                         tg_xxzzzzz_yyyzzz_1, tg_xxzzzzz_yyzzzz_0, tg_xxzzzzz_yyzzzz_1, tg_xxzzzzz_yzzzzz_0, \
                                         tg_xxzzzzz_yzzzzz_1, tg_xxzzzzz_zzzzzz_0, tg_xxzzzzz_zzzzzz_1, tg_xyyyyyy_xxxxx_1, \
                                         tg_xyyyyyy_xxxxxx_0, tg_xyyyyyy_xxxxxx_1, tg_xyyyyyy_xxxxxy_0, tg_xyyyyyy_xxxxxy_1, \
                                         tg_xyyyyyy_xxxxxz_0, tg_xyyyyyy_xxxxxz_1, tg_xyyyyyy_xxxxy_1, tg_xyyyyyy_xxxxyy_0, \
                                         tg_xyyyyyy_xxxxyy_1, tg_xyyyyyy_xxxxyz_0, tg_xyyyyyy_xxxxyz_1, tg_xyyyyyy_xxxxz_1, \
                                         tg_xyyyyyy_xxxxzz_0, tg_xyyyyyy_xxxxzz_1, tg_xyyyyyy_xxxyy_1, tg_xyyyyyy_xxxyyy_0, \
                                         tg_xyyyyyy_xxxyyy_1, tg_xyyyyyy_xxxyyz_0, tg_xyyyyyy_xxxyyz_1, tg_xyyyyyy_xxxyz_1, \
                                         tg_xyyyyyy_xxxyzz_0, tg_xyyyyyy_xxxyzz_1, tg_xyyyyyy_xxxzz_1, tg_xyyyyyy_xxxzzz_0, \
                                         tg_xyyyyyy_xxxzzz_1, tg_xyyyyyy_xxyyy_1, tg_xyyyyyy_xxyyyy_0, tg_xyyyyyy_xxyyyy_1, \
                                         tg_xyyyyyy_xxyyyz_0, tg_xyyyyyy_xxyyyz_1, tg_xyyyyyy_xxyyz_1, tg_xyyyyyy_xxyyzz_0, \
                                         tg_xyyyyyy_xxyyzz_1, tg_xyyyyyy_xxyzz_1, tg_xyyyyyy_xxyzzz_0, tg_xyyyyyy_xxyzzz_1, \
                                         tg_xyyyyyy_xxzzz_1, tg_xyyyyyy_xxzzzz_0, tg_xyyyyyy_xxzzzz_1, tg_xyyyyyy_xyyyy_1, \
                                         tg_xyyyyyy_xyyyyy_0, tg_xyyyyyy_xyyyyy_1, tg_xyyyyyy_xyyyyz_0, tg_xyyyyyy_xyyyyz_1, \
                                         tg_xyyyyyy_xyyyz_1, tg_xyyyyyy_xyyyzz_0, tg_xyyyyyy_xyyyzz_1, tg_xyyyyyy_xyyzz_1, \
                                         tg_xyyyyyy_xyyzzz_0, tg_xyyyyyy_xyyzzz_1, tg_xyyyyyy_xyzzz_1, tg_xyyyyyy_xyzzzz_0, \
                                         tg_xyyyyyy_xyzzzz_1, tg_xyyyyyy_xzzzz_1, tg_xyyyyyy_xzzzzz_0, tg_xyyyyyy_xzzzzz_1, \
                                         tg_xyyyyyy_yyyyy_1, tg_xyyyyyy_yyyyyy_0, tg_xyyyyyy_yyyyyy_1, tg_xyyyyyy_yyyyyz_0, \
                                         tg_xyyyyyy_yyyyyz_1, tg_xyyyyyy_yyyyz_1, tg_xyyyyyy_yyyyzz_0, tg_xyyyyyy_yyyyzz_1, \
                                         tg_xyyyyyy_yyyzz_1, tg_xyyyyyy_yyyzzz_0, tg_xyyyyyy_yyyzzz_1, tg_xyyyyyy_yyzzz_1, \
                                         tg_xyyyyyy_yyzzzz_0, tg_xyyyyyy_yyzzzz_1, tg_xyyyyyy_yzzzz_1, tg_xyyyyyy_yzzzzz_0, \
                                         tg_xyyyyyy_yzzzzz_1, tg_xyyyyyy_zzzzz_1, tg_xyyyyyy_zzzzzz_0, tg_xyyyyyy_zzzzzz_1, \
                                         tg_xyyyyyz_xxxxx_1, tg_xyyyyyz_xxxxxx_0, tg_xyyyyyz_xxxxxx_1, tg_xyyyyyz_xxxxxy_0, \
                                         tg_xyyyyyz_xxxxxy_1, tg_xyyyyyz_xxxxxz_0, tg_xyyyyyz_xxxxxz_1, tg_xyyyyyz_xxxxy_1, \
                                         tg_xyyyyyz_xxxxyy_0, tg_xyyyyyz_xxxxyy_1, tg_xyyyyyz_xxxxyz_0, tg_xyyyyyz_xxxxyz_1, \
                                         tg_xyyyyyz_xxxxz_1, tg_xyyyyyz_xxxxzz_0, tg_xyyyyyz_xxxxzz_1, tg_xyyyyyz_xxxyy_1, \
                                         tg_xyyyyyz_xxxyyy_0, tg_xyyyyyz_xxxyyy_1, tg_xyyyyyz_xxxyyz_0, tg_xyyyyyz_xxxyyz_1, \
                                         tg_xyyyyyz_xxxyz_1, tg_xyyyyyz_xxxyzz_0, tg_xyyyyyz_xxxyzz_1, tg_xyyyyyz_xxxzz_1, \
                                         tg_xyyyyyz_xxxzzz_0, tg_xyyyyyz_xxxzzz_1, tg_xyyyyyz_xxyyy_1, tg_xyyyyyz_xxyyyy_0, \
                                         tg_xyyyyyz_xxyyyy_1, tg_xyyyyyz_xxyyyz_0, tg_xyyyyyz_xxyyyz_1, tg_xyyyyyz_xxyyz_1, \
                                         tg_xyyyyyz_xxyyzz_0, tg_xyyyyyz_xxyyzz_1, tg_xyyyyyz_xxyzz_1, tg_xyyyyyz_xxyzzz_0, \
                                         tg_xyyyyyz_xxyzzz_1, tg_xyyyyyz_xxzzz_1, tg_xyyyyyz_xxzzzz_0, tg_xyyyyyz_xxzzzz_1, \
                                         tg_xyyyyyz_xyyyy_1, tg_xyyyyyz_xyyyyy_0, tg_xyyyyyz_xyyyyy_1, tg_xyyyyyz_xyyyyz_0, \
                                         tg_xyyyyyz_xyyyyz_1, tg_xyyyyyz_xyyyz_1, tg_xyyyyyz_xyyyzz_0, tg_xyyyyyz_xyyyzz_1, \
                                         tg_xyyyyyz_xyyzz_1, tg_xyyyyyz_xyyzzz_0, tg_xyyyyyz_xyyzzz_1, tg_xyyyyyz_xyzzz_1, \
                                         tg_xyyyyyz_xyzzzz_0, tg_xyyyyyz_xyzzzz_1, tg_xyyyyyz_xzzzz_1, tg_xyyyyyz_xzzzzz_0, \
                                         tg_xyyyyyz_xzzzzz_1, tg_xyyyyyz_yyyyy_1, tg_xyyyyyz_yyyyyy_0, tg_xyyyyyz_yyyyyy_1, \
                                         tg_xyyyyyz_yyyyyz_0, tg_xyyyyyz_yyyyyz_1, tg_xyyyyyz_yyyyz_1, tg_xyyyyyz_yyyyzz_0, \
                                         tg_xyyyyyz_yyyyzz_1, tg_xyyyyyz_yyyzz_1, tg_xyyyyyz_yyyzzz_0, tg_xyyyyyz_yyyzzz_1, \
                                         tg_xyyyyyz_yyzzz_1, tg_xyyyyyz_yyzzzz_0, tg_xyyyyyz_yyzzzz_1, tg_xyyyyyz_yzzzz_1, \
                                         tg_xyyyyyz_yzzzzz_0, tg_xyyyyyz_yzzzzz_1, tg_xyyyyyz_zzzzz_1, tg_xyyyyyz_zzzzzz_0, \
                                         tg_xyyyyyz_zzzzzz_1, tg_xyyyyzz_xxxxx_1, tg_xyyyyzz_xxxxxx_0, tg_xyyyyzz_xxxxxx_1, \
                                         tg_xyyyyzz_xxxxxy_0, tg_xyyyyzz_xxxxxy_1, tg_xyyyyzz_xxxxxz_0, tg_xyyyyzz_xxxxxz_1, \
                                         tg_xyyyyzz_xxxxy_1, tg_xyyyyzz_xxxxyy_0, tg_xyyyyzz_xxxxyy_1, tg_xyyyyzz_xxxxyz_0, \
                                         tg_xyyyyzz_xxxxyz_1, tg_xyyyyzz_xxxxz_1, tg_xyyyyzz_xxxxzz_0, tg_xyyyyzz_xxxxzz_1, \
                                         tg_xyyyyzz_xxxyy_1, tg_xyyyyzz_xxxyyy_0, tg_xyyyyzz_xxxyyy_1, tg_xyyyyzz_xxxyyz_0, \
                                         tg_xyyyyzz_xxxyyz_1, tg_xyyyyzz_xxxyz_1, tg_xyyyyzz_xxxyzz_0, tg_xyyyyzz_xxxyzz_1, \
                                         tg_xyyyyzz_xxxzz_1, tg_xyyyyzz_xxxzzz_0, tg_xyyyyzz_xxxzzz_1, tg_xyyyyzz_xxyyy_1, \
                                         tg_xyyyyzz_xxyyyy_0, tg_xyyyyzz_xxyyyy_1, tg_xyyyyzz_xxyyyz_0, tg_xyyyyzz_xxyyyz_1, \
                                         tg_xyyyyzz_xxyyz_1, tg_xyyyyzz_xxyyzz_0, tg_xyyyyzz_xxyyzz_1, tg_xyyyyzz_xxyzz_1, \
                                         tg_xyyyyzz_xxyzzz_0, tg_xyyyyzz_xxyzzz_1, tg_xyyyyzz_xxzzz_1, tg_xyyyyzz_xxzzzz_0, \
                                         tg_xyyyyzz_xxzzzz_1, tg_xyyyyzz_xyyyy_1, tg_xyyyyzz_xyyyyy_0, tg_xyyyyzz_xyyyyy_1, \
                                         tg_xyyyyzz_xyyyyz_0, tg_xyyyyzz_xyyyyz_1, tg_xyyyyzz_xyyyz_1, tg_xyyyyzz_xyyyzz_0, \
                                         tg_xyyyyzz_xyyyzz_1, tg_xyyyyzz_xyyzz_1, tg_xyyyyzz_xyyzzz_0, tg_xyyyyzz_xyyzzz_1, \
                                         tg_xyyyyzz_xyzzz_1, tg_xyyyyzz_xyzzzz_0, tg_xyyyyzz_xyzzzz_1, tg_xyyyyzz_xzzzz_1, \
                                         tg_xyyyyzz_xzzzzz_0, tg_xyyyyzz_xzzzzz_1, tg_xyyyyzz_yyyyy_1, tg_xyyyyzz_yyyyyy_0, \
                                         tg_xyyyyzz_yyyyyy_1, tg_xyyyyzz_yyyyyz_0, tg_xyyyyzz_yyyyyz_1, tg_xyyyyzz_yyyyz_1, \
                                         tg_xyyyyzz_yyyyzz_0, tg_xyyyyzz_yyyyzz_1, tg_xyyyyzz_yyyzz_1, tg_xyyyyzz_yyyzzz_0, \
                                         tg_xyyyyzz_yyyzzz_1, tg_xyyyyzz_yyzzz_1, tg_xyyyyzz_yyzzzz_0, tg_xyyyyzz_yyzzzz_1, \
                                         tg_xyyyyzz_yzzzz_1, tg_xyyyyzz_yzzzzz_0, tg_xyyyyzz_yzzzzz_1, tg_xyyyyzz_zzzzz_1, \
                                         tg_xyyyyzz_zzzzzz_0, tg_xyyyyzz_zzzzzz_1, tg_xyyyzzz_xxxxx_1, tg_xyyyzzz_xxxxxx_0, \
                                         tg_xyyyzzz_xxxxxx_1, tg_xyyyzzz_xxxxxy_0, tg_xyyyzzz_xxxxxy_1, tg_xyyyzzz_xxxxxz_0, \
                                         tg_xyyyzzz_xxxxxz_1, tg_xyyyzzz_xxxxy_1, tg_xyyyzzz_xxxxyy_0, tg_xyyyzzz_xxxxyy_1, \
                                         tg_xyyyzzz_xxxxyz_0, tg_xyyyzzz_xxxxyz_1, tg_xyyyzzz_xxxxz_1, tg_xyyyzzz_xxxxzz_0, \
                                         tg_xyyyzzz_xxxxzz_1, tg_xyyyzzz_xxxyy_1, tg_xyyyzzz_xxxyyy_0, tg_xyyyzzz_xxxyyy_1, \
                                         tg_xyyyzzz_xxxyz_1, tg_xyyyzzz_xxxzz_1, tg_xyyyzzz_xxyyy_1, tg_xzzzzz_yyyyyz_0, \
                                         tg_xzzzzz_yyyyyz_1, tg_xzzzzz_yyyyzz_0, tg_xzzzzz_yyyyzz_1, tg_xzzzzz_yyyzzz_0, \
                                         tg_xzzzzz_yyyzzz_1, tg_xzzzzz_yyzzzz_0, tg_xzzzzz_yyzzzz_1, tg_xzzzzz_yzzzzz_0, \
                                         tg_xzzzzz_yzzzzz_1, tg_xzzzzz_zzzzzz_0, tg_xzzzzz_zzzzzz_1, tg_yyyyyy_xxxxxx_0, \
                                         tg_yyyyyy_xxxxxx_1, tg_yyyyyy_xxxxxy_0, tg_yyyyyy_xxxxxy_1, tg_yyyyyy_xxxxxz_0, \
                                         tg_yyyyyy_xxxxxz_1, tg_yyyyyy_xxxxyy_0, tg_yyyyyy_xxxxyy_1, tg_yyyyyy_xxxxyz_0, \
                                         tg_yyyyyy_xxxxyz_1, tg_yyyyyy_xxxxzz_0, tg_yyyyyy_xxxxzz_1, tg_yyyyyy_xxxyyy_0, \
                                         tg_yyyyyy_xxxyyy_1, tg_yyyyyy_xxxyyz_0, tg_yyyyyy_xxxyyz_1, tg_yyyyyy_xxxyzz_0, \
                                         tg_yyyyyy_xxxyzz_1, tg_yyyyyy_xxxzzz_0, tg_yyyyyy_xxxzzz_1, tg_yyyyyy_xxyyyy_0, \
                                         tg_yyyyyy_xxyyyy_1, tg_yyyyyy_xxyyyz_0, tg_yyyyyy_xxyyyz_1, tg_yyyyyy_xxyyzz_0, \
                                         tg_yyyyyy_xxyyzz_1, tg_yyyyyy_xxyzzz_0, tg_yyyyyy_xxyzzz_1, tg_yyyyyy_xxzzzz_0, \
                                         tg_yyyyyy_xxzzzz_1, tg_yyyyyy_xyyyyy_0, tg_yyyyyy_xyyyyy_1, tg_yyyyyy_xyyyyz_0, \
                                         tg_yyyyyy_xyyyyz_1, tg_yyyyyy_xyyyzz_0, tg_yyyyyy_xyyyzz_1, tg_yyyyyy_xyyzzz_0, \
                                         tg_yyyyyy_xyyzzz_1, tg_yyyyyy_xyzzzz_0, tg_yyyyyy_xyzzzz_1, tg_yyyyyy_xzzzzz_0, \
                                         tg_yyyyyy_xzzzzz_1, tg_yyyyyy_yyyyyy_0, tg_yyyyyy_yyyyyy_1, tg_yyyyyy_yyyyyz_0, \
                                         tg_yyyyyy_yyyyyz_1, tg_yyyyyy_yyyyzz_0, tg_yyyyyy_yyyyzz_1, tg_yyyyyy_yyyzzz_0, \
                                         tg_yyyyyy_yyyzzz_1, tg_yyyyyy_yyzzzz_0, tg_yyyyyy_yyzzzz_1, tg_yyyyyy_yzzzzz_0, \
                                         tg_yyyyyy_yzzzzz_1, tg_yyyyyy_zzzzzz_0, tg_yyyyyy_zzzzzz_1, tg_yyyyyz_xxxxxx_0, \
                                         tg_yyyyyz_xxxxxx_1, tg_yyyyyz_xxxxxy_0, tg_yyyyyz_xxxxxy_1, tg_yyyyyz_xxxxxz_0, \
                                         tg_yyyyyz_xxxxxz_1, tg_yyyyyz_xxxxyy_0, tg_yyyyyz_xxxxyy_1, tg_yyyyyz_xxxxyz_0, \
                                         tg_yyyyyz_xxxxyz_1, tg_yyyyyz_xxxxzz_0, tg_yyyyyz_xxxxzz_1, tg_yyyyyz_xxxyyy_0, \
                                         tg_yyyyyz_xxxyyy_1, tg_yyyyyz_xxxyyz_0, tg_yyyyyz_xxxyyz_1, tg_yyyyyz_xxxyzz_0, \
                                         tg_yyyyyz_xxxyzz_1, tg_yyyyyz_xxxzzz_0, tg_yyyyyz_xxxzzz_1, tg_yyyyyz_xxyyyy_0, \
                                         tg_yyyyyz_xxyyyy_1, tg_yyyyyz_xxyyyz_0, tg_yyyyyz_xxyyyz_1, tg_yyyyyz_xxyyzz_0, \
                                         tg_yyyyyz_xxyyzz_1, tg_yyyyyz_xxyzzz_0, tg_yyyyyz_xxyzzz_1, tg_yyyyyz_xxzzzz_0, \
                                         tg_yyyyyz_xxzzzz_1, tg_yyyyyz_xyyyyy_0, tg_yyyyyz_xyyyyy_1, tg_yyyyyz_xyyyyz_0, \
                                         tg_yyyyyz_xyyyyz_1, tg_yyyyyz_xyyyzz_0, tg_yyyyyz_xyyyzz_1, tg_yyyyyz_xyyzzz_0, \
                                         tg_yyyyyz_xyyzzz_1, tg_yyyyyz_xyzzzz_0, tg_yyyyyz_xyzzzz_1, tg_yyyyyz_xzzzzz_0, \
                                         tg_yyyyyz_xzzzzz_1, tg_yyyyyz_yyyyyy_0, tg_yyyyyz_yyyyyy_1, tg_yyyyyz_yyyyyz_0, \
                                         tg_yyyyyz_yyyyyz_1, tg_yyyyyz_yyyyzz_0, tg_yyyyyz_yyyyzz_1, tg_yyyyyz_yyyzzz_0, \
                                         tg_yyyyyz_yyyzzz_1, tg_yyyyyz_yyzzzz_0, tg_yyyyyz_yyzzzz_1, tg_yyyyyz_yzzzzz_0, \
                                         tg_yyyyyz_yzzzzz_1, tg_yyyyyz_zzzzzz_0, tg_yyyyyz_zzzzzz_1, tg_yyyyzz_xxxxxx_0, \
                                         tg_yyyyzz_xxxxxx_1, tg_yyyyzz_xxxxxy_0, tg_yyyyzz_xxxxxy_1, tg_yyyyzz_xxxxxz_0, \
                                         tg_yyyyzz_xxxxxz_1, tg_yyyyzz_xxxxyy_0, tg_yyyyzz_xxxxyy_1, tg_yyyyzz_xxxxyz_0, \
                                         tg_yyyyzz_xxxxyz_1, tg_yyyyzz_xxxxzz_0, tg_yyyyzz_xxxxzz_1, tg_yyyyzz_xxxyyy_0, \
                                         tg_yyyyzz_xxxyyy_1, tg_yyyyzz_xxxyyz_0, tg_yyyyzz_xxxyyz_1, tg_yyyyzz_xxxyzz_0, \
                                         tg_yyyyzz_xxxyzz_1, tg_yyyyzz_xxxzzz_0, tg_yyyyzz_xxxzzz_1, tg_yyyyzz_xxyyyy_0, \
                                         tg_yyyyzz_xxyyyy_1, tg_yyyyzz_xxyyyz_0, tg_yyyyzz_xxyyyz_1, tg_yyyyzz_xxyyzz_0, \
                                         tg_yyyyzz_xxyyzz_1, tg_yyyyzz_xxyzzz_0, tg_yyyyzz_xxyzzz_1, tg_yyyyzz_xxzzzz_0, \
                                         tg_yyyyzz_xxzzzz_1, tg_yyyyzz_xyyyyy_0, tg_yyyyzz_xyyyyy_1, tg_yyyyzz_xyyyyz_0, \
                                         tg_yyyyzz_xyyyyz_1, tg_yyyyzz_xyyyzz_0, tg_yyyyzz_xyyyzz_1, tg_yyyyzz_xyyzzz_0, \
                                         tg_yyyyzz_xyyzzz_1, tg_yyyyzz_xyzzzz_0, tg_yyyyzz_xyzzzz_1, tg_yyyyzz_xzzzzz_0, \
                                         tg_yyyyzz_xzzzzz_1, tg_yyyyzz_yyyyyy_0, tg_yyyyzz_yyyyyy_1, tg_yyyyzz_yyyyyz_0, \
                                         tg_yyyyzz_yyyyyz_1, tg_yyyyzz_yyyyzz_0, tg_yyyyzz_yyyyzz_1, tg_yyyyzz_yyyzzz_0, \
                                         tg_yyyyzz_yyyzzz_1, tg_yyyyzz_yyzzzz_0, tg_yyyyzz_yyzzzz_1, tg_yyyyzz_yzzzzz_0, \
                                         tg_yyyyzz_yzzzzz_1, tg_yyyyzz_zzzzzz_0, tg_yyyyzz_zzzzzz_1, tg_yyyzzz_xxxxxx_0, \
                                         tg_yyyzzz_xxxxxx_1, tg_yyyzzz_xxxxxy_0, tg_yyyzzz_xxxxxy_1, tg_yyyzzz_xxxxxz_0, \
                                         tg_yyyzzz_xxxxxz_1, tg_yyyzzz_xxxxyy_0, tg_yyyzzz_xxxxyy_1, tg_yyyzzz_xxxxyz_0, \
                                         tg_yyyzzz_xxxxyz_1, tg_yyyzzz_xxxxzz_0, tg_yyyzzz_xxxxzz_1, tg_yyyzzz_xxxyyy_0, \
                                         tg_yyyzzz_xxxyyy_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxxzzzzz_yyyyyz_0[j] = pb_x * tg_xxzzzzz_yyyyyz_0[j] + fr * tg_xxzzzzz_yyyyyz_1[j] + fl1_fx * (tg_xzzzzz_yyyyyz_0[j] - tg_xzzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxxzzzzz_yyyyzz_0[j] = pb_x * tg_xxzzzzz_yyyyzz_0[j] + fr * tg_xxzzzzz_yyyyzz_1[j] + fl1_fx * (tg_xzzzzz_yyyyzz_0[j] - tg_xzzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxxzzzzz_yyyzzz_0[j] = pb_x * tg_xxzzzzz_yyyzzz_0[j] + fr * tg_xxzzzzz_yyyzzz_1[j] + fl1_fx * (tg_xzzzzz_yyyzzz_0[j] - tg_xzzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxxzzzzz_yyzzzz_0[j] = pb_x * tg_xxzzzzz_yyzzzz_0[j] + fr * tg_xxzzzzz_yyzzzz_1[j] + fl1_fx * (tg_xzzzzz_yyzzzz_0[j] - tg_xzzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxxzzzzz_yzzzzz_0[j] = pb_x * tg_xxzzzzz_yzzzzz_0[j] + fr * tg_xxzzzzz_yzzzzz_1[j] + fl1_fx * (tg_xzzzzz_yzzzzz_0[j] - tg_xzzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxxzzzzz_zzzzzz_0[j] = pb_x * tg_xxzzzzz_zzzzzz_0[j] + fr * tg_xxzzzzz_zzzzzz_1[j] + fl1_fx * (tg_xzzzzz_zzzzzz_0[j] - tg_xzzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyy_xxxxxx_0[j] = pb_x * tg_xyyyyyy_xxxxxx_0[j] + fr * tg_xyyyyyy_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxxx_0[j] - tg_yyyyyy_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyyy_xxxxx_1[j];

                    tg_xxyyyyyy_xxxxxy_0[j] = pb_x * tg_xyyyyyy_xxxxxy_0[j] + fr * tg_xyyyyyy_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxxy_0[j] - tg_yyyyyy_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyyy_xxxxy_1[j];

                    tg_xxyyyyyy_xxxxxz_0[j] = pb_x * tg_xyyyyyy_xxxxxz_0[j] + fr * tg_xyyyyyy_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxxz_0[j] - tg_yyyyyy_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyyy_xxxxz_1[j];

                    tg_xxyyyyyy_xxxxyy_0[j] = pb_x * tg_xyyyyyy_xxxxyy_0[j] + fr * tg_xyyyyyy_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxyy_0[j] - tg_yyyyyy_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyy_xxxyy_1[j];

                    tg_xxyyyyyy_xxxxyz_0[j] = pb_x * tg_xyyyyyy_xxxxyz_0[j] + fr * tg_xyyyyyy_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxyz_0[j] - tg_yyyyyy_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyy_xxxyz_1[j];

                    tg_xxyyyyyy_xxxxzz_0[j] = pb_x * tg_xyyyyyy_xxxxzz_0[j] + fr * tg_xyyyyyy_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxxzz_0[j] - tg_yyyyyy_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyy_xxxzz_1[j];

                    tg_xxyyyyyy_xxxyyy_0[j] = pb_x * tg_xyyyyyy_xxxyyy_0[j] + fr * tg_xyyyyyy_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxyyy_0[j] - tg_yyyyyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyy_xxyyy_1[j];

                    tg_xxyyyyyy_xxxyyz_0[j] = pb_x * tg_xyyyyyy_xxxyyz_0[j] + fr * tg_xyyyyyy_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxyyz_0[j] - tg_yyyyyy_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyy_xxyyz_1[j];

                    tg_xxyyyyyy_xxxyzz_0[j] = pb_x * tg_xyyyyyy_xxxyzz_0[j] + fr * tg_xyyyyyy_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxyzz_0[j] - tg_yyyyyy_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyy_xxyzz_1[j];

                    tg_xxyyyyyy_xxxzzz_0[j] = pb_x * tg_xyyyyyy_xxxzzz_0[j] + fr * tg_xyyyyyy_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxxzzz_0[j] - tg_yyyyyy_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyy_xxzzz_1[j];

                    tg_xxyyyyyy_xxyyyy_0[j] = pb_x * tg_xyyyyyy_xxyyyy_0[j] + fr * tg_xyyyyyy_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxyyyy_0[j] - tg_yyyyyy_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_xyyyy_1[j];

                    tg_xxyyyyyy_xxyyyz_0[j] = pb_x * tg_xyyyyyy_xxyyyz_0[j] + fr * tg_xyyyyyy_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxyyyz_0[j] - tg_yyyyyy_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_xyyyz_1[j];

                    tg_xxyyyyyy_xxyyzz_0[j] = pb_x * tg_xyyyyyy_xxyyzz_0[j] + fr * tg_xyyyyyy_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxyyzz_0[j] - tg_yyyyyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_xyyzz_1[j];

                    tg_xxyyyyyy_xxyzzz_0[j] = pb_x * tg_xyyyyyy_xxyzzz_0[j] + fr * tg_xyyyyyy_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxyzzz_0[j] - tg_yyyyyy_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_xyzzz_1[j];

                    tg_xxyyyyyy_xxzzzz_0[j] = pb_x * tg_xyyyyyy_xxzzzz_0[j] + fr * tg_xyyyyyy_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xxzzzz_0[j] - tg_yyyyyy_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyy_xzzzz_1[j];

                    tg_xxyyyyyy_xyyyyy_0[j] = pb_x * tg_xyyyyyy_xyyyyy_0[j] + fr * tg_xyyyyyy_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xyyyyy_0[j] - tg_yyyyyy_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_yyyyy_1[j];

                    tg_xxyyyyyy_xyyyyz_0[j] = pb_x * tg_xyyyyyy_xyyyyz_0[j] + fr * tg_xyyyyyy_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xyyyyz_0[j] - tg_yyyyyy_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_yyyyz_1[j];

                    tg_xxyyyyyy_xyyyzz_0[j] = pb_x * tg_xyyyyyy_xyyyzz_0[j] + fr * tg_xyyyyyy_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xyyyzz_0[j] - tg_yyyyyy_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_yyyzz_1[j];

                    tg_xxyyyyyy_xyyzzz_0[j] = pb_x * tg_xyyyyyy_xyyzzz_0[j] + fr * tg_xyyyyyy_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xyyzzz_0[j] - tg_yyyyyy_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_yyzzz_1[j];

                    tg_xxyyyyyy_xyzzzz_0[j] = pb_x * tg_xyyyyyy_xyzzzz_0[j] + fr * tg_xyyyyyy_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xyzzzz_0[j] - tg_yyyyyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_yzzzz_1[j];

                    tg_xxyyyyyy_xzzzzz_0[j] = pb_x * tg_xyyyyyy_xzzzzz_0[j] + fr * tg_xyyyyyy_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_xzzzzz_0[j] - tg_yyyyyy_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyy_zzzzz_1[j];

                    tg_xxyyyyyy_yyyyyy_0[j] = pb_x * tg_xyyyyyy_yyyyyy_0[j] + fr * tg_xyyyyyy_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yyyyyy_0[j] - tg_yyyyyy_yyyyyy_1[j] * fl1_fza);

                    tg_xxyyyyyy_yyyyyz_0[j] = pb_x * tg_xyyyyyy_yyyyyz_0[j] + fr * tg_xyyyyyy_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yyyyyz_0[j] - tg_yyyyyy_yyyyyz_1[j] * fl1_fza);

                    tg_xxyyyyyy_yyyyzz_0[j] = pb_x * tg_xyyyyyy_yyyyzz_0[j] + fr * tg_xyyyyyy_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yyyyzz_0[j] - tg_yyyyyy_yyyyzz_1[j] * fl1_fza);

                    tg_xxyyyyyy_yyyzzz_0[j] = pb_x * tg_xyyyyyy_yyyzzz_0[j] + fr * tg_xyyyyyy_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yyyzzz_0[j] - tg_yyyyyy_yyyzzz_1[j] * fl1_fza);

                    tg_xxyyyyyy_yyzzzz_0[j] = pb_x * tg_xyyyyyy_yyzzzz_0[j] + fr * tg_xyyyyyy_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yyzzzz_0[j] - tg_yyyyyy_yyzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyy_yzzzzz_0[j] = pb_x * tg_xyyyyyy_yzzzzz_0[j] + fr * tg_xyyyyyy_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_yzzzzz_0[j] - tg_yyyyyy_yzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyy_zzzzzz_0[j] = pb_x * tg_xyyyyyy_zzzzzz_0[j] + fr * tg_xyyyyyy_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyy_zzzzzz_0[j] - tg_yyyyyy_zzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyz_xxxxxx_0[j] = pb_x * tg_xyyyyyz_xxxxxx_0[j] + fr * tg_xyyyyyz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxxx_0[j] - tg_yyyyyz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyyz_xxxxx_1[j];

                    tg_xxyyyyyz_xxxxxy_0[j] = pb_x * tg_xyyyyyz_xxxxxy_0[j] + fr * tg_xyyyyyz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxxy_0[j] - tg_yyyyyz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyyz_xxxxy_1[j];

                    tg_xxyyyyyz_xxxxxz_0[j] = pb_x * tg_xyyyyyz_xxxxxz_0[j] + fr * tg_xyyyyyz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxxz_0[j] - tg_yyyyyz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyyz_xxxxz_1[j];

                    tg_xxyyyyyz_xxxxyy_0[j] = pb_x * tg_xyyyyyz_xxxxyy_0[j] + fr * tg_xyyyyyz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxyy_0[j] - tg_yyyyyz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyz_xxxyy_1[j];

                    tg_xxyyyyyz_xxxxyz_0[j] = pb_x * tg_xyyyyyz_xxxxyz_0[j] + fr * tg_xyyyyyz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxyz_0[j] - tg_yyyyyz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyz_xxxyz_1[j];

                    tg_xxyyyyyz_xxxxzz_0[j] = pb_x * tg_xyyyyyz_xxxxzz_0[j] + fr * tg_xyyyyyz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxxzz_0[j] - tg_yyyyyz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyyz_xxxzz_1[j];

                    tg_xxyyyyyz_xxxyyy_0[j] = pb_x * tg_xyyyyyz_xxxyyy_0[j] + fr * tg_xyyyyyz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxyyy_0[j] - tg_yyyyyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyz_xxyyy_1[j];

                    tg_xxyyyyyz_xxxyyz_0[j] = pb_x * tg_xyyyyyz_xxxyyz_0[j] + fr * tg_xyyyyyz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxyyz_0[j] - tg_yyyyyz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyz_xxyyz_1[j];

                    tg_xxyyyyyz_xxxyzz_0[j] = pb_x * tg_xyyyyyz_xxxyzz_0[j] + fr * tg_xyyyyyz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxyzz_0[j] - tg_yyyyyz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyz_xxyzz_1[j];

                    tg_xxyyyyyz_xxxzzz_0[j] = pb_x * tg_xyyyyyz_xxxzzz_0[j] + fr * tg_xyyyyyz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxxzzz_0[j] - tg_yyyyyz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyyz_xxzzz_1[j];

                    tg_xxyyyyyz_xxyyyy_0[j] = pb_x * tg_xyyyyyz_xxyyyy_0[j] + fr * tg_xyyyyyz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxyyyy_0[j] - tg_yyyyyz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_xyyyy_1[j];

                    tg_xxyyyyyz_xxyyyz_0[j] = pb_x * tg_xyyyyyz_xxyyyz_0[j] + fr * tg_xyyyyyz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxyyyz_0[j] - tg_yyyyyz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_xyyyz_1[j];

                    tg_xxyyyyyz_xxyyzz_0[j] = pb_x * tg_xyyyyyz_xxyyzz_0[j] + fr * tg_xyyyyyz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxyyzz_0[j] - tg_yyyyyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_xyyzz_1[j];

                    tg_xxyyyyyz_xxyzzz_0[j] = pb_x * tg_xyyyyyz_xxyzzz_0[j] + fr * tg_xyyyyyz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxyzzz_0[j] - tg_yyyyyz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_xyzzz_1[j];

                    tg_xxyyyyyz_xxzzzz_0[j] = pb_x * tg_xyyyyyz_xxzzzz_0[j] + fr * tg_xyyyyyz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xxzzzz_0[j] - tg_yyyyyz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyyz_xzzzz_1[j];

                    tg_xxyyyyyz_xyyyyy_0[j] = pb_x * tg_xyyyyyz_xyyyyy_0[j] + fr * tg_xyyyyyz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xyyyyy_0[j] - tg_yyyyyz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_yyyyy_1[j];

                    tg_xxyyyyyz_xyyyyz_0[j] = pb_x * tg_xyyyyyz_xyyyyz_0[j] + fr * tg_xyyyyyz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xyyyyz_0[j] - tg_yyyyyz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_yyyyz_1[j];

                    tg_xxyyyyyz_xyyyzz_0[j] = pb_x * tg_xyyyyyz_xyyyzz_0[j] + fr * tg_xyyyyyz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xyyyzz_0[j] - tg_yyyyyz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_yyyzz_1[j];

                    tg_xxyyyyyz_xyyzzz_0[j] = pb_x * tg_xyyyyyz_xyyzzz_0[j] + fr * tg_xyyyyyz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xyyzzz_0[j] - tg_yyyyyz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_yyzzz_1[j];

                    tg_xxyyyyyz_xyzzzz_0[j] = pb_x * tg_xyyyyyz_xyzzzz_0[j] + fr * tg_xyyyyyz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xyzzzz_0[j] - tg_yyyyyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_yzzzz_1[j];

                    tg_xxyyyyyz_xzzzzz_0[j] = pb_x * tg_xyyyyyz_xzzzzz_0[j] + fr * tg_xyyyyyz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_xzzzzz_0[j] - tg_yyyyyz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyyz_zzzzz_1[j];

                    tg_xxyyyyyz_yyyyyy_0[j] = pb_x * tg_xyyyyyz_yyyyyy_0[j] + fr * tg_xyyyyyz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yyyyyy_0[j] - tg_yyyyyz_yyyyyy_1[j] * fl1_fza);

                    tg_xxyyyyyz_yyyyyz_0[j] = pb_x * tg_xyyyyyz_yyyyyz_0[j] + fr * tg_xyyyyyz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yyyyyz_0[j] - tg_yyyyyz_yyyyyz_1[j] * fl1_fza);

                    tg_xxyyyyyz_yyyyzz_0[j] = pb_x * tg_xyyyyyz_yyyyzz_0[j] + fr * tg_xyyyyyz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yyyyzz_0[j] - tg_yyyyyz_yyyyzz_1[j] * fl1_fza);

                    tg_xxyyyyyz_yyyzzz_0[j] = pb_x * tg_xyyyyyz_yyyzzz_0[j] + fr * tg_xyyyyyz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yyyzzz_0[j] - tg_yyyyyz_yyyzzz_1[j] * fl1_fza);

                    tg_xxyyyyyz_yyzzzz_0[j] = pb_x * tg_xyyyyyz_yyzzzz_0[j] + fr * tg_xyyyyyz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yyzzzz_0[j] - tg_yyyyyz_yyzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyz_yzzzzz_0[j] = pb_x * tg_xyyyyyz_yzzzzz_0[j] + fr * tg_xyyyyyz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_yzzzzz_0[j] - tg_yyyyyz_yzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyyz_zzzzzz_0[j] = pb_x * tg_xyyyyyz_zzzzzz_0[j] + fr * tg_xyyyyyz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyyz_zzzzzz_0[j] - tg_yyyyyz_zzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyzz_xxxxxx_0[j] = pb_x * tg_xyyyyzz_xxxxxx_0[j] + fr * tg_xyyyyzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxxx_0[j] - tg_yyyyzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyyzz_xxxxx_1[j];

                    tg_xxyyyyzz_xxxxxy_0[j] = pb_x * tg_xyyyyzz_xxxxxy_0[j] + fr * tg_xyyyyzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxxy_0[j] - tg_yyyyzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyzz_xxxxy_1[j];

                    tg_xxyyyyzz_xxxxxz_0[j] = pb_x * tg_xyyyyzz_xxxxxz_0[j] + fr * tg_xyyyyzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxxz_0[j] - tg_yyyyzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyyzz_xxxxz_1[j];

                    tg_xxyyyyzz_xxxxyy_0[j] = pb_x * tg_xyyyyzz_xxxxyy_0[j] + fr * tg_xyyyyzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxyy_0[j] - tg_yyyyzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyzz_xxxyy_1[j];

                    tg_xxyyyyzz_xxxxyz_0[j] = pb_x * tg_xyyyyzz_xxxxyz_0[j] + fr * tg_xyyyyzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxyz_0[j] - tg_yyyyzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyzz_xxxyz_1[j];

                    tg_xxyyyyzz_xxxxzz_0[j] = pb_x * tg_xyyyyzz_xxxxzz_0[j] + fr * tg_xyyyyzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxxzz_0[j] - tg_yyyyzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyyzz_xxxzz_1[j];

                    tg_xxyyyyzz_xxxyyy_0[j] = pb_x * tg_xyyyyzz_xxxyyy_0[j] + fr * tg_xyyyyzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxyyy_0[j] - tg_yyyyzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyzz_xxyyy_1[j];

                    tg_xxyyyyzz_xxxyyz_0[j] = pb_x * tg_xyyyyzz_xxxyyz_0[j] + fr * tg_xyyyyzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxyyz_0[j] - tg_yyyyzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyzz_xxyyz_1[j];

                    tg_xxyyyyzz_xxxyzz_0[j] = pb_x * tg_xyyyyzz_xxxyzz_0[j] + fr * tg_xyyyyzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxyzz_0[j] - tg_yyyyzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyzz_xxyzz_1[j];

                    tg_xxyyyyzz_xxxzzz_0[j] = pb_x * tg_xyyyyzz_xxxzzz_0[j] + fr * tg_xyyyyzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxxzzz_0[j] - tg_yyyyzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyyzz_xxzzz_1[j];

                    tg_xxyyyyzz_xxyyyy_0[j] = pb_x * tg_xyyyyzz_xxyyyy_0[j] + fr * tg_xyyyyzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxyyyy_0[j] - tg_yyyyzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_xyyyy_1[j];

                    tg_xxyyyyzz_xxyyyz_0[j] = pb_x * tg_xyyyyzz_xxyyyz_0[j] + fr * tg_xyyyyzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxyyyz_0[j] - tg_yyyyzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_xyyyz_1[j];

                    tg_xxyyyyzz_xxyyzz_0[j] = pb_x * tg_xyyyyzz_xxyyzz_0[j] + fr * tg_xyyyyzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxyyzz_0[j] - tg_yyyyzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_xyyzz_1[j];

                    tg_xxyyyyzz_xxyzzz_0[j] = pb_x * tg_xyyyyzz_xxyzzz_0[j] + fr * tg_xyyyyzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxyzzz_0[j] - tg_yyyyzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_xyzzz_1[j];

                    tg_xxyyyyzz_xxzzzz_0[j] = pb_x * tg_xyyyyzz_xxzzzz_0[j] + fr * tg_xyyyyzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xxzzzz_0[j] - tg_yyyyzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyyzz_xzzzz_1[j];

                    tg_xxyyyyzz_xyyyyy_0[j] = pb_x * tg_xyyyyzz_xyyyyy_0[j] + fr * tg_xyyyyzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xyyyyy_0[j] - tg_yyyyzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_yyyyy_1[j];

                    tg_xxyyyyzz_xyyyyz_0[j] = pb_x * tg_xyyyyzz_xyyyyz_0[j] + fr * tg_xyyyyzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xyyyyz_0[j] - tg_yyyyzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_yyyyz_1[j];

                    tg_xxyyyyzz_xyyyzz_0[j] = pb_x * tg_xyyyyzz_xyyyzz_0[j] + fr * tg_xyyyyzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xyyyzz_0[j] - tg_yyyyzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_yyyzz_1[j];

                    tg_xxyyyyzz_xyyzzz_0[j] = pb_x * tg_xyyyyzz_xyyzzz_0[j] + fr * tg_xyyyyzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xyyzzz_0[j] - tg_yyyyzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_yyzzz_1[j];

                    tg_xxyyyyzz_xyzzzz_0[j] = pb_x * tg_xyyyyzz_xyzzzz_0[j] + fr * tg_xyyyyzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xyzzzz_0[j] - tg_yyyyzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_yzzzz_1[j];

                    tg_xxyyyyzz_xzzzzz_0[j] = pb_x * tg_xyyyyzz_xzzzzz_0[j] + fr * tg_xyyyyzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_xzzzzz_0[j] - tg_yyyyzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyyzz_zzzzz_1[j];

                    tg_xxyyyyzz_yyyyyy_0[j] = pb_x * tg_xyyyyzz_yyyyyy_0[j] + fr * tg_xyyyyzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yyyyyy_0[j] - tg_yyyyzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxyyyyzz_yyyyyz_0[j] = pb_x * tg_xyyyyzz_yyyyyz_0[j] + fr * tg_xyyyyzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yyyyyz_0[j] - tg_yyyyzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxyyyyzz_yyyyzz_0[j] = pb_x * tg_xyyyyzz_yyyyzz_0[j] + fr * tg_xyyyyzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yyyyzz_0[j] - tg_yyyyzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxyyyyzz_yyyzzz_0[j] = pb_x * tg_xyyyyzz_yyyzzz_0[j] + fr * tg_xyyyyzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yyyzzz_0[j] - tg_yyyyzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxyyyyzz_yyzzzz_0[j] = pb_x * tg_xyyyyzz_yyzzzz_0[j] + fr * tg_xyyyyzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yyzzzz_0[j] - tg_yyyyzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxyyyyzz_yzzzzz_0[j] = pb_x * tg_xyyyyzz_yzzzzz_0[j] + fr * tg_xyyyyzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_yzzzzz_0[j] - tg_yyyyzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxyyyyzz_zzzzzz_0[j] = pb_x * tg_xyyyyzz_zzzzzz_0[j] + fr * tg_xyyyyzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyyzz_zzzzzz_0[j] - tg_yyyyzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxyyyzzz_xxxxxx_0[j] = pb_x * tg_xyyyzzz_xxxxxx_0[j] + fr * tg_xyyyzzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxxx_0[j] - tg_yyyzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyyzzz_xxxxx_1[j];

                    tg_xxyyyzzz_xxxxxy_0[j] = pb_x * tg_xyyyzzz_xxxxxy_0[j] + fr * tg_xyyyzzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxxy_0[j] - tg_yyyzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyzzz_xxxxy_1[j];

                    tg_xxyyyzzz_xxxxxz_0[j] = pb_x * tg_xyyyzzz_xxxxxz_0[j] + fr * tg_xyyyzzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxxz_0[j] - tg_yyyzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyyzzz_xxxxz_1[j];

                    tg_xxyyyzzz_xxxxyy_0[j] = pb_x * tg_xyyyzzz_xxxxyy_0[j] + fr * tg_xyyyzzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxyy_0[j] - tg_yyyzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzzz_xxxyy_1[j];

                    tg_xxyyyzzz_xxxxyz_0[j] = pb_x * tg_xyyyzzz_xxxxyz_0[j] + fr * tg_xyyyzzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxyz_0[j] - tg_yyyzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzzz_xxxyz_1[j];

                    tg_xxyyyzzz_xxxxzz_0[j] = pb_x * tg_xyyyzzz_xxxxzz_0[j] + fr * tg_xyyyzzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxxzz_0[j] - tg_yyyzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyyzzz_xxxzz_1[j];

                    tg_xxyyyzzz_xxxyyy_0[j] = pb_x * tg_xyyyzzz_xxxyyy_0[j] + fr * tg_xyyyzzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxyyy_0[j] - tg_yyyzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzzz_xxyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_679_776(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (679,776)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xyyyzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 679); 

                auto tg_xyyyzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 680); 

                auto tg_xyyyzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 681); 

                auto tg_xyyyzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 682); 

                auto tg_xyyyzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 683); 

                auto tg_xyyyzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 684); 

                auto tg_xyyyzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 685); 

                auto tg_xyyyzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 686); 

                auto tg_xyyyzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 687); 

                auto tg_xyyyzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 688); 

                auto tg_xyyyzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 689); 

                auto tg_xyyyzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 690); 

                auto tg_xyyyzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 691); 

                auto tg_xyyyzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 692); 

                auto tg_xyyyzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 693); 

                auto tg_xyyyzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 694); 

                auto tg_xyyyzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 695); 

                auto tg_xyyyzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 696); 

                auto tg_xyyyzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 697); 

                auto tg_xyyyzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 698); 

                auto tg_xyyyzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 699); 

                auto tg_xyyzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 700); 

                auto tg_xyyzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 701); 

                auto tg_xyyzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 702); 

                auto tg_xyyzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 703); 

                auto tg_xyyzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 704); 

                auto tg_xyyzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 705); 

                auto tg_xyyzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 706); 

                auto tg_xyyzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 707); 

                auto tg_xyyzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 708); 

                auto tg_xyyzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 709); 

                auto tg_xyyzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 710); 

                auto tg_xyyzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 711); 

                auto tg_xyyzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 712); 

                auto tg_xyyzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 713); 

                auto tg_xyyzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 714); 

                auto tg_xyyzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 715); 

                auto tg_xyyzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 716); 

                auto tg_xyyzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 717); 

                auto tg_xyyzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 718); 

                auto tg_xyyzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 719); 

                auto tg_xyyzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 720); 

                auto tg_xyyzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 721); 

                auto tg_xyyzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 722); 

                auto tg_xyyzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 723); 

                auto tg_xyyzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 724); 

                auto tg_xyyzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 725); 

                auto tg_xyyzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 726); 

                auto tg_xyyzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 727); 

                auto tg_xyzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 728); 

                auto tg_xyzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 729); 

                auto tg_xyzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 730); 

                auto tg_xyzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 731); 

                auto tg_xyzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 732); 

                auto tg_xyzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 733); 

                auto tg_xyzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 734); 

                auto tg_xyzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 735); 

                auto tg_xyzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 736); 

                auto tg_xyzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 737); 

                auto tg_xyzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 738); 

                auto tg_xyzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 739); 

                auto tg_xyzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 740); 

                auto tg_xyzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 741); 

                auto tg_xyzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 742); 

                auto tg_xyzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 743); 

                auto tg_xyzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 744); 

                auto tg_xyzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 745); 

                auto tg_xyzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 746); 

                auto tg_xyzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 747); 

                auto tg_xyzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 748); 

                auto tg_xyzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 749); 

                auto tg_xyzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 750); 

                auto tg_xyzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 751); 

                auto tg_xyzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 752); 

                auto tg_xyzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 753); 

                auto tg_xyzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 754); 

                auto tg_xyzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 755); 

                auto tg_xzzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 756); 

                auto tg_xzzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 757); 

                auto tg_xzzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 758); 

                auto tg_xzzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 759); 

                auto tg_xzzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 760); 

                auto tg_xzzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 761); 

                auto tg_xzzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 762); 

                auto tg_xzzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 763); 

                auto tg_xzzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 764); 

                auto tg_xzzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 765); 

                auto tg_xzzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 766); 

                auto tg_xzzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 767); 

                auto tg_xzzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 768); 

                auto tg_xzzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 769); 

                auto tg_xzzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 770); 

                auto tg_xzzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 771); 

                auto tg_xzzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 772); 

                auto tg_xzzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 773); 

                auto tg_xzzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 774); 

                auto tg_xzzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 775); 

                auto tg_xyyyzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 679); 

                auto tg_xyyyzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 680); 

                auto tg_xyyyzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 681); 

                auto tg_xyyyzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 682); 

                auto tg_xyyyzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 683); 

                auto tg_xyyyzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 684); 

                auto tg_xyyyzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 685); 

                auto tg_xyyyzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 686); 

                auto tg_xyyyzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 687); 

                auto tg_xyyyzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 688); 

                auto tg_xyyyzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 689); 

                auto tg_xyyyzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 690); 

                auto tg_xyyyzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 691); 

                auto tg_xyyyzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 692); 

                auto tg_xyyyzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 693); 

                auto tg_xyyyzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 694); 

                auto tg_xyyyzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 695); 

                auto tg_xyyyzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 696); 

                auto tg_xyyyzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 697); 

                auto tg_xyyyzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 698); 

                auto tg_xyyyzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 699); 

                auto tg_xyyzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 700); 

                auto tg_xyyzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 701); 

                auto tg_xyyzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 702); 

                auto tg_xyyzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 703); 

                auto tg_xyyzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 704); 

                auto tg_xyyzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 705); 

                auto tg_xyyzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 706); 

                auto tg_xyyzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 707); 

                auto tg_xyyzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 708); 

                auto tg_xyyzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 709); 

                auto tg_xyyzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 710); 

                auto tg_xyyzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 711); 

                auto tg_xyyzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 712); 

                auto tg_xyyzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 713); 

                auto tg_xyyzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 714); 

                auto tg_xyyzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 715); 

                auto tg_xyyzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 716); 

                auto tg_xyyzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 717); 

                auto tg_xyyzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 718); 

                auto tg_xyyzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 719); 

                auto tg_xyyzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 720); 

                auto tg_xyyzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 721); 

                auto tg_xyyzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 722); 

                auto tg_xyyzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 723); 

                auto tg_xyyzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 724); 

                auto tg_xyyzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 725); 

                auto tg_xyyzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 726); 

                auto tg_xyyzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 727); 

                auto tg_xyzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 728); 

                auto tg_xyzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 729); 

                auto tg_xyzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 730); 

                auto tg_xyzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 731); 

                auto tg_xyzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 732); 

                auto tg_xyzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 733); 

                auto tg_xyzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 734); 

                auto tg_xyzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 735); 

                auto tg_xyzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 736); 

                auto tg_xyzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 737); 

                auto tg_xyzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 738); 

                auto tg_xyzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 739); 

                auto tg_xyzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 740); 

                auto tg_xyzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 741); 

                auto tg_xyzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 742); 

                auto tg_xyzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 743); 

                auto tg_xyzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 744); 

                auto tg_xyzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 745); 

                auto tg_xyzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 746); 

                auto tg_xyzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 747); 

                auto tg_xyzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 748); 

                auto tg_xyzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 749); 

                auto tg_xyzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 750); 

                auto tg_xyzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 751); 

                auto tg_xyzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 752); 

                auto tg_xyzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 753); 

                auto tg_xyzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 754); 

                auto tg_xyzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 755); 

                auto tg_xzzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 756); 

                auto tg_xzzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 757); 

                auto tg_xzzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 758); 

                auto tg_xzzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 759); 

                auto tg_xzzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 760); 

                auto tg_xzzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 761); 

                auto tg_xzzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 762); 

                auto tg_xzzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 763); 

                auto tg_xzzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 764); 

                auto tg_xzzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 765); 

                auto tg_xzzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 766); 

                auto tg_xzzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 767); 

                auto tg_xzzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 768); 

                auto tg_xzzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 769); 

                auto tg_xzzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 770); 

                auto tg_xzzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 771); 

                auto tg_xzzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 772); 

                auto tg_xzzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 773); 

                auto tg_xzzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 774); 

                auto tg_xzzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 775); 

                auto tg_yyyzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 699); 

                auto tg_yyzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 733); 

                auto tg_yzzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 743); 

                auto tg_yzzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 775); 

                auto tg_yyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 699); 

                auto tg_yyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 733); 

                auto tg_yzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 743); 

                auto tg_yzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 775); 

                auto tg_xyyyzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 511); 

                auto tg_xyyyzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 512); 

                auto tg_xyyyzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 513); 

                auto tg_xyyyzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 514); 

                auto tg_xyyyzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 515); 

                auto tg_xyyyzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 516); 

                auto tg_xyyyzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 517); 

                auto tg_xyyyzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 518); 

                auto tg_xyyyzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 519); 

                auto tg_xyyyzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 520); 

                auto tg_xyyyzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 521); 

                auto tg_xyyyzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 522); 

                auto tg_xyyyzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 523); 

                auto tg_xyyyzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 524); 

                auto tg_xyyzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 525); 

                auto tg_xyyzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 526); 

                auto tg_xyyzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 527); 

                auto tg_xyyzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 528); 

                auto tg_xyyzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 529); 

                auto tg_xyyzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 530); 

                auto tg_xyyzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 531); 

                auto tg_xyyzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 532); 

                auto tg_xyyzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 533); 

                auto tg_xyyzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 534); 

                auto tg_xyyzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 535); 

                auto tg_xyyzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 536); 

                auto tg_xyyzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 537); 

                auto tg_xyyzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 538); 

                auto tg_xyyzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 539); 

                auto tg_xyyzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 540); 

                auto tg_xyyzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 541); 

                auto tg_xyyzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 542); 

                auto tg_xyyzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 543); 

                auto tg_xyyzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 544); 

                auto tg_xyyzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 545); 

                auto tg_xyzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 546); 

                auto tg_xyzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 547); 

                auto tg_xyzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 548); 

                auto tg_xyzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 549); 

                auto tg_xyzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 550); 

                auto tg_xyzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 551); 

                auto tg_xyzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 552); 

                auto tg_xyzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 553); 

                auto tg_xyzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 554); 

                auto tg_xyzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 555); 

                auto tg_xyzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 556); 

                auto tg_xyzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 557); 

                auto tg_xyzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 558); 

                auto tg_xyzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 559); 

                auto tg_xyzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 560); 

                auto tg_xyzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 561); 

                auto tg_xyzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 562); 

                auto tg_xyzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 563); 

                auto tg_xyzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 564); 

                auto tg_xyzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 565); 

                auto tg_xyzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 566); 

                auto tg_xzzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 567); 

                auto tg_xzzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 568); 

                auto tg_xzzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 569); 

                auto tg_xzzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 570); 

                auto tg_xzzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 571); 

                auto tg_xzzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 572); 

                auto tg_xzzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 573); 

                auto tg_xzzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 574); 

                auto tg_xzzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 575); 

                auto tg_xzzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 576); 

                auto tg_xzzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 577); 

                auto tg_xzzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 578); 

                auto tg_xzzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 579); 

                auto tg_xzzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 580); 

                auto tg_xzzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 581); 

                auto tg_xzzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 582); 

                auto tg_xzzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 583); 

                auto tg_xzzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 584); 

                auto tg_xzzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 585); 

                auto tg_xzzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 586); 

                // set up pointers to integrals

                auto tg_xxyyyzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 679); 

                auto tg_xxyyyzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 680); 

                auto tg_xxyyyzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 681); 

                auto tg_xxyyyzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 682); 

                auto tg_xxyyyzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 683); 

                auto tg_xxyyyzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 684); 

                auto tg_xxyyyzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 685); 

                auto tg_xxyyyzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 686); 

                auto tg_xxyyyzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 687); 

                auto tg_xxyyyzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 688); 

                auto tg_xxyyyzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 689); 

                auto tg_xxyyyzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 690); 

                auto tg_xxyyyzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 691); 

                auto tg_xxyyyzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 692); 

                auto tg_xxyyyzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 693); 

                auto tg_xxyyyzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 694); 

                auto tg_xxyyyzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 695); 

                auto tg_xxyyyzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 696); 

                auto tg_xxyyyzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 697); 

                auto tg_xxyyyzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 698); 

                auto tg_xxyyyzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 699); 

                auto tg_xxyyzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 700); 

                auto tg_xxyyzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 701); 

                auto tg_xxyyzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 702); 

                auto tg_xxyyzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 703); 

                auto tg_xxyyzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 704); 

                auto tg_xxyyzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 705); 

                auto tg_xxyyzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 706); 

                auto tg_xxyyzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 707); 

                auto tg_xxyyzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 708); 

                auto tg_xxyyzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 709); 

                auto tg_xxyyzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 710); 

                auto tg_xxyyzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 711); 

                auto tg_xxyyzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 712); 

                auto tg_xxyyzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 713); 

                auto tg_xxyyzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 714); 

                auto tg_xxyyzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 715); 

                auto tg_xxyyzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 716); 

                auto tg_xxyyzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 717); 

                auto tg_xxyyzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 718); 

                auto tg_xxyyzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 719); 

                auto tg_xxyyzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 720); 

                auto tg_xxyyzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 721); 

                auto tg_xxyyzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 722); 

                auto tg_xxyyzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 723); 

                auto tg_xxyyzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 724); 

                auto tg_xxyyzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 725); 

                auto tg_xxyyzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 726); 

                auto tg_xxyyzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 727); 

                auto tg_xxyzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 728); 

                auto tg_xxyzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 729); 

                auto tg_xxyzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 730); 

                auto tg_xxyzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 731); 

                auto tg_xxyzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 732); 

                auto tg_xxyzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 733); 

                auto tg_xxyzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 734); 

                auto tg_xxyzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 735); 

                auto tg_xxyzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 736); 

                auto tg_xxyzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 737); 

                auto tg_xxyzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 738); 

                auto tg_xxyzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 739); 

                auto tg_xxyzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 740); 

                auto tg_xxyzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 741); 

                auto tg_xxyzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 742); 

                auto tg_xxyzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 743); 

                auto tg_xxyzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 744); 

                auto tg_xxyzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 745); 

                auto tg_xxyzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 746); 

                auto tg_xxyzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 747); 

                auto tg_xxyzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 748); 

                auto tg_xxyzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 749); 

                auto tg_xxyzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 750); 

                auto tg_xxyzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 751); 

                auto tg_xxyzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 752); 

                auto tg_xxyzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 753); 

                auto tg_xxyzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 754); 

                auto tg_xxyzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 755); 

                auto tg_xxzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 756); 

                auto tg_xxzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 757); 

                auto tg_xxzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 758); 

                auto tg_xxzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 759); 

                auto tg_xxzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 760); 

                auto tg_xxzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 761); 

                auto tg_xxzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 762); 

                auto tg_xxzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 763); 

                auto tg_xxzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 764); 

                auto tg_xxzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 765); 

                auto tg_xxzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 766); 

                auto tg_xxzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 767); 

                auto tg_xxzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 768); 

                auto tg_xxzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 769); 

                auto tg_xxzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 770); 

                auto tg_xxzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 771); 

                auto tg_xxzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 772); 

                auto tg_xxzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 773); 

                auto tg_xxzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 774); 

                auto tg_xxzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 775); 

                // Batch of Integrals (679,776)

                #pragma omp simd aligned(fxn, fza, tg_xxyyyzzz_xxxyyz_0, tg_xxyyyzzz_xxxyzz_0, \
                                         tg_xxyyyzzz_xxxzzz_0, tg_xxyyyzzz_xxyyyy_0, tg_xxyyyzzz_xxyyyz_0, tg_xxyyyzzz_xxyyzz_0, \
                                         tg_xxyyyzzz_xxyzzz_0, tg_xxyyyzzz_xxzzzz_0, tg_xxyyyzzz_xyyyyy_0, tg_xxyyyzzz_xyyyyz_0, \
                                         tg_xxyyyzzz_xyyyzz_0, tg_xxyyyzzz_xyyzzz_0, tg_xxyyyzzz_xyzzzz_0, tg_xxyyyzzz_xzzzzz_0, \
                                         tg_xxyyyzzz_yyyyyy_0, tg_xxyyyzzz_yyyyyz_0, tg_xxyyyzzz_yyyyzz_0, tg_xxyyyzzz_yyyzzz_0, \
                                         tg_xxyyyzzz_yyzzzz_0, tg_xxyyyzzz_yzzzzz_0, tg_xxyyyzzz_zzzzzz_0, tg_xxyyzzzz_xxxxxx_0, \
                                         tg_xxyyzzzz_xxxxxy_0, tg_xxyyzzzz_xxxxxz_0, tg_xxyyzzzz_xxxxyy_0, tg_xxyyzzzz_xxxxyz_0, \
                                         tg_xxyyzzzz_xxxxzz_0, tg_xxyyzzzz_xxxyyy_0, tg_xxyyzzzz_xxxyyz_0, tg_xxyyzzzz_xxxyzz_0, \
                                         tg_xxyyzzzz_xxxzzz_0, tg_xxyyzzzz_xxyyyy_0, tg_xxyyzzzz_xxyyyz_0, tg_xxyyzzzz_xxyyzz_0, \
                                         tg_xxyyzzzz_xxyzzz_0, tg_xxyyzzzz_xxzzzz_0, tg_xxyyzzzz_xyyyyy_0, tg_xxyyzzzz_xyyyyz_0, \
                                         tg_xxyyzzzz_xyyyzz_0, tg_xxyyzzzz_xyyzzz_0, tg_xxyyzzzz_xyzzzz_0, tg_xxyyzzzz_xzzzzz_0, \
                                         tg_xxyyzzzz_yyyyyy_0, tg_xxyyzzzz_yyyyyz_0, tg_xxyyzzzz_yyyyzz_0, tg_xxyyzzzz_yyyzzz_0, \
                                         tg_xxyyzzzz_yyzzzz_0, tg_xxyyzzzz_yzzzzz_0, tg_xxyyzzzz_zzzzzz_0, tg_xxyzzzzz_xxxxxx_0, \
                                         tg_xxyzzzzz_xxxxxy_0, tg_xxyzzzzz_xxxxxz_0, tg_xxyzzzzz_xxxxyy_0, tg_xxyzzzzz_xxxxyz_0, \
                                         tg_xxyzzzzz_xxxxzz_0, tg_xxyzzzzz_xxxyyy_0, tg_xxyzzzzz_xxxyyz_0, tg_xxyzzzzz_xxxyzz_0, \
                                         tg_xxyzzzzz_xxxzzz_0, tg_xxyzzzzz_xxyyyy_0, tg_xxyzzzzz_xxyyyz_0, tg_xxyzzzzz_xxyyzz_0, \
                                         tg_xxyzzzzz_xxyzzz_0, tg_xxyzzzzz_xxzzzz_0, tg_xxyzzzzz_xyyyyy_0, tg_xxyzzzzz_xyyyyz_0, \
                                         tg_xxyzzzzz_xyyyzz_0, tg_xxyzzzzz_xyyzzz_0, tg_xxyzzzzz_xyzzzz_0, tg_xxyzzzzz_xzzzzz_0, \
                                         tg_xxyzzzzz_yyyyyy_0, tg_xxyzzzzz_yyyyyz_0, tg_xxyzzzzz_yyyyzz_0, tg_xxyzzzzz_yyyzzz_0, \
                                         tg_xxyzzzzz_yyzzzz_0, tg_xxyzzzzz_yzzzzz_0, tg_xxyzzzzz_zzzzzz_0, tg_xxzzzzzz_xxxxxx_0, \
                                         tg_xxzzzzzz_xxxxxy_0, tg_xxzzzzzz_xxxxxz_0, tg_xxzzzzzz_xxxxyy_0, tg_xxzzzzzz_xxxxyz_0, \
                                         tg_xxzzzzzz_xxxxzz_0, tg_xxzzzzzz_xxxyyy_0, tg_xxzzzzzz_xxxyyz_0, tg_xxzzzzzz_xxxyzz_0, \
                                         tg_xxzzzzzz_xxxzzz_0, tg_xxzzzzzz_xxyyyy_0, tg_xxzzzzzz_xxyyyz_0, tg_xxzzzzzz_xxyyzz_0, \
                                         tg_xxzzzzzz_xxyzzz_0, tg_xxzzzzzz_xxzzzz_0, tg_xxzzzzzz_xyyyyy_0, tg_xxzzzzzz_xyyyyz_0, \
                                         tg_xxzzzzzz_xyyyzz_0, tg_xxzzzzzz_xyyzzz_0, tg_xxzzzzzz_xyzzzz_0, tg_xyyyzzz_xxxyyz_0, \
                                         tg_xyyyzzz_xxxyyz_1, tg_xyyyzzz_xxxyzz_0, tg_xyyyzzz_xxxyzz_1, tg_xyyyzzz_xxxzzz_0, \
                                         tg_xyyyzzz_xxxzzz_1, tg_xyyyzzz_xxyyyy_0, tg_xyyyzzz_xxyyyy_1, tg_xyyyzzz_xxyyyz_0, \
                                         tg_xyyyzzz_xxyyyz_1, tg_xyyyzzz_xxyyz_1, tg_xyyyzzz_xxyyzz_0, tg_xyyyzzz_xxyyzz_1, \
                                         tg_xyyyzzz_xxyzz_1, tg_xyyyzzz_xxyzzz_0, tg_xyyyzzz_xxyzzz_1, tg_xyyyzzz_xxzzz_1, \
                                         tg_xyyyzzz_xxzzzz_0, tg_xyyyzzz_xxzzzz_1, tg_xyyyzzz_xyyyy_1, tg_xyyyzzz_xyyyyy_0, \
                                         tg_xyyyzzz_xyyyyy_1, tg_xyyyzzz_xyyyyz_0, tg_xyyyzzz_xyyyyz_1, tg_xyyyzzz_xyyyz_1, \
                                         tg_xyyyzzz_xyyyzz_0, tg_xyyyzzz_xyyyzz_1, tg_xyyyzzz_xyyzz_1, tg_xyyyzzz_xyyzzz_0, \
                                         tg_xyyyzzz_xyyzzz_1, tg_xyyyzzz_xyzzz_1, tg_xyyyzzz_xyzzzz_0, tg_xyyyzzz_xyzzzz_1, \
                                         tg_xyyyzzz_xzzzz_1, tg_xyyyzzz_xzzzzz_0, tg_xyyyzzz_xzzzzz_1, tg_xyyyzzz_yyyyy_1, \
                                         tg_xyyyzzz_yyyyyy_0, tg_xyyyzzz_yyyyyy_1, tg_xyyyzzz_yyyyyz_0, tg_xyyyzzz_yyyyyz_1, \
                                         tg_xyyyzzz_yyyyz_1, tg_xyyyzzz_yyyyzz_0, tg_xyyyzzz_yyyyzz_1, tg_xyyyzzz_yyyzz_1, \
                                         tg_xyyyzzz_yyyzzz_0, tg_xyyyzzz_yyyzzz_1, tg_xyyyzzz_yyzzz_1, tg_xyyyzzz_yyzzzz_0, \
                                         tg_xyyyzzz_yyzzzz_1, tg_xyyyzzz_yzzzz_1, tg_xyyyzzz_yzzzzz_0, tg_xyyyzzz_yzzzzz_1, \
                                         tg_xyyyzzz_zzzzz_1, tg_xyyyzzz_zzzzzz_0, tg_xyyyzzz_zzzzzz_1, tg_xyyzzzz_xxxxx_1, \
                                         tg_xyyzzzz_xxxxxx_0, tg_xyyzzzz_xxxxxx_1, tg_xyyzzzz_xxxxxy_0, tg_xyyzzzz_xxxxxy_1, \
                                         tg_xyyzzzz_xxxxxz_0, tg_xyyzzzz_xxxxxz_1, tg_xyyzzzz_xxxxy_1, tg_xyyzzzz_xxxxyy_0, \
                                         tg_xyyzzzz_xxxxyy_1, tg_xyyzzzz_xxxxyz_0, tg_xyyzzzz_xxxxyz_1, tg_xyyzzzz_xxxxz_1, \
                                         tg_xyyzzzz_xxxxzz_0, tg_xyyzzzz_xxxxzz_1, tg_xyyzzzz_xxxyy_1, tg_xyyzzzz_xxxyyy_0, \
                                         tg_xyyzzzz_xxxyyy_1, tg_xyyzzzz_xxxyyz_0, tg_xyyzzzz_xxxyyz_1, tg_xyyzzzz_xxxyz_1, \
                                         tg_xyyzzzz_xxxyzz_0, tg_xyyzzzz_xxxyzz_1, tg_xyyzzzz_xxxzz_1, tg_xyyzzzz_xxxzzz_0, \
                                         tg_xyyzzzz_xxxzzz_1, tg_xyyzzzz_xxyyy_1, tg_xyyzzzz_xxyyyy_0, tg_xyyzzzz_xxyyyy_1, \
                                         tg_xyyzzzz_xxyyyz_0, tg_xyyzzzz_xxyyyz_1, tg_xyyzzzz_xxyyz_1, tg_xyyzzzz_xxyyzz_0, \
                                         tg_xyyzzzz_xxyyzz_1, tg_xyyzzzz_xxyzz_1, tg_xyyzzzz_xxyzzz_0, tg_xyyzzzz_xxyzzz_1, \
                                         tg_xyyzzzz_xxzzz_1, tg_xyyzzzz_xxzzzz_0, tg_xyyzzzz_xxzzzz_1, tg_xyyzzzz_xyyyy_1, \
                                         tg_xyyzzzz_xyyyyy_0, tg_xyyzzzz_xyyyyy_1, tg_xyyzzzz_xyyyyz_0, tg_xyyzzzz_xyyyyz_1, \
                                         tg_xyyzzzz_xyyyz_1, tg_xyyzzzz_xyyyzz_0, tg_xyyzzzz_xyyyzz_1, tg_xyyzzzz_xyyzz_1, \
                                         tg_xyyzzzz_xyyzzz_0, tg_xyyzzzz_xyyzzz_1, tg_xyyzzzz_xyzzz_1, tg_xyyzzzz_xyzzzz_0, \
                                         tg_xyyzzzz_xyzzzz_1, tg_xyyzzzz_xzzzz_1, tg_xyyzzzz_xzzzzz_0, tg_xyyzzzz_xzzzzz_1, \
                                         tg_xyyzzzz_yyyyy_1, tg_xyyzzzz_yyyyyy_0, tg_xyyzzzz_yyyyyy_1, tg_xyyzzzz_yyyyyz_0, \
                                         tg_xyyzzzz_yyyyyz_1, tg_xyyzzzz_yyyyz_1, tg_xyyzzzz_yyyyzz_0, tg_xyyzzzz_yyyyzz_1, \
                                         tg_xyyzzzz_yyyzz_1, tg_xyyzzzz_yyyzzz_0, tg_xyyzzzz_yyyzzz_1, tg_xyyzzzz_yyzzz_1, \
                                         tg_xyyzzzz_yyzzzz_0, tg_xyyzzzz_yyzzzz_1, tg_xyyzzzz_yzzzz_1, tg_xyyzzzz_yzzzzz_0, \
                                         tg_xyyzzzz_yzzzzz_1, tg_xyyzzzz_zzzzz_1, tg_xyyzzzz_zzzzzz_0, tg_xyyzzzz_zzzzzz_1, \
                                         tg_xyzzzzz_xxxxx_1, tg_xyzzzzz_xxxxxx_0, tg_xyzzzzz_xxxxxx_1, tg_xyzzzzz_xxxxxy_0, \
                                         tg_xyzzzzz_xxxxxy_1, tg_xyzzzzz_xxxxxz_0, tg_xyzzzzz_xxxxxz_1, tg_xyzzzzz_xxxxy_1, \
                                         tg_xyzzzzz_xxxxyy_0, tg_xyzzzzz_xxxxyy_1, tg_xyzzzzz_xxxxyz_0, tg_xyzzzzz_xxxxyz_1, \
                                         tg_xyzzzzz_xxxxz_1, tg_xyzzzzz_xxxxzz_0, tg_xyzzzzz_xxxxzz_1, tg_xyzzzzz_xxxyy_1, \
                                         tg_xyzzzzz_xxxyyy_0, tg_xyzzzzz_xxxyyy_1, tg_xyzzzzz_xxxyyz_0, tg_xyzzzzz_xxxyyz_1, \
                                         tg_xyzzzzz_xxxyz_1, tg_xyzzzzz_xxxyzz_0, tg_xyzzzzz_xxxyzz_1, tg_xyzzzzz_xxxzz_1, \
                                         tg_xyzzzzz_xxxzzz_0, tg_xyzzzzz_xxxzzz_1, tg_xyzzzzz_xxyyy_1, tg_xyzzzzz_xxyyyy_0, \
                                         tg_xyzzzzz_xxyyyy_1, tg_xyzzzzz_xxyyyz_0, tg_xyzzzzz_xxyyyz_1, tg_xyzzzzz_xxyyz_1, \
                                         tg_xyzzzzz_xxyyzz_0, tg_xyzzzzz_xxyyzz_1, tg_xyzzzzz_xxyzz_1, tg_xyzzzzz_xxyzzz_0, \
                                         tg_xyzzzzz_xxyzzz_1, tg_xyzzzzz_xxzzz_1, tg_xyzzzzz_xxzzzz_0, tg_xyzzzzz_xxzzzz_1, \
                                         tg_xyzzzzz_xyyyy_1, tg_xyzzzzz_xyyyyy_0, tg_xyzzzzz_xyyyyy_1, tg_xyzzzzz_xyyyyz_0, \
                                         tg_xyzzzzz_xyyyyz_1, tg_xyzzzzz_xyyyz_1, tg_xyzzzzz_xyyyzz_0, tg_xyzzzzz_xyyyzz_1, \
                                         tg_xyzzzzz_xyyzz_1, tg_xyzzzzz_xyyzzz_0, tg_xyzzzzz_xyyzzz_1, tg_xyzzzzz_xyzzz_1, \
                                         tg_xyzzzzz_xyzzzz_0, tg_xyzzzzz_xyzzzz_1, tg_xyzzzzz_xzzzz_1, tg_xyzzzzz_xzzzzz_0, \
                                         tg_xyzzzzz_xzzzzz_1, tg_xyzzzzz_yyyyy_1, tg_xyzzzzz_yyyyyy_0, tg_xyzzzzz_yyyyyy_1, \
                                         tg_xyzzzzz_yyyyyz_0, tg_xyzzzzz_yyyyyz_1, tg_xyzzzzz_yyyyz_1, tg_xyzzzzz_yyyyzz_0, \
                                         tg_xyzzzzz_yyyyzz_1, tg_xyzzzzz_yyyzz_1, tg_xyzzzzz_yyyzzz_0, tg_xyzzzzz_yyyzzz_1, \
                                         tg_xyzzzzz_yyzzz_1, tg_xyzzzzz_yyzzzz_0, tg_xyzzzzz_yyzzzz_1, tg_xyzzzzz_yzzzz_1, \
                                         tg_xyzzzzz_yzzzzz_0, tg_xyzzzzz_yzzzzz_1, tg_xyzzzzz_zzzzz_1, tg_xyzzzzz_zzzzzz_0, \
                                         tg_xyzzzzz_zzzzzz_1, tg_xzzzzzz_xxxxx_1, tg_xzzzzzz_xxxxxx_0, tg_xzzzzzz_xxxxxx_1, \
                                         tg_xzzzzzz_xxxxxy_0, tg_xzzzzzz_xxxxxy_1, tg_xzzzzzz_xxxxxz_0, tg_xzzzzzz_xxxxxz_1, \
                                         tg_xzzzzzz_xxxxy_1, tg_xzzzzzz_xxxxyy_0, tg_xzzzzzz_xxxxyy_1, tg_xzzzzzz_xxxxyz_0, \
                                         tg_xzzzzzz_xxxxyz_1, tg_xzzzzzz_xxxxz_1, tg_xzzzzzz_xxxxzz_0, tg_xzzzzzz_xxxxzz_1, \
                                         tg_xzzzzzz_xxxyy_1, tg_xzzzzzz_xxxyyy_0, tg_xzzzzzz_xxxyyy_1, tg_xzzzzzz_xxxyyz_0, \
                                         tg_xzzzzzz_xxxyyz_1, tg_xzzzzzz_xxxyz_1, tg_xzzzzzz_xxxyzz_0, tg_xzzzzzz_xxxyzz_1, \
                                         tg_xzzzzzz_xxxzz_1, tg_xzzzzzz_xxxzzz_0, tg_xzzzzzz_xxxzzz_1, tg_xzzzzzz_xxyyy_1, \
                                         tg_xzzzzzz_xxyyyy_0, tg_xzzzzzz_xxyyyy_1, tg_xzzzzzz_xxyyyz_0, tg_xzzzzzz_xxyyyz_1, \
                                         tg_xzzzzzz_xxyyz_1, tg_xzzzzzz_xxyyzz_0, tg_xzzzzzz_xxyyzz_1, tg_xzzzzzz_xxyzz_1, \
                                         tg_xzzzzzz_xxyzzz_0, tg_xzzzzzz_xxyzzz_1, tg_xzzzzzz_xxzzz_1, tg_xzzzzzz_xxzzzz_0, \
                                         tg_xzzzzzz_xxzzzz_1, tg_xzzzzzz_xyyyy_1, tg_xzzzzzz_xyyyyy_0, tg_xzzzzzz_xyyyyy_1, \
                                         tg_xzzzzzz_xyyyyz_0, tg_xzzzzzz_xyyyyz_1, tg_xzzzzzz_xyyyz_1, tg_xzzzzzz_xyyyzz_0, \
                                         tg_xzzzzzz_xyyyzz_1, tg_xzzzzzz_xyyzz_1, tg_xzzzzzz_xyyzzz_0, tg_xzzzzzz_xyyzzz_1, \
                                         tg_xzzzzzz_xyzzz_1, tg_xzzzzzz_xyzzzz_0, tg_xzzzzzz_xyzzzz_1, tg_xzzzzzz_xzzzz_1, \
                                         tg_xzzzzzz_yyyyy_1, tg_xzzzzzz_yyyyz_1, tg_xzzzzzz_yyyzz_1, tg_xzzzzzz_yyzzz_1, \
                                         tg_xzzzzzz_yzzzz_1, tg_yyyzzz_xxxyyz_0, tg_yyyzzz_xxxyyz_1, tg_yyyzzz_xxxyzz_0, \
                                         tg_yyyzzz_xxxyzz_1, tg_yyyzzz_xxxzzz_0, tg_yyyzzz_xxxzzz_1, tg_yyyzzz_xxyyyy_0, \
                                         tg_yyyzzz_xxyyyy_1, tg_yyyzzz_xxyyyz_0, tg_yyyzzz_xxyyyz_1, tg_yyyzzz_xxyyzz_0, \
                                         tg_yyyzzz_xxyyzz_1, tg_yyyzzz_xxyzzz_0, tg_yyyzzz_xxyzzz_1, tg_yyyzzz_xxzzzz_0, \
                                         tg_yyyzzz_xxzzzz_1, tg_yyyzzz_xyyyyy_0, tg_yyyzzz_xyyyyy_1, tg_yyyzzz_xyyyyz_0, \
                                         tg_yyyzzz_xyyyyz_1, tg_yyyzzz_xyyyzz_0, tg_yyyzzz_xyyyzz_1, tg_yyyzzz_xyyzzz_0, \
                                         tg_yyyzzz_xyyzzz_1, tg_yyyzzz_xyzzzz_0, tg_yyyzzz_xyzzzz_1, tg_yyyzzz_xzzzzz_0, \
                                         tg_yyyzzz_xzzzzz_1, tg_yyyzzz_yyyyyy_0, tg_yyyzzz_yyyyyy_1, tg_yyyzzz_yyyyyz_0, \
                                         tg_yyyzzz_yyyyyz_1, tg_yyyzzz_yyyyzz_0, tg_yyyzzz_yyyyzz_1, tg_yyyzzz_yyyzzz_0, \
                                         tg_yyyzzz_yyyzzz_1, tg_yyyzzz_yyzzzz_0, tg_yyyzzz_yyzzzz_1, tg_yyyzzz_yzzzzz_0, \
                                         tg_yyyzzz_yzzzzz_1, tg_yyyzzz_zzzzzz_0, tg_yyyzzz_zzzzzz_1, tg_yyzzzz_xxxxxx_0, \
                                         tg_yyzzzz_xxxxxx_1, tg_yyzzzz_xxxxxy_0, tg_yyzzzz_xxxxxy_1, tg_yyzzzz_xxxxxz_0, \
                                         tg_yyzzzz_xxxxxz_1, tg_yyzzzz_xxxxyy_0, tg_yyzzzz_xxxxyy_1, tg_yyzzzz_xxxxyz_0, \
                                         tg_yyzzzz_xxxxyz_1, tg_yyzzzz_xxxxzz_0, tg_yyzzzz_xxxxzz_1, tg_yyzzzz_xxxyyy_0, \
                                         tg_yyzzzz_xxxyyy_1, tg_yyzzzz_xxxyyz_0, tg_yyzzzz_xxxyyz_1, tg_yyzzzz_xxxyzz_0, \
                                         tg_yyzzzz_xxxyzz_1, tg_yyzzzz_xxxzzz_0, tg_yyzzzz_xxxzzz_1, tg_yyzzzz_xxyyyy_0, \
                                         tg_yyzzzz_xxyyyy_1, tg_yyzzzz_xxyyyz_0, tg_yyzzzz_xxyyyz_1, tg_yyzzzz_xxyyzz_0, \
                                         tg_yyzzzz_xxyyzz_1, tg_yyzzzz_xxyzzz_0, tg_yyzzzz_xxyzzz_1, tg_yyzzzz_xxzzzz_0, \
                                         tg_yyzzzz_xxzzzz_1, tg_yyzzzz_xyyyyy_0, tg_yyzzzz_xyyyyy_1, tg_yyzzzz_xyyyyz_0, \
                                         tg_yyzzzz_xyyyyz_1, tg_yyzzzz_xyyyzz_0, tg_yyzzzz_xyyyzz_1, tg_yyzzzz_xyyzzz_0, \
                                         tg_yyzzzz_xyyzzz_1, tg_yyzzzz_xyzzzz_0, tg_yyzzzz_xyzzzz_1, tg_yyzzzz_xzzzzz_0, \
                                         tg_yyzzzz_xzzzzz_1, tg_yyzzzz_yyyyyy_0, tg_yyzzzz_yyyyyy_1, tg_yyzzzz_yyyyyz_0, \
                                         tg_yyzzzz_yyyyyz_1, tg_yyzzzz_yyyyzz_0, tg_yyzzzz_yyyyzz_1, tg_yyzzzz_yyyzzz_0, \
                                         tg_yyzzzz_yyyzzz_1, tg_yyzzzz_yyzzzz_0, tg_yyzzzz_yyzzzz_1, tg_yyzzzz_yzzzzz_0, \
                                         tg_yyzzzz_yzzzzz_1, tg_yyzzzz_zzzzzz_0, tg_yyzzzz_zzzzzz_1, tg_yzzzzz_xxxxxx_0, \
                                         tg_yzzzzz_xxxxxx_1, tg_yzzzzz_xxxxxy_0, tg_yzzzzz_xxxxxy_1, tg_yzzzzz_xxxxxz_0, \
                                         tg_yzzzzz_xxxxxz_1, tg_yzzzzz_xxxxyy_0, tg_yzzzzz_xxxxyy_1, tg_yzzzzz_xxxxyz_0, \
                                         tg_yzzzzz_xxxxyz_1, tg_yzzzzz_xxxxzz_0, tg_yzzzzz_xxxxzz_1, tg_yzzzzz_xxxyyy_0, \
                                         tg_yzzzzz_xxxyyy_1, tg_yzzzzz_xxxyyz_0, tg_yzzzzz_xxxyyz_1, tg_yzzzzz_xxxyzz_0, \
                                         tg_yzzzzz_xxxyzz_1, tg_yzzzzz_xxxzzz_0, tg_yzzzzz_xxxzzz_1, tg_yzzzzz_xxyyyy_0, \
                                         tg_yzzzzz_xxyyyy_1, tg_yzzzzz_xxyyyz_0, tg_yzzzzz_xxyyyz_1, tg_yzzzzz_xxyyzz_0, \
                                         tg_yzzzzz_xxyyzz_1, tg_yzzzzz_xxyzzz_0, tg_yzzzzz_xxyzzz_1, tg_yzzzzz_xxzzzz_0, \
                                         tg_yzzzzz_xxzzzz_1, tg_yzzzzz_xyyyyy_0, tg_yzzzzz_xyyyyy_1, tg_yzzzzz_xyyyyz_0, \
                                         tg_yzzzzz_xyyyyz_1, tg_yzzzzz_xyyyzz_0, tg_yzzzzz_xyyyzz_1, tg_yzzzzz_xyyzzz_0, \
                                         tg_yzzzzz_xyyzzz_1, tg_yzzzzz_xyzzzz_0, tg_yzzzzz_xyzzzz_1, tg_yzzzzz_xzzzzz_0, \
                                         tg_yzzzzz_xzzzzz_1, tg_yzzzzz_yyyyyy_0, tg_yzzzzz_yyyyyy_1, tg_yzzzzz_yyyyyz_0, \
                                         tg_yzzzzz_yyyyyz_1, tg_yzzzzz_yyyyzz_0, tg_yzzzzz_yyyyzz_1, tg_yzzzzz_yyyzzz_0, \
                                         tg_yzzzzz_yyyzzz_1, tg_yzzzzz_yyzzzz_0, tg_yzzzzz_yyzzzz_1, tg_yzzzzz_yzzzzz_0, \
                                         tg_yzzzzz_yzzzzz_1, tg_yzzzzz_zzzzzz_0, tg_yzzzzz_zzzzzz_1, tg_zzzzzz_xxxxxx_0, \
                                         tg_zzzzzz_xxxxxx_1, tg_zzzzzz_xxxxxy_0, tg_zzzzzz_xxxxxy_1, tg_zzzzzz_xxxxxz_0, \
                                         tg_zzzzzz_xxxxxz_1, tg_zzzzzz_xxxxyy_0, tg_zzzzzz_xxxxyy_1, tg_zzzzzz_xxxxyz_0, \
                                         tg_zzzzzz_xxxxyz_1, tg_zzzzzz_xxxxzz_0, tg_zzzzzz_xxxxzz_1, tg_zzzzzz_xxxyyy_0, \
                                         tg_zzzzzz_xxxyyy_1, tg_zzzzzz_xxxyyz_0, tg_zzzzzz_xxxyyz_1, tg_zzzzzz_xxxyzz_0, \
                                         tg_zzzzzz_xxxyzz_1, tg_zzzzzz_xxxzzz_0, tg_zzzzzz_xxxzzz_1, tg_zzzzzz_xxyyyy_0, \
                                         tg_zzzzzz_xxyyyy_1, tg_zzzzzz_xxyyyz_0, tg_zzzzzz_xxyyyz_1, tg_zzzzzz_xxyyzz_0, \
                                         tg_zzzzzz_xxyyzz_1, tg_zzzzzz_xxyzzz_0, tg_zzzzzz_xxyzzz_1, tg_zzzzzz_xxzzzz_0, \
                                         tg_zzzzzz_xxzzzz_1, tg_zzzzzz_xyyyyy_0, tg_zzzzzz_xyyyyy_1, tg_zzzzzz_xyyyyz_0, \
                                         tg_zzzzzz_xyyyyz_1, tg_zzzzzz_xyyyzz_0, tg_zzzzzz_xyyyzz_1, tg_zzzzzz_xyyzzz_0, \
                                         tg_zzzzzz_xyyzzz_1, tg_zzzzzz_xyzzzz_0, tg_zzzzzz_xyzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxyyyzzz_xxxyyz_0[j] = pb_x * tg_xyyyzzz_xxxyyz_0[j] + fr * tg_xyyyzzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxyyz_0[j] - tg_yyyzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzzz_xxyyz_1[j];

                    tg_xxyyyzzz_xxxyzz_0[j] = pb_x * tg_xyyyzzz_xxxyzz_0[j] + fr * tg_xyyyzzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxyzz_0[j] - tg_yyyzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzzz_xxyzz_1[j];

                    tg_xxyyyzzz_xxxzzz_0[j] = pb_x * tg_xyyyzzz_xxxzzz_0[j] + fr * tg_xyyyzzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxxzzz_0[j] - tg_yyyzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyyzzz_xxzzz_1[j];

                    tg_xxyyyzzz_xxyyyy_0[j] = pb_x * tg_xyyyzzz_xxyyyy_0[j] + fr * tg_xyyyzzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxyyyy_0[j] - tg_yyyzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_xyyyy_1[j];

                    tg_xxyyyzzz_xxyyyz_0[j] = pb_x * tg_xyyyzzz_xxyyyz_0[j] + fr * tg_xyyyzzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxyyyz_0[j] - tg_yyyzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_xyyyz_1[j];

                    tg_xxyyyzzz_xxyyzz_0[j] = pb_x * tg_xyyyzzz_xxyyzz_0[j] + fr * tg_xyyyzzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxyyzz_0[j] - tg_yyyzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_xyyzz_1[j];

                    tg_xxyyyzzz_xxyzzz_0[j] = pb_x * tg_xyyyzzz_xxyzzz_0[j] + fr * tg_xyyyzzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxyzzz_0[j] - tg_yyyzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_xyzzz_1[j];

                    tg_xxyyyzzz_xxzzzz_0[j] = pb_x * tg_xyyyzzz_xxzzzz_0[j] + fr * tg_xyyyzzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xxzzzz_0[j] - tg_yyyzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyyzzz_xzzzz_1[j];

                    tg_xxyyyzzz_xyyyyy_0[j] = pb_x * tg_xyyyzzz_xyyyyy_0[j] + fr * tg_xyyyzzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xyyyyy_0[j] - tg_yyyzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_yyyyy_1[j];

                    tg_xxyyyzzz_xyyyyz_0[j] = pb_x * tg_xyyyzzz_xyyyyz_0[j] + fr * tg_xyyyzzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xyyyyz_0[j] - tg_yyyzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_yyyyz_1[j];

                    tg_xxyyyzzz_xyyyzz_0[j] = pb_x * tg_xyyyzzz_xyyyzz_0[j] + fr * tg_xyyyzzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xyyyzz_0[j] - tg_yyyzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_yyyzz_1[j];

                    tg_xxyyyzzz_xyyzzz_0[j] = pb_x * tg_xyyyzzz_xyyzzz_0[j] + fr * tg_xyyyzzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xyyzzz_0[j] - tg_yyyzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_yyzzz_1[j];

                    tg_xxyyyzzz_xyzzzz_0[j] = pb_x * tg_xyyyzzz_xyzzzz_0[j] + fr * tg_xyyyzzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xyzzzz_0[j] - tg_yyyzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_yzzzz_1[j];

                    tg_xxyyyzzz_xzzzzz_0[j] = pb_x * tg_xyyyzzz_xzzzzz_0[j] + fr * tg_xyyyzzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_xzzzzz_0[j] - tg_yyyzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyyzzz_zzzzz_1[j];

                    tg_xxyyyzzz_yyyyyy_0[j] = pb_x * tg_xyyyzzz_yyyyyy_0[j] + fr * tg_xyyyzzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yyyyyy_0[j] - tg_yyyzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxyyyzzz_yyyyyz_0[j] = pb_x * tg_xyyyzzz_yyyyyz_0[j] + fr * tg_xyyyzzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yyyyyz_0[j] - tg_yyyzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxyyyzzz_yyyyzz_0[j] = pb_x * tg_xyyyzzz_yyyyzz_0[j] + fr * tg_xyyyzzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yyyyzz_0[j] - tg_yyyzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxyyyzzz_yyyzzz_0[j] = pb_x * tg_xyyyzzz_yyyzzz_0[j] + fr * tg_xyyyzzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yyyzzz_0[j] - tg_yyyzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxyyyzzz_yyzzzz_0[j] = pb_x * tg_xyyyzzz_yyzzzz_0[j] + fr * tg_xyyyzzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yyzzzz_0[j] - tg_yyyzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxyyyzzz_yzzzzz_0[j] = pb_x * tg_xyyyzzz_yzzzzz_0[j] + fr * tg_xyyyzzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_yzzzzz_0[j] - tg_yyyzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxyyyzzz_zzzzzz_0[j] = pb_x * tg_xyyyzzz_zzzzzz_0[j] + fr * tg_xyyyzzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyyzzz_zzzzzz_0[j] - tg_yyyzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxyyzzzz_xxxxxx_0[j] = pb_x * tg_xyyzzzz_xxxxxx_0[j] + fr * tg_xyyzzzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxxx_0[j] - tg_yyzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyyzzzz_xxxxx_1[j];

                    tg_xxyyzzzz_xxxxxy_0[j] = pb_x * tg_xyyzzzz_xxxxxy_0[j] + fr * tg_xyyzzzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxxy_0[j] - tg_yyzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzzzz_xxxxy_1[j];

                    tg_xxyyzzzz_xxxxxz_0[j] = pb_x * tg_xyyzzzz_xxxxxz_0[j] + fr * tg_xyyzzzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxxz_0[j] - tg_yyzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyyzzzz_xxxxz_1[j];

                    tg_xxyyzzzz_xxxxyy_0[j] = pb_x * tg_xyyzzzz_xxxxyy_0[j] + fr * tg_xyyzzzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxyy_0[j] - tg_yyzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzzz_xxxyy_1[j];

                    tg_xxyyzzzz_xxxxyz_0[j] = pb_x * tg_xyyzzzz_xxxxyz_0[j] + fr * tg_xyyzzzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxyz_0[j] - tg_yyzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzzz_xxxyz_1[j];

                    tg_xxyyzzzz_xxxxzz_0[j] = pb_x * tg_xyyzzzz_xxxxzz_0[j] + fr * tg_xyyzzzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxxzz_0[j] - tg_yyzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyyzzzz_xxxzz_1[j];

                    tg_xxyyzzzz_xxxyyy_0[j] = pb_x * tg_xyyzzzz_xxxyyy_0[j] + fr * tg_xyyzzzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxyyy_0[j] - tg_yyzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzzz_xxyyy_1[j];

                    tg_xxyyzzzz_xxxyyz_0[j] = pb_x * tg_xyyzzzz_xxxyyz_0[j] + fr * tg_xyyzzzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxyyz_0[j] - tg_yyzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzzz_xxyyz_1[j];

                    tg_xxyyzzzz_xxxyzz_0[j] = pb_x * tg_xyyzzzz_xxxyzz_0[j] + fr * tg_xyyzzzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxyzz_0[j] - tg_yyzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzzz_xxyzz_1[j];

                    tg_xxyyzzzz_xxxzzz_0[j] = pb_x * tg_xyyzzzz_xxxzzz_0[j] + fr * tg_xyyzzzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxxzzz_0[j] - tg_yyzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyyzzzz_xxzzz_1[j];

                    tg_xxyyzzzz_xxyyyy_0[j] = pb_x * tg_xyyzzzz_xxyyyy_0[j] + fr * tg_xyyzzzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxyyyy_0[j] - tg_yyzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_xyyyy_1[j];

                    tg_xxyyzzzz_xxyyyz_0[j] = pb_x * tg_xyyzzzz_xxyyyz_0[j] + fr * tg_xyyzzzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxyyyz_0[j] - tg_yyzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_xyyyz_1[j];

                    tg_xxyyzzzz_xxyyzz_0[j] = pb_x * tg_xyyzzzz_xxyyzz_0[j] + fr * tg_xyyzzzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxyyzz_0[j] - tg_yyzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_xyyzz_1[j];

                    tg_xxyyzzzz_xxyzzz_0[j] = pb_x * tg_xyyzzzz_xxyzzz_0[j] + fr * tg_xyyzzzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxyzzz_0[j] - tg_yyzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_xyzzz_1[j];

                    tg_xxyyzzzz_xxzzzz_0[j] = pb_x * tg_xyyzzzz_xxzzzz_0[j] + fr * tg_xyyzzzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xxzzzz_0[j] - tg_yyzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyyzzzz_xzzzz_1[j];

                    tg_xxyyzzzz_xyyyyy_0[j] = pb_x * tg_xyyzzzz_xyyyyy_0[j] + fr * tg_xyyzzzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xyyyyy_0[j] - tg_yyzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_yyyyy_1[j];

                    tg_xxyyzzzz_xyyyyz_0[j] = pb_x * tg_xyyzzzz_xyyyyz_0[j] + fr * tg_xyyzzzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xyyyyz_0[j] - tg_yyzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_yyyyz_1[j];

                    tg_xxyyzzzz_xyyyzz_0[j] = pb_x * tg_xyyzzzz_xyyyzz_0[j] + fr * tg_xyyzzzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xyyyzz_0[j] - tg_yyzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_yyyzz_1[j];

                    tg_xxyyzzzz_xyyzzz_0[j] = pb_x * tg_xyyzzzz_xyyzzz_0[j] + fr * tg_xyyzzzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xyyzzz_0[j] - tg_yyzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_yyzzz_1[j];

                    tg_xxyyzzzz_xyzzzz_0[j] = pb_x * tg_xyyzzzz_xyzzzz_0[j] + fr * tg_xyyzzzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xyzzzz_0[j] - tg_yyzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_yzzzz_1[j];

                    tg_xxyyzzzz_xzzzzz_0[j] = pb_x * tg_xyyzzzz_xzzzzz_0[j] + fr * tg_xyyzzzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_xzzzzz_0[j] - tg_yyzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyyzzzz_zzzzz_1[j];

                    tg_xxyyzzzz_yyyyyy_0[j] = pb_x * tg_xyyzzzz_yyyyyy_0[j] + fr * tg_xyyzzzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yyyyyy_0[j] - tg_yyzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxyyzzzz_yyyyyz_0[j] = pb_x * tg_xyyzzzz_yyyyyz_0[j] + fr * tg_xyyzzzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yyyyyz_0[j] - tg_yyzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxyyzzzz_yyyyzz_0[j] = pb_x * tg_xyyzzzz_yyyyzz_0[j] + fr * tg_xyyzzzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yyyyzz_0[j] - tg_yyzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxyyzzzz_yyyzzz_0[j] = pb_x * tg_xyyzzzz_yyyzzz_0[j] + fr * tg_xyyzzzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yyyzzz_0[j] - tg_yyzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxyyzzzz_yyzzzz_0[j] = pb_x * tg_xyyzzzz_yyzzzz_0[j] + fr * tg_xyyzzzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yyzzzz_0[j] - tg_yyzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxyyzzzz_yzzzzz_0[j] = pb_x * tg_xyyzzzz_yzzzzz_0[j] + fr * tg_xyyzzzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_yzzzzz_0[j] - tg_yyzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxyyzzzz_zzzzzz_0[j] = pb_x * tg_xyyzzzz_zzzzzz_0[j] + fr * tg_xyyzzzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yyzzzz_zzzzzz_0[j] - tg_yyzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxyzzzzz_xxxxxx_0[j] = pb_x * tg_xyzzzzz_xxxxxx_0[j] + fr * tg_xyzzzzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxxx_0[j] - tg_yzzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xyzzzzz_xxxxx_1[j];

                    tg_xxyzzzzz_xxxxxy_0[j] = pb_x * tg_xyzzzzz_xxxxxy_0[j] + fr * tg_xyzzzzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxxy_0[j] - tg_yzzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzzzz_xxxxy_1[j];

                    tg_xxyzzzzz_xxxxxz_0[j] = pb_x * tg_xyzzzzz_xxxxxz_0[j] + fr * tg_xyzzzzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxxz_0[j] - tg_yzzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xyzzzzz_xxxxz_1[j];

                    tg_xxyzzzzz_xxxxyy_0[j] = pb_x * tg_xyzzzzz_xxxxyy_0[j] + fr * tg_xyzzzzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxyy_0[j] - tg_yzzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzzz_xxxyy_1[j];

                    tg_xxyzzzzz_xxxxyz_0[j] = pb_x * tg_xyzzzzz_xxxxyz_0[j] + fr * tg_xyzzzzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxyz_0[j] - tg_yzzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzzz_xxxyz_1[j];

                    tg_xxyzzzzz_xxxxzz_0[j] = pb_x * tg_xyzzzzz_xxxxzz_0[j] + fr * tg_xyzzzzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxxzz_0[j] - tg_yzzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xyzzzzz_xxxzz_1[j];

                    tg_xxyzzzzz_xxxyyy_0[j] = pb_x * tg_xyzzzzz_xxxyyy_0[j] + fr * tg_xyzzzzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxyyy_0[j] - tg_yzzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzzz_xxyyy_1[j];

                    tg_xxyzzzzz_xxxyyz_0[j] = pb_x * tg_xyzzzzz_xxxyyz_0[j] + fr * tg_xyzzzzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxyyz_0[j] - tg_yzzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzzz_xxyyz_1[j];

                    tg_xxyzzzzz_xxxyzz_0[j] = pb_x * tg_xyzzzzz_xxxyzz_0[j] + fr * tg_xyzzzzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxyzz_0[j] - tg_yzzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzzz_xxyzz_1[j];

                    tg_xxyzzzzz_xxxzzz_0[j] = pb_x * tg_xyzzzzz_xxxzzz_0[j] + fr * tg_xyzzzzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxxzzz_0[j] - tg_yzzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xyzzzzz_xxzzz_1[j];

                    tg_xxyzzzzz_xxyyyy_0[j] = pb_x * tg_xyzzzzz_xxyyyy_0[j] + fr * tg_xyzzzzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxyyyy_0[j] - tg_yzzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_xyyyy_1[j];

                    tg_xxyzzzzz_xxyyyz_0[j] = pb_x * tg_xyzzzzz_xxyyyz_0[j] + fr * tg_xyzzzzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxyyyz_0[j] - tg_yzzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_xyyyz_1[j];

                    tg_xxyzzzzz_xxyyzz_0[j] = pb_x * tg_xyzzzzz_xxyyzz_0[j] + fr * tg_xyzzzzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxyyzz_0[j] - tg_yzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_xyyzz_1[j];

                    tg_xxyzzzzz_xxyzzz_0[j] = pb_x * tg_xyzzzzz_xxyzzz_0[j] + fr * tg_xyzzzzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxyzzz_0[j] - tg_yzzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_xyzzz_1[j];

                    tg_xxyzzzzz_xxzzzz_0[j] = pb_x * tg_xyzzzzz_xxzzzz_0[j] + fr * tg_xyzzzzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xxzzzz_0[j] - tg_yzzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xyzzzzz_xzzzz_1[j];

                    tg_xxyzzzzz_xyyyyy_0[j] = pb_x * tg_xyzzzzz_xyyyyy_0[j] + fr * tg_xyzzzzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xyyyyy_0[j] - tg_yzzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_yyyyy_1[j];

                    tg_xxyzzzzz_xyyyyz_0[j] = pb_x * tg_xyzzzzz_xyyyyz_0[j] + fr * tg_xyzzzzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xyyyyz_0[j] - tg_yzzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_yyyyz_1[j];

                    tg_xxyzzzzz_xyyyzz_0[j] = pb_x * tg_xyzzzzz_xyyyzz_0[j] + fr * tg_xyzzzzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xyyyzz_0[j] - tg_yzzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_yyyzz_1[j];

                    tg_xxyzzzzz_xyyzzz_0[j] = pb_x * tg_xyzzzzz_xyyzzz_0[j] + fr * tg_xyzzzzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xyyzzz_0[j] - tg_yzzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_yyzzz_1[j];

                    tg_xxyzzzzz_xyzzzz_0[j] = pb_x * tg_xyzzzzz_xyzzzz_0[j] + fr * tg_xyzzzzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xyzzzz_0[j] - tg_yzzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_yzzzz_1[j];

                    tg_xxyzzzzz_xzzzzz_0[j] = pb_x * tg_xyzzzzz_xzzzzz_0[j] + fr * tg_xyzzzzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_xzzzzz_0[j] - tg_yzzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xyzzzzz_zzzzz_1[j];

                    tg_xxyzzzzz_yyyyyy_0[j] = pb_x * tg_xyzzzzz_yyyyyy_0[j] + fr * tg_xyzzzzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yyyyyy_0[j] - tg_yzzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxyzzzzz_yyyyyz_0[j] = pb_x * tg_xyzzzzz_yyyyyz_0[j] + fr * tg_xyzzzzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yyyyyz_0[j] - tg_yzzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxyzzzzz_yyyyzz_0[j] = pb_x * tg_xyzzzzz_yyyyzz_0[j] + fr * tg_xyzzzzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yyyyzz_0[j] - tg_yzzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxyzzzzz_yyyzzz_0[j] = pb_x * tg_xyzzzzz_yyyzzz_0[j] + fr * tg_xyzzzzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yyyzzz_0[j] - tg_yzzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxyzzzzz_yyzzzz_0[j] = pb_x * tg_xyzzzzz_yyzzzz_0[j] + fr * tg_xyzzzzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yyzzzz_0[j] - tg_yzzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxyzzzzz_yzzzzz_0[j] = pb_x * tg_xyzzzzz_yzzzzz_0[j] + fr * tg_xyzzzzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_yzzzzz_0[j] - tg_yzzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxyzzzzz_zzzzzz_0[j] = pb_x * tg_xyzzzzz_zzzzzz_0[j] + fr * tg_xyzzzzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_yzzzzz_zzzzzz_0[j] - tg_yzzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xxzzzzzz_xxxxxx_0[j] = pb_x * tg_xzzzzzz_xxxxxx_0[j] + fr * tg_xzzzzzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxx_0[j] - tg_zzzzzz_xxxxxx_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_xzzzzzz_xxxxx_1[j];

                    tg_xxzzzzzz_xxxxxy_0[j] = pb_x * tg_xzzzzzz_xxxxxy_0[j] + fr * tg_xzzzzzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxy_0[j] - tg_zzzzzz_xxxxxy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzzzz_xxxxy_1[j];

                    tg_xxzzzzzz_xxxxxz_0[j] = pb_x * tg_xzzzzzz_xxxxxz_0[j] + fr * tg_xzzzzzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxz_0[j] - tg_zzzzzz_xxxxxz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_xzzzzzz_xxxxz_1[j];

                    tg_xxzzzzzz_xxxxyy_0[j] = pb_x * tg_xzzzzzz_xxxxyy_0[j] + fr * tg_xzzzzzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxyy_0[j] - tg_zzzzzz_xxxxyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzzz_xxxyy_1[j];

                    tg_xxzzzzzz_xxxxyz_0[j] = pb_x * tg_xzzzzzz_xxxxyz_0[j] + fr * tg_xzzzzzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxyz_0[j] - tg_zzzzzz_xxxxyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzzz_xxxyz_1[j];

                    tg_xxzzzzzz_xxxxzz_0[j] = pb_x * tg_xzzzzzz_xxxxzz_0[j] + fr * tg_xzzzzzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxzz_0[j] - tg_zzzzzz_xxxxzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_xzzzzzz_xxxzz_1[j];

                    tg_xxzzzzzz_xxxyyy_0[j] = pb_x * tg_xzzzzzz_xxxyyy_0[j] + fr * tg_xzzzzzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyyy_0[j] - tg_zzzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzzz_xxyyy_1[j];

                    tg_xxzzzzzz_xxxyyz_0[j] = pb_x * tg_xzzzzzz_xxxyyz_0[j] + fr * tg_xzzzzzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyyz_0[j] - tg_zzzzzz_xxxyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzzz_xxyyz_1[j];

                    tg_xxzzzzzz_xxxyzz_0[j] = pb_x * tg_xzzzzzz_xxxyzz_0[j] + fr * tg_xzzzzzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyzz_0[j] - tg_zzzzzz_xxxyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzzz_xxyzz_1[j];

                    tg_xxzzzzzz_xxxzzz_0[j] = pb_x * tg_xzzzzzz_xxxzzz_0[j] + fr * tg_xzzzzzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxzzz_0[j] - tg_zzzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_xzzzzzz_xxzzz_1[j];

                    tg_xxzzzzzz_xxyyyy_0[j] = pb_x * tg_xzzzzzz_xxyyyy_0[j] + fr * tg_xzzzzzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyyy_0[j] - tg_zzzzzz_xxyyyy_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_xyyyy_1[j];

                    tg_xxzzzzzz_xxyyyz_0[j] = pb_x * tg_xzzzzzz_xxyyyz_0[j] + fr * tg_xzzzzzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyyz_0[j] - tg_zzzzzz_xxyyyz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_xyyyz_1[j];

                    tg_xxzzzzzz_xxyyzz_0[j] = pb_x * tg_xzzzzzz_xxyyzz_0[j] + fr * tg_xzzzzzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyzz_0[j] - tg_zzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_xyyzz_1[j];

                    tg_xxzzzzzz_xxyzzz_0[j] = pb_x * tg_xzzzzzz_xxyzzz_0[j] + fr * tg_xzzzzzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyzzz_0[j] - tg_zzzzzz_xxyzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_xyzzz_1[j];

                    tg_xxzzzzzz_xxzzzz_0[j] = pb_x * tg_xzzzzzz_xxzzzz_0[j] + fr * tg_xzzzzzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxzzzz_0[j] - tg_zzzzzz_xxzzzz_1[j] * fl1_fza) + fl1_fxn * tg_xzzzzzz_xzzzz_1[j];

                    tg_xxzzzzzz_xyyyyy_0[j] = pb_x * tg_xzzzzzz_xyyyyy_0[j] + fr * tg_xzzzzzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyyy_0[j] - tg_zzzzzz_xyyyyy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_yyyyy_1[j];

                    tg_xxzzzzzz_xyyyyz_0[j] = pb_x * tg_xzzzzzz_xyyyyz_0[j] + fr * tg_xzzzzzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyyz_0[j] - tg_zzzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_yyyyz_1[j];

                    tg_xxzzzzzz_xyyyzz_0[j] = pb_x * tg_xzzzzzz_xyyyzz_0[j] + fr * tg_xzzzzzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyzz_0[j] - tg_zzzzzz_xyyyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_yyyzz_1[j];

                    tg_xxzzzzzz_xyyzzz_0[j] = pb_x * tg_xzzzzzz_xyyzzz_0[j] + fr * tg_xzzzzzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyzzz_0[j] - tg_zzzzzz_xyyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_yyzzz_1[j];

                    tg_xxzzzzzz_xyzzzz_0[j] = pb_x * tg_xzzzzzz_xyzzzz_0[j] + fr * tg_xzzzzzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyzzzz_0[j] - tg_zzzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_yzzzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_776_873(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (776,873)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_xzzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 776); 

                auto tg_xzzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 777); 

                auto tg_xzzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 778); 

                auto tg_xzzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 779); 

                auto tg_xzzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 780); 

                auto tg_xzzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 781); 

                auto tg_xzzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 782); 

                auto tg_xzzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 783); 

                auto tg_yyyyyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 784); 

                auto tg_yyyyyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 785); 

                auto tg_yyyyyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 786); 

                auto tg_yyyyyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 787); 

                auto tg_yyyyyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 788); 

                auto tg_yyyyyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 789); 

                auto tg_yyyyyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 790); 

                auto tg_yyyyyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 791); 

                auto tg_yyyyyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 792); 

                auto tg_yyyyyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 793); 

                auto tg_yyyyyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 794); 

                auto tg_yyyyyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 795); 

                auto tg_yyyyyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 796); 

                auto tg_yyyyyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 797); 

                auto tg_yyyyyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 798); 

                auto tg_yyyyyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 799); 

                auto tg_yyyyyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 800); 

                auto tg_yyyyyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 801); 

                auto tg_yyyyyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 802); 

                auto tg_yyyyyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 803); 

                auto tg_yyyyyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 804); 

                auto tg_yyyyyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 805); 

                auto tg_yyyyyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 806); 

                auto tg_yyyyyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 807); 

                auto tg_yyyyyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 808); 

                auto tg_yyyyyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 809); 

                auto tg_yyyyyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 810); 

                auto tg_yyyyyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 811); 

                auto tg_yyyyyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 812); 

                auto tg_yyyyyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 813); 

                auto tg_yyyyyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 814); 

                auto tg_yyyyyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 815); 

                auto tg_yyyyyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 816); 

                auto tg_yyyyyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 817); 

                auto tg_yyyyyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 818); 

                auto tg_yyyyyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 819); 

                auto tg_yyyyyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 820); 

                auto tg_yyyyyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 821); 

                auto tg_yyyyyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 822); 

                auto tg_yyyyyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 823); 

                auto tg_yyyyyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 824); 

                auto tg_yyyyyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 825); 

                auto tg_yyyyyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 826); 

                auto tg_yyyyyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 827); 

                auto tg_yyyyyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 828); 

                auto tg_yyyyyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 829); 

                auto tg_yyyyyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 830); 

                auto tg_yyyyyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 831); 

                auto tg_yyyyyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 832); 

                auto tg_yyyyyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 833); 

                auto tg_yyyyyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 834); 

                auto tg_yyyyyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 835); 

                auto tg_yyyyyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 836); 

                auto tg_yyyyyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 837); 

                auto tg_yyyyyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 838); 

                auto tg_yyyyyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 839); 

                auto tg_yyyyyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 840); 

                auto tg_yyyyyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 841); 

                auto tg_yyyyyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 842); 

                auto tg_yyyyyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 843); 

                auto tg_yyyyyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 844); 

                auto tg_yyyyyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 845); 

                auto tg_yyyyyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 846); 

                auto tg_yyyyyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 847); 

                auto tg_yyyyyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 848); 

                auto tg_yyyyyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 849); 

                auto tg_yyyyyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 850); 

                auto tg_yyyyyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 851); 

                auto tg_yyyyyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 852); 

                auto tg_yyyyyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 853); 

                auto tg_yyyyyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 854); 

                auto tg_yyyyyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 855); 

                auto tg_yyyyyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 856); 

                auto tg_yyyyyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 857); 

                auto tg_yyyyyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 858); 

                auto tg_yyyyyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 859); 

                auto tg_yyyyyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 860); 

                auto tg_yyyyyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 861); 

                auto tg_yyyyyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 862); 

                auto tg_yyyyyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 863); 

                auto tg_yyyyyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 864); 

                auto tg_yyyyyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 865); 

                auto tg_yyyyyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 866); 

                auto tg_yyyyyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 867); 

                auto tg_yyyyzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 868); 

                auto tg_yyyyzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 869); 

                auto tg_yyyyzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 870); 

                auto tg_yyyyzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 871); 

                auto tg_yyyyzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 872); 

                auto tg_xzzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 776); 

                auto tg_xzzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 777); 

                auto tg_xzzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 778); 

                auto tg_xzzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 779); 

                auto tg_xzzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 780); 

                auto tg_xzzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 781); 

                auto tg_xzzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 782); 

                auto tg_xzzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 783); 

                auto tg_yyyyyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 784); 

                auto tg_yyyyyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 785); 

                auto tg_yyyyyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 786); 

                auto tg_yyyyyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 787); 

                auto tg_yyyyyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 788); 

                auto tg_yyyyyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 789); 

                auto tg_yyyyyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 790); 

                auto tg_yyyyyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 791); 

                auto tg_yyyyyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 792); 

                auto tg_yyyyyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 793); 

                auto tg_yyyyyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 794); 

                auto tg_yyyyyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 795); 

                auto tg_yyyyyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 796); 

                auto tg_yyyyyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 797); 

                auto tg_yyyyyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 798); 

                auto tg_yyyyyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 799); 

                auto tg_yyyyyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 800); 

                auto tg_yyyyyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 801); 

                auto tg_yyyyyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 802); 

                auto tg_yyyyyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 803); 

                auto tg_yyyyyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 804); 

                auto tg_yyyyyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 805); 

                auto tg_yyyyyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 806); 

                auto tg_yyyyyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 807); 

                auto tg_yyyyyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 808); 

                auto tg_yyyyyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 809); 

                auto tg_yyyyyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 810); 

                auto tg_yyyyyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 811); 

                auto tg_yyyyyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 812); 

                auto tg_yyyyyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 813); 

                auto tg_yyyyyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 814); 

                auto tg_yyyyyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 815); 

                auto tg_yyyyyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 816); 

                auto tg_yyyyyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 817); 

                auto tg_yyyyyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 818); 

                auto tg_yyyyyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 819); 

                auto tg_yyyyyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 820); 

                auto tg_yyyyyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 821); 

                auto tg_yyyyyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 822); 

                auto tg_yyyyyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 823); 

                auto tg_yyyyyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 824); 

                auto tg_yyyyyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 825); 

                auto tg_yyyyyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 826); 

                auto tg_yyyyyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 827); 

                auto tg_yyyyyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 828); 

                auto tg_yyyyyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 829); 

                auto tg_yyyyyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 830); 

                auto tg_yyyyyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 831); 

                auto tg_yyyyyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 832); 

                auto tg_yyyyyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 833); 

                auto tg_yyyyyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 834); 

                auto tg_yyyyyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 835); 

                auto tg_yyyyyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 836); 

                auto tg_yyyyyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 837); 

                auto tg_yyyyyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 838); 

                auto tg_yyyyyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 839); 

                auto tg_yyyyyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 840); 

                auto tg_yyyyyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 841); 

                auto tg_yyyyyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 842); 

                auto tg_yyyyyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 843); 

                auto tg_yyyyyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 844); 

                auto tg_yyyyyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 845); 

                auto tg_yyyyyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 846); 

                auto tg_yyyyyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 847); 

                auto tg_yyyyyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 848); 

                auto tg_yyyyyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 849); 

                auto tg_yyyyyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 850); 

                auto tg_yyyyyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 851); 

                auto tg_yyyyyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 852); 

                auto tg_yyyyyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 853); 

                auto tg_yyyyyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 854); 

                auto tg_yyyyyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 855); 

                auto tg_yyyyyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 856); 

                auto tg_yyyyyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 857); 

                auto tg_yyyyyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 858); 

                auto tg_yyyyyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 859); 

                auto tg_yyyyyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 860); 

                auto tg_yyyyyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 861); 

                auto tg_yyyyyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 862); 

                auto tg_yyyyyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 863); 

                auto tg_yyyyyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 864); 

                auto tg_yyyyyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 865); 

                auto tg_yyyyyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 866); 

                auto tg_yyyyyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 867); 

                auto tg_yyyyzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 868); 

                auto tg_yyyyzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 869); 

                auto tg_yyyyzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 870); 

                auto tg_yyyyzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 871); 

                auto tg_yyyyzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 872); 

                auto tg_zzzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 782); 

                auto tg_zzzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 783); 

                auto tg_zzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 782); 

                auto tg_zzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 783); 

                auto tg_xzzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 587); 

                auto tg_yyyyyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 588); 

                auto tg_yyyyyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 589); 

                auto tg_yyyyyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 590); 

                auto tg_yyyyyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 591); 

                auto tg_yyyyyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 592); 

                auto tg_yyyyyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 593); 

                auto tg_yyyyyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 594); 

                auto tg_yyyyyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 595); 

                auto tg_yyyyyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 596); 

                auto tg_yyyyyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 597); 

                auto tg_yyyyyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 598); 

                auto tg_yyyyyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 599); 

                auto tg_yyyyyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 600); 

                auto tg_yyyyyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 601); 

                auto tg_yyyyyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 602); 

                auto tg_yyyyyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 603); 

                auto tg_yyyyyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 604); 

                auto tg_yyyyyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 605); 

                auto tg_yyyyyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 606); 

                auto tg_yyyyyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 607); 

                auto tg_yyyyyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 608); 

                auto tg_yyyyyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 609); 

                auto tg_yyyyyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 610); 

                auto tg_yyyyyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 611); 

                auto tg_yyyyyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 612); 

                auto tg_yyyyyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 613); 

                auto tg_yyyyyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 614); 

                auto tg_yyyyyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 615); 

                auto tg_yyyyyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 616); 

                auto tg_yyyyyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 617); 

                auto tg_yyyyyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 618); 

                auto tg_yyyyyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 619); 

                auto tg_yyyyyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 620); 

                auto tg_yyyyyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 621); 

                auto tg_yyyyyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 622); 

                auto tg_yyyyyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 623); 

                auto tg_yyyyyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 624); 

                auto tg_yyyyyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 625); 

                auto tg_yyyyyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 626); 

                auto tg_yyyyyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 627); 

                auto tg_yyyyyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 628); 

                auto tg_yyyyyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 629); 

                auto tg_yyyyyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 630); 

                auto tg_yyyyyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 631); 

                auto tg_yyyyyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 632); 

                auto tg_yyyyyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 633); 

                auto tg_yyyyyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 634); 

                auto tg_yyyyyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 635); 

                auto tg_yyyyyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 636); 

                auto tg_yyyyyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 637); 

                auto tg_yyyyyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 638); 

                auto tg_yyyyyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 639); 

                auto tg_yyyyyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 640); 

                auto tg_yyyyyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 641); 

                auto tg_yyyyyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 642); 

                auto tg_yyyyyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 643); 

                auto tg_yyyyyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 644); 

                auto tg_yyyyyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 645); 

                auto tg_yyyyyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 646); 

                auto tg_yyyyyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 647); 

                auto tg_yyyyyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 648); 

                auto tg_yyyyyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 649); 

                auto tg_yyyyyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 650); 

                auto tg_yyyyzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 651); 

                auto tg_yyyyzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 652); 

                auto tg_yyyyzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 653); 

                auto tg_yyyyzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 654); 

                auto tg_yyyyzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 655); 

                // set up pointers to integrals

                auto tg_xxzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 776); 

                auto tg_xxzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 777); 

                auto tg_xxzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 778); 

                auto tg_xxzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 779); 

                auto tg_xxzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 780); 

                auto tg_xxzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 781); 

                auto tg_xxzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 782); 

                auto tg_xxzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 783); 

                auto tg_xyyyyyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 784); 

                auto tg_xyyyyyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 785); 

                auto tg_xyyyyyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 786); 

                auto tg_xyyyyyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 787); 

                auto tg_xyyyyyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 788); 

                auto tg_xyyyyyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 789); 

                auto tg_xyyyyyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 790); 

                auto tg_xyyyyyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 791); 

                auto tg_xyyyyyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 792); 

                auto tg_xyyyyyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 793); 

                auto tg_xyyyyyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 794); 

                auto tg_xyyyyyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 795); 

                auto tg_xyyyyyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 796); 

                auto tg_xyyyyyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 797); 

                auto tg_xyyyyyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 798); 

                auto tg_xyyyyyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 799); 

                auto tg_xyyyyyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 800); 

                auto tg_xyyyyyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 801); 

                auto tg_xyyyyyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 802); 

                auto tg_xyyyyyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 803); 

                auto tg_xyyyyyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 804); 

                auto tg_xyyyyyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 805); 

                auto tg_xyyyyyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 806); 

                auto tg_xyyyyyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 807); 

                auto tg_xyyyyyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 808); 

                auto tg_xyyyyyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 809); 

                auto tg_xyyyyyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 810); 

                auto tg_xyyyyyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 811); 

                auto tg_xyyyyyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 812); 

                auto tg_xyyyyyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 813); 

                auto tg_xyyyyyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 814); 

                auto tg_xyyyyyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 815); 

                auto tg_xyyyyyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 816); 

                auto tg_xyyyyyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 817); 

                auto tg_xyyyyyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 818); 

                auto tg_xyyyyyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 819); 

                auto tg_xyyyyyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 820); 

                auto tg_xyyyyyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 821); 

                auto tg_xyyyyyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 822); 

                auto tg_xyyyyyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 823); 

                auto tg_xyyyyyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 824); 

                auto tg_xyyyyyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 825); 

                auto tg_xyyyyyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 826); 

                auto tg_xyyyyyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 827); 

                auto tg_xyyyyyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 828); 

                auto tg_xyyyyyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 829); 

                auto tg_xyyyyyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 830); 

                auto tg_xyyyyyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 831); 

                auto tg_xyyyyyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 832); 

                auto tg_xyyyyyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 833); 

                auto tg_xyyyyyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 834); 

                auto tg_xyyyyyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 835); 

                auto tg_xyyyyyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 836); 

                auto tg_xyyyyyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 837); 

                auto tg_xyyyyyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 838); 

                auto tg_xyyyyyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 839); 

                auto tg_xyyyyyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 840); 

                auto tg_xyyyyyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 841); 

                auto tg_xyyyyyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 842); 

                auto tg_xyyyyyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 843); 

                auto tg_xyyyyyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 844); 

                auto tg_xyyyyyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 845); 

                auto tg_xyyyyyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 846); 

                auto tg_xyyyyyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 847); 

                auto tg_xyyyyyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 848); 

                auto tg_xyyyyyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 849); 

                auto tg_xyyyyyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 850); 

                auto tg_xyyyyyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 851); 

                auto tg_xyyyyyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 852); 

                auto tg_xyyyyyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 853); 

                auto tg_xyyyyyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 854); 

                auto tg_xyyyyyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 855); 

                auto tg_xyyyyyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 856); 

                auto tg_xyyyyyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 857); 

                auto tg_xyyyyyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 858); 

                auto tg_xyyyyyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 859); 

                auto tg_xyyyyyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 860); 

                auto tg_xyyyyyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 861); 

                auto tg_xyyyyyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 862); 

                auto tg_xyyyyyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 863); 

                auto tg_xyyyyyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 864); 

                auto tg_xyyyyyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 865); 

                auto tg_xyyyyyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 866); 

                auto tg_xyyyyyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 867); 

                auto tg_xyyyyzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 868); 

                auto tg_xyyyyzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 869); 

                auto tg_xyyyyzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 870); 

                auto tg_xyyyyzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 871); 

                auto tg_xyyyyzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 872); 

                // Batch of Integrals (776,873)

                #pragma omp simd aligned(fxn, fza, tg_xxzzzzzz_xzzzzz_0, tg_xxzzzzzz_yyyyyy_0, \
                                         tg_xxzzzzzz_yyyyyz_0, tg_xxzzzzzz_yyyyzz_0, tg_xxzzzzzz_yyyzzz_0, tg_xxzzzzzz_yyzzzz_0, \
                                         tg_xxzzzzzz_yzzzzz_0, tg_xxzzzzzz_zzzzzz_0, tg_xyyyyyyy_xxxxxx_0, tg_xyyyyyyy_xxxxxy_0, \
                                         tg_xyyyyyyy_xxxxxz_0, tg_xyyyyyyy_xxxxyy_0, tg_xyyyyyyy_xxxxyz_0, tg_xyyyyyyy_xxxxzz_0, \
                                         tg_xyyyyyyy_xxxyyy_0, tg_xyyyyyyy_xxxyyz_0, tg_xyyyyyyy_xxxyzz_0, tg_xyyyyyyy_xxxzzz_0, \
                                         tg_xyyyyyyy_xxyyyy_0, tg_xyyyyyyy_xxyyyz_0, tg_xyyyyyyy_xxyyzz_0, tg_xyyyyyyy_xxyzzz_0, \
                                         tg_xyyyyyyy_xxzzzz_0, tg_xyyyyyyy_xyyyyy_0, tg_xyyyyyyy_xyyyyz_0, tg_xyyyyyyy_xyyyzz_0, \
                                         tg_xyyyyyyy_xyyzzz_0, tg_xyyyyyyy_xyzzzz_0, tg_xyyyyyyy_xzzzzz_0, tg_xyyyyyyy_yyyyyy_0, \
                                         tg_xyyyyyyy_yyyyyz_0, tg_xyyyyyyy_yyyyzz_0, tg_xyyyyyyy_yyyzzz_0, tg_xyyyyyyy_yyzzzz_0, \
                                         tg_xyyyyyyy_yzzzzz_0, tg_xyyyyyyy_zzzzzz_0, tg_xyyyyyyz_xxxxxx_0, tg_xyyyyyyz_xxxxxy_0, \
                                         tg_xyyyyyyz_xxxxxz_0, tg_xyyyyyyz_xxxxyy_0, tg_xyyyyyyz_xxxxyz_0, tg_xyyyyyyz_xxxxzz_0, \
                                         tg_xyyyyyyz_xxxyyy_0, tg_xyyyyyyz_xxxyyz_0, tg_xyyyyyyz_xxxyzz_0, tg_xyyyyyyz_xxxzzz_0, \
                                         tg_xyyyyyyz_xxyyyy_0, tg_xyyyyyyz_xxyyyz_0, tg_xyyyyyyz_xxyyzz_0, tg_xyyyyyyz_xxyzzz_0, \
                                         tg_xyyyyyyz_xxzzzz_0, tg_xyyyyyyz_xyyyyy_0, tg_xyyyyyyz_xyyyyz_0, tg_xyyyyyyz_xyyyzz_0, \
                                         tg_xyyyyyyz_xyyzzz_0, tg_xyyyyyyz_xyzzzz_0, tg_xyyyyyyz_xzzzzz_0, tg_xyyyyyyz_yyyyyy_0, \
                                         tg_xyyyyyyz_yyyyyz_0, tg_xyyyyyyz_yyyyzz_0, tg_xyyyyyyz_yyyzzz_0, tg_xyyyyyyz_yyzzzz_0, \
                                         tg_xyyyyyyz_yzzzzz_0, tg_xyyyyyyz_zzzzzz_0, tg_xyyyyyzz_xxxxxx_0, tg_xyyyyyzz_xxxxxy_0, \
                                         tg_xyyyyyzz_xxxxxz_0, tg_xyyyyyzz_xxxxyy_0, tg_xyyyyyzz_xxxxyz_0, tg_xyyyyyzz_xxxxzz_0, \
                                         tg_xyyyyyzz_xxxyyy_0, tg_xyyyyyzz_xxxyyz_0, tg_xyyyyyzz_xxxyzz_0, tg_xyyyyyzz_xxxzzz_0, \
                                         tg_xyyyyyzz_xxyyyy_0, tg_xyyyyyzz_xxyyyz_0, tg_xyyyyyzz_xxyyzz_0, tg_xyyyyyzz_xxyzzz_0, \
                                         tg_xyyyyyzz_xxzzzz_0, tg_xyyyyyzz_xyyyyy_0, tg_xyyyyyzz_xyyyyz_0, tg_xyyyyyzz_xyyyzz_0, \
                                         tg_xyyyyyzz_xyyzzz_0, tg_xyyyyyzz_xyzzzz_0, tg_xyyyyyzz_xzzzzz_0, tg_xyyyyyzz_yyyyyy_0, \
                                         tg_xyyyyyzz_yyyyyz_0, tg_xyyyyyzz_yyyyzz_0, tg_xyyyyyzz_yyyzzz_0, tg_xyyyyyzz_yyzzzz_0, \
                                         tg_xyyyyyzz_yzzzzz_0, tg_xyyyyyzz_zzzzzz_0, tg_xyyyyzzz_xxxxxx_0, tg_xyyyyzzz_xxxxxy_0, \
                                         tg_xyyyyzzz_xxxxxz_0, tg_xyyyyzzz_xxxxyy_0, tg_xyyyyzzz_xxxxyz_0, tg_xzzzzzz_xzzzzz_0, \
                                         tg_xzzzzzz_xzzzzz_1, tg_xzzzzzz_yyyyyy_0, tg_xzzzzzz_yyyyyy_1, tg_xzzzzzz_yyyyyz_0, \
                                         tg_xzzzzzz_yyyyyz_1, tg_xzzzzzz_yyyyzz_0, tg_xzzzzzz_yyyyzz_1, tg_xzzzzzz_yyyzzz_0, \
                                         tg_xzzzzzz_yyyzzz_1, tg_xzzzzzz_yyzzzz_0, tg_xzzzzzz_yyzzzz_1, tg_xzzzzzz_yzzzzz_0, \
                                         tg_xzzzzzz_yzzzzz_1, tg_xzzzzzz_zzzzz_1, tg_xzzzzzz_zzzzzz_0, tg_xzzzzzz_zzzzzz_1, \
                                         tg_yyyyyyy_xxxxx_1, tg_yyyyyyy_xxxxxx_0, tg_yyyyyyy_xxxxxx_1, tg_yyyyyyy_xxxxxy_0, \
                                         tg_yyyyyyy_xxxxxy_1, tg_yyyyyyy_xxxxxz_0, tg_yyyyyyy_xxxxxz_1, tg_yyyyyyy_xxxxy_1, \
                                         tg_yyyyyyy_xxxxyy_0, tg_yyyyyyy_xxxxyy_1, tg_yyyyyyy_xxxxyz_0, tg_yyyyyyy_xxxxyz_1, \
                                         tg_yyyyyyy_xxxxz_1, tg_yyyyyyy_xxxxzz_0, tg_yyyyyyy_xxxxzz_1, tg_yyyyyyy_xxxyy_1, \
                                         tg_yyyyyyy_xxxyyy_0, tg_yyyyyyy_xxxyyy_1, tg_yyyyyyy_xxxyyz_0, tg_yyyyyyy_xxxyyz_1, \
                                         tg_yyyyyyy_xxxyz_1, tg_yyyyyyy_xxxyzz_0, tg_yyyyyyy_xxxyzz_1, tg_yyyyyyy_xxxzz_1, \
                                         tg_yyyyyyy_xxxzzz_0, tg_yyyyyyy_xxxzzz_1, tg_yyyyyyy_xxyyy_1, tg_yyyyyyy_xxyyyy_0, \
                                         tg_yyyyyyy_xxyyyy_1, tg_yyyyyyy_xxyyyz_0, tg_yyyyyyy_xxyyyz_1, tg_yyyyyyy_xxyyz_1, \
                                         tg_yyyyyyy_xxyyzz_0, tg_yyyyyyy_xxyyzz_1, tg_yyyyyyy_xxyzz_1, tg_yyyyyyy_xxyzzz_0, \
                                         tg_yyyyyyy_xxyzzz_1, tg_yyyyyyy_xxzzz_1, tg_yyyyyyy_xxzzzz_0, tg_yyyyyyy_xxzzzz_1, \
                                         tg_yyyyyyy_xyyyy_1, tg_yyyyyyy_xyyyyy_0, tg_yyyyyyy_xyyyyy_1, tg_yyyyyyy_xyyyyz_0, \
                                         tg_yyyyyyy_xyyyyz_1, tg_yyyyyyy_xyyyz_1, tg_yyyyyyy_xyyyzz_0, tg_yyyyyyy_xyyyzz_1, \
                                         tg_yyyyyyy_xyyzz_1, tg_yyyyyyy_xyyzzz_0, tg_yyyyyyy_xyyzzz_1, tg_yyyyyyy_xyzzz_1, \
                                         tg_yyyyyyy_xyzzzz_0, tg_yyyyyyy_xyzzzz_1, tg_yyyyyyy_xzzzz_1, tg_yyyyyyy_xzzzzz_0, \
                                         tg_yyyyyyy_xzzzzz_1, tg_yyyyyyy_yyyyy_1, tg_yyyyyyy_yyyyyy_0, tg_yyyyyyy_yyyyyy_1, \
                                         tg_yyyyyyy_yyyyyz_0, tg_yyyyyyy_yyyyyz_1, tg_yyyyyyy_yyyyz_1, tg_yyyyyyy_yyyyzz_0, \
                                         tg_yyyyyyy_yyyyzz_1, tg_yyyyyyy_yyyzz_1, tg_yyyyyyy_yyyzzz_0, tg_yyyyyyy_yyyzzz_1, \
                                         tg_yyyyyyy_yyzzz_1, tg_yyyyyyy_yyzzzz_0, tg_yyyyyyy_yyzzzz_1, tg_yyyyyyy_yzzzz_1, \
                                         tg_yyyyyyy_yzzzzz_0, tg_yyyyyyy_yzzzzz_1, tg_yyyyyyy_zzzzz_1, tg_yyyyyyy_zzzzzz_0, \
                                         tg_yyyyyyy_zzzzzz_1, tg_yyyyyyz_xxxxx_1, tg_yyyyyyz_xxxxxx_0, tg_yyyyyyz_xxxxxx_1, \
                                         tg_yyyyyyz_xxxxxy_0, tg_yyyyyyz_xxxxxy_1, tg_yyyyyyz_xxxxxz_0, tg_yyyyyyz_xxxxxz_1, \
                                         tg_yyyyyyz_xxxxy_1, tg_yyyyyyz_xxxxyy_0, tg_yyyyyyz_xxxxyy_1, tg_yyyyyyz_xxxxyz_0, \
                                         tg_yyyyyyz_xxxxyz_1, tg_yyyyyyz_xxxxz_1, tg_yyyyyyz_xxxxzz_0, tg_yyyyyyz_xxxxzz_1, \
                                         tg_yyyyyyz_xxxyy_1, tg_yyyyyyz_xxxyyy_0, tg_yyyyyyz_xxxyyy_1, tg_yyyyyyz_xxxyyz_0, \
                                         tg_yyyyyyz_xxxyyz_1, tg_yyyyyyz_xxxyz_1, tg_yyyyyyz_xxxyzz_0, tg_yyyyyyz_xxxyzz_1, \
                                         tg_yyyyyyz_xxxzz_1, tg_yyyyyyz_xxxzzz_0, tg_yyyyyyz_xxxzzz_1, tg_yyyyyyz_xxyyy_1, \
                                         tg_yyyyyyz_xxyyyy_0, tg_yyyyyyz_xxyyyy_1, tg_yyyyyyz_xxyyyz_0, tg_yyyyyyz_xxyyyz_1, \
                                         tg_yyyyyyz_xxyyz_1, tg_yyyyyyz_xxyyzz_0, tg_yyyyyyz_xxyyzz_1, tg_yyyyyyz_xxyzz_1, \
                                         tg_yyyyyyz_xxyzzz_0, tg_yyyyyyz_xxyzzz_1, tg_yyyyyyz_xxzzz_1, tg_yyyyyyz_xxzzzz_0, \
                                         tg_yyyyyyz_xxzzzz_1, tg_yyyyyyz_xyyyy_1, tg_yyyyyyz_xyyyyy_0, tg_yyyyyyz_xyyyyy_1, \
                                         tg_yyyyyyz_xyyyyz_0, tg_yyyyyyz_xyyyyz_1, tg_yyyyyyz_xyyyz_1, tg_yyyyyyz_xyyyzz_0, \
                                         tg_yyyyyyz_xyyyzz_1, tg_yyyyyyz_xyyzz_1, tg_yyyyyyz_xyyzzz_0, tg_yyyyyyz_xyyzzz_1, \
                                         tg_yyyyyyz_xyzzz_1, tg_yyyyyyz_xyzzzz_0, tg_yyyyyyz_xyzzzz_1, tg_yyyyyyz_xzzzz_1, \
                                         tg_yyyyyyz_xzzzzz_0, tg_yyyyyyz_xzzzzz_1, tg_yyyyyyz_yyyyy_1, tg_yyyyyyz_yyyyyy_0, \
                                         tg_yyyyyyz_yyyyyy_1, tg_yyyyyyz_yyyyyz_0, tg_yyyyyyz_yyyyyz_1, tg_yyyyyyz_yyyyz_1, \
                                         tg_yyyyyyz_yyyyzz_0, tg_yyyyyyz_yyyyzz_1, tg_yyyyyyz_yyyzz_1, tg_yyyyyyz_yyyzzz_0, \
                                         tg_yyyyyyz_yyyzzz_1, tg_yyyyyyz_yyzzz_1, tg_yyyyyyz_yyzzzz_0, tg_yyyyyyz_yyzzzz_1, \
                                         tg_yyyyyyz_yzzzz_1, tg_yyyyyyz_yzzzzz_0, tg_yyyyyyz_yzzzzz_1, tg_yyyyyyz_zzzzz_1, \
                                         tg_yyyyyyz_zzzzzz_0, tg_yyyyyyz_zzzzzz_1, tg_yyyyyzz_xxxxx_1, tg_yyyyyzz_xxxxxx_0, \
                                         tg_yyyyyzz_xxxxxx_1, tg_yyyyyzz_xxxxxy_0, tg_yyyyyzz_xxxxxy_1, tg_yyyyyzz_xxxxxz_0, \
                                         tg_yyyyyzz_xxxxxz_1, tg_yyyyyzz_xxxxy_1, tg_yyyyyzz_xxxxyy_0, tg_yyyyyzz_xxxxyy_1, \
                                         tg_yyyyyzz_xxxxyz_0, tg_yyyyyzz_xxxxyz_1, tg_yyyyyzz_xxxxz_1, tg_yyyyyzz_xxxxzz_0, \
                                         tg_yyyyyzz_xxxxzz_1, tg_yyyyyzz_xxxyy_1, tg_yyyyyzz_xxxyyy_0, tg_yyyyyzz_xxxyyy_1, \
                                         tg_yyyyyzz_xxxyyz_0, tg_yyyyyzz_xxxyyz_1, tg_yyyyyzz_xxxyz_1, tg_yyyyyzz_xxxyzz_0, \
                                         tg_yyyyyzz_xxxyzz_1, tg_yyyyyzz_xxxzz_1, tg_yyyyyzz_xxxzzz_0, tg_yyyyyzz_xxxzzz_1, \
                                         tg_yyyyyzz_xxyyy_1, tg_yyyyyzz_xxyyyy_0, tg_yyyyyzz_xxyyyy_1, tg_yyyyyzz_xxyyyz_0, \
                                         tg_yyyyyzz_xxyyyz_1, tg_yyyyyzz_xxyyz_1, tg_yyyyyzz_xxyyzz_0, tg_yyyyyzz_xxyyzz_1, \
                                         tg_yyyyyzz_xxyzz_1, tg_yyyyyzz_xxyzzz_0, tg_yyyyyzz_xxyzzz_1, tg_yyyyyzz_xxzzz_1, \
                                         tg_yyyyyzz_xxzzzz_0, tg_yyyyyzz_xxzzzz_1, tg_yyyyyzz_xyyyy_1, tg_yyyyyzz_xyyyyy_0, \
                                         tg_yyyyyzz_xyyyyy_1, tg_yyyyyzz_xyyyyz_0, tg_yyyyyzz_xyyyyz_1, tg_yyyyyzz_xyyyz_1, \
                                         tg_yyyyyzz_xyyyzz_0, tg_yyyyyzz_xyyyzz_1, tg_yyyyyzz_xyyzz_1, tg_yyyyyzz_xyyzzz_0, \
                                         tg_yyyyyzz_xyyzzz_1, tg_yyyyyzz_xyzzz_1, tg_yyyyyzz_xyzzzz_0, tg_yyyyyzz_xyzzzz_1, \
                                         tg_yyyyyzz_xzzzz_1, tg_yyyyyzz_xzzzzz_0, tg_yyyyyzz_xzzzzz_1, tg_yyyyyzz_yyyyy_1, \
                                         tg_yyyyyzz_yyyyyy_0, tg_yyyyyzz_yyyyyy_1, tg_yyyyyzz_yyyyyz_0, tg_yyyyyzz_yyyyyz_1, \
                                         tg_yyyyyzz_yyyyz_1, tg_yyyyyzz_yyyyzz_0, tg_yyyyyzz_yyyyzz_1, tg_yyyyyzz_yyyzz_1, \
                                         tg_yyyyyzz_yyyzzz_0, tg_yyyyyzz_yyyzzz_1, tg_yyyyyzz_yyzzz_1, tg_yyyyyzz_yyzzzz_0, \
                                         tg_yyyyyzz_yyzzzz_1, tg_yyyyyzz_yzzzz_1, tg_yyyyyzz_yzzzzz_0, tg_yyyyyzz_yzzzzz_1, \
                                         tg_yyyyyzz_zzzzz_1, tg_yyyyyzz_zzzzzz_0, tg_yyyyyzz_zzzzzz_1, tg_yyyyzzz_xxxxx_1, \
                                         tg_yyyyzzz_xxxxxx_0, tg_yyyyzzz_xxxxxx_1, tg_yyyyzzz_xxxxxy_0, tg_yyyyzzz_xxxxxy_1, \
                                         tg_yyyyzzz_xxxxxz_0, tg_yyyyzzz_xxxxxz_1, tg_yyyyzzz_xxxxy_1, tg_yyyyzzz_xxxxyy_0, \
                                         tg_yyyyzzz_xxxxyy_1, tg_yyyyzzz_xxxxyz_0, tg_yyyyzzz_xxxxyz_1, tg_yyyyzzz_xxxxz_1, \
                                         tg_yyyyzzz_xxxyy_1, tg_yyyyzzz_xxxyz_1, tg_zzzzzz_xzzzzz_0, tg_zzzzzz_xzzzzz_1, \
                                         tg_zzzzzz_yyyyyy_0, tg_zzzzzz_yyyyyy_1, tg_zzzzzz_yyyyyz_0, tg_zzzzzz_yyyyyz_1, \
                                         tg_zzzzzz_yyyyzz_0, tg_zzzzzz_yyyyzz_1, tg_zzzzzz_yyyzzz_0, tg_zzzzzz_yyyzzz_1, \
                                         tg_zzzzzz_yyzzzz_0, tg_zzzzzz_yyzzzz_1, tg_zzzzzz_yzzzzz_0, tg_zzzzzz_yzzzzz_1, \
                                         tg_zzzzzz_zzzzzz_0, tg_zzzzzz_zzzzzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xxzzzzzz_xzzzzz_0[j] = pb_x * tg_xzzzzzz_xzzzzz_0[j] + fr * tg_xzzzzzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xzzzzz_0[j] - tg_zzzzzz_xzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_xzzzzzz_zzzzz_1[j];

                    tg_xxzzzzzz_yyyyyy_0[j] = pb_x * tg_xzzzzzz_yyyyyy_0[j] + fr * tg_xzzzzzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyyy_0[j] - tg_zzzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_xxzzzzzz_yyyyyz_0[j] = pb_x * tg_xzzzzzz_yyyyyz_0[j] + fr * tg_xzzzzzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyyz_0[j] - tg_zzzzzz_yyyyyz_1[j] * fl1_fza);

                    tg_xxzzzzzz_yyyyzz_0[j] = pb_x * tg_xzzzzzz_yyyyzz_0[j] + fr * tg_xzzzzzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyzz_0[j] - tg_zzzzzz_yyyyzz_1[j] * fl1_fza);

                    tg_xxzzzzzz_yyyzzz_0[j] = pb_x * tg_xzzzzzz_yyyzzz_0[j] + fr * tg_xzzzzzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyzzz_0[j] - tg_zzzzzz_yyyzzz_1[j] * fl1_fza);

                    tg_xxzzzzzz_yyzzzz_0[j] = pb_x * tg_xzzzzzz_yyzzzz_0[j] + fr * tg_xzzzzzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyzzzz_0[j] - tg_zzzzzz_yyzzzz_1[j] * fl1_fza);

                    tg_xxzzzzzz_yzzzzz_0[j] = pb_x * tg_xzzzzzz_yzzzzz_0[j] + fr * tg_xzzzzzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yzzzzz_0[j] - tg_zzzzzz_yzzzzz_1[j] * fl1_fza);

                    tg_xxzzzzzz_zzzzzz_0[j] = pb_x * tg_xzzzzzz_zzzzzz_0[j] + fr * tg_xzzzzzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_zzzzzz_0[j] - tg_zzzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_xyyyyyyy_xxxxxx_0[j] = pb_x * tg_yyyyyyy_xxxxxx_0[j] + fr * tg_yyyyyyy_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyyyyyy_xxxxx_1[j];

                    tg_xyyyyyyy_xxxxxy_0[j] = pb_x * tg_yyyyyyy_xxxxxy_0[j] + fr * tg_yyyyyyy_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyyyyyy_xxxxy_1[j];

                    tg_xyyyyyyy_xxxxxz_0[j] = pb_x * tg_yyyyyyy_xxxxxz_0[j] + fr * tg_yyyyyyy_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyyyyyy_xxxxz_1[j];

                    tg_xyyyyyyy_xxxxyy_0[j] = pb_x * tg_yyyyyyy_xxxxyy_0[j] + fr * tg_yyyyyyy_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyyyyyy_xxxyy_1[j];

                    tg_xyyyyyyy_xxxxyz_0[j] = pb_x * tg_yyyyyyy_xxxxyz_0[j] + fr * tg_yyyyyyy_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyyyyyy_xxxyz_1[j];

                    tg_xyyyyyyy_xxxxzz_0[j] = pb_x * tg_yyyyyyy_xxxxzz_0[j] + fr * tg_yyyyyyy_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyyy_xxxzz_1[j];

                    tg_xyyyyyyy_xxxyyy_0[j] = pb_x * tg_yyyyyyy_xxxyyy_0[j] + fr * tg_yyyyyyy_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyyyy_xxyyy_1[j];

                    tg_xyyyyyyy_xxxyyz_0[j] = pb_x * tg_yyyyyyy_xxxyyz_0[j] + fr * tg_yyyyyyy_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyy_xxyyz_1[j];

                    tg_xyyyyyyy_xxxyzz_0[j] = pb_x * tg_yyyyyyy_xxxyzz_0[j] + fr * tg_yyyyyyy_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyy_xxyzz_1[j];

                    tg_xyyyyyyy_xxxzzz_0[j] = pb_x * tg_yyyyyyy_xxxzzz_0[j] + fr * tg_yyyyyyy_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyy_xxzzz_1[j];

                    tg_xyyyyyyy_xxyyyy_0[j] = pb_x * tg_yyyyyyy_xxyyyy_0[j] + fr * tg_yyyyyyy_xxyyyy_1[j] + fl1_fxn * tg_yyyyyyy_xyyyy_1[j];

                    tg_xyyyyyyy_xxyyyz_0[j] = pb_x * tg_yyyyyyy_xxyyyz_0[j] + fr * tg_yyyyyyy_xxyyyz_1[j] + fl1_fxn * tg_yyyyyyy_xyyyz_1[j];

                    tg_xyyyyyyy_xxyyzz_0[j] = pb_x * tg_yyyyyyy_xxyyzz_0[j] + fr * tg_yyyyyyy_xxyyzz_1[j] + fl1_fxn * tg_yyyyyyy_xyyzz_1[j];

                    tg_xyyyyyyy_xxyzzz_0[j] = pb_x * tg_yyyyyyy_xxyzzz_0[j] + fr * tg_yyyyyyy_xxyzzz_1[j] + fl1_fxn * tg_yyyyyyy_xyzzz_1[j];

                    tg_xyyyyyyy_xxzzzz_0[j] = pb_x * tg_yyyyyyy_xxzzzz_0[j] + fr * tg_yyyyyyy_xxzzzz_1[j] + fl1_fxn * tg_yyyyyyy_xzzzz_1[j];

                    tg_xyyyyyyy_xyyyyy_0[j] = pb_x * tg_yyyyyyy_xyyyyy_0[j] + fr * tg_yyyyyyy_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_yyyyy_1[j];

                    tg_xyyyyyyy_xyyyyz_0[j] = pb_x * tg_yyyyyyy_xyyyyz_0[j] + fr * tg_yyyyyyy_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_yyyyz_1[j];

                    tg_xyyyyyyy_xyyyzz_0[j] = pb_x * tg_yyyyyyy_xyyyzz_0[j] + fr * tg_yyyyyyy_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_yyyzz_1[j];

                    tg_xyyyyyyy_xyyzzz_0[j] = pb_x * tg_yyyyyyy_xyyzzz_0[j] + fr * tg_yyyyyyy_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_yyzzz_1[j];

                    tg_xyyyyyyy_xyzzzz_0[j] = pb_x * tg_yyyyyyy_xyzzzz_0[j] + fr * tg_yyyyyyy_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_yzzzz_1[j];

                    tg_xyyyyyyy_xzzzzz_0[j] = pb_x * tg_yyyyyyy_xzzzzz_0[j] + fr * tg_yyyyyyy_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyy_zzzzz_1[j];

                    tg_xyyyyyyy_yyyyyy_0[j] = pb_x * tg_yyyyyyy_yyyyyy_0[j] + fr * tg_yyyyyyy_yyyyyy_1[j];

                    tg_xyyyyyyy_yyyyyz_0[j] = pb_x * tg_yyyyyyy_yyyyyz_0[j] + fr * tg_yyyyyyy_yyyyyz_1[j];

                    tg_xyyyyyyy_yyyyzz_0[j] = pb_x * tg_yyyyyyy_yyyyzz_0[j] + fr * tg_yyyyyyy_yyyyzz_1[j];

                    tg_xyyyyyyy_yyyzzz_0[j] = pb_x * tg_yyyyyyy_yyyzzz_0[j] + fr * tg_yyyyyyy_yyyzzz_1[j];

                    tg_xyyyyyyy_yyzzzz_0[j] = pb_x * tg_yyyyyyy_yyzzzz_0[j] + fr * tg_yyyyyyy_yyzzzz_1[j];

                    tg_xyyyyyyy_yzzzzz_0[j] = pb_x * tg_yyyyyyy_yzzzzz_0[j] + fr * tg_yyyyyyy_yzzzzz_1[j];

                    tg_xyyyyyyy_zzzzzz_0[j] = pb_x * tg_yyyyyyy_zzzzzz_0[j] + fr * tg_yyyyyyy_zzzzzz_1[j];

                    tg_xyyyyyyz_xxxxxx_0[j] = pb_x * tg_yyyyyyz_xxxxxx_0[j] + fr * tg_yyyyyyz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyyyyyz_xxxxx_1[j];

                    tg_xyyyyyyz_xxxxxy_0[j] = pb_x * tg_yyyyyyz_xxxxxy_0[j] + fr * tg_yyyyyyz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyyyyyz_xxxxy_1[j];

                    tg_xyyyyyyz_xxxxxz_0[j] = pb_x * tg_yyyyyyz_xxxxxz_0[j] + fr * tg_yyyyyyz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyyyyyz_xxxxz_1[j];

                    tg_xyyyyyyz_xxxxyy_0[j] = pb_x * tg_yyyyyyz_xxxxyy_0[j] + fr * tg_yyyyyyz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyyyyyz_xxxyy_1[j];

                    tg_xyyyyyyz_xxxxyz_0[j] = pb_x * tg_yyyyyyz_xxxxyz_0[j] + fr * tg_yyyyyyz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyyyyyz_xxxyz_1[j];

                    tg_xyyyyyyz_xxxxzz_0[j] = pb_x * tg_yyyyyyz_xxxxzz_0[j] + fr * tg_yyyyyyz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyyz_xxxzz_1[j];

                    tg_xyyyyyyz_xxxyyy_0[j] = pb_x * tg_yyyyyyz_xxxyyy_0[j] + fr * tg_yyyyyyz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyyyz_xxyyy_1[j];

                    tg_xyyyyyyz_xxxyyz_0[j] = pb_x * tg_yyyyyyz_xxxyyz_0[j] + fr * tg_yyyyyyz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyz_xxyyz_1[j];

                    tg_xyyyyyyz_xxxyzz_0[j] = pb_x * tg_yyyyyyz_xxxyzz_0[j] + fr * tg_yyyyyyz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyz_xxyzz_1[j];

                    tg_xyyyyyyz_xxxzzz_0[j] = pb_x * tg_yyyyyyz_xxxzzz_0[j] + fr * tg_yyyyyyz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyyz_xxzzz_1[j];

                    tg_xyyyyyyz_xxyyyy_0[j] = pb_x * tg_yyyyyyz_xxyyyy_0[j] + fr * tg_yyyyyyz_xxyyyy_1[j] + fl1_fxn * tg_yyyyyyz_xyyyy_1[j];

                    tg_xyyyyyyz_xxyyyz_0[j] = pb_x * tg_yyyyyyz_xxyyyz_0[j] + fr * tg_yyyyyyz_xxyyyz_1[j] + fl1_fxn * tg_yyyyyyz_xyyyz_1[j];

                    tg_xyyyyyyz_xxyyzz_0[j] = pb_x * tg_yyyyyyz_xxyyzz_0[j] + fr * tg_yyyyyyz_xxyyzz_1[j] + fl1_fxn * tg_yyyyyyz_xyyzz_1[j];

                    tg_xyyyyyyz_xxyzzz_0[j] = pb_x * tg_yyyyyyz_xxyzzz_0[j] + fr * tg_yyyyyyz_xxyzzz_1[j] + fl1_fxn * tg_yyyyyyz_xyzzz_1[j];

                    tg_xyyyyyyz_xxzzzz_0[j] = pb_x * tg_yyyyyyz_xxzzzz_0[j] + fr * tg_yyyyyyz_xxzzzz_1[j] + fl1_fxn * tg_yyyyyyz_xzzzz_1[j];

                    tg_xyyyyyyz_xyyyyy_0[j] = pb_x * tg_yyyyyyz_xyyyyy_0[j] + fr * tg_yyyyyyz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_yyyyy_1[j];

                    tg_xyyyyyyz_xyyyyz_0[j] = pb_x * tg_yyyyyyz_xyyyyz_0[j] + fr * tg_yyyyyyz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_yyyyz_1[j];

                    tg_xyyyyyyz_xyyyzz_0[j] = pb_x * tg_yyyyyyz_xyyyzz_0[j] + fr * tg_yyyyyyz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_yyyzz_1[j];

                    tg_xyyyyyyz_xyyzzz_0[j] = pb_x * tg_yyyyyyz_xyyzzz_0[j] + fr * tg_yyyyyyz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_yyzzz_1[j];

                    tg_xyyyyyyz_xyzzzz_0[j] = pb_x * tg_yyyyyyz_xyzzzz_0[j] + fr * tg_yyyyyyz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_yzzzz_1[j];

                    tg_xyyyyyyz_xzzzzz_0[j] = pb_x * tg_yyyyyyz_xzzzzz_0[j] + fr * tg_yyyyyyz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyyz_zzzzz_1[j];

                    tg_xyyyyyyz_yyyyyy_0[j] = pb_x * tg_yyyyyyz_yyyyyy_0[j] + fr * tg_yyyyyyz_yyyyyy_1[j];

                    tg_xyyyyyyz_yyyyyz_0[j] = pb_x * tg_yyyyyyz_yyyyyz_0[j] + fr * tg_yyyyyyz_yyyyyz_1[j];

                    tg_xyyyyyyz_yyyyzz_0[j] = pb_x * tg_yyyyyyz_yyyyzz_0[j] + fr * tg_yyyyyyz_yyyyzz_1[j];

                    tg_xyyyyyyz_yyyzzz_0[j] = pb_x * tg_yyyyyyz_yyyzzz_0[j] + fr * tg_yyyyyyz_yyyzzz_1[j];

                    tg_xyyyyyyz_yyzzzz_0[j] = pb_x * tg_yyyyyyz_yyzzzz_0[j] + fr * tg_yyyyyyz_yyzzzz_1[j];

                    tg_xyyyyyyz_yzzzzz_0[j] = pb_x * tg_yyyyyyz_yzzzzz_0[j] + fr * tg_yyyyyyz_yzzzzz_1[j];

                    tg_xyyyyyyz_zzzzzz_0[j] = pb_x * tg_yyyyyyz_zzzzzz_0[j] + fr * tg_yyyyyyz_zzzzzz_1[j];

                    tg_xyyyyyzz_xxxxxx_0[j] = pb_x * tg_yyyyyzz_xxxxxx_0[j] + fr * tg_yyyyyzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyyyyzz_xxxxx_1[j];

                    tg_xyyyyyzz_xxxxxy_0[j] = pb_x * tg_yyyyyzz_xxxxxy_0[j] + fr * tg_yyyyyzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyyyyzz_xxxxy_1[j];

                    tg_xyyyyyzz_xxxxxz_0[j] = pb_x * tg_yyyyyzz_xxxxxz_0[j] + fr * tg_yyyyyzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyyyyzz_xxxxz_1[j];

                    tg_xyyyyyzz_xxxxyy_0[j] = pb_x * tg_yyyyyzz_xxxxyy_0[j] + fr * tg_yyyyyzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyyyyzz_xxxyy_1[j];

                    tg_xyyyyyzz_xxxxyz_0[j] = pb_x * tg_yyyyyzz_xxxxyz_0[j] + fr * tg_yyyyyzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyyyyzz_xxxyz_1[j];

                    tg_xyyyyyzz_xxxxzz_0[j] = pb_x * tg_yyyyyzz_xxxxzz_0[j] + fr * tg_yyyyyzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyyyyzz_xxxzz_1[j];

                    tg_xyyyyyzz_xxxyyy_0[j] = pb_x * tg_yyyyyzz_xxxyyy_0[j] + fr * tg_yyyyyzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyyzz_xxyyy_1[j];

                    tg_xyyyyyzz_xxxyyz_0[j] = pb_x * tg_yyyyyzz_xxxyyz_0[j] + fr * tg_yyyyyzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyyzz_xxyyz_1[j];

                    tg_xyyyyyzz_xxxyzz_0[j] = pb_x * tg_yyyyyzz_xxxyzz_0[j] + fr * tg_yyyyyzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyzz_xxyzz_1[j];

                    tg_xyyyyyzz_xxxzzz_0[j] = pb_x * tg_yyyyyzz_xxxzzz_0[j] + fr * tg_yyyyyzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyyzz_xxzzz_1[j];

                    tg_xyyyyyzz_xxyyyy_0[j] = pb_x * tg_yyyyyzz_xxyyyy_0[j] + fr * tg_yyyyyzz_xxyyyy_1[j] + fl1_fxn * tg_yyyyyzz_xyyyy_1[j];

                    tg_xyyyyyzz_xxyyyz_0[j] = pb_x * tg_yyyyyzz_xxyyyz_0[j] + fr * tg_yyyyyzz_xxyyyz_1[j] + fl1_fxn * tg_yyyyyzz_xyyyz_1[j];

                    tg_xyyyyyzz_xxyyzz_0[j] = pb_x * tg_yyyyyzz_xxyyzz_0[j] + fr * tg_yyyyyzz_xxyyzz_1[j] + fl1_fxn * tg_yyyyyzz_xyyzz_1[j];

                    tg_xyyyyyzz_xxyzzz_0[j] = pb_x * tg_yyyyyzz_xxyzzz_0[j] + fr * tg_yyyyyzz_xxyzzz_1[j] + fl1_fxn * tg_yyyyyzz_xyzzz_1[j];

                    tg_xyyyyyzz_xxzzzz_0[j] = pb_x * tg_yyyyyzz_xxzzzz_0[j] + fr * tg_yyyyyzz_xxzzzz_1[j] + fl1_fxn * tg_yyyyyzz_xzzzz_1[j];

                    tg_xyyyyyzz_xyyyyy_0[j] = pb_x * tg_yyyyyzz_xyyyyy_0[j] + fr * tg_yyyyyzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_yyyyy_1[j];

                    tg_xyyyyyzz_xyyyyz_0[j] = pb_x * tg_yyyyyzz_xyyyyz_0[j] + fr * tg_yyyyyzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_yyyyz_1[j];

                    tg_xyyyyyzz_xyyyzz_0[j] = pb_x * tg_yyyyyzz_xyyyzz_0[j] + fr * tg_yyyyyzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_yyyzz_1[j];

                    tg_xyyyyyzz_xyyzzz_0[j] = pb_x * tg_yyyyyzz_xyyzzz_0[j] + fr * tg_yyyyyzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_yyzzz_1[j];

                    tg_xyyyyyzz_xyzzzz_0[j] = pb_x * tg_yyyyyzz_xyzzzz_0[j] + fr * tg_yyyyyzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_yzzzz_1[j];

                    tg_xyyyyyzz_xzzzzz_0[j] = pb_x * tg_yyyyyzz_xzzzzz_0[j] + fr * tg_yyyyyzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyyzz_zzzzz_1[j];

                    tg_xyyyyyzz_yyyyyy_0[j] = pb_x * tg_yyyyyzz_yyyyyy_0[j] + fr * tg_yyyyyzz_yyyyyy_1[j];

                    tg_xyyyyyzz_yyyyyz_0[j] = pb_x * tg_yyyyyzz_yyyyyz_0[j] + fr * tg_yyyyyzz_yyyyyz_1[j];

                    tg_xyyyyyzz_yyyyzz_0[j] = pb_x * tg_yyyyyzz_yyyyzz_0[j] + fr * tg_yyyyyzz_yyyyzz_1[j];

                    tg_xyyyyyzz_yyyzzz_0[j] = pb_x * tg_yyyyyzz_yyyzzz_0[j] + fr * tg_yyyyyzz_yyyzzz_1[j];

                    tg_xyyyyyzz_yyzzzz_0[j] = pb_x * tg_yyyyyzz_yyzzzz_0[j] + fr * tg_yyyyyzz_yyzzzz_1[j];

                    tg_xyyyyyzz_yzzzzz_0[j] = pb_x * tg_yyyyyzz_yzzzzz_0[j] + fr * tg_yyyyyzz_yzzzzz_1[j];

                    tg_xyyyyyzz_zzzzzz_0[j] = pb_x * tg_yyyyyzz_zzzzzz_0[j] + fr * tg_yyyyyzz_zzzzzz_1[j];

                    tg_xyyyyzzz_xxxxxx_0[j] = pb_x * tg_yyyyzzz_xxxxxx_0[j] + fr * tg_yyyyzzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyyyzzz_xxxxx_1[j];

                    tg_xyyyyzzz_xxxxxy_0[j] = pb_x * tg_yyyyzzz_xxxxxy_0[j] + fr * tg_yyyyzzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyyyzzz_xxxxy_1[j];

                    tg_xyyyyzzz_xxxxxz_0[j] = pb_x * tg_yyyyzzz_xxxxxz_0[j] + fr * tg_yyyyzzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyyyzzz_xxxxz_1[j];

                    tg_xyyyyzzz_xxxxyy_0[j] = pb_x * tg_yyyyzzz_xxxxyy_0[j] + fr * tg_yyyyzzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyyyzzz_xxxyy_1[j];

                    tg_xyyyyzzz_xxxxyz_0[j] = pb_x * tg_yyyyzzz_xxxxyz_0[j] + fr * tg_yyyyzzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyyyzzz_xxxyz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_873_970(      CMemBlock2D<double>* primBuffer,
                                         const CRecursionMap&       recursionMap,
                                         const CMemBlock2D<double>& osFactors,
                                         const CMemBlock2D<double>& wpDistances,
                                         const CGtoPairsBlock&      braGtoPairsBlock,
                                         const CGtoPairsBlock&      ketGtoPairsBlock,
                                         const int32_t              nKetPrimPairs,
                                         const int32_t              iContrPair)
    {
        // Batch of Integrals (873,970)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        // set up pointers to common Obara-Saika factors

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                // set up pointers to auxilary integrals

                auto tg_yyyyzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 873); 

                auto tg_yyyyzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 874); 

                auto tg_yyyyzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 875); 

                auto tg_yyyyzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 876); 

                auto tg_yyyyzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 877); 

                auto tg_yyyyzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 878); 

                auto tg_yyyyzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 879); 

                auto tg_yyyyzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 880); 

                auto tg_yyyyzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 881); 

                auto tg_yyyyzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 882); 

                auto tg_yyyyzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 883); 

                auto tg_yyyyzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 884); 

                auto tg_yyyyzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 885); 

                auto tg_yyyyzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 886); 

                auto tg_yyyyzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 887); 

                auto tg_yyyyzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 888); 

                auto tg_yyyyzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 889); 

                auto tg_yyyyzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 890); 

                auto tg_yyyyzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 891); 

                auto tg_yyyyzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 892); 

                auto tg_yyyyzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 893); 

                auto tg_yyyyzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 894); 

                auto tg_yyyyzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 895); 

                auto tg_yyyzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 896); 

                auto tg_yyyzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 897); 

                auto tg_yyyzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 898); 

                auto tg_yyyzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 899); 

                auto tg_yyyzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 900); 

                auto tg_yyyzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 901); 

                auto tg_yyyzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 902); 

                auto tg_yyyzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 903); 

                auto tg_yyyzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 904); 

                auto tg_yyyzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 905); 

                auto tg_yyyzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 906); 

                auto tg_yyyzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 907); 

                auto tg_yyyzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 908); 

                auto tg_yyyzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 909); 

                auto tg_yyyzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 910); 

                auto tg_yyyzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 911); 

                auto tg_yyyzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 912); 

                auto tg_yyyzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 913); 

                auto tg_yyyzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 914); 

                auto tg_yyyzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 915); 

                auto tg_yyyzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 916); 

                auto tg_yyyzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 917); 

                auto tg_yyyzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 918); 

                auto tg_yyyzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 919); 

                auto tg_yyyzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 920); 

                auto tg_yyyzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 921); 

                auto tg_yyyzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 922); 

                auto tg_yyyzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 923); 

                auto tg_yyzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 924); 

                auto tg_yyzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 925); 

                auto tg_yyzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 926); 

                auto tg_yyzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 927); 

                auto tg_yyzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 928); 

                auto tg_yyzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 929); 

                auto tg_yyzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 930); 

                auto tg_yyzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 931); 

                auto tg_yyzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 932); 

                auto tg_yyzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 933); 

                auto tg_yyzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 934); 

                auto tg_yyzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 935); 

                auto tg_yyzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 936); 

                auto tg_yyzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 937); 

                auto tg_yyzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 938); 

                auto tg_yyzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 939); 

                auto tg_yyzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 940); 

                auto tg_yyzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 941); 

                auto tg_yyzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 942); 

                auto tg_yyzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 943); 

                auto tg_yyzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 944); 

                auto tg_yyzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 945); 

                auto tg_yyzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 946); 

                auto tg_yyzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 947); 

                auto tg_yyzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 948); 

                auto tg_yyzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 949); 

                auto tg_yyzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 950); 

                auto tg_yyzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 951); 

                auto tg_yzzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 952); 

                auto tg_yzzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 953); 

                auto tg_yzzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 954); 

                auto tg_yzzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 955); 

                auto tg_yzzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 956); 

                auto tg_yzzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 957); 

                auto tg_yzzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 958); 

                auto tg_yzzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 959); 

                auto tg_yzzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 960); 

                auto tg_yzzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 961); 

                auto tg_yzzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 962); 

                auto tg_yzzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 963); 

                auto tg_yzzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 964); 

                auto tg_yzzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 965); 

                auto tg_yzzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 966); 

                auto tg_yzzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 967); 

                auto tg_yzzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 968); 

                auto tg_yzzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 969); 

                auto tg_yyyyzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 873); 

                auto tg_yyyyzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 874); 

                auto tg_yyyyzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 875); 

                auto tg_yyyyzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 876); 

                auto tg_yyyyzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 877); 

                auto tg_yyyyzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 878); 

                auto tg_yyyyzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 879); 

                auto tg_yyyyzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 880); 

                auto tg_yyyyzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 881); 

                auto tg_yyyyzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 882); 

                auto tg_yyyyzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 883); 

                auto tg_yyyyzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 884); 

                auto tg_yyyyzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 885); 

                auto tg_yyyyzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 886); 

                auto tg_yyyyzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 887); 

                auto tg_yyyyzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 888); 

                auto tg_yyyyzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 889); 

                auto tg_yyyyzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 890); 

                auto tg_yyyyzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 891); 

                auto tg_yyyyzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 892); 

                auto tg_yyyyzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 893); 

                auto tg_yyyyzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 894); 

                auto tg_yyyyzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 895); 

                auto tg_yyyzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 896); 

                auto tg_yyyzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 897); 

                auto tg_yyyzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 898); 

                auto tg_yyyzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 899); 

                auto tg_yyyzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 900); 

                auto tg_yyyzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 901); 

                auto tg_yyyzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 902); 

                auto tg_yyyzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 903); 

                auto tg_yyyzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 904); 

                auto tg_yyyzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 905); 

                auto tg_yyyzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 906); 

                auto tg_yyyzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 907); 

                auto tg_yyyzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 908); 

                auto tg_yyyzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 909); 

                auto tg_yyyzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 910); 

                auto tg_yyyzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 911); 

                auto tg_yyyzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 912); 

                auto tg_yyyzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 913); 

                auto tg_yyyzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 914); 

                auto tg_yyyzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 915); 

                auto tg_yyyzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 916); 

                auto tg_yyyzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 917); 

                auto tg_yyyzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 918); 

                auto tg_yyyzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 919); 

                auto tg_yyyzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 920); 

                auto tg_yyyzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 921); 

                auto tg_yyyzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 922); 

                auto tg_yyyzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 923); 

                auto tg_yyzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 924); 

                auto tg_yyzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 925); 

                auto tg_yyzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 926); 

                auto tg_yyzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 927); 

                auto tg_yyzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 928); 

                auto tg_yyzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 929); 

                auto tg_yyzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 930); 

                auto tg_yyzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 931); 

                auto tg_yyzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 932); 

                auto tg_yyzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 933); 

                auto tg_yyzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 934); 

                auto tg_yyzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 935); 

                auto tg_yyzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 936); 

                auto tg_yyzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 937); 

                auto tg_yyzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 938); 

                auto tg_yyzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 939); 

                auto tg_yyzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 940); 

                auto tg_yyzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 941); 

                auto tg_yyzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 942); 

                auto tg_yyzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 943); 

                auto tg_yyzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 944); 

                auto tg_yyzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 945); 

                auto tg_yyzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 946); 

                auto tg_yyzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 947); 

                auto tg_yyzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 948); 

                auto tg_yyzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 949); 

                auto tg_yyzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 950); 

                auto tg_yyzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 951); 

                auto tg_yzzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 952); 

                auto tg_yzzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 953); 

                auto tg_yzzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 954); 

                auto tg_yzzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 955); 

                auto tg_yzzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 956); 

                auto tg_yzzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 957); 

                auto tg_yzzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 958); 

                auto tg_yzzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 959); 

                auto tg_yzzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 960); 

                auto tg_yzzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 961); 

                auto tg_yzzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 962); 

                auto tg_yzzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 963); 

                auto tg_yzzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 964); 

                auto tg_yzzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 965); 

                auto tg_yzzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 966); 

                auto tg_yzzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 967); 

                auto tg_yzzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 968); 

                auto tg_yzzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 969); 

                auto tg_yyyyzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 656); 

                auto tg_yyyyzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 657); 

                auto tg_yyyyzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 658); 

                auto tg_yyyyzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 659); 

                auto tg_yyyyzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 660); 

                auto tg_yyyyzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 661); 

                auto tg_yyyyzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 662); 

                auto tg_yyyyzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 663); 

                auto tg_yyyyzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 664); 

                auto tg_yyyyzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 665); 

                auto tg_yyyyzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 666); 

                auto tg_yyyyzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 667); 

                auto tg_yyyyzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 668); 

                auto tg_yyyyzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 669); 

                auto tg_yyyyzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 670); 

                auto tg_yyyyzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 671); 

                auto tg_yyyzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 672); 

                auto tg_yyyzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 673); 

                auto tg_yyyzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 674); 

                auto tg_yyyzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 675); 

                auto tg_yyyzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 676); 

                auto tg_yyyzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 677); 

                auto tg_yyyzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 678); 

                auto tg_yyyzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 679); 

                auto tg_yyyzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 680); 

                auto tg_yyyzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 681); 

                auto tg_yyyzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 682); 

                auto tg_yyyzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 683); 

                auto tg_yyyzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 684); 

                auto tg_yyyzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 685); 

                auto tg_yyyzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 686); 

                auto tg_yyyzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 687); 

                auto tg_yyyzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 688); 

                auto tg_yyyzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 689); 

                auto tg_yyyzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 690); 

                auto tg_yyyzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 691); 

                auto tg_yyyzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 692); 

                auto tg_yyzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 693); 

                auto tg_yyzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 694); 

                auto tg_yyzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 695); 

                auto tg_yyzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 696); 

                auto tg_yyzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 697); 

                auto tg_yyzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 698); 

                auto tg_yyzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 699); 

                auto tg_yyzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 700); 

                auto tg_yyzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 701); 

                auto tg_yyzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 702); 

                auto tg_yyzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 703); 

                auto tg_yyzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 704); 

                auto tg_yyzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 705); 

                auto tg_yyzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 706); 

                auto tg_yyzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 707); 

                auto tg_yyzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 708); 

                auto tg_yyzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 709); 

                auto tg_yyzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 710); 

                auto tg_yyzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 711); 

                auto tg_yyzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 712); 

                auto tg_yyzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 713); 

                auto tg_yzzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 714); 

                auto tg_yzzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 715); 

                auto tg_yzzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 716); 

                auto tg_yzzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 717); 

                auto tg_yzzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 718); 

                auto tg_yzzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 719); 

                auto tg_yzzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 720); 

                auto tg_yzzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 721); 

                auto tg_yzzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 722); 

                auto tg_yzzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 723); 

                auto tg_yzzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 724); 

                auto tg_yzzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 725); 

                auto tg_yzzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 726); 

                auto tg_yzzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 727); 

                auto tg_yzzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 728); 

                auto tg_yzzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 729); 

                auto tg_yzzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 730); 

                auto tg_yzzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 731); 

                // set up pointers to integrals

                auto tg_xyyyyzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 873); 

                auto tg_xyyyyzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 874); 

                auto tg_xyyyyzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 875); 

                auto tg_xyyyyzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 876); 

                auto tg_xyyyyzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 877); 

                auto tg_xyyyyzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 878); 

                auto tg_xyyyyzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 879); 

                auto tg_xyyyyzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 880); 

                auto tg_xyyyyzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 881); 

                auto tg_xyyyyzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 882); 

                auto tg_xyyyyzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 883); 

                auto tg_xyyyyzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 884); 

                auto tg_xyyyyzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 885); 

                auto tg_xyyyyzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 886); 

                auto tg_xyyyyzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 887); 

                auto tg_xyyyyzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 888); 

                auto tg_xyyyyzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 889); 

                auto tg_xyyyyzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 890); 

                auto tg_xyyyyzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 891); 

                auto tg_xyyyyzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 892); 

                auto tg_xyyyyzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 893); 

                auto tg_xyyyyzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 894); 

                auto tg_xyyyyzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 895); 

                auto tg_xyyyzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 896); 

                auto tg_xyyyzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 897); 

                auto tg_xyyyzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 898); 

                auto tg_xyyyzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 899); 

                auto tg_xyyyzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 900); 

                auto tg_xyyyzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 901); 

                auto tg_xyyyzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 902); 

                auto tg_xyyyzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 903); 

                auto tg_xyyyzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 904); 

                auto tg_xyyyzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 905); 

                auto tg_xyyyzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 906); 

                auto tg_xyyyzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 907); 

                auto tg_xyyyzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 908); 

                auto tg_xyyyzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 909); 

                auto tg_xyyyzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 910); 

                auto tg_xyyyzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 911); 

                auto tg_xyyyzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 912); 

                auto tg_xyyyzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 913); 

                auto tg_xyyyzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 914); 

                auto tg_xyyyzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 915); 

                auto tg_xyyyzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 916); 

                auto tg_xyyyzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 917); 

                auto tg_xyyyzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 918); 

                auto tg_xyyyzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 919); 

                auto tg_xyyyzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 920); 

                auto tg_xyyyzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 921); 

                auto tg_xyyyzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 922); 

                auto tg_xyyyzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 923); 

                auto tg_xyyzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 924); 

                auto tg_xyyzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 925); 

                auto tg_xyyzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 926); 

                auto tg_xyyzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 927); 

                auto tg_xyyzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 928); 

                auto tg_xyyzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 929); 

                auto tg_xyyzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 930); 

                auto tg_xyyzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 931); 

                auto tg_xyyzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 932); 

                auto tg_xyyzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 933); 

                auto tg_xyyzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 934); 

                auto tg_xyyzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 935); 

                auto tg_xyyzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 936); 

                auto tg_xyyzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 937); 

                auto tg_xyyzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 938); 

                auto tg_xyyzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 939); 

                auto tg_xyyzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 940); 

                auto tg_xyyzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 941); 

                auto tg_xyyzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 942); 

                auto tg_xyyzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 943); 

                auto tg_xyyzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 944); 

                auto tg_xyyzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 945); 

                auto tg_xyyzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 946); 

                auto tg_xyyzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 947); 

                auto tg_xyyzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 948); 

                auto tg_xyyzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 949); 

                auto tg_xyyzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 950); 

                auto tg_xyyzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 951); 

                auto tg_xyzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 952); 

                auto tg_xyzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 953); 

                auto tg_xyzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 954); 

                auto tg_xyzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 955); 

                auto tg_xyzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 956); 

                auto tg_xyzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 957); 

                auto tg_xyzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 958); 

                auto tg_xyzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 959); 

                auto tg_xyzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 960); 

                auto tg_xyzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 961); 

                auto tg_xyzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 962); 

                auto tg_xyzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 963); 

                auto tg_xyzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 964); 

                auto tg_xyzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 965); 

                auto tg_xyzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 966); 

                auto tg_xyzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 967); 

                auto tg_xyzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 968); 

                auto tg_xyzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 969); 

                // Batch of Integrals (873,970)

                #pragma omp simd aligned(fxn, tg_xyyyyzzz_xxxxzz_0, tg_xyyyyzzz_xxxyyy_0, \
                                         tg_xyyyyzzz_xxxyyz_0, tg_xyyyyzzz_xxxyzz_0, tg_xyyyyzzz_xxxzzz_0, tg_xyyyyzzz_xxyyyy_0, \
                                         tg_xyyyyzzz_xxyyyz_0, tg_xyyyyzzz_xxyyzz_0, tg_xyyyyzzz_xxyzzz_0, tg_xyyyyzzz_xxzzzz_0, \
                                         tg_xyyyyzzz_xyyyyy_0, tg_xyyyyzzz_xyyyyz_0, tg_xyyyyzzz_xyyyzz_0, tg_xyyyyzzz_xyyzzz_0, \
                                         tg_xyyyyzzz_xyzzzz_0, tg_xyyyyzzz_xzzzzz_0, tg_xyyyyzzz_yyyyyy_0, tg_xyyyyzzz_yyyyyz_0, \
                                         tg_xyyyyzzz_yyyyzz_0, tg_xyyyyzzz_yyyzzz_0, tg_xyyyyzzz_yyzzzz_0, tg_xyyyyzzz_yzzzzz_0, \
                                         tg_xyyyyzzz_zzzzzz_0, tg_xyyyzzzz_xxxxxx_0, tg_xyyyzzzz_xxxxxy_0, tg_xyyyzzzz_xxxxxz_0, \
                                         tg_xyyyzzzz_xxxxyy_0, tg_xyyyzzzz_xxxxyz_0, tg_xyyyzzzz_xxxxzz_0, tg_xyyyzzzz_xxxyyy_0, \
                                         tg_xyyyzzzz_xxxyyz_0, tg_xyyyzzzz_xxxyzz_0, tg_xyyyzzzz_xxxzzz_0, tg_xyyyzzzz_xxyyyy_0, \
                                         tg_xyyyzzzz_xxyyyz_0, tg_xyyyzzzz_xxyyzz_0, tg_xyyyzzzz_xxyzzz_0, tg_xyyyzzzz_xxzzzz_0, \
                                         tg_xyyyzzzz_xyyyyy_0, tg_xyyyzzzz_xyyyyz_0, tg_xyyyzzzz_xyyyzz_0, tg_xyyyzzzz_xyyzzz_0, \
                                         tg_xyyyzzzz_xyzzzz_0, tg_xyyyzzzz_xzzzzz_0, tg_xyyyzzzz_yyyyyy_0, tg_xyyyzzzz_yyyyyz_0, \
                                         tg_xyyyzzzz_yyyyzz_0, tg_xyyyzzzz_yyyzzz_0, tg_xyyyzzzz_yyzzzz_0, tg_xyyyzzzz_yzzzzz_0, \
                                         tg_xyyyzzzz_zzzzzz_0, tg_xyyzzzzz_xxxxxx_0, tg_xyyzzzzz_xxxxxy_0, tg_xyyzzzzz_xxxxxz_0, \
                                         tg_xyyzzzzz_xxxxyy_0, tg_xyyzzzzz_xxxxyz_0, tg_xyyzzzzz_xxxxzz_0, tg_xyyzzzzz_xxxyyy_0, \
                                         tg_xyyzzzzz_xxxyyz_0, tg_xyyzzzzz_xxxyzz_0, tg_xyyzzzzz_xxxzzz_0, tg_xyyzzzzz_xxyyyy_0, \
                                         tg_xyyzzzzz_xxyyyz_0, tg_xyyzzzzz_xxyyzz_0, tg_xyyzzzzz_xxyzzz_0, tg_xyyzzzzz_xxzzzz_0, \
                                         tg_xyyzzzzz_xyyyyy_0, tg_xyyzzzzz_xyyyyz_0, tg_xyyzzzzz_xyyyzz_0, tg_xyyzzzzz_xyyzzz_0, \
                                         tg_xyyzzzzz_xyzzzz_0, tg_xyyzzzzz_xzzzzz_0, tg_xyyzzzzz_yyyyyy_0, tg_xyyzzzzz_yyyyyz_0, \
                                         tg_xyyzzzzz_yyyyzz_0, tg_xyyzzzzz_yyyzzz_0, tg_xyyzzzzz_yyzzzz_0, tg_xyyzzzzz_yzzzzz_0, \
                                         tg_xyyzzzzz_zzzzzz_0, tg_xyzzzzzz_xxxxxx_0, tg_xyzzzzzz_xxxxxy_0, tg_xyzzzzzz_xxxxxz_0, \
                                         tg_xyzzzzzz_xxxxyy_0, tg_xyzzzzzz_xxxxyz_0, tg_xyzzzzzz_xxxxzz_0, tg_xyzzzzzz_xxxyyy_0, \
                                         tg_xyzzzzzz_xxxyyz_0, tg_xyzzzzzz_xxxyzz_0, tg_xyzzzzzz_xxxzzz_0, tg_xyzzzzzz_xxyyyy_0, \
                                         tg_xyzzzzzz_xxyyyz_0, tg_xyzzzzzz_xxyyzz_0, tg_xyzzzzzz_xxyzzz_0, tg_xyzzzzzz_xxzzzz_0, \
                                         tg_xyzzzzzz_xyyyyy_0, tg_xyzzzzzz_xyyyyz_0, tg_xyzzzzzz_xyyyzz_0, tg_yyyyzzz_xxxxzz_0, \
                                         tg_yyyyzzz_xxxxzz_1, tg_yyyyzzz_xxxyyy_0, tg_yyyyzzz_xxxyyy_1, tg_yyyyzzz_xxxyyz_0, \
                                         tg_yyyyzzz_xxxyyz_1, tg_yyyyzzz_xxxyzz_0, tg_yyyyzzz_xxxyzz_1, tg_yyyyzzz_xxxzz_1, \
                                         tg_yyyyzzz_xxxzzz_0, tg_yyyyzzz_xxxzzz_1, tg_yyyyzzz_xxyyy_1, tg_yyyyzzz_xxyyyy_0, \
                                         tg_yyyyzzz_xxyyyy_1, tg_yyyyzzz_xxyyyz_0, tg_yyyyzzz_xxyyyz_1, tg_yyyyzzz_xxyyz_1, \
                                         tg_yyyyzzz_xxyyzz_0, tg_yyyyzzz_xxyyzz_1, tg_yyyyzzz_xxyzz_1, tg_yyyyzzz_xxyzzz_0, \
                                         tg_yyyyzzz_xxyzzz_1, tg_yyyyzzz_xxzzz_1, tg_yyyyzzz_xxzzzz_0, tg_yyyyzzz_xxzzzz_1, \
                                         tg_yyyyzzz_xyyyy_1, tg_yyyyzzz_xyyyyy_0, tg_yyyyzzz_xyyyyy_1, tg_yyyyzzz_xyyyyz_0, \
                                         tg_yyyyzzz_xyyyyz_1, tg_yyyyzzz_xyyyz_1, tg_yyyyzzz_xyyyzz_0, tg_yyyyzzz_xyyyzz_1, \
                                         tg_yyyyzzz_xyyzz_1, tg_yyyyzzz_xyyzzz_0, tg_yyyyzzz_xyyzzz_1, tg_yyyyzzz_xyzzz_1, \
                                         tg_yyyyzzz_xyzzzz_0, tg_yyyyzzz_xyzzzz_1, tg_yyyyzzz_xzzzz_1, tg_yyyyzzz_xzzzzz_0, \
                                         tg_yyyyzzz_xzzzzz_1, tg_yyyyzzz_yyyyy_1, tg_yyyyzzz_yyyyyy_0, tg_yyyyzzz_yyyyyy_1, \
                                         tg_yyyyzzz_yyyyyz_0, tg_yyyyzzz_yyyyyz_1, tg_yyyyzzz_yyyyz_1, tg_yyyyzzz_yyyyzz_0, \
                                         tg_yyyyzzz_yyyyzz_1, tg_yyyyzzz_yyyzz_1, tg_yyyyzzz_yyyzzz_0, tg_yyyyzzz_yyyzzz_1, \
                                         tg_yyyyzzz_yyzzz_1, tg_yyyyzzz_yyzzzz_0, tg_yyyyzzz_yyzzzz_1, tg_yyyyzzz_yzzzz_1, \
                                         tg_yyyyzzz_yzzzzz_0, tg_yyyyzzz_yzzzzz_1, tg_yyyyzzz_zzzzz_1, tg_yyyyzzz_zzzzzz_0, \
                                         tg_yyyyzzz_zzzzzz_1, tg_yyyzzzz_xxxxx_1, tg_yyyzzzz_xxxxxx_0, tg_yyyzzzz_xxxxxx_1, \
                                         tg_yyyzzzz_xxxxxy_0, tg_yyyzzzz_xxxxxy_1, tg_yyyzzzz_xxxxxz_0, tg_yyyzzzz_xxxxxz_1, \
                                         tg_yyyzzzz_xxxxy_1, tg_yyyzzzz_xxxxyy_0, tg_yyyzzzz_xxxxyy_1, tg_yyyzzzz_xxxxyz_0, \
                                         tg_yyyzzzz_xxxxyz_1, tg_yyyzzzz_xxxxz_1, tg_yyyzzzz_xxxxzz_0, tg_yyyzzzz_xxxxzz_1, \
                                         tg_yyyzzzz_xxxyy_1, tg_yyyzzzz_xxxyyy_0, tg_yyyzzzz_xxxyyy_1, tg_yyyzzzz_xxxyyz_0, \
                                         tg_yyyzzzz_xxxyyz_1, tg_yyyzzzz_xxxyz_1, tg_yyyzzzz_xxxyzz_0, tg_yyyzzzz_xxxyzz_1, \
                                         tg_yyyzzzz_xxxzz_1, tg_yyyzzzz_xxxzzz_0, tg_yyyzzzz_xxxzzz_1, tg_yyyzzzz_xxyyy_1, \
                                         tg_yyyzzzz_xxyyyy_0, tg_yyyzzzz_xxyyyy_1, tg_yyyzzzz_xxyyyz_0, tg_yyyzzzz_xxyyyz_1, \
                                         tg_yyyzzzz_xxyyz_1, tg_yyyzzzz_xxyyzz_0, tg_yyyzzzz_xxyyzz_1, tg_yyyzzzz_xxyzz_1, \
                                         tg_yyyzzzz_xxyzzz_0, tg_yyyzzzz_xxyzzz_1, tg_yyyzzzz_xxzzz_1, tg_yyyzzzz_xxzzzz_0, \
                                         tg_yyyzzzz_xxzzzz_1, tg_yyyzzzz_xyyyy_1, tg_yyyzzzz_xyyyyy_0, tg_yyyzzzz_xyyyyy_1, \
                                         tg_yyyzzzz_xyyyyz_0, tg_yyyzzzz_xyyyyz_1, tg_yyyzzzz_xyyyz_1, tg_yyyzzzz_xyyyzz_0, \
                                         tg_yyyzzzz_xyyyzz_1, tg_yyyzzzz_xyyzz_1, tg_yyyzzzz_xyyzzz_0, tg_yyyzzzz_xyyzzz_1, \
                                         tg_yyyzzzz_xyzzz_1, tg_yyyzzzz_xyzzzz_0, tg_yyyzzzz_xyzzzz_1, tg_yyyzzzz_xzzzz_1, \
                                         tg_yyyzzzz_xzzzzz_0, tg_yyyzzzz_xzzzzz_1, tg_yyyzzzz_yyyyy_1, tg_yyyzzzz_yyyyyy_0, \
                                         tg_yyyzzzz_yyyyyy_1, tg_yyyzzzz_yyyyyz_0, tg_yyyzzzz_yyyyyz_1, tg_yyyzzzz_yyyyz_1, \
                                         tg_yyyzzzz_yyyyzz_0, tg_yyyzzzz_yyyyzz_1, tg_yyyzzzz_yyyzz_1, tg_yyyzzzz_yyyzzz_0, \
                                         tg_yyyzzzz_yyyzzz_1, tg_yyyzzzz_yyzzz_1, tg_yyyzzzz_yyzzzz_0, tg_yyyzzzz_yyzzzz_1, \
                                         tg_yyyzzzz_yzzzz_1, tg_yyyzzzz_yzzzzz_0, tg_yyyzzzz_yzzzzz_1, tg_yyyzzzz_zzzzz_1, \
                                         tg_yyyzzzz_zzzzzz_0, tg_yyyzzzz_zzzzzz_1, tg_yyzzzzz_xxxxx_1, tg_yyzzzzz_xxxxxx_0, \
                                         tg_yyzzzzz_xxxxxx_1, tg_yyzzzzz_xxxxxy_0, tg_yyzzzzz_xxxxxy_1, tg_yyzzzzz_xxxxxz_0, \
                                         tg_yyzzzzz_xxxxxz_1, tg_yyzzzzz_xxxxy_1, tg_yyzzzzz_xxxxyy_0, tg_yyzzzzz_xxxxyy_1, \
                                         tg_yyzzzzz_xxxxyz_0, tg_yyzzzzz_xxxxyz_1, tg_yyzzzzz_xxxxz_1, tg_yyzzzzz_xxxxzz_0, \
                                         tg_yyzzzzz_xxxxzz_1, tg_yyzzzzz_xxxyy_1, tg_yyzzzzz_xxxyyy_0, tg_yyzzzzz_xxxyyy_1, \
                                         tg_yyzzzzz_xxxyyz_0, tg_yyzzzzz_xxxyyz_1, tg_yyzzzzz_xxxyz_1, tg_yyzzzzz_xxxyzz_0, \
                                         tg_yyzzzzz_xxxyzz_1, tg_yyzzzzz_xxxzz_1, tg_yyzzzzz_xxxzzz_0, tg_yyzzzzz_xxxzzz_1, \
                                         tg_yyzzzzz_xxyyy_1, tg_yyzzzzz_xxyyyy_0, tg_yyzzzzz_xxyyyy_1, tg_yyzzzzz_xxyyyz_0, \
                                         tg_yyzzzzz_xxyyyz_1, tg_yyzzzzz_xxyyz_1, tg_yyzzzzz_xxyyzz_0, tg_yyzzzzz_xxyyzz_1, \
                                         tg_yyzzzzz_xxyzz_1, tg_yyzzzzz_xxyzzz_0, tg_yyzzzzz_xxyzzz_1, tg_yyzzzzz_xxzzz_1, \
                                         tg_yyzzzzz_xxzzzz_0, tg_yyzzzzz_xxzzzz_1, tg_yyzzzzz_xyyyy_1, tg_yyzzzzz_xyyyyy_0, \
                                         tg_yyzzzzz_xyyyyy_1, tg_yyzzzzz_xyyyyz_0, tg_yyzzzzz_xyyyyz_1, tg_yyzzzzz_xyyyz_1, \
                                         tg_yyzzzzz_xyyyzz_0, tg_yyzzzzz_xyyyzz_1, tg_yyzzzzz_xyyzz_1, tg_yyzzzzz_xyyzzz_0, \
                                         tg_yyzzzzz_xyyzzz_1, tg_yyzzzzz_xyzzz_1, tg_yyzzzzz_xyzzzz_0, tg_yyzzzzz_xyzzzz_1, \
                                         tg_yyzzzzz_xzzzz_1, tg_yyzzzzz_xzzzzz_0, tg_yyzzzzz_xzzzzz_1, tg_yyzzzzz_yyyyy_1, \
                                         tg_yyzzzzz_yyyyyy_0, tg_yyzzzzz_yyyyyy_1, tg_yyzzzzz_yyyyyz_0, tg_yyzzzzz_yyyyyz_1, \
                                         tg_yyzzzzz_yyyyz_1, tg_yyzzzzz_yyyyzz_0, tg_yyzzzzz_yyyyzz_1, tg_yyzzzzz_yyyzz_1, \
                                         tg_yyzzzzz_yyyzzz_0, tg_yyzzzzz_yyyzzz_1, tg_yyzzzzz_yyzzz_1, tg_yyzzzzz_yyzzzz_0, \
                                         tg_yyzzzzz_yyzzzz_1, tg_yyzzzzz_yzzzz_1, tg_yyzzzzz_yzzzzz_0, tg_yyzzzzz_yzzzzz_1, \
                                         tg_yyzzzzz_zzzzz_1, tg_yyzzzzz_zzzzzz_0, tg_yyzzzzz_zzzzzz_1, tg_yzzzzzz_xxxxx_1, \
                                         tg_yzzzzzz_xxxxxx_0, tg_yzzzzzz_xxxxxx_1, tg_yzzzzzz_xxxxxy_0, tg_yzzzzzz_xxxxxy_1, \
                                         tg_yzzzzzz_xxxxxz_0, tg_yzzzzzz_xxxxxz_1, tg_yzzzzzz_xxxxy_1, tg_yzzzzzz_xxxxyy_0, \
                                         tg_yzzzzzz_xxxxyy_1, tg_yzzzzzz_xxxxyz_0, tg_yzzzzzz_xxxxyz_1, tg_yzzzzzz_xxxxz_1, \
                                         tg_yzzzzzz_xxxxzz_0, tg_yzzzzzz_xxxxzz_1, tg_yzzzzzz_xxxyy_1, tg_yzzzzzz_xxxyyy_0, \
                                         tg_yzzzzzz_xxxyyy_1, tg_yzzzzzz_xxxyyz_0, tg_yzzzzzz_xxxyyz_1, tg_yzzzzzz_xxxyz_1, \
                                         tg_yzzzzzz_xxxyzz_0, tg_yzzzzzz_xxxyzz_1, tg_yzzzzzz_xxxzz_1, tg_yzzzzzz_xxxzzz_0, \
                                         tg_yzzzzzz_xxxzzz_1, tg_yzzzzzz_xxyyy_1, tg_yzzzzzz_xxyyyy_0, tg_yzzzzzz_xxyyyy_1, \
                                         tg_yzzzzzz_xxyyyz_0, tg_yzzzzzz_xxyyyz_1, tg_yzzzzzz_xxyyz_1, tg_yzzzzzz_xxyyzz_0, \
                                         tg_yzzzzzz_xxyyzz_1, tg_yzzzzzz_xxyzz_1, tg_yzzzzzz_xxyzzz_0, tg_yzzzzzz_xxyzzz_1, \
                                         tg_yzzzzzz_xxzzz_1, tg_yzzzzzz_xxzzzz_0, tg_yzzzzzz_xxzzzz_1, tg_yzzzzzz_xyyyy_1, \
                                         tg_yzzzzzz_xyyyyy_0, tg_yzzzzzz_xyyyyy_1, tg_yzzzzzz_xyyyyz_0, tg_yzzzzzz_xyyyyz_1, \
                                         tg_yzzzzzz_xyyyz_1, tg_yzzzzzz_xyyyzz_0, tg_yzzzzzz_xyyyzz_1, tg_yzzzzzz_xyyzz_1, \
                                         tg_yzzzzzz_xyzzz_1, tg_yzzzzzz_xzzzz_1, tg_yzzzzzz_yyyyy_1, tg_yzzzzzz_yyyyz_1, \
                                         tg_yzzzzzz_yyyzz_1, wp_x: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fxn = fxn[j];

                    double fr = wp_x[j]; 

                    tg_xyyyyzzz_xxxxzz_0[j] = pb_x * tg_yyyyzzz_xxxxzz_0[j] + fr * tg_yyyyzzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyyyzzz_xxxzz_1[j];

                    tg_xyyyyzzz_xxxyyy_0[j] = pb_x * tg_yyyyzzz_xxxyyy_0[j] + fr * tg_yyyyzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyyyzzz_xxyyy_1[j];

                    tg_xyyyyzzz_xxxyyz_0[j] = pb_x * tg_yyyyzzz_xxxyyz_0[j] + fr * tg_yyyyzzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyyyzzz_xxyyz_1[j];

                    tg_xyyyyzzz_xxxyzz_0[j] = pb_x * tg_yyyyzzz_xxxyzz_0[j] + fr * tg_yyyyzzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyyyzzz_xxyzz_1[j];

                    tg_xyyyyzzz_xxxzzz_0[j] = pb_x * tg_yyyyzzz_xxxzzz_0[j] + fr * tg_yyyyzzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyyyzzz_xxzzz_1[j];

                    tg_xyyyyzzz_xxyyyy_0[j] = pb_x * tg_yyyyzzz_xxyyyy_0[j] + fr * tg_yyyyzzz_xxyyyy_1[j] + fl1_fxn * tg_yyyyzzz_xyyyy_1[j];

                    tg_xyyyyzzz_xxyyyz_0[j] = pb_x * tg_yyyyzzz_xxyyyz_0[j] + fr * tg_yyyyzzz_xxyyyz_1[j] + fl1_fxn * tg_yyyyzzz_xyyyz_1[j];

                    tg_xyyyyzzz_xxyyzz_0[j] = pb_x * tg_yyyyzzz_xxyyzz_0[j] + fr * tg_yyyyzzz_xxyyzz_1[j] + fl1_fxn * tg_yyyyzzz_xyyzz_1[j];

                    tg_xyyyyzzz_xxyzzz_0[j] = pb_x * tg_yyyyzzz_xxyzzz_0[j] + fr * tg_yyyyzzz_xxyzzz_1[j] + fl1_fxn * tg_yyyyzzz_xyzzz_1[j];

                    tg_xyyyyzzz_xxzzzz_0[j] = pb_x * tg_yyyyzzz_xxzzzz_0[j] + fr * tg_yyyyzzz_xxzzzz_1[j] + fl1_fxn * tg_yyyyzzz_xzzzz_1[j];

                    tg_xyyyyzzz_xyyyyy_0[j] = pb_x * tg_yyyyzzz_xyyyyy_0[j] + fr * tg_yyyyzzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_yyyyy_1[j];

                    tg_xyyyyzzz_xyyyyz_0[j] = pb_x * tg_yyyyzzz_xyyyyz_0[j] + fr * tg_yyyyzzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_yyyyz_1[j];

                    tg_xyyyyzzz_xyyyzz_0[j] = pb_x * tg_yyyyzzz_xyyyzz_0[j] + fr * tg_yyyyzzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_yyyzz_1[j];

                    tg_xyyyyzzz_xyyzzz_0[j] = pb_x * tg_yyyyzzz_xyyzzz_0[j] + fr * tg_yyyyzzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_yyzzz_1[j];

                    tg_xyyyyzzz_xyzzzz_0[j] = pb_x * tg_yyyyzzz_xyzzzz_0[j] + fr * tg_yyyyzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_yzzzz_1[j];

                    tg_xyyyyzzz_xzzzzz_0[j] = pb_x * tg_yyyyzzz_xzzzzz_0[j] + fr * tg_yyyyzzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyyzzz_zzzzz_1[j];

                    tg_xyyyyzzz_yyyyyy_0[j] = pb_x * tg_yyyyzzz_yyyyyy_0[j] + fr * tg_yyyyzzz_yyyyyy_1[j];

                    tg_xyyyyzzz_yyyyyz_0[j] = pb_x * tg_yyyyzzz_yyyyyz_0[j] + fr * tg_yyyyzzz_yyyyyz_1[j];

                    tg_xyyyyzzz_yyyyzz_0[j] = pb_x * tg_yyyyzzz_yyyyzz_0[j] + fr * tg_yyyyzzz_yyyyzz_1[j];

                    tg_xyyyyzzz_yyyzzz_0[j] = pb_x * tg_yyyyzzz_yyyzzz_0[j] + fr * tg_yyyyzzz_yyyzzz_1[j];

                    tg_xyyyyzzz_yyzzzz_0[j] = pb_x * tg_yyyyzzz_yyzzzz_0[j] + fr * tg_yyyyzzz_yyzzzz_1[j];

                    tg_xyyyyzzz_yzzzzz_0[j] = pb_x * tg_yyyyzzz_yzzzzz_0[j] + fr * tg_yyyyzzz_yzzzzz_1[j];

                    tg_xyyyyzzz_zzzzzz_0[j] = pb_x * tg_yyyyzzz_zzzzzz_0[j] + fr * tg_yyyyzzz_zzzzzz_1[j];

                    tg_xyyyzzzz_xxxxxx_0[j] = pb_x * tg_yyyzzzz_xxxxxx_0[j] + fr * tg_yyyzzzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyyzzzz_xxxxx_1[j];

                    tg_xyyyzzzz_xxxxxy_0[j] = pb_x * tg_yyyzzzz_xxxxxy_0[j] + fr * tg_yyyzzzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyyzzzz_xxxxy_1[j];

                    tg_xyyyzzzz_xxxxxz_0[j] = pb_x * tg_yyyzzzz_xxxxxz_0[j] + fr * tg_yyyzzzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyyzzzz_xxxxz_1[j];

                    tg_xyyyzzzz_xxxxyy_0[j] = pb_x * tg_yyyzzzz_xxxxyy_0[j] + fr * tg_yyyzzzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyyzzzz_xxxyy_1[j];

                    tg_xyyyzzzz_xxxxyz_0[j] = pb_x * tg_yyyzzzz_xxxxyz_0[j] + fr * tg_yyyzzzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyyzzzz_xxxyz_1[j];

                    tg_xyyyzzzz_xxxxzz_0[j] = pb_x * tg_yyyzzzz_xxxxzz_0[j] + fr * tg_yyyzzzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyyzzzz_xxxzz_1[j];

                    tg_xyyyzzzz_xxxyyy_0[j] = pb_x * tg_yyyzzzz_xxxyyy_0[j] + fr * tg_yyyzzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyyzzzz_xxyyy_1[j];

                    tg_xyyyzzzz_xxxyyz_0[j] = pb_x * tg_yyyzzzz_xxxyyz_0[j] + fr * tg_yyyzzzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyyzzzz_xxyyz_1[j];

                    tg_xyyyzzzz_xxxyzz_0[j] = pb_x * tg_yyyzzzz_xxxyzz_0[j] + fr * tg_yyyzzzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyyzzzz_xxyzz_1[j];

                    tg_xyyyzzzz_xxxzzz_0[j] = pb_x * tg_yyyzzzz_xxxzzz_0[j] + fr * tg_yyyzzzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyyzzzz_xxzzz_1[j];

                    tg_xyyyzzzz_xxyyyy_0[j] = pb_x * tg_yyyzzzz_xxyyyy_0[j] + fr * tg_yyyzzzz_xxyyyy_1[j] + fl1_fxn * tg_yyyzzzz_xyyyy_1[j];

                    tg_xyyyzzzz_xxyyyz_0[j] = pb_x * tg_yyyzzzz_xxyyyz_0[j] + fr * tg_yyyzzzz_xxyyyz_1[j] + fl1_fxn * tg_yyyzzzz_xyyyz_1[j];

                    tg_xyyyzzzz_xxyyzz_0[j] = pb_x * tg_yyyzzzz_xxyyzz_0[j] + fr * tg_yyyzzzz_xxyyzz_1[j] + fl1_fxn * tg_yyyzzzz_xyyzz_1[j];

                    tg_xyyyzzzz_xxyzzz_0[j] = pb_x * tg_yyyzzzz_xxyzzz_0[j] + fr * tg_yyyzzzz_xxyzzz_1[j] + fl1_fxn * tg_yyyzzzz_xyzzz_1[j];

                    tg_xyyyzzzz_xxzzzz_0[j] = pb_x * tg_yyyzzzz_xxzzzz_0[j] + fr * tg_yyyzzzz_xxzzzz_1[j] + fl1_fxn * tg_yyyzzzz_xzzzz_1[j];

                    tg_xyyyzzzz_xyyyyy_0[j] = pb_x * tg_yyyzzzz_xyyyyy_0[j] + fr * tg_yyyzzzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_yyyyy_1[j];

                    tg_xyyyzzzz_xyyyyz_0[j] = pb_x * tg_yyyzzzz_xyyyyz_0[j] + fr * tg_yyyzzzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_yyyyz_1[j];

                    tg_xyyyzzzz_xyyyzz_0[j] = pb_x * tg_yyyzzzz_xyyyzz_0[j] + fr * tg_yyyzzzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_yyyzz_1[j];

                    tg_xyyyzzzz_xyyzzz_0[j] = pb_x * tg_yyyzzzz_xyyzzz_0[j] + fr * tg_yyyzzzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_yyzzz_1[j];

                    tg_xyyyzzzz_xyzzzz_0[j] = pb_x * tg_yyyzzzz_xyzzzz_0[j] + fr * tg_yyyzzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_yzzzz_1[j];

                    tg_xyyyzzzz_xzzzzz_0[j] = pb_x * tg_yyyzzzz_xzzzzz_0[j] + fr * tg_yyyzzzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyyzzzz_zzzzz_1[j];

                    tg_xyyyzzzz_yyyyyy_0[j] = pb_x * tg_yyyzzzz_yyyyyy_0[j] + fr * tg_yyyzzzz_yyyyyy_1[j];

                    tg_xyyyzzzz_yyyyyz_0[j] = pb_x * tg_yyyzzzz_yyyyyz_0[j] + fr * tg_yyyzzzz_yyyyyz_1[j];

                    tg_xyyyzzzz_yyyyzz_0[j] = pb_x * tg_yyyzzzz_yyyyzz_0[j] + fr * tg_yyyzzzz_yyyyzz_1[j];

                    tg_xyyyzzzz_yyyzzz_0[j] = pb_x * tg_yyyzzzz_yyyzzz_0[j] + fr * tg_yyyzzzz_yyyzzz_1[j];

                    tg_xyyyzzzz_yyzzzz_0[j] = pb_x * tg_yyyzzzz_yyzzzz_0[j] + fr * tg_yyyzzzz_yyzzzz_1[j];

                    tg_xyyyzzzz_yzzzzz_0[j] = pb_x * tg_yyyzzzz_yzzzzz_0[j] + fr * tg_yyyzzzz_yzzzzz_1[j];

                    tg_xyyyzzzz_zzzzzz_0[j] = pb_x * tg_yyyzzzz_zzzzzz_0[j] + fr * tg_yyyzzzz_zzzzzz_1[j];

                    tg_xyyzzzzz_xxxxxx_0[j] = pb_x * tg_yyzzzzz_xxxxxx_0[j] + fr * tg_yyzzzzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yyzzzzz_xxxxx_1[j];

                    tg_xyyzzzzz_xxxxxy_0[j] = pb_x * tg_yyzzzzz_xxxxxy_0[j] + fr * tg_yyzzzzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yyzzzzz_xxxxy_1[j];

                    tg_xyyzzzzz_xxxxxz_0[j] = pb_x * tg_yyzzzzz_xxxxxz_0[j] + fr * tg_yyzzzzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yyzzzzz_xxxxz_1[j];

                    tg_xyyzzzzz_xxxxyy_0[j] = pb_x * tg_yyzzzzz_xxxxyy_0[j] + fr * tg_yyzzzzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yyzzzzz_xxxyy_1[j];

                    tg_xyyzzzzz_xxxxyz_0[j] = pb_x * tg_yyzzzzz_xxxxyz_0[j] + fr * tg_yyzzzzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yyzzzzz_xxxyz_1[j];

                    tg_xyyzzzzz_xxxxzz_0[j] = pb_x * tg_yyzzzzz_xxxxzz_0[j] + fr * tg_yyzzzzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yyzzzzz_xxxzz_1[j];

                    tg_xyyzzzzz_xxxyyy_0[j] = pb_x * tg_yyzzzzz_xxxyyy_0[j] + fr * tg_yyzzzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yyzzzzz_xxyyy_1[j];

                    tg_xyyzzzzz_xxxyyz_0[j] = pb_x * tg_yyzzzzz_xxxyyz_0[j] + fr * tg_yyzzzzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yyzzzzz_xxyyz_1[j];

                    tg_xyyzzzzz_xxxyzz_0[j] = pb_x * tg_yyzzzzz_xxxyzz_0[j] + fr * tg_yyzzzzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yyzzzzz_xxyzz_1[j];

                    tg_xyyzzzzz_xxxzzz_0[j] = pb_x * tg_yyzzzzz_xxxzzz_0[j] + fr * tg_yyzzzzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yyzzzzz_xxzzz_1[j];

                    tg_xyyzzzzz_xxyyyy_0[j] = pb_x * tg_yyzzzzz_xxyyyy_0[j] + fr * tg_yyzzzzz_xxyyyy_1[j] + fl1_fxn * tg_yyzzzzz_xyyyy_1[j];

                    tg_xyyzzzzz_xxyyyz_0[j] = pb_x * tg_yyzzzzz_xxyyyz_0[j] + fr * tg_yyzzzzz_xxyyyz_1[j] + fl1_fxn * tg_yyzzzzz_xyyyz_1[j];

                    tg_xyyzzzzz_xxyyzz_0[j] = pb_x * tg_yyzzzzz_xxyyzz_0[j] + fr * tg_yyzzzzz_xxyyzz_1[j] + fl1_fxn * tg_yyzzzzz_xyyzz_1[j];

                    tg_xyyzzzzz_xxyzzz_0[j] = pb_x * tg_yyzzzzz_xxyzzz_0[j] + fr * tg_yyzzzzz_xxyzzz_1[j] + fl1_fxn * tg_yyzzzzz_xyzzz_1[j];

                    tg_xyyzzzzz_xxzzzz_0[j] = pb_x * tg_yyzzzzz_xxzzzz_0[j] + fr * tg_yyzzzzz_xxzzzz_1[j] + fl1_fxn * tg_yyzzzzz_xzzzz_1[j];

                    tg_xyyzzzzz_xyyyyy_0[j] = pb_x * tg_yyzzzzz_xyyyyy_0[j] + fr * tg_yyzzzzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_yyyyy_1[j];

                    tg_xyyzzzzz_xyyyyz_0[j] = pb_x * tg_yyzzzzz_xyyyyz_0[j] + fr * tg_yyzzzzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_yyyyz_1[j];

                    tg_xyyzzzzz_xyyyzz_0[j] = pb_x * tg_yyzzzzz_xyyyzz_0[j] + fr * tg_yyzzzzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_yyyzz_1[j];

                    tg_xyyzzzzz_xyyzzz_0[j] = pb_x * tg_yyzzzzz_xyyzzz_0[j] + fr * tg_yyzzzzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_yyzzz_1[j];

                    tg_xyyzzzzz_xyzzzz_0[j] = pb_x * tg_yyzzzzz_xyzzzz_0[j] + fr * tg_yyzzzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_yzzzz_1[j];

                    tg_xyyzzzzz_xzzzzz_0[j] = pb_x * tg_yyzzzzz_xzzzzz_0[j] + fr * tg_yyzzzzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yyzzzzz_zzzzz_1[j];

                    tg_xyyzzzzz_yyyyyy_0[j] = pb_x * tg_yyzzzzz_yyyyyy_0[j] + fr * tg_yyzzzzz_yyyyyy_1[j];

                    tg_xyyzzzzz_yyyyyz_0[j] = pb_x * tg_yyzzzzz_yyyyyz_0[j] + fr * tg_yyzzzzz_yyyyyz_1[j];

                    tg_xyyzzzzz_yyyyzz_0[j] = pb_x * tg_yyzzzzz_yyyyzz_0[j] + fr * tg_yyzzzzz_yyyyzz_1[j];

                    tg_xyyzzzzz_yyyzzz_0[j] = pb_x * tg_yyzzzzz_yyyzzz_0[j] + fr * tg_yyzzzzz_yyyzzz_1[j];

                    tg_xyyzzzzz_yyzzzz_0[j] = pb_x * tg_yyzzzzz_yyzzzz_0[j] + fr * tg_yyzzzzz_yyzzzz_1[j];

                    tg_xyyzzzzz_yzzzzz_0[j] = pb_x * tg_yyzzzzz_yzzzzz_0[j] + fr * tg_yyzzzzz_yzzzzz_1[j];

                    tg_xyyzzzzz_zzzzzz_0[j] = pb_x * tg_yyzzzzz_zzzzzz_0[j] + fr * tg_yyzzzzz_zzzzzz_1[j];

                    tg_xyzzzzzz_xxxxxx_0[j] = pb_x * tg_yzzzzzz_xxxxxx_0[j] + fr * tg_yzzzzzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_yzzzzzz_xxxxx_1[j];

                    tg_xyzzzzzz_xxxxxy_0[j] = pb_x * tg_yzzzzzz_xxxxxy_0[j] + fr * tg_yzzzzzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_yzzzzzz_xxxxy_1[j];

                    tg_xyzzzzzz_xxxxxz_0[j] = pb_x * tg_yzzzzzz_xxxxxz_0[j] + fr * tg_yzzzzzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_yzzzzzz_xxxxz_1[j];

                    tg_xyzzzzzz_xxxxyy_0[j] = pb_x * tg_yzzzzzz_xxxxyy_0[j] + fr * tg_yzzzzzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_yzzzzzz_xxxyy_1[j];

                    tg_xyzzzzzz_xxxxyz_0[j] = pb_x * tg_yzzzzzz_xxxxyz_0[j] + fr * tg_yzzzzzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_yzzzzzz_xxxyz_1[j];

                    tg_xyzzzzzz_xxxxzz_0[j] = pb_x * tg_yzzzzzz_xxxxzz_0[j] + fr * tg_yzzzzzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_yzzzzzz_xxxzz_1[j];

                    tg_xyzzzzzz_xxxyyy_0[j] = pb_x * tg_yzzzzzz_xxxyyy_0[j] + fr * tg_yzzzzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_yzzzzzz_xxyyy_1[j];

                    tg_xyzzzzzz_xxxyyz_0[j] = pb_x * tg_yzzzzzz_xxxyyz_0[j] + fr * tg_yzzzzzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_yzzzzzz_xxyyz_1[j];

                    tg_xyzzzzzz_xxxyzz_0[j] = pb_x * tg_yzzzzzz_xxxyzz_0[j] + fr * tg_yzzzzzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_yzzzzzz_xxyzz_1[j];

                    tg_xyzzzzzz_xxxzzz_0[j] = pb_x * tg_yzzzzzz_xxxzzz_0[j] + fr * tg_yzzzzzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_yzzzzzz_xxzzz_1[j];

                    tg_xyzzzzzz_xxyyyy_0[j] = pb_x * tg_yzzzzzz_xxyyyy_0[j] + fr * tg_yzzzzzz_xxyyyy_1[j] + fl1_fxn * tg_yzzzzzz_xyyyy_1[j];

                    tg_xyzzzzzz_xxyyyz_0[j] = pb_x * tg_yzzzzzz_xxyyyz_0[j] + fr * tg_yzzzzzz_xxyyyz_1[j] + fl1_fxn * tg_yzzzzzz_xyyyz_1[j];

                    tg_xyzzzzzz_xxyyzz_0[j] = pb_x * tg_yzzzzzz_xxyyzz_0[j] + fr * tg_yzzzzzz_xxyyzz_1[j] + fl1_fxn * tg_yzzzzzz_xyyzz_1[j];

                    tg_xyzzzzzz_xxyzzz_0[j] = pb_x * tg_yzzzzzz_xxyzzz_0[j] + fr * tg_yzzzzzz_xxyzzz_1[j] + fl1_fxn * tg_yzzzzzz_xyzzz_1[j];

                    tg_xyzzzzzz_xxzzzz_0[j] = pb_x * tg_yzzzzzz_xxzzzz_0[j] + fr * tg_yzzzzzz_xxzzzz_1[j] + fl1_fxn * tg_yzzzzzz_xzzzz_1[j];

                    tg_xyzzzzzz_xyyyyy_0[j] = pb_x * tg_yzzzzzz_xyyyyy_0[j] + fr * tg_yzzzzzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_yyyyy_1[j];

                    tg_xyzzzzzz_xyyyyz_0[j] = pb_x * tg_yzzzzzz_xyyyyz_0[j] + fr * tg_yzzzzzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_yyyyz_1[j];

                    tg_xyzzzzzz_xyyyzz_0[j] = pb_x * tg_yzzzzzz_xyyyzz_0[j] + fr * tg_yzzzzzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_yyyzz_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_970_1067(      CMemBlock2D<double>* primBuffer,
                                          const CRecursionMap&       recursionMap,
                                          const CMemBlock2D<double>& osFactors,
                                          const CMemBlock2D<double>& wpDistances,
                                          const CGtoPairsBlock&      braGtoPairsBlock,
                                          const CGtoPairsBlock&      ketGtoPairsBlock,
                                          const int32_t              nKetPrimPairs,
                                          const int32_t              iContrPair)
    {
        // Batch of Integrals (970,1067)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_x = braGtoPairsBlock.getDistancesPBX();

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_x = r_pb_x[i];

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_x = wpDistances.data(3 * idx);

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyyyy_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 784); 

                auto tg_yyyyyyy_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 785); 

                auto tg_yyyyyyy_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 786); 

                auto tg_yyyyyyy_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 787); 

                auto tg_yyyyyyy_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 788); 

                auto tg_yyyyyyy_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 789); 

                auto tg_yyyyyyy_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 790); 

                auto tg_yyyyyyy_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 791); 

                auto tg_yyyyyyy_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 792); 

                auto tg_yyyyyyy_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 793); 

                auto tg_yyyyyyy_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 794); 

                auto tg_yyyyyyy_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 795); 

                auto tg_yyyyyyy_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 796); 

                auto tg_yyyyyyy_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 797); 

                auto tg_yyyyyyy_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 798); 

                auto tg_yyyyyyy_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 799); 

                auto tg_yyyyyyy_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 800); 

                auto tg_yyyyyyy_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 801); 

                auto tg_yyyyyyy_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 802); 

                auto tg_yyyyyyy_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 803); 

                auto tg_yyyyyyy_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 804); 

                auto tg_yyyyyyy_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 805); 

                auto tg_yyyyyyy_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 806); 

                auto tg_yyyyyyy_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 807); 

                auto tg_yyyyyyy_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 808); 

                auto tg_yyyyyyy_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 809); 

                auto tg_yyyyyyy_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 810); 

                auto tg_yyyyyyy_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 811); 

                auto tg_yyyyyyz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 812); 

                auto tg_yyyyyyz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 813); 

                auto tg_yyyyyyz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 814); 

                auto tg_yyyyyyz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 815); 

                auto tg_yyyyyyz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 816); 

                auto tg_yyyyyyz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 817); 

                auto tg_yyyyyyz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 818); 

                auto tg_yyyyyyz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 819); 

                auto tg_yyyyyyz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 820); 

                auto tg_yyyyyyz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 821); 

                auto tg_yyyyyyz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 822); 

                auto tg_yyyyyyz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 823); 

                auto tg_yyyyyyz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 824); 

                auto tg_yyyyyyz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 825); 

                auto tg_yyyyyyz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 826); 

                auto tg_yyyyyyz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 827); 

                auto tg_yyyyyyz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 828); 

                auto tg_yyyyyyz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 829); 

                auto tg_yyyyyyz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 830); 

                auto tg_yyyyyyz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 831); 

                auto tg_yyyyyyz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 832); 

                auto tg_yyyyyyz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 833); 

                auto tg_yyyyyyz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 834); 

                auto tg_yyyyyyz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 835); 

                auto tg_yyyyyyz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 836); 

                auto tg_yyyyyyz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 837); 

                auto tg_yyyyyyz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 838); 

                auto tg_yyyyyyz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 839); 

                auto tg_yyyyyzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 840); 

                auto tg_yyyyyzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 841); 

                auto tg_yyyyyzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 842); 

                auto tg_yzzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 970); 

                auto tg_yzzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 971); 

                auto tg_yzzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 972); 

                auto tg_yzzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 973); 

                auto tg_yzzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 974); 

                auto tg_yzzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 975); 

                auto tg_yzzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 976); 

                auto tg_yzzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 977); 

                auto tg_yzzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 978); 

                auto tg_yzzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 979); 

                auto tg_zzzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 980); 

                auto tg_zzzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 981); 

                auto tg_zzzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 982); 

                auto tg_zzzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 983); 

                auto tg_zzzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 984); 

                auto tg_zzzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 985); 

                auto tg_zzzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 986); 

                auto tg_zzzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 987); 

                auto tg_zzzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 988); 

                auto tg_zzzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 989); 

                auto tg_zzzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 990); 

                auto tg_zzzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 991); 

                auto tg_zzzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 992); 

                auto tg_zzzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 993); 

                auto tg_zzzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 994); 

                auto tg_zzzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 995); 

                auto tg_zzzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 996); 

                auto tg_zzzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 997); 

                auto tg_zzzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 998); 

                auto tg_zzzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 999); 

                auto tg_zzzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1000); 

                auto tg_zzzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1001); 

                auto tg_zzzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1002); 

                auto tg_zzzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1003); 

                auto tg_zzzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1004); 

                auto tg_zzzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1005); 

                auto tg_zzzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1006); 

                auto tg_zzzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1007); 

                auto tg_yyyyyyy_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 784); 

                auto tg_yyyyyyy_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 785); 

                auto tg_yyyyyyy_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 786); 

                auto tg_yyyyyyy_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 787); 

                auto tg_yyyyyyy_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 788); 

                auto tg_yyyyyyy_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 789); 

                auto tg_yyyyyyy_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 790); 

                auto tg_yyyyyyy_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 791); 

                auto tg_yyyyyyy_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 792); 

                auto tg_yyyyyyy_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 793); 

                auto tg_yyyyyyy_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 794); 

                auto tg_yyyyyyy_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 795); 

                auto tg_yyyyyyy_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 796); 

                auto tg_yyyyyyy_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 797); 

                auto tg_yyyyyyy_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 798); 

                auto tg_yyyyyyy_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 799); 

                auto tg_yyyyyyy_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 800); 

                auto tg_yyyyyyy_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 801); 

                auto tg_yyyyyyy_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 802); 

                auto tg_yyyyyyy_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 803); 

                auto tg_yyyyyyy_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 804); 

                auto tg_yyyyyyy_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 805); 

                auto tg_yyyyyyy_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 806); 

                auto tg_yyyyyyy_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 807); 

                auto tg_yyyyyyy_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 808); 

                auto tg_yyyyyyy_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 809); 

                auto tg_yyyyyyy_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 810); 

                auto tg_yyyyyyy_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 811); 

                auto tg_yyyyyyz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 812); 

                auto tg_yyyyyyz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 813); 

                auto tg_yyyyyyz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 814); 

                auto tg_yyyyyyz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 815); 

                auto tg_yyyyyyz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 816); 

                auto tg_yyyyyyz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 817); 

                auto tg_yyyyyyz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 818); 

                auto tg_yyyyyyz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 819); 

                auto tg_yyyyyyz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 820); 

                auto tg_yyyyyyz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 821); 

                auto tg_yyyyyyz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 822); 

                auto tg_yyyyyyz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 823); 

                auto tg_yyyyyyz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 824); 

                auto tg_yyyyyyz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 825); 

                auto tg_yyyyyyz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 826); 

                auto tg_yyyyyyz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 827); 

                auto tg_yyyyyyz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 828); 

                auto tg_yyyyyyz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 829); 

                auto tg_yyyyyyz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 830); 

                auto tg_yyyyyyz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 831); 

                auto tg_yyyyyyz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 832); 

                auto tg_yyyyyyz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 833); 

                auto tg_yyyyyyz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 834); 

                auto tg_yyyyyyz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 835); 

                auto tg_yyyyyyz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 836); 

                auto tg_yyyyyyz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 837); 

                auto tg_yyyyyyz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 838); 

                auto tg_yyyyyyz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 839); 

                auto tg_yyyyyzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 840); 

                auto tg_yyyyyzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 841); 

                auto tg_yyyyyzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 842); 

                auto tg_yzzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 970); 

                auto tg_yzzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 971); 

                auto tg_yzzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 972); 

                auto tg_yzzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 973); 

                auto tg_yzzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 974); 

                auto tg_yzzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 975); 

                auto tg_yzzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 976); 

                auto tg_yzzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 977); 

                auto tg_yzzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 978); 

                auto tg_yzzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 979); 

                auto tg_zzzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 980); 

                auto tg_zzzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 981); 

                auto tg_zzzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 982); 

                auto tg_zzzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 983); 

                auto tg_zzzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 984); 

                auto tg_zzzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 985); 

                auto tg_zzzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 986); 

                auto tg_zzzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 987); 

                auto tg_zzzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 988); 

                auto tg_zzzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 989); 

                auto tg_zzzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 990); 

                auto tg_zzzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 991); 

                auto tg_zzzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 992); 

                auto tg_zzzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 993); 

                auto tg_zzzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 994); 

                auto tg_zzzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 995); 

                auto tg_zzzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 996); 

                auto tg_zzzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 997); 

                auto tg_zzzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 998); 

                auto tg_zzzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 999); 

                auto tg_zzzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1000); 

                auto tg_zzzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1001); 

                auto tg_zzzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1002); 

                auto tg_zzzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1003); 

                auto tg_zzzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1004); 

                auto tg_zzzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1005); 

                auto tg_zzzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1006); 

                auto tg_zzzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1007); 

                auto tg_yyyyyy_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 623); 

                auto tg_yyyyyz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 646); 

                auto tg_yyyyyy_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 588); 

                auto tg_yyyyyy_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 589); 

                auto tg_yyyyyy_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 590); 

                auto tg_yyyyyy_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 591); 

                auto tg_yyyyyy_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 592); 

                auto tg_yyyyyy_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 593); 

                auto tg_yyyyyy_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 594); 

                auto tg_yyyyyy_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 595); 

                auto tg_yyyyyy_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 596); 

                auto tg_yyyyyy_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 597); 

                auto tg_yyyyyy_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 598); 

                auto tg_yyyyyy_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 599); 

                auto tg_yyyyyy_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 600); 

                auto tg_yyyyyy_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 601); 

                auto tg_yyyyyy_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 602); 

                auto tg_yyyyyy_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 603); 

                auto tg_yyyyyy_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 604); 

                auto tg_yyyyyy_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 605); 

                auto tg_yyyyyy_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 606); 

                auto tg_yyyyyy_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 607); 

                auto tg_yyyyyy_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 608); 

                auto tg_yyyyyy_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 609); 

                auto tg_yyyyyy_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 610); 

                auto tg_yyyyyy_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 611); 

                auto tg_yyyyyy_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 612); 

                auto tg_yyyyyy_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 613); 

                auto tg_yyyyyy_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 614); 

                auto tg_yyyyyy_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 615); 

                auto tg_yyyyyz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 616); 

                auto tg_yyyyyz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 617); 

                auto tg_yyyyyz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 618); 

                auto tg_yyyyyz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 619); 

                auto tg_yyyyyz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 620); 

                auto tg_yyyyyz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 621); 

                auto tg_yyyyyz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 622); 

                auto tg_yyyyyz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 623); 

                auto tg_yyyyyz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 624); 

                auto tg_yyyyyz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 625); 

                auto tg_yyyyyz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 626); 

                auto tg_yyyyyz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 627); 

                auto tg_yyyyyz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 628); 

                auto tg_yyyyyz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 629); 

                auto tg_yyyyyz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 630); 

                auto tg_yyyyyz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 631); 

                auto tg_yyyyyz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 632); 

                auto tg_yyyyyz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 633); 

                auto tg_yyyyyz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 634); 

                auto tg_yyyyyz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 635); 

                auto tg_yyyyyz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 636); 

                auto tg_yyyyyz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 637); 

                auto tg_yyyyyz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 638); 

                auto tg_yyyyyz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 639); 

                auto tg_yyyyyz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 640); 

                auto tg_yyyyyz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 641); 

                auto tg_yyyyyz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 642); 

                auto tg_yyyyyz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 643); 

                auto tg_yyyyzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 644); 

                auto tg_yyyyzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 645); 

                auto tg_yyyyzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 646); 

                auto tg_yyyyyyy_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 588); 

                auto tg_yyyyyyy_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 589); 

                auto tg_yyyyyyy_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 590); 

                auto tg_yyyyyyy_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 591); 

                auto tg_yyyyyyy_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 592); 

                auto tg_yyyyyyy_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 593); 

                auto tg_yyyyyyy_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 594); 

                auto tg_yyyyyyy_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 595); 

                auto tg_yyyyyyy_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 596); 

                auto tg_yyyyyyy_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 597); 

                auto tg_yyyyyyy_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 598); 

                auto tg_yyyyyyy_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 599); 

                auto tg_yyyyyyy_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 600); 

                auto tg_yyyyyyy_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 601); 

                auto tg_yyyyyyy_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 602); 

                auto tg_yyyyyyy_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 603); 

                auto tg_yyyyyyy_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 604); 

                auto tg_yyyyyyy_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 605); 

                auto tg_yyyyyyy_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 606); 

                auto tg_yyyyyyy_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 607); 

                auto tg_yyyyyyy_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 608); 

                auto tg_yyyyyyz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 609); 

                auto tg_yyyyyyz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 610); 

                auto tg_yyyyyyz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 611); 

                auto tg_yyyyyyz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 612); 

                auto tg_yyyyyyz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 613); 

                auto tg_yyyyyyz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 614); 

                auto tg_yyyyyyz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 615); 

                auto tg_yyyyyyz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 616); 

                auto tg_yyyyyyz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 617); 

                auto tg_yyyyyyz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 618); 

                auto tg_yyyyyyz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 619); 

                auto tg_yyyyyyz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 620); 

                auto tg_yyyyyyz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 621); 

                auto tg_yyyyyyz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 622); 

                auto tg_yyyyyyz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 623); 

                auto tg_yyyyyyz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 624); 

                auto tg_yyyyyyz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 625); 

                auto tg_yyyyyyz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 626); 

                auto tg_yyyyyyz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 627); 

                auto tg_yyyyyyz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 628); 

                auto tg_yyyyyyz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 629); 

                auto tg_yyyyyzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 630); 

                auto tg_yzzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 732); 

                auto tg_yzzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 733); 

                auto tg_yzzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 734); 

                auto tg_zzzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 735); 

                auto tg_zzzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 736); 

                auto tg_zzzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 737); 

                auto tg_zzzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 738); 

                auto tg_zzzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 739); 

                auto tg_zzzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 740); 

                auto tg_zzzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 741); 

                auto tg_zzzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 742); 

                auto tg_zzzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 743); 

                auto tg_zzzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 744); 

                auto tg_zzzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 745); 

                auto tg_zzzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 746); 

                auto tg_zzzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 747); 

                auto tg_zzzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 748); 

                auto tg_zzzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 749); 

                auto tg_zzzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 750); 

                auto tg_zzzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 751); 

                auto tg_zzzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 752); 

                auto tg_zzzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 753); 

                auto tg_zzzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 754); 

                auto tg_zzzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 755); 

                // set up pointers to integrals

                auto tg_xyzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 970); 

                auto tg_xyzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 971); 

                auto tg_xyzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 972); 

                auto tg_xyzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 973); 

                auto tg_xyzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 974); 

                auto tg_xyzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 975); 

                auto tg_xyzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 976); 

                auto tg_xyzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 977); 

                auto tg_xyzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 978); 

                auto tg_xyzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 979); 

                auto tg_xzzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 980); 

                auto tg_xzzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 981); 

                auto tg_xzzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 982); 

                auto tg_xzzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 983); 

                auto tg_xzzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 984); 

                auto tg_xzzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 985); 

                auto tg_xzzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 986); 

                auto tg_xzzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 987); 

                auto tg_xzzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 988); 

                auto tg_xzzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 989); 

                auto tg_xzzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 990); 

                auto tg_xzzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 991); 

                auto tg_xzzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 992); 

                auto tg_xzzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 993); 

                auto tg_xzzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 994); 

                auto tg_xzzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 995); 

                auto tg_xzzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 996); 

                auto tg_xzzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 997); 

                auto tg_xzzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 998); 

                auto tg_xzzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 999); 

                auto tg_xzzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1000); 

                auto tg_xzzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1001); 

                auto tg_xzzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1002); 

                auto tg_xzzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1003); 

                auto tg_xzzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1004); 

                auto tg_xzzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1005); 

                auto tg_xzzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1006); 

                auto tg_xzzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1007); 

                auto tg_yyyyyyyy_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1008); 

                auto tg_yyyyyyyy_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1009); 

                auto tg_yyyyyyyy_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1010); 

                auto tg_yyyyyyyy_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1011); 

                auto tg_yyyyyyyy_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1012); 

                auto tg_yyyyyyyy_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1013); 

                auto tg_yyyyyyyy_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1014); 

                auto tg_yyyyyyyy_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1015); 

                auto tg_yyyyyyyy_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1016); 

                auto tg_yyyyyyyy_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1017); 

                auto tg_yyyyyyyy_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1018); 

                auto tg_yyyyyyyy_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1019); 

                auto tg_yyyyyyyy_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1020); 

                auto tg_yyyyyyyy_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1021); 

                auto tg_yyyyyyyy_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1022); 

                auto tg_yyyyyyyy_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1023); 

                auto tg_yyyyyyyy_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1024); 

                auto tg_yyyyyyyy_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1025); 

                auto tg_yyyyyyyy_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1026); 

                auto tg_yyyyyyyy_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1027); 

                auto tg_yyyyyyyy_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1028); 

                auto tg_yyyyyyyy_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1029); 

                auto tg_yyyyyyyy_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1030); 

                auto tg_yyyyyyyy_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1031); 

                auto tg_yyyyyyyy_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1032); 

                auto tg_yyyyyyyy_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1033); 

                auto tg_yyyyyyyy_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1034); 

                auto tg_yyyyyyyy_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1035); 

                auto tg_yyyyyyyz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1036); 

                auto tg_yyyyyyyz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1037); 

                auto tg_yyyyyyyz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1038); 

                auto tg_yyyyyyyz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1039); 

                auto tg_yyyyyyyz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1040); 

                auto tg_yyyyyyyz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1041); 

                auto tg_yyyyyyyz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1042); 

                auto tg_yyyyyyyz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1043); 

                auto tg_yyyyyyyz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1044); 

                auto tg_yyyyyyyz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1045); 

                auto tg_yyyyyyyz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1046); 

                auto tg_yyyyyyyz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1047); 

                auto tg_yyyyyyyz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1048); 

                auto tg_yyyyyyyz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1049); 

                auto tg_yyyyyyyz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1050); 

                auto tg_yyyyyyyz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1051); 

                auto tg_yyyyyyyz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1052); 

                auto tg_yyyyyyyz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1053); 

                auto tg_yyyyyyyz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1054); 

                auto tg_yyyyyyyz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1055); 

                auto tg_yyyyyyyz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1056); 

                auto tg_yyyyyyyz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1057); 

                auto tg_yyyyyyyz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1058); 

                auto tg_yyyyyyyz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1059); 

                auto tg_yyyyyyyz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1060); 

                auto tg_yyyyyyyz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1061); 

                auto tg_yyyyyyyz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1062); 

                auto tg_yyyyyyyz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1063); 

                auto tg_yyyyyyzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1064); 

                auto tg_yyyyyyzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1065); 

                auto tg_yyyyyyzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1066); 

                // Batch of Integrals (970,1067)

                #pragma omp simd aligned(fxn, fza, tg_xyzzzzzz_xyyzzz_0, tg_xyzzzzzz_xyzzzz_0, \
                                         tg_xyzzzzzz_xzzzzz_0, tg_xyzzzzzz_yyyyyy_0, tg_xyzzzzzz_yyyyyz_0, tg_xyzzzzzz_yyyyzz_0, \
                                         tg_xyzzzzzz_yyyzzz_0, tg_xyzzzzzz_yyzzzz_0, tg_xyzzzzzz_yzzzzz_0, tg_xyzzzzzz_zzzzzz_0, \
                                         tg_xzzzzzzz_xxxxxx_0, tg_xzzzzzzz_xxxxxy_0, tg_xzzzzzzz_xxxxxz_0, tg_xzzzzzzz_xxxxyy_0, \
                                         tg_xzzzzzzz_xxxxyz_0, tg_xzzzzzzz_xxxxzz_0, tg_xzzzzzzz_xxxyyy_0, tg_xzzzzzzz_xxxyyz_0, \
                                         tg_xzzzzzzz_xxxyzz_0, tg_xzzzzzzz_xxxzzz_0, tg_xzzzzzzz_xxyyyy_0, tg_xzzzzzzz_xxyyyz_0, \
                                         tg_xzzzzzzz_xxyyzz_0, tg_xzzzzzzz_xxyzzz_0, tg_xzzzzzzz_xxzzzz_0, tg_xzzzzzzz_xyyyyy_0, \
                                         tg_xzzzzzzz_xyyyyz_0, tg_xzzzzzzz_xyyyzz_0, tg_xzzzzzzz_xyyzzz_0, tg_xzzzzzzz_xyzzzz_0, \
                                         tg_xzzzzzzz_xzzzzz_0, tg_xzzzzzzz_yyyyyy_0, tg_xzzzzzzz_yyyyyz_0, tg_xzzzzzzz_yyyyzz_0, \
                                         tg_xzzzzzzz_yyyzzz_0, tg_xzzzzzzz_yyzzzz_0, tg_xzzzzzzz_yzzzzz_0, tg_xzzzzzzz_zzzzzz_0, \
                                         tg_yyyyyy_xxxxxx_0, tg_yyyyyy_xxxxxx_1, tg_yyyyyy_xxxxxy_0, tg_yyyyyy_xxxxxy_1, \
                                         tg_yyyyyy_xxxxxz_0, tg_yyyyyy_xxxxxz_1, tg_yyyyyy_xxxxyy_0, tg_yyyyyy_xxxxyy_1, \
                                         tg_yyyyyy_xxxxyz_0, tg_yyyyyy_xxxxyz_1, tg_yyyyyy_xxxxzz_0, tg_yyyyyy_xxxxzz_1, \
                                         tg_yyyyyy_xxxyyy_0, tg_yyyyyy_xxxyyy_1, tg_yyyyyy_xxxyyz_0, tg_yyyyyy_xxxyyz_1, \
                                         tg_yyyyyy_xxxyzz_0, tg_yyyyyy_xxxyzz_1, tg_yyyyyy_xxxzzz_0, tg_yyyyyy_xxxzzz_1, \
                                         tg_yyyyyy_xxyyyy_0, tg_yyyyyy_xxyyyy_1, tg_yyyyyy_xxyyyz_0, tg_yyyyyy_xxyyyz_1, \
                                         tg_yyyyyy_xxyyzz_0, tg_yyyyyy_xxyyzz_1, tg_yyyyyy_xxyzzz_0, tg_yyyyyy_xxyzzz_1, \
                                         tg_yyyyyy_xxzzzz_0, tg_yyyyyy_xxzzzz_1, tg_yyyyyy_xyyyyy_0, tg_yyyyyy_xyyyyy_1, \
                                         tg_yyyyyy_xyyyyz_0, tg_yyyyyy_xyyyyz_1, tg_yyyyyy_xyyyzz_0, tg_yyyyyy_xyyyzz_1, \
                                         tg_yyyyyy_xyyzzz_0, tg_yyyyyy_xyyzzz_1, tg_yyyyyy_xyzzzz_0, tg_yyyyyy_xyzzzz_1, \
                                         tg_yyyyyy_xzzzzz_0, tg_yyyyyy_xzzzzz_1, tg_yyyyyy_yyyyyy_0, tg_yyyyyy_yyyyyy_1, \
                                         tg_yyyyyy_yyyyyz_0, tg_yyyyyy_yyyyyz_1, tg_yyyyyy_yyyyzz_0, tg_yyyyyy_yyyyzz_1, \
                                         tg_yyyyyy_yyyzzz_0, tg_yyyyyy_yyyzzz_1, tg_yyyyyy_yyzzzz_0, tg_yyyyyy_yyzzzz_1, \
                                         tg_yyyyyy_yzzzzz_0, tg_yyyyyy_yzzzzz_1, tg_yyyyyy_zzzzzz_0, tg_yyyyyy_zzzzzz_1, \
                                         tg_yyyyyyy_xxxxx_1, tg_yyyyyyy_xxxxxx_0, tg_yyyyyyy_xxxxxx_1, tg_yyyyyyy_xxxxxy_0, \
                                         tg_yyyyyyy_xxxxxy_1, tg_yyyyyyy_xxxxxz_0, tg_yyyyyyy_xxxxxz_1, tg_yyyyyyy_xxxxy_1, \
                                         tg_yyyyyyy_xxxxyy_0, tg_yyyyyyy_xxxxyy_1, tg_yyyyyyy_xxxxyz_0, tg_yyyyyyy_xxxxyz_1, \
                                         tg_yyyyyyy_xxxxz_1, tg_yyyyyyy_xxxxzz_0, tg_yyyyyyy_xxxxzz_1, tg_yyyyyyy_xxxyy_1, \
                                         tg_yyyyyyy_xxxyyy_0, tg_yyyyyyy_xxxyyy_1, tg_yyyyyyy_xxxyyz_0, tg_yyyyyyy_xxxyyz_1, \
                                         tg_yyyyyyy_xxxyz_1, tg_yyyyyyy_xxxyzz_0, tg_yyyyyyy_xxxyzz_1, tg_yyyyyyy_xxxzz_1, \
                                         tg_yyyyyyy_xxxzzz_0, tg_yyyyyyy_xxxzzz_1, tg_yyyyyyy_xxyyy_1, tg_yyyyyyy_xxyyyy_0, \
                                         tg_yyyyyyy_xxyyyy_1, tg_yyyyyyy_xxyyyz_0, tg_yyyyyyy_xxyyyz_1, tg_yyyyyyy_xxyyz_1, \
                                         tg_yyyyyyy_xxyyzz_0, tg_yyyyyyy_xxyyzz_1, tg_yyyyyyy_xxyzz_1, tg_yyyyyyy_xxyzzz_0, \
                                         tg_yyyyyyy_xxyzzz_1, tg_yyyyyyy_xxzzz_1, tg_yyyyyyy_xxzzzz_0, tg_yyyyyyy_xxzzzz_1, \
                                         tg_yyyyyyy_xyyyy_1, tg_yyyyyyy_xyyyyy_0, tg_yyyyyyy_xyyyyy_1, tg_yyyyyyy_xyyyyz_0, \
                                         tg_yyyyyyy_xyyyyz_1, tg_yyyyyyy_xyyyz_1, tg_yyyyyyy_xyyyzz_0, tg_yyyyyyy_xyyyzz_1, \
                                         tg_yyyyyyy_xyyzz_1, tg_yyyyyyy_xyyzzz_0, tg_yyyyyyy_xyyzzz_1, tg_yyyyyyy_xyzzz_1, \
                                         tg_yyyyyyy_xyzzzz_0, tg_yyyyyyy_xyzzzz_1, tg_yyyyyyy_xzzzz_1, tg_yyyyyyy_xzzzzz_0, \
                                         tg_yyyyyyy_xzzzzz_1, tg_yyyyyyy_yyyyy_1, tg_yyyyyyy_yyyyyy_0, tg_yyyyyyy_yyyyyy_1, \
                                         tg_yyyyyyy_yyyyyz_0, tg_yyyyyyy_yyyyyz_1, tg_yyyyyyy_yyyyz_1, tg_yyyyyyy_yyyyzz_0, \
                                         tg_yyyyyyy_yyyyzz_1, tg_yyyyyyy_yyyzz_1, tg_yyyyyyy_yyyzzz_0, tg_yyyyyyy_yyyzzz_1, \
                                         tg_yyyyyyy_yyzzz_1, tg_yyyyyyy_yyzzzz_0, tg_yyyyyyy_yyzzzz_1, tg_yyyyyyy_yzzzz_1, \
                                         tg_yyyyyyy_yzzzzz_0, tg_yyyyyyy_yzzzzz_1, tg_yyyyyyy_zzzzz_1, tg_yyyyyyy_zzzzzz_0, \
                                         tg_yyyyyyy_zzzzzz_1, tg_yyyyyyyy_xxxxxx_0, tg_yyyyyyyy_xxxxxy_0, tg_yyyyyyyy_xxxxxz_0, \
                                         tg_yyyyyyyy_xxxxyy_0, tg_yyyyyyyy_xxxxyz_0, tg_yyyyyyyy_xxxxzz_0, tg_yyyyyyyy_xxxyyy_0, \
                                         tg_yyyyyyyy_xxxyyz_0, tg_yyyyyyyy_xxxyzz_0, tg_yyyyyyyy_xxxzzz_0, tg_yyyyyyyy_xxyyyy_0, \
                                         tg_yyyyyyyy_xxyyyz_0, tg_yyyyyyyy_xxyyzz_0, tg_yyyyyyyy_xxyzzz_0, tg_yyyyyyyy_xxzzzz_0, \
                                         tg_yyyyyyyy_xyyyyy_0, tg_yyyyyyyy_xyyyyz_0, tg_yyyyyyyy_xyyyzz_0, tg_yyyyyyyy_xyyzzz_0, \
                                         tg_yyyyyyyy_xyzzzz_0, tg_yyyyyyyy_xzzzzz_0, tg_yyyyyyyy_yyyyyy_0, tg_yyyyyyyy_yyyyyz_0, \
                                         tg_yyyyyyyy_yyyyzz_0, tg_yyyyyyyy_yyyzzz_0, tg_yyyyyyyy_yyzzzz_0, tg_yyyyyyyy_yzzzzz_0, \
                                         tg_yyyyyyyy_zzzzzz_0, tg_yyyyyyyz_xxxxxx_0, tg_yyyyyyyz_xxxxxy_0, tg_yyyyyyyz_xxxxxz_0, \
                                         tg_yyyyyyyz_xxxxyy_0, tg_yyyyyyyz_xxxxyz_0, tg_yyyyyyyz_xxxxzz_0, tg_yyyyyyyz_xxxyyy_0, \
                                         tg_yyyyyyyz_xxxyyz_0, tg_yyyyyyyz_xxxyzz_0, tg_yyyyyyyz_xxxzzz_0, tg_yyyyyyyz_xxyyyy_0, \
                                         tg_yyyyyyyz_xxyyyz_0, tg_yyyyyyyz_xxyyzz_0, tg_yyyyyyyz_xxyzzz_0, tg_yyyyyyyz_xxzzzz_0, \
                                         tg_yyyyyyyz_xyyyyy_0, tg_yyyyyyyz_xyyyyz_0, tg_yyyyyyyz_xyyyzz_0, tg_yyyyyyyz_xyyzzz_0, \
                                         tg_yyyyyyyz_xyzzzz_0, tg_yyyyyyyz_xzzzzz_0, tg_yyyyyyyz_yyyyyy_0, tg_yyyyyyyz_yyyyyz_0, \
                                         tg_yyyyyyyz_yyyyzz_0, tg_yyyyyyyz_yyyzzz_0, tg_yyyyyyyz_yyzzzz_0, tg_yyyyyyyz_yzzzzz_0, \
                                         tg_yyyyyyyz_zzzzzz_0, tg_yyyyyyz_xxxxx_1, tg_yyyyyyz_xxxxxx_0, tg_yyyyyyz_xxxxxx_1, \
                                         tg_yyyyyyz_xxxxxy_0, tg_yyyyyyz_xxxxxy_1, tg_yyyyyyz_xxxxxz_0, tg_yyyyyyz_xxxxxz_1, \
                                         tg_yyyyyyz_xxxxy_1, tg_yyyyyyz_xxxxyy_0, tg_yyyyyyz_xxxxyy_1, tg_yyyyyyz_xxxxyz_0, \
                                         tg_yyyyyyz_xxxxyz_1, tg_yyyyyyz_xxxxz_1, tg_yyyyyyz_xxxxzz_0, tg_yyyyyyz_xxxxzz_1, \
                                         tg_yyyyyyz_xxxyy_1, tg_yyyyyyz_xxxyyy_0, tg_yyyyyyz_xxxyyy_1, tg_yyyyyyz_xxxyyz_0, \
                                         tg_yyyyyyz_xxxyyz_1, tg_yyyyyyz_xxxyz_1, tg_yyyyyyz_xxxyzz_0, tg_yyyyyyz_xxxyzz_1, \
                                         tg_yyyyyyz_xxxzz_1, tg_yyyyyyz_xxxzzz_0, tg_yyyyyyz_xxxzzz_1, tg_yyyyyyz_xxyyy_1, \
                                         tg_yyyyyyz_xxyyyy_0, tg_yyyyyyz_xxyyyy_1, tg_yyyyyyz_xxyyyz_0, tg_yyyyyyz_xxyyyz_1, \
                                         tg_yyyyyyz_xxyyz_1, tg_yyyyyyz_xxyyzz_0, tg_yyyyyyz_xxyyzz_1, tg_yyyyyyz_xxyzz_1, \
                                         tg_yyyyyyz_xxyzzz_0, tg_yyyyyyz_xxyzzz_1, tg_yyyyyyz_xxzzz_1, tg_yyyyyyz_xxzzzz_0, \
                                         tg_yyyyyyz_xxzzzz_1, tg_yyyyyyz_xyyyy_1, tg_yyyyyyz_xyyyyy_0, tg_yyyyyyz_xyyyyy_1, \
                                         tg_yyyyyyz_xyyyyz_0, tg_yyyyyyz_xyyyyz_1, tg_yyyyyyz_xyyyz_1, tg_yyyyyyz_xyyyzz_0, \
                                         tg_yyyyyyz_xyyyzz_1, tg_yyyyyyz_xyyzz_1, tg_yyyyyyz_xyyzzz_0, tg_yyyyyyz_xyyzzz_1, \
                                         tg_yyyyyyz_xyzzz_1, tg_yyyyyyz_xyzzzz_0, tg_yyyyyyz_xyzzzz_1, tg_yyyyyyz_xzzzz_1, \
                                         tg_yyyyyyz_xzzzzz_0, tg_yyyyyyz_xzzzzz_1, tg_yyyyyyz_yyyyy_1, tg_yyyyyyz_yyyyyy_0, \
                                         tg_yyyyyyz_yyyyyy_1, tg_yyyyyyz_yyyyyz_0, tg_yyyyyyz_yyyyyz_1, tg_yyyyyyz_yyyyz_1, \
                                         tg_yyyyyyz_yyyyzz_0, tg_yyyyyyz_yyyyzz_1, tg_yyyyyyz_yyyzz_1, tg_yyyyyyz_yyyzzz_0, \
                                         tg_yyyyyyz_yyyzzz_1, tg_yyyyyyz_yyzzz_1, tg_yyyyyyz_yyzzzz_0, tg_yyyyyyz_yyzzzz_1, \
                                         tg_yyyyyyz_yzzzz_1, tg_yyyyyyz_yzzzzz_0, tg_yyyyyyz_yzzzzz_1, tg_yyyyyyz_zzzzz_1, \
                                         tg_yyyyyyz_zzzzzz_0, tg_yyyyyyz_zzzzzz_1, tg_yyyyyyzz_xxxxxx_0, tg_yyyyyyzz_xxxxxy_0, \
                                         tg_yyyyyyzz_xxxxxz_0, tg_yyyyyz_xxxxxx_0, tg_yyyyyz_xxxxxx_1, tg_yyyyyz_xxxxxy_0, \
                                         tg_yyyyyz_xxxxxy_1, tg_yyyyyz_xxxxxz_0, tg_yyyyyz_xxxxxz_1, tg_yyyyyz_xxxxyy_0, \
                                         tg_yyyyyz_xxxxyy_1, tg_yyyyyz_xxxxyz_0, tg_yyyyyz_xxxxyz_1, tg_yyyyyz_xxxxzz_0, \
                                         tg_yyyyyz_xxxxzz_1, tg_yyyyyz_xxxyyy_0, tg_yyyyyz_xxxyyy_1, tg_yyyyyz_xxxyyz_0, \
                                         tg_yyyyyz_xxxyyz_1, tg_yyyyyz_xxxyzz_0, tg_yyyyyz_xxxyzz_1, tg_yyyyyz_xxxzzz_0, \
                                         tg_yyyyyz_xxxzzz_1, tg_yyyyyz_xxyyyy_0, tg_yyyyyz_xxyyyy_1, tg_yyyyyz_xxyyyz_0, \
                                         tg_yyyyyz_xxyyyz_1, tg_yyyyyz_xxyyzz_0, tg_yyyyyz_xxyyzz_1, tg_yyyyyz_xxyzzz_0, \
                                         tg_yyyyyz_xxyzzz_1, tg_yyyyyz_xxzzzz_0, tg_yyyyyz_xxzzzz_1, tg_yyyyyz_xyyyyy_0, \
                                         tg_yyyyyz_xyyyyy_1, tg_yyyyyz_xyyyyz_0, tg_yyyyyz_xyyyyz_1, tg_yyyyyz_xyyyzz_0, \
                                         tg_yyyyyz_xyyyzz_1, tg_yyyyyz_xyyzzz_0, tg_yyyyyz_xyyzzz_1, tg_yyyyyz_xyzzzz_0, \
                                         tg_yyyyyz_xyzzzz_1, tg_yyyyyz_xzzzzz_0, tg_yyyyyz_xzzzzz_1, tg_yyyyyz_yyyyyy_0, \
                                         tg_yyyyyz_yyyyyy_1, tg_yyyyyz_yyyyyz_0, tg_yyyyyz_yyyyyz_1, tg_yyyyyz_yyyyzz_0, \
                                         tg_yyyyyz_yyyyzz_1, tg_yyyyyz_yyyzzz_0, tg_yyyyyz_yyyzzz_1, tg_yyyyyz_yyzzzz_0, \
                                         tg_yyyyyz_yyzzzz_1, tg_yyyyyz_yzzzzz_0, tg_yyyyyz_yzzzzz_1, tg_yyyyyz_zzzzzz_0, \
                                         tg_yyyyyz_zzzzzz_1, tg_yyyyyzz_xxxxx_1, tg_yyyyyzz_xxxxxx_0, tg_yyyyyzz_xxxxxx_1, \
                                         tg_yyyyyzz_xxxxxy_0, tg_yyyyyzz_xxxxxy_1, tg_yyyyyzz_xxxxxz_0, tg_yyyyyzz_xxxxxz_1, \
                                         tg_yyyyzz_xxxxxx_0, tg_yyyyzz_xxxxxx_1, tg_yyyyzz_xxxxxy_0, tg_yyyyzz_xxxxxy_1, \
                                         tg_yyyyzz_xxxxxz_0, tg_yyyyzz_xxxxxz_1, tg_yzzzzzz_xyyzzz_0, tg_yzzzzzz_xyyzzz_1, \
                                         tg_yzzzzzz_xyzzzz_0, tg_yzzzzzz_xyzzzz_1, tg_yzzzzzz_xzzzzz_0, tg_yzzzzzz_xzzzzz_1, \
                                         tg_yzzzzzz_yyyyyy_0, tg_yzzzzzz_yyyyyy_1, tg_yzzzzzz_yyyyyz_0, tg_yzzzzzz_yyyyyz_1, \
                                         tg_yzzzzzz_yyyyzz_0, tg_yzzzzzz_yyyyzz_1, tg_yzzzzzz_yyyzzz_0, tg_yzzzzzz_yyyzzz_1, \
                                         tg_yzzzzzz_yyzzz_1, tg_yzzzzzz_yyzzzz_0, tg_yzzzzzz_yyzzzz_1, tg_yzzzzzz_yzzzz_1, \
                                         tg_yzzzzzz_yzzzzz_0, tg_yzzzzzz_yzzzzz_1, tg_yzzzzzz_zzzzz_1, tg_yzzzzzz_zzzzzz_0, \
                                         tg_yzzzzzz_zzzzzz_1, tg_zzzzzzz_xxxxx_1, tg_zzzzzzz_xxxxxx_0, tg_zzzzzzz_xxxxxx_1, \
                                         tg_zzzzzzz_xxxxxy_0, tg_zzzzzzz_xxxxxy_1, tg_zzzzzzz_xxxxxz_0, tg_zzzzzzz_xxxxxz_1, \
                                         tg_zzzzzzz_xxxxy_1, tg_zzzzzzz_xxxxyy_0, tg_zzzzzzz_xxxxyy_1, tg_zzzzzzz_xxxxyz_0, \
                                         tg_zzzzzzz_xxxxyz_1, tg_zzzzzzz_xxxxz_1, tg_zzzzzzz_xxxxzz_0, tg_zzzzzzz_xxxxzz_1, \
                                         tg_zzzzzzz_xxxyy_1, tg_zzzzzzz_xxxyyy_0, tg_zzzzzzz_xxxyyy_1, tg_zzzzzzz_xxxyyz_0, \
                                         tg_zzzzzzz_xxxyyz_1, tg_zzzzzzz_xxxyz_1, tg_zzzzzzz_xxxyzz_0, tg_zzzzzzz_xxxyzz_1, \
                                         tg_zzzzzzz_xxxzz_1, tg_zzzzzzz_xxxzzz_0, tg_zzzzzzz_xxxzzz_1, tg_zzzzzzz_xxyyy_1, \
                                         tg_zzzzzzz_xxyyyy_0, tg_zzzzzzz_xxyyyy_1, tg_zzzzzzz_xxyyyz_0, tg_zzzzzzz_xxyyyz_1, \
                                         tg_zzzzzzz_xxyyz_1, tg_zzzzzzz_xxyyzz_0, tg_zzzzzzz_xxyyzz_1, tg_zzzzzzz_xxyzz_1, \
                                         tg_zzzzzzz_xxyzzz_0, tg_zzzzzzz_xxyzzz_1, tg_zzzzzzz_xxzzz_1, tg_zzzzzzz_xxzzzz_0, \
                                         tg_zzzzzzz_xxzzzz_1, tg_zzzzzzz_xyyyy_1, tg_zzzzzzz_xyyyyy_0, tg_zzzzzzz_xyyyyy_1, \
                                         tg_zzzzzzz_xyyyyz_0, tg_zzzzzzz_xyyyyz_1, tg_zzzzzzz_xyyyz_1, tg_zzzzzzz_xyyyzz_0, \
                                         tg_zzzzzzz_xyyyzz_1, tg_zzzzzzz_xyyzz_1, tg_zzzzzzz_xyyzzz_0, tg_zzzzzzz_xyyzzz_1, \
                                         tg_zzzzzzz_xyzzz_1, tg_zzzzzzz_xyzzzz_0, tg_zzzzzzz_xyzzzz_1, tg_zzzzzzz_xzzzz_1, \
                                         tg_zzzzzzz_xzzzzz_0, tg_zzzzzzz_xzzzzz_1, tg_zzzzzzz_yyyyy_1, tg_zzzzzzz_yyyyyy_0, \
                                         tg_zzzzzzz_yyyyyy_1, tg_zzzzzzz_yyyyyz_0, tg_zzzzzzz_yyyyyz_1, tg_zzzzzzz_yyyyz_1, \
                                         tg_zzzzzzz_yyyyzz_0, tg_zzzzzzz_yyyyzz_1, tg_zzzzzzz_yyyzz_1, tg_zzzzzzz_yyyzzz_0, \
                                         tg_zzzzzzz_yyyzzz_1, tg_zzzzzzz_yyzzz_1, tg_zzzzzzz_yyzzzz_0, tg_zzzzzzz_yyzzzz_1, \
                                         tg_zzzzzzz_yzzzz_1, tg_zzzzzzz_yzzzzz_0, tg_zzzzzzz_yzzzzz_1, tg_zzzzzzz_zzzzz_1, \
                                         tg_zzzzzzz_zzzzzz_0, tg_zzzzzzz_zzzzzz_1, wp_x, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_x[j]; 

                    tg_xyzzzzzz_xyyzzz_0[j] = pb_x * tg_yzzzzzz_xyyzzz_0[j] + fr * tg_yzzzzzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_yyzzz_1[j];

                    tg_xyzzzzzz_xyzzzz_0[j] = pb_x * tg_yzzzzzz_xyzzzz_0[j] + fr * tg_yzzzzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_yzzzz_1[j];

                    tg_xyzzzzzz_xzzzzz_0[j] = pb_x * tg_yzzzzzz_xzzzzz_0[j] + fr * tg_yzzzzzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_yzzzzzz_zzzzz_1[j];

                    tg_xyzzzzzz_yyyyyy_0[j] = pb_x * tg_yzzzzzz_yyyyyy_0[j] + fr * tg_yzzzzzz_yyyyyy_1[j];

                    tg_xyzzzzzz_yyyyyz_0[j] = pb_x * tg_yzzzzzz_yyyyyz_0[j] + fr * tg_yzzzzzz_yyyyyz_1[j];

                    tg_xyzzzzzz_yyyyzz_0[j] = pb_x * tg_yzzzzzz_yyyyzz_0[j] + fr * tg_yzzzzzz_yyyyzz_1[j];

                    tg_xyzzzzzz_yyyzzz_0[j] = pb_x * tg_yzzzzzz_yyyzzz_0[j] + fr * tg_yzzzzzz_yyyzzz_1[j];

                    tg_xyzzzzzz_yyzzzz_0[j] = pb_x * tg_yzzzzzz_yyzzzz_0[j] + fr * tg_yzzzzzz_yyzzzz_1[j];

                    tg_xyzzzzzz_yzzzzz_0[j] = pb_x * tg_yzzzzzz_yzzzzz_0[j] + fr * tg_yzzzzzz_yzzzzz_1[j];

                    tg_xyzzzzzz_zzzzzz_0[j] = pb_x * tg_yzzzzzz_zzzzzz_0[j] + fr * tg_yzzzzzz_zzzzzz_1[j];

                    tg_xzzzzzzz_xxxxxx_0[j] = pb_x * tg_zzzzzzz_xxxxxx_0[j] + fr * tg_zzzzzzz_xxxxxx_1[j] + 3.0 * fl1_fxn * tg_zzzzzzz_xxxxx_1[j];

                    tg_xzzzzzzz_xxxxxy_0[j] = pb_x * tg_zzzzzzz_xxxxxy_0[j] + fr * tg_zzzzzzz_xxxxxy_1[j] + 2.5 * fl1_fxn * tg_zzzzzzz_xxxxy_1[j];

                    tg_xzzzzzzz_xxxxxz_0[j] = pb_x * tg_zzzzzzz_xxxxxz_0[j] + fr * tg_zzzzzzz_xxxxxz_1[j] + 2.5 * fl1_fxn * tg_zzzzzzz_xxxxz_1[j];

                    tg_xzzzzzzz_xxxxyy_0[j] = pb_x * tg_zzzzzzz_xxxxyy_0[j] + fr * tg_zzzzzzz_xxxxyy_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_xxxyy_1[j];

                    tg_xzzzzzzz_xxxxyz_0[j] = pb_x * tg_zzzzzzz_xxxxyz_0[j] + fr * tg_zzzzzzz_xxxxyz_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_xxxyz_1[j];

                    tg_xzzzzzzz_xxxxzz_0[j] = pb_x * tg_zzzzzzz_xxxxzz_0[j] + fr * tg_zzzzzzz_xxxxzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_xxxzz_1[j];

                    tg_xzzzzzzz_xxxyyy_0[j] = pb_x * tg_zzzzzzz_xxxyyy_0[j] + fr * tg_zzzzzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxyyy_1[j];

                    tg_xzzzzzzz_xxxyyz_0[j] = pb_x * tg_zzzzzzz_xxxyyz_0[j] + fr * tg_zzzzzzz_xxxyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxyyz_1[j];

                    tg_xzzzzzzz_xxxyzz_0[j] = pb_x * tg_zzzzzzz_xxxyzz_0[j] + fr * tg_zzzzzzz_xxxyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxyzz_1[j];

                    tg_xzzzzzzz_xxxzzz_0[j] = pb_x * tg_zzzzzzz_xxxzzz_0[j] + fr * tg_zzzzzzz_xxxzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxzzz_1[j];

                    tg_xzzzzzzz_xxyyyy_0[j] = pb_x * tg_zzzzzzz_xxyyyy_0[j] + fr * tg_zzzzzzz_xxyyyy_1[j] + fl1_fxn * tg_zzzzzzz_xyyyy_1[j];

                    tg_xzzzzzzz_xxyyyz_0[j] = pb_x * tg_zzzzzzz_xxyyyz_0[j] + fr * tg_zzzzzzz_xxyyyz_1[j] + fl1_fxn * tg_zzzzzzz_xyyyz_1[j];

                    tg_xzzzzzzz_xxyyzz_0[j] = pb_x * tg_zzzzzzz_xxyyzz_0[j] + fr * tg_zzzzzzz_xxyyzz_1[j] + fl1_fxn * tg_zzzzzzz_xyyzz_1[j];

                    tg_xzzzzzzz_xxyzzz_0[j] = pb_x * tg_zzzzzzz_xxyzzz_0[j] + fr * tg_zzzzzzz_xxyzzz_1[j] + fl1_fxn * tg_zzzzzzz_xyzzz_1[j];

                    tg_xzzzzzzz_xxzzzz_0[j] = pb_x * tg_zzzzzzz_xxzzzz_0[j] + fr * tg_zzzzzzz_xxzzzz_1[j] + fl1_fxn * tg_zzzzzzz_xzzzz_1[j];

                    tg_xzzzzzzz_xyyyyy_0[j] = pb_x * tg_zzzzzzz_xyyyyy_0[j] + fr * tg_zzzzzzz_xyyyyy_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_yyyyy_1[j];

                    tg_xzzzzzzz_xyyyyz_0[j] = pb_x * tg_zzzzzzz_xyyyyz_0[j] + fr * tg_zzzzzzz_xyyyyz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_yyyyz_1[j];

                    tg_xzzzzzzz_xyyyzz_0[j] = pb_x * tg_zzzzzzz_xyyyzz_0[j] + fr * tg_zzzzzzz_xyyyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_yyyzz_1[j];

                    tg_xzzzzzzz_xyyzzz_0[j] = pb_x * tg_zzzzzzz_xyyzzz_0[j] + fr * tg_zzzzzzz_xyyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_yyzzz_1[j];

                    tg_xzzzzzzz_xyzzzz_0[j] = pb_x * tg_zzzzzzz_xyzzzz_0[j] + fr * tg_zzzzzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_yzzzz_1[j];

                    tg_xzzzzzzz_xzzzzz_0[j] = pb_x * tg_zzzzzzz_xzzzzz_0[j] + fr * tg_zzzzzzz_xzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_zzzzz_1[j];

                    tg_xzzzzzzz_yyyyyy_0[j] = pb_x * tg_zzzzzzz_yyyyyy_0[j] + fr * tg_zzzzzzz_yyyyyy_1[j];

                    tg_xzzzzzzz_yyyyyz_0[j] = pb_x * tg_zzzzzzz_yyyyyz_0[j] + fr * tg_zzzzzzz_yyyyyz_1[j];

                    tg_xzzzzzzz_yyyyzz_0[j] = pb_x * tg_zzzzzzz_yyyyzz_0[j] + fr * tg_zzzzzzz_yyyyzz_1[j];

                    tg_xzzzzzzz_yyyzzz_0[j] = pb_x * tg_zzzzzzz_yyyzzz_0[j] + fr * tg_zzzzzzz_yyyzzz_1[j];

                    tg_xzzzzzzz_yyzzzz_0[j] = pb_x * tg_zzzzzzz_yyzzzz_0[j] + fr * tg_zzzzzzz_yyzzzz_1[j];

                    tg_xzzzzzzz_yzzzzz_0[j] = pb_x * tg_zzzzzzz_yzzzzz_0[j] + fr * tg_zzzzzzz_yzzzzz_1[j];

                    tg_xzzzzzzz_zzzzzz_0[j] = pb_x * tg_zzzzzzz_zzzzzz_0[j] + fr * tg_zzzzzzz_zzzzzz_1[j];

                    fr = wp_y[j]; 

                    tg_yyyyyyyy_xxxxxx_0[j] = pb_y * tg_yyyyyyy_xxxxxx_0[j] + fr * tg_yyyyyyy_xxxxxx_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxxx_0[j] - tg_yyyyyy_xxxxxx_1[j] * fl1_fza);

                    tg_yyyyyyyy_xxxxxy_0[j] = pb_y * tg_yyyyyyy_xxxxxy_0[j] + fr * tg_yyyyyyy_xxxxxy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxxy_0[j] - tg_yyyyyy_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_xxxxx_1[j];

                    tg_yyyyyyyy_xxxxxz_0[j] = pb_y * tg_yyyyyyy_xxxxxz_0[j] + fr * tg_yyyyyyy_xxxxxz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxxz_0[j] - tg_yyyyyy_xxxxxz_1[j] * fl1_fza);

                    tg_yyyyyyyy_xxxxyy_0[j] = pb_y * tg_yyyyyyy_xxxxyy_0[j] + fr * tg_yyyyyyy_xxxxyy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxyy_0[j] - tg_yyyyyy_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_xxxxy_1[j];

                    tg_yyyyyyyy_xxxxyz_0[j] = pb_y * tg_yyyyyyy_xxxxyz_0[j] + fr * tg_yyyyyyy_xxxxyz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxyz_0[j] - tg_yyyyyy_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_xxxxz_1[j];

                    tg_yyyyyyyy_xxxxzz_0[j] = pb_y * tg_yyyyyyy_xxxxzz_0[j] + fr * tg_yyyyyyy_xxxxzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxxzz_0[j] - tg_yyyyyy_xxxxzz_1[j] * fl1_fza);

                    tg_yyyyyyyy_xxxyyy_0[j] = pb_y * tg_yyyyyyy_xxxyyy_0[j] + fr * tg_yyyyyyy_xxxyyy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxyyy_0[j] - tg_yyyyyy_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyy_xxxyy_1[j];

                    tg_yyyyyyyy_xxxyyz_0[j] = pb_y * tg_yyyyyyy_xxxyyz_0[j] + fr * tg_yyyyyyy_xxxyyz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxyyz_0[j] - tg_yyyyyy_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_xxxyz_1[j];

                    tg_yyyyyyyy_xxxyzz_0[j] = pb_y * tg_yyyyyyy_xxxyzz_0[j] + fr * tg_yyyyyyy_xxxyzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxyzz_0[j] - tg_yyyyyy_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_xxxzz_1[j];

                    tg_yyyyyyyy_xxxzzz_0[j] = pb_y * tg_yyyyyyy_xxxzzz_0[j] + fr * tg_yyyyyyy_xxxzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxxzzz_0[j] - tg_yyyyyy_xxxzzz_1[j] * fl1_fza);

                    tg_yyyyyyyy_xxyyyy_0[j] = pb_y * tg_yyyyyyy_xxyyyy_0[j] + fr * tg_yyyyyyy_xxyyyy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxyyyy_0[j] - tg_yyyyyy_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyy_xxyyy_1[j];

                    tg_yyyyyyyy_xxyyyz_0[j] = pb_y * tg_yyyyyyy_xxyyyz_0[j] + fr * tg_yyyyyyy_xxyyyz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxyyyz_0[j] - tg_yyyyyy_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyy_xxyyz_1[j];

                    tg_yyyyyyyy_xxyyzz_0[j] = pb_y * tg_yyyyyyy_xxyyzz_0[j] + fr * tg_yyyyyyy_xxyyzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxyyzz_0[j] - tg_yyyyyy_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_xxyzz_1[j];

                    tg_yyyyyyyy_xxyzzz_0[j] = pb_y * tg_yyyyyyy_xxyzzz_0[j] + fr * tg_yyyyyyy_xxyzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxyzzz_0[j] - tg_yyyyyy_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_xxzzz_1[j];

                    tg_yyyyyyyy_xxzzzz_0[j] = pb_y * tg_yyyyyyy_xxzzzz_0[j] + fr * tg_yyyyyyy_xxzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xxzzzz_0[j] - tg_yyyyyy_xxzzzz_1[j] * fl1_fza);

                    tg_yyyyyyyy_xyyyyy_0[j] = pb_y * tg_yyyyyyy_xyyyyy_0[j] + fr * tg_yyyyyyy_xyyyyy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xyyyyy_0[j] - tg_yyyyyy_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyyy_xyyyy_1[j];

                    tg_yyyyyyyy_xyyyyz_0[j] = pb_y * tg_yyyyyyy_xyyyyz_0[j] + fr * tg_yyyyyyy_xyyyyz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xyyyyz_0[j] - tg_yyyyyy_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyy_xyyyz_1[j];

                    tg_yyyyyyyy_xyyyzz_0[j] = pb_y * tg_yyyyyyy_xyyyzz_0[j] + fr * tg_yyyyyyy_xyyyzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xyyyzz_0[j] - tg_yyyyyy_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyy_xyyzz_1[j];

                    tg_yyyyyyyy_xyyzzz_0[j] = pb_y * tg_yyyyyyy_xyyzzz_0[j] + fr * tg_yyyyyyy_xyyzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xyyzzz_0[j] - tg_yyyyyy_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_xyzzz_1[j];

                    tg_yyyyyyyy_xyzzzz_0[j] = pb_y * tg_yyyyyyy_xyzzzz_0[j] + fr * tg_yyyyyyy_xyzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xyzzzz_0[j] - tg_yyyyyy_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_xzzzz_1[j];

                    tg_yyyyyyyy_xzzzzz_0[j] = pb_y * tg_yyyyyyy_xzzzzz_0[j] + fr * tg_yyyyyyy_xzzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_xzzzzz_0[j] - tg_yyyyyy_xzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyyy_yyyyyy_0[j] = pb_y * tg_yyyyyyy_yyyyyy_0[j] + fr * tg_yyyyyyy_yyyyyy_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yyyyyy_0[j] - tg_yyyyyy_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyyy_yyyyy_1[j];

                    tg_yyyyyyyy_yyyyyz_0[j] = pb_y * tg_yyyyyyy_yyyyyz_0[j] + fr * tg_yyyyyyy_yyyyyz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yyyyyz_0[j] - tg_yyyyyy_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyyy_yyyyz_1[j];

                    tg_yyyyyyyy_yyyyzz_0[j] = pb_y * tg_yyyyyyy_yyyyzz_0[j] + fr * tg_yyyyyyy_yyyyzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yyyyzz_0[j] - tg_yyyyyy_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyy_yyyzz_1[j];

                    tg_yyyyyyyy_yyyzzz_0[j] = pb_y * tg_yyyyyyy_yyyzzz_0[j] + fr * tg_yyyyyyy_yyyzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yyyzzz_0[j] - tg_yyyyyy_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyy_yyzzz_1[j];

                    tg_yyyyyyyy_yyzzzz_0[j] = pb_y * tg_yyyyyyy_yyzzzz_0[j] + fr * tg_yyyyyyy_yyzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yyzzzz_0[j] - tg_yyyyyy_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyy_yzzzz_1[j];

                    tg_yyyyyyyy_yzzzzz_0[j] = pb_y * tg_yyyyyyy_yzzzzz_0[j] + fr * tg_yyyyyyy_yzzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_yzzzzz_0[j] - tg_yyyyyy_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyy_zzzzz_1[j];

                    tg_yyyyyyyy_zzzzzz_0[j] = pb_y * tg_yyyyyyy_zzzzzz_0[j] + fr * tg_yyyyyyy_zzzzzz_1[j] + 3.5 * fl1_fx * (tg_yyyyyy_zzzzzz_0[j] - tg_yyyyyy_zzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xxxxxx_0[j] = pb_y * tg_yyyyyyz_xxxxxx_0[j] + fr * tg_yyyyyyz_xxxxxx_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxxx_0[j] - tg_yyyyyz_xxxxxx_1[j] * fl1_fza);

                    tg_yyyyyyyz_xxxxxy_0[j] = pb_y * tg_yyyyyyz_xxxxxy_0[j] + fr * tg_yyyyyyz_xxxxxy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxxy_0[j] - tg_yyyyyz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_xxxxx_1[j];

                    tg_yyyyyyyz_xxxxxz_0[j] = pb_y * tg_yyyyyyz_xxxxxz_0[j] + fr * tg_yyyyyyz_xxxxxz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxxz_0[j] - tg_yyyyyz_xxxxxz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xxxxyy_0[j] = pb_y * tg_yyyyyyz_xxxxyy_0[j] + fr * tg_yyyyyyz_xxxxyy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxyy_0[j] - tg_yyyyyz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_xxxxy_1[j];

                    tg_yyyyyyyz_xxxxyz_0[j] = pb_y * tg_yyyyyyz_xxxxyz_0[j] + fr * tg_yyyyyyz_xxxxyz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxyz_0[j] - tg_yyyyyz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_xxxxz_1[j];

                    tg_yyyyyyyz_xxxxzz_0[j] = pb_y * tg_yyyyyyz_xxxxzz_0[j] + fr * tg_yyyyyyz_xxxxzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxxzz_0[j] - tg_yyyyyz_xxxxzz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xxxyyy_0[j] = pb_y * tg_yyyyyyz_xxxyyy_0[j] + fr * tg_yyyyyyz_xxxyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxyyy_0[j] - tg_yyyyyz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyz_xxxyy_1[j];

                    tg_yyyyyyyz_xxxyyz_0[j] = pb_y * tg_yyyyyyz_xxxyyz_0[j] + fr * tg_yyyyyyz_xxxyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxyyz_0[j] - tg_yyyyyz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_xxxyz_1[j];

                    tg_yyyyyyyz_xxxyzz_0[j] = pb_y * tg_yyyyyyz_xxxyzz_0[j] + fr * tg_yyyyyyz_xxxyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxyzz_0[j] - tg_yyyyyz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_xxxzz_1[j];

                    tg_yyyyyyyz_xxxzzz_0[j] = pb_y * tg_yyyyyyz_xxxzzz_0[j] + fr * tg_yyyyyyz_xxxzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxxzzz_0[j] - tg_yyyyyz_xxxzzz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xxyyyy_0[j] = pb_y * tg_yyyyyyz_xxyyyy_0[j] + fr * tg_yyyyyyz_xxyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxyyyy_0[j] - tg_yyyyyz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyz_xxyyy_1[j];

                    tg_yyyyyyyz_xxyyyz_0[j] = pb_y * tg_yyyyyyz_xxyyyz_0[j] + fr * tg_yyyyyyz_xxyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxyyyz_0[j] - tg_yyyyyz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyz_xxyyz_1[j];

                    tg_yyyyyyyz_xxyyzz_0[j] = pb_y * tg_yyyyyyz_xxyyzz_0[j] + fr * tg_yyyyyyz_xxyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxyyzz_0[j] - tg_yyyyyz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_xxyzz_1[j];

                    tg_yyyyyyyz_xxyzzz_0[j] = pb_y * tg_yyyyyyz_xxyzzz_0[j] + fr * tg_yyyyyyz_xxyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxyzzz_0[j] - tg_yyyyyz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_xxzzz_1[j];

                    tg_yyyyyyyz_xxzzzz_0[j] = pb_y * tg_yyyyyyz_xxzzzz_0[j] + fr * tg_yyyyyyz_xxzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xxzzzz_0[j] - tg_yyyyyz_xxzzzz_1[j] * fl1_fza);

                    tg_yyyyyyyz_xyyyyy_0[j] = pb_y * tg_yyyyyyz_xyyyyy_0[j] + fr * tg_yyyyyyz_xyyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xyyyyy_0[j] - tg_yyyyyz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyyz_xyyyy_1[j];

                    tg_yyyyyyyz_xyyyyz_0[j] = pb_y * tg_yyyyyyz_xyyyyz_0[j] + fr * tg_yyyyyyz_xyyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xyyyyz_0[j] - tg_yyyyyz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyz_xyyyz_1[j];

                    tg_yyyyyyyz_xyyyzz_0[j] = pb_y * tg_yyyyyyz_xyyyzz_0[j] + fr * tg_yyyyyyz_xyyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xyyyzz_0[j] - tg_yyyyyz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyz_xyyzz_1[j];

                    tg_yyyyyyyz_xyyzzz_0[j] = pb_y * tg_yyyyyyz_xyyzzz_0[j] + fr * tg_yyyyyyz_xyyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xyyzzz_0[j] - tg_yyyyyz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_xyzzz_1[j];

                    tg_yyyyyyyz_xyzzzz_0[j] = pb_y * tg_yyyyyyz_xyzzzz_0[j] + fr * tg_yyyyyyz_xyzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xyzzzz_0[j] - tg_yyyyyz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_xzzzz_1[j];

                    tg_yyyyyyyz_xzzzzz_0[j] = pb_y * tg_yyyyyyz_xzzzzz_0[j] + fr * tg_yyyyyyz_xzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_xzzzzz_0[j] - tg_yyyyyz_xzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyyz_yyyyyy_0[j] = pb_y * tg_yyyyyyz_yyyyyy_0[j] + fr * tg_yyyyyyz_yyyyyy_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yyyyyy_0[j] - tg_yyyyyz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyyz_yyyyy_1[j];

                    tg_yyyyyyyz_yyyyyz_0[j] = pb_y * tg_yyyyyyz_yyyyyz_0[j] + fr * tg_yyyyyyz_yyyyyz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yyyyyz_0[j] - tg_yyyyyz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyyz_yyyyz_1[j];

                    tg_yyyyyyyz_yyyyzz_0[j] = pb_y * tg_yyyyyyz_yyyyzz_0[j] + fr * tg_yyyyyyz_yyyyzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yyyyzz_0[j] - tg_yyyyyz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyyz_yyyzz_1[j];

                    tg_yyyyyyyz_yyyzzz_0[j] = pb_y * tg_yyyyyyz_yyyzzz_0[j] + fr * tg_yyyyyyz_yyyzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yyyzzz_0[j] - tg_yyyyyz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyyz_yyzzz_1[j];

                    tg_yyyyyyyz_yyzzzz_0[j] = pb_y * tg_yyyyyyz_yyzzzz_0[j] + fr * tg_yyyyyyz_yyzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yyzzzz_0[j] - tg_yyyyyz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyyz_yzzzz_1[j];

                    tg_yyyyyyyz_yzzzzz_0[j] = pb_y * tg_yyyyyyz_yzzzzz_0[j] + fr * tg_yyyyyyz_yzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_yzzzzz_0[j] - tg_yyyyyz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyyz_zzzzz_1[j];

                    tg_yyyyyyyz_zzzzzz_0[j] = pb_y * tg_yyyyyyz_zzzzzz_0[j] + fr * tg_yyyyyyz_zzzzzz_1[j] + 3.0 * fl1_fx * (tg_yyyyyz_zzzzzz_0[j] - tg_yyyyyz_zzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyzz_xxxxxx_0[j] = pb_y * tg_yyyyyzz_xxxxxx_0[j] + fr * tg_yyyyyzz_xxxxxx_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxxx_0[j] - tg_yyyyzz_xxxxxx_1[j] * fl1_fza);

                    tg_yyyyyyzz_xxxxxy_0[j] = pb_y * tg_yyyyyzz_xxxxxy_0[j] + fr * tg_yyyyyzz_xxxxxy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxxy_0[j] - tg_yyyyzz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_xxxxx_1[j];

                    tg_yyyyyyzz_xxxxxz_0[j] = pb_y * tg_yyyyyzz_xxxxxz_0[j] + fr * tg_yyyyyzz_xxxxxz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxxz_0[j] - tg_yyyyzz_xxxxxz_1[j] * fl1_fza);
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_1067_1164(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1067,1164)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                // set up pointers to auxilary integrals

                auto tg_yyyyyzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 843); 

                auto tg_yyyyyzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 844); 

                auto tg_yyyyyzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 845); 

                auto tg_yyyyyzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 846); 

                auto tg_yyyyyzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 847); 

                auto tg_yyyyyzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 848); 

                auto tg_yyyyyzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 849); 

                auto tg_yyyyyzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 850); 

                auto tg_yyyyyzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 851); 

                auto tg_yyyyyzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 852); 

                auto tg_yyyyyzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 853); 

                auto tg_yyyyyzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 854); 

                auto tg_yyyyyzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 855); 

                auto tg_yyyyyzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 856); 

                auto tg_yyyyyzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 857); 

                auto tg_yyyyyzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 858); 

                auto tg_yyyyyzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 859); 

                auto tg_yyyyyzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 860); 

                auto tg_yyyyyzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 861); 

                auto tg_yyyyyzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 862); 

                auto tg_yyyyyzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 863); 

                auto tg_yyyyyzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 864); 

                auto tg_yyyyyzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 865); 

                auto tg_yyyyyzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 866); 

                auto tg_yyyyyzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 867); 

                auto tg_yyyyzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 868); 

                auto tg_yyyyzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 869); 

                auto tg_yyyyzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 870); 

                auto tg_yyyyzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 871); 

                auto tg_yyyyzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 872); 

                auto tg_yyyyzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 873); 

                auto tg_yyyyzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 874); 

                auto tg_yyyyzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 875); 

                auto tg_yyyyzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 876); 

                auto tg_yyyyzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 877); 

                auto tg_yyyyzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 878); 

                auto tg_yyyyzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 879); 

                auto tg_yyyyzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 880); 

                auto tg_yyyyzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 881); 

                auto tg_yyyyzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 882); 

                auto tg_yyyyzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 883); 

                auto tg_yyyyzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 884); 

                auto tg_yyyyzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 885); 

                auto tg_yyyyzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 886); 

                auto tg_yyyyzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 887); 

                auto tg_yyyyzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 888); 

                auto tg_yyyyzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 889); 

                auto tg_yyyyzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 890); 

                auto tg_yyyyzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 891); 

                auto tg_yyyyzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 892); 

                auto tg_yyyyzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 893); 

                auto tg_yyyyzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 894); 

                auto tg_yyyyzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 895); 

                auto tg_yyyzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 896); 

                auto tg_yyyzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 897); 

                auto tg_yyyzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 898); 

                auto tg_yyyzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 899); 

                auto tg_yyyzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 900); 

                auto tg_yyyzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 901); 

                auto tg_yyyzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 902); 

                auto tg_yyyzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 903); 

                auto tg_yyyzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 904); 

                auto tg_yyyzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 905); 

                auto tg_yyyzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 906); 

                auto tg_yyyzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 907); 

                auto tg_yyyzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 908); 

                auto tg_yyyzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 909); 

                auto tg_yyyzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 910); 

                auto tg_yyyzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 911); 

                auto tg_yyyzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 912); 

                auto tg_yyyzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 913); 

                auto tg_yyyzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 914); 

                auto tg_yyyzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 915); 

                auto tg_yyyzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 916); 

                auto tg_yyyzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 917); 

                auto tg_yyyzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 918); 

                auto tg_yyyzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 919); 

                auto tg_yyyzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 920); 

                auto tg_yyyzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 921); 

                auto tg_yyyzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 922); 

                auto tg_yyyzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 923); 

                auto tg_yyzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 924); 

                auto tg_yyzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 925); 

                auto tg_yyzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 926); 

                auto tg_yyzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 927); 

                auto tg_yyzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 928); 

                auto tg_yyzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 929); 

                auto tg_yyzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 930); 

                auto tg_yyzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 931); 

                auto tg_yyzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 932); 

                auto tg_yyzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 933); 

                auto tg_yyzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 934); 

                auto tg_yyzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 935); 

                auto tg_yyzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 936); 

                auto tg_yyzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 937); 

                auto tg_yyzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 938); 

                auto tg_yyzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 939); 

                auto tg_yyyyyzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 843); 

                auto tg_yyyyyzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 844); 

                auto tg_yyyyyzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 845); 

                auto tg_yyyyyzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 846); 

                auto tg_yyyyyzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 847); 

                auto tg_yyyyyzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 848); 

                auto tg_yyyyyzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 849); 

                auto tg_yyyyyzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 850); 

                auto tg_yyyyyzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 851); 

                auto tg_yyyyyzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 852); 

                auto tg_yyyyyzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 853); 

                auto tg_yyyyyzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 854); 

                auto tg_yyyyyzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 855); 

                auto tg_yyyyyzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 856); 

                auto tg_yyyyyzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 857); 

                auto tg_yyyyyzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 858); 

                auto tg_yyyyyzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 859); 

                auto tg_yyyyyzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 860); 

                auto tg_yyyyyzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 861); 

                auto tg_yyyyyzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 862); 

                auto tg_yyyyyzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 863); 

                auto tg_yyyyyzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 864); 

                auto tg_yyyyyzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 865); 

                auto tg_yyyyyzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 866); 

                auto tg_yyyyyzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 867); 

                auto tg_yyyyzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 868); 

                auto tg_yyyyzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 869); 

                auto tg_yyyyzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 870); 

                auto tg_yyyyzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 871); 

                auto tg_yyyyzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 872); 

                auto tg_yyyyzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 873); 

                auto tg_yyyyzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 874); 

                auto tg_yyyyzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 875); 

                auto tg_yyyyzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 876); 

                auto tg_yyyyzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 877); 

                auto tg_yyyyzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 878); 

                auto tg_yyyyzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 879); 

                auto tg_yyyyzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 880); 

                auto tg_yyyyzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 881); 

                auto tg_yyyyzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 882); 

                auto tg_yyyyzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 883); 

                auto tg_yyyyzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 884); 

                auto tg_yyyyzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 885); 

                auto tg_yyyyzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 886); 

                auto tg_yyyyzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 887); 

                auto tg_yyyyzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 888); 

                auto tg_yyyyzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 889); 

                auto tg_yyyyzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 890); 

                auto tg_yyyyzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 891); 

                auto tg_yyyyzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 892); 

                auto tg_yyyyzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 893); 

                auto tg_yyyyzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 894); 

                auto tg_yyyyzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 895); 

                auto tg_yyyzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 896); 

                auto tg_yyyzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 897); 

                auto tg_yyyzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 898); 

                auto tg_yyyzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 899); 

                auto tg_yyyzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 900); 

                auto tg_yyyzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 901); 

                auto tg_yyyzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 902); 

                auto tg_yyyzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 903); 

                auto tg_yyyzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 904); 

                auto tg_yyyzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 905); 

                auto tg_yyyzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 906); 

                auto tg_yyyzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 907); 

                auto tg_yyyzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 908); 

                auto tg_yyyzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 909); 

                auto tg_yyyzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 910); 

                auto tg_yyyzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 911); 

                auto tg_yyyzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 912); 

                auto tg_yyyzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 913); 

                auto tg_yyyzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 914); 

                auto tg_yyyzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 915); 

                auto tg_yyyzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 916); 

                auto tg_yyyzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 917); 

                auto tg_yyyzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 918); 

                auto tg_yyyzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 919); 

                auto tg_yyyzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 920); 

                auto tg_yyyzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 921); 

                auto tg_yyyzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 922); 

                auto tg_yyyzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 923); 

                auto tg_yyzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 924); 

                auto tg_yyzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 925); 

                auto tg_yyzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 926); 

                auto tg_yyzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 927); 

                auto tg_yyzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 928); 

                auto tg_yyzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 929); 

                auto tg_yyzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 930); 

                auto tg_yyzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 931); 

                auto tg_yyzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 932); 

                auto tg_yyzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 933); 

                auto tg_yyzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 934); 

                auto tg_yyzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 935); 

                auto tg_yyzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 936); 

                auto tg_yyzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 937); 

                auto tg_yyzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 938); 

                auto tg_yyzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 939); 

                auto tg_yyyyzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 656); 

                auto tg_yyyyzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 678); 

                auto tg_yyyzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 699); 

                auto tg_yyzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 733); 

                auto tg_yzzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 743); 

                auto tg_yyyyzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 647); 

                auto tg_yyyyzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 648); 

                auto tg_yyyyzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 649); 

                auto tg_yyyyzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 650); 

                auto tg_yyyyzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 651); 

                auto tg_yyyyzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 652); 

                auto tg_yyyyzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 653); 

                auto tg_yyyyzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 654); 

                auto tg_yyyyzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 655); 

                auto tg_yyyyzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 656); 

                auto tg_yyyyzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 657); 

                auto tg_yyyyzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 658); 

                auto tg_yyyyzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 659); 

                auto tg_yyyyzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 660); 

                auto tg_yyyyzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 661); 

                auto tg_yyyyzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 662); 

                auto tg_yyyyzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 663); 

                auto tg_yyyyzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 664); 

                auto tg_yyyyzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 665); 

                auto tg_yyyyzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 666); 

                auto tg_yyyyzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 667); 

                auto tg_yyyyzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 668); 

                auto tg_yyyyzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 669); 

                auto tg_yyyyzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 670); 

                auto tg_yyyyzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 671); 

                auto tg_yyyzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 672); 

                auto tg_yyyzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 673); 

                auto tg_yyyzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 674); 

                auto tg_yyyzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 675); 

                auto tg_yyyzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 676); 

                auto tg_yyyzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 677); 

                auto tg_yyyzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 678); 

                auto tg_yyyzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 679); 

                auto tg_yyyzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 680); 

                auto tg_yyyzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 681); 

                auto tg_yyyzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 682); 

                auto tg_yyyzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 683); 

                auto tg_yyyzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 684); 

                auto tg_yyyzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 685); 

                auto tg_yyyzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 686); 

                auto tg_yyyzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 687); 

                auto tg_yyyzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 688); 

                auto tg_yyyzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 689); 

                auto tg_yyyzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 690); 

                auto tg_yyyzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 691); 

                auto tg_yyyzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 692); 

                auto tg_yyyzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 693); 

                auto tg_yyyzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 694); 

                auto tg_yyyzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 695); 

                auto tg_yyyzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 696); 

                auto tg_yyyzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 697); 

                auto tg_yyyzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 698); 

                auto tg_yyyzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 699); 

                auto tg_yyzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 700); 

                auto tg_yyzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 701); 

                auto tg_yyzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 702); 

                auto tg_yyzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 703); 

                auto tg_yyzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 704); 

                auto tg_yyzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 705); 

                auto tg_yyzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 706); 

                auto tg_yyzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 707); 

                auto tg_yyzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 708); 

                auto tg_yyzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 709); 

                auto tg_yyzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 710); 

                auto tg_yyzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 711); 

                auto tg_yyzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 712); 

                auto tg_yyzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 713); 

                auto tg_yyzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 714); 

                auto tg_yyzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 715); 

                auto tg_yyzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 716); 

                auto tg_yyzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 717); 

                auto tg_yyzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 718); 

                auto tg_yyzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 719); 

                auto tg_yyzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 720); 

                auto tg_yyzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 721); 

                auto tg_yyzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 722); 

                auto tg_yyzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 723); 

                auto tg_yyzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 724); 

                auto tg_yyzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 725); 

                auto tg_yyzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 726); 

                auto tg_yyzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 727); 

                auto tg_yzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 728); 

                auto tg_yzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 729); 

                auto tg_yzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 730); 

                auto tg_yzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 731); 

                auto tg_yzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 732); 

                auto tg_yzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 733); 

                auto tg_yzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 734); 

                auto tg_yzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 735); 

                auto tg_yzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 736); 

                auto tg_yzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 737); 

                auto tg_yzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 738); 

                auto tg_yzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 739); 

                auto tg_yzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 740); 

                auto tg_yzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 741); 

                auto tg_yzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 742); 

                auto tg_yzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 743); 

                auto tg_yyyyyzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 631); 

                auto tg_yyyyyzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 632); 

                auto tg_yyyyyzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 633); 

                auto tg_yyyyyzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 634); 

                auto tg_yyyyyzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 635); 

                auto tg_yyyyyzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 636); 

                auto tg_yyyyyzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 637); 

                auto tg_yyyyyzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 638); 

                auto tg_yyyyyzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 639); 

                auto tg_yyyyyzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 640); 

                auto tg_yyyyyzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 641); 

                auto tg_yyyyyzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 642); 

                auto tg_yyyyyzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 643); 

                auto tg_yyyyyzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 644); 

                auto tg_yyyyyzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 645); 

                auto tg_yyyyyzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 646); 

                auto tg_yyyyyzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 647); 

                auto tg_yyyyyzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 648); 

                auto tg_yyyyyzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 649); 

                auto tg_yyyyyzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 650); 

                auto tg_yyyyzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 651); 

                auto tg_yyyyzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 652); 

                auto tg_yyyyzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 653); 

                auto tg_yyyyzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 654); 

                auto tg_yyyyzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 655); 

                auto tg_yyyyzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 656); 

                auto tg_yyyyzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 657); 

                auto tg_yyyyzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 658); 

                auto tg_yyyyzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 659); 

                auto tg_yyyyzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 660); 

                auto tg_yyyyzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 661); 

                auto tg_yyyyzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 662); 

                auto tg_yyyyzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 663); 

                auto tg_yyyyzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 664); 

                auto tg_yyyyzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 665); 

                auto tg_yyyyzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 666); 

                auto tg_yyyyzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 667); 

                auto tg_yyyyzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 668); 

                auto tg_yyyyzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 669); 

                auto tg_yyyyzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 670); 

                auto tg_yyyyzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 671); 

                auto tg_yyyzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 672); 

                auto tg_yyyzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 673); 

                auto tg_yyyzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 674); 

                auto tg_yyyzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 675); 

                auto tg_yyyzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 676); 

                auto tg_yyyzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 677); 

                auto tg_yyyzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 678); 

                auto tg_yyyzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 679); 

                auto tg_yyyzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 680); 

                auto tg_yyyzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 681); 

                auto tg_yyyzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 682); 

                auto tg_yyyzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 683); 

                auto tg_yyyzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 684); 

                auto tg_yyyzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 685); 

                auto tg_yyyzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 686); 

                auto tg_yyyzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 687); 

                auto tg_yyyzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 688); 

                auto tg_yyyzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 689); 

                auto tg_yyyzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 690); 

                auto tg_yyyzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 691); 

                auto tg_yyyzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 692); 

                auto tg_yyzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 693); 

                auto tg_yyzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 694); 

                auto tg_yyzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 695); 

                auto tg_yyzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 696); 

                auto tg_yyzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 697); 

                auto tg_yyzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 698); 

                auto tg_yyzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 699); 

                auto tg_yyzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 700); 

                auto tg_yyzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 701); 

                auto tg_yyzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 702); 

                auto tg_yyzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 703); 

                // set up pointers to integrals

                auto tg_yyyyyyzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1067); 

                auto tg_yyyyyyzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1068); 

                auto tg_yyyyyyzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1069); 

                auto tg_yyyyyyzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1070); 

                auto tg_yyyyyyzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1071); 

                auto tg_yyyyyyzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1072); 

                auto tg_yyyyyyzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1073); 

                auto tg_yyyyyyzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1074); 

                auto tg_yyyyyyzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1075); 

                auto tg_yyyyyyzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1076); 

                auto tg_yyyyyyzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1077); 

                auto tg_yyyyyyzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1078); 

                auto tg_yyyyyyzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1079); 

                auto tg_yyyyyyzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1080); 

                auto tg_yyyyyyzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1081); 

                auto tg_yyyyyyzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1082); 

                auto tg_yyyyyyzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1083); 

                auto tg_yyyyyyzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1084); 

                auto tg_yyyyyyzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1085); 

                auto tg_yyyyyyzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1086); 

                auto tg_yyyyyyzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1087); 

                auto tg_yyyyyyzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1088); 

                auto tg_yyyyyyzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1089); 

                auto tg_yyyyyyzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1090); 

                auto tg_yyyyyyzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1091); 

                auto tg_yyyyyzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1092); 

                auto tg_yyyyyzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1093); 

                auto tg_yyyyyzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1094); 

                auto tg_yyyyyzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1095); 

                auto tg_yyyyyzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1096); 

                auto tg_yyyyyzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1097); 

                auto tg_yyyyyzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1098); 

                auto tg_yyyyyzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1099); 

                auto tg_yyyyyzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1100); 

                auto tg_yyyyyzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1101); 

                auto tg_yyyyyzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1102); 

                auto tg_yyyyyzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1103); 

                auto tg_yyyyyzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1104); 

                auto tg_yyyyyzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1105); 

                auto tg_yyyyyzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1106); 

                auto tg_yyyyyzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1107); 

                auto tg_yyyyyzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1108); 

                auto tg_yyyyyzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1109); 

                auto tg_yyyyyzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1110); 

                auto tg_yyyyyzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1111); 

                auto tg_yyyyyzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1112); 

                auto tg_yyyyyzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1113); 

                auto tg_yyyyyzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1114); 

                auto tg_yyyyyzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1115); 

                auto tg_yyyyyzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1116); 

                auto tg_yyyyyzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1117); 

                auto tg_yyyyyzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1118); 

                auto tg_yyyyyzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1119); 

                auto tg_yyyyzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1120); 

                auto tg_yyyyzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1121); 

                auto tg_yyyyzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1122); 

                auto tg_yyyyzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1123); 

                auto tg_yyyyzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1124); 

                auto tg_yyyyzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1125); 

                auto tg_yyyyzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1126); 

                auto tg_yyyyzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1127); 

                auto tg_yyyyzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1128); 

                auto tg_yyyyzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1129); 

                auto tg_yyyyzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1130); 

                auto tg_yyyyzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1131); 

                auto tg_yyyyzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1132); 

                auto tg_yyyyzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1133); 

                auto tg_yyyyzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1134); 

                auto tg_yyyyzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1135); 

                auto tg_yyyyzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1136); 

                auto tg_yyyyzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1137); 

                auto tg_yyyyzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1138); 

                auto tg_yyyyzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1139); 

                auto tg_yyyyzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1140); 

                auto tg_yyyyzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1141); 

                auto tg_yyyyzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1142); 

                auto tg_yyyyzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1143); 

                auto tg_yyyyzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1144); 

                auto tg_yyyyzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1145); 

                auto tg_yyyyzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1146); 

                auto tg_yyyyzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1147); 

                auto tg_yyyzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1148); 

                auto tg_yyyzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1149); 

                auto tg_yyyzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1150); 

                auto tg_yyyzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1151); 

                auto tg_yyyzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1152); 

                auto tg_yyyzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1153); 

                auto tg_yyyzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1154); 

                auto tg_yyyzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1155); 

                auto tg_yyyzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1156); 

                auto tg_yyyzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1157); 

                auto tg_yyyzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1158); 

                auto tg_yyyzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1159); 

                auto tg_yyyzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1160); 

                auto tg_yyyzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1161); 

                auto tg_yyyzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1162); 

                auto tg_yyyzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1163); 

                // Batch of Integrals (1067,1164)

                #pragma omp simd aligned(fxn, fza, tg_yyyyyyzz_xxxxyy_0, tg_yyyyyyzz_xxxxyz_0, \
                                         tg_yyyyyyzz_xxxxzz_0, tg_yyyyyyzz_xxxyyy_0, tg_yyyyyyzz_xxxyyz_0, tg_yyyyyyzz_xxxyzz_0, \
                                         tg_yyyyyyzz_xxxzzz_0, tg_yyyyyyzz_xxyyyy_0, tg_yyyyyyzz_xxyyyz_0, tg_yyyyyyzz_xxyyzz_0, \
                                         tg_yyyyyyzz_xxyzzz_0, tg_yyyyyyzz_xxzzzz_0, tg_yyyyyyzz_xyyyyy_0, tg_yyyyyyzz_xyyyyz_0, \
                                         tg_yyyyyyzz_xyyyzz_0, tg_yyyyyyzz_xyyzzz_0, tg_yyyyyyzz_xyzzzz_0, tg_yyyyyyzz_xzzzzz_0, \
                                         tg_yyyyyyzz_yyyyyy_0, tg_yyyyyyzz_yyyyyz_0, tg_yyyyyyzz_yyyyzz_0, tg_yyyyyyzz_yyyzzz_0, \
                                         tg_yyyyyyzz_yyzzzz_0, tg_yyyyyyzz_yzzzzz_0, tg_yyyyyyzz_zzzzzz_0, tg_yyyyyzz_xxxxy_1, \
                                         tg_yyyyyzz_xxxxyy_0, tg_yyyyyzz_xxxxyy_1, tg_yyyyyzz_xxxxyz_0, tg_yyyyyzz_xxxxyz_1, \
                                         tg_yyyyyzz_xxxxz_1, tg_yyyyyzz_xxxxzz_0, tg_yyyyyzz_xxxxzz_1, tg_yyyyyzz_xxxyy_1, \
                                         tg_yyyyyzz_xxxyyy_0, tg_yyyyyzz_xxxyyy_1, tg_yyyyyzz_xxxyyz_0, tg_yyyyyzz_xxxyyz_1, \
                                         tg_yyyyyzz_xxxyz_1, tg_yyyyyzz_xxxyzz_0, tg_yyyyyzz_xxxyzz_1, tg_yyyyyzz_xxxzz_1, \
                                         tg_yyyyyzz_xxxzzz_0, tg_yyyyyzz_xxxzzz_1, tg_yyyyyzz_xxyyy_1, tg_yyyyyzz_xxyyyy_0, \
                                         tg_yyyyyzz_xxyyyy_1, tg_yyyyyzz_xxyyyz_0, tg_yyyyyzz_xxyyyz_1, tg_yyyyyzz_xxyyz_1, \
                                         tg_yyyyyzz_xxyyzz_0, tg_yyyyyzz_xxyyzz_1, tg_yyyyyzz_xxyzz_1, tg_yyyyyzz_xxyzzz_0, \
                                         tg_yyyyyzz_xxyzzz_1, tg_yyyyyzz_xxzzz_1, tg_yyyyyzz_xxzzzz_0, tg_yyyyyzz_xxzzzz_1, \
                                         tg_yyyyyzz_xyyyy_1, tg_yyyyyzz_xyyyyy_0, tg_yyyyyzz_xyyyyy_1, tg_yyyyyzz_xyyyyz_0, \
                                         tg_yyyyyzz_xyyyyz_1, tg_yyyyyzz_xyyyz_1, tg_yyyyyzz_xyyyzz_0, tg_yyyyyzz_xyyyzz_1, \
                                         tg_yyyyyzz_xyyzz_1, tg_yyyyyzz_xyyzzz_0, tg_yyyyyzz_xyyzzz_1, tg_yyyyyzz_xyzzz_1, \
                                         tg_yyyyyzz_xyzzzz_0, tg_yyyyyzz_xyzzzz_1, tg_yyyyyzz_xzzzz_1, tg_yyyyyzz_xzzzzz_0, \
                                         tg_yyyyyzz_xzzzzz_1, tg_yyyyyzz_yyyyy_1, tg_yyyyyzz_yyyyyy_0, tg_yyyyyzz_yyyyyy_1, \
                                         tg_yyyyyzz_yyyyyz_0, tg_yyyyyzz_yyyyyz_1, tg_yyyyyzz_yyyyz_1, tg_yyyyyzz_yyyyzz_0, \
                                         tg_yyyyyzz_yyyyzz_1, tg_yyyyyzz_yyyzz_1, tg_yyyyyzz_yyyzzz_0, tg_yyyyyzz_yyyzzz_1, \
                                         tg_yyyyyzz_yyzzz_1, tg_yyyyyzz_yyzzzz_0, tg_yyyyyzz_yyzzzz_1, tg_yyyyyzz_yzzzz_1, \
                                         tg_yyyyyzz_yzzzzz_0, tg_yyyyyzz_yzzzzz_1, tg_yyyyyzz_zzzzz_1, tg_yyyyyzz_zzzzzz_0, \
                                         tg_yyyyyzz_zzzzzz_1, tg_yyyyyzzz_xxxxxx_0, tg_yyyyyzzz_xxxxxy_0, tg_yyyyyzzz_xxxxxz_0, \
                                         tg_yyyyyzzz_xxxxyy_0, tg_yyyyyzzz_xxxxyz_0, tg_yyyyyzzz_xxxxzz_0, tg_yyyyyzzz_xxxyyy_0, \
                                         tg_yyyyyzzz_xxxyyz_0, tg_yyyyyzzz_xxxyzz_0, tg_yyyyyzzz_xxxzzz_0, tg_yyyyyzzz_xxyyyy_0, \
                                         tg_yyyyyzzz_xxyyyz_0, tg_yyyyyzzz_xxyyzz_0, tg_yyyyyzzz_xxyzzz_0, tg_yyyyyzzz_xxzzzz_0, \
                                         tg_yyyyyzzz_xyyyyy_0, tg_yyyyyzzz_xyyyyz_0, tg_yyyyyzzz_xyyyzz_0, tg_yyyyyzzz_xyyzzz_0, \
                                         tg_yyyyyzzz_xyzzzz_0, tg_yyyyyzzz_xzzzzz_0, tg_yyyyyzzz_yyyyyy_0, tg_yyyyyzzz_yyyyyz_0, \
                                         tg_yyyyyzzz_yyyyzz_0, tg_yyyyyzzz_yyyzzz_0, tg_yyyyyzzz_yyzzzz_0, tg_yyyyyzzz_yzzzzz_0, \
                                         tg_yyyyyzzz_zzzzzz_0, tg_yyyyzz_xxxxyy_0, tg_yyyyzz_xxxxyy_1, tg_yyyyzz_xxxxyz_0, \
                                         tg_yyyyzz_xxxxyz_1, tg_yyyyzz_xxxxzz_0, tg_yyyyzz_xxxxzz_1, tg_yyyyzz_xxxyyy_0, \
                                         tg_yyyyzz_xxxyyy_1, tg_yyyyzz_xxxyyz_0, tg_yyyyzz_xxxyyz_1, tg_yyyyzz_xxxyzz_0, \
                                         tg_yyyyzz_xxxyzz_1, tg_yyyyzz_xxxzzz_0, tg_yyyyzz_xxxzzz_1, tg_yyyyzz_xxyyyy_0, \
                                         tg_yyyyzz_xxyyyy_1, tg_yyyyzz_xxyyyz_0, tg_yyyyzz_xxyyyz_1, tg_yyyyzz_xxyyzz_0, \
                                         tg_yyyyzz_xxyyzz_1, tg_yyyyzz_xxyzzz_0, tg_yyyyzz_xxyzzz_1, tg_yyyyzz_xxzzzz_0, \
                                         tg_yyyyzz_xxzzzz_1, tg_yyyyzz_xyyyyy_0, tg_yyyyzz_xyyyyy_1, tg_yyyyzz_xyyyyz_0, \
                                         tg_yyyyzz_xyyyyz_1, tg_yyyyzz_xyyyzz_0, tg_yyyyzz_xyyyzz_1, tg_yyyyzz_xyyzzz_0, \
                                         tg_yyyyzz_xyyzzz_1, tg_yyyyzz_xyzzzz_0, tg_yyyyzz_xyzzzz_1, tg_yyyyzz_xzzzzz_0, \
                                         tg_yyyyzz_xzzzzz_1, tg_yyyyzz_yyyyyy_0, tg_yyyyzz_yyyyyy_1, tg_yyyyzz_yyyyyz_0, \
                                         tg_yyyyzz_yyyyyz_1, tg_yyyyzz_yyyyzz_0, tg_yyyyzz_yyyyzz_1, tg_yyyyzz_yyyzzz_0, \
                                         tg_yyyyzz_yyyzzz_1, tg_yyyyzz_yyzzzz_0, tg_yyyyzz_yyzzzz_1, tg_yyyyzz_yzzzzz_0, \
                                         tg_yyyyzz_yzzzzz_1, tg_yyyyzz_zzzzzz_0, tg_yyyyzz_zzzzzz_1, tg_yyyyzzz_xxxxx_1, \
                                         tg_yyyyzzz_xxxxxx_0, tg_yyyyzzz_xxxxxx_1, tg_yyyyzzz_xxxxxy_0, tg_yyyyzzz_xxxxxy_1, \
                                         tg_yyyyzzz_xxxxxz_0, tg_yyyyzzz_xxxxxz_1, tg_yyyyzzz_xxxxy_1, tg_yyyyzzz_xxxxyy_0, \
                                         tg_yyyyzzz_xxxxyy_1, tg_yyyyzzz_xxxxyz_0, tg_yyyyzzz_xxxxyz_1, tg_yyyyzzz_xxxxz_1, \
                                         tg_yyyyzzz_xxxxzz_0, tg_yyyyzzz_xxxxzz_1, tg_yyyyzzz_xxxyy_1, tg_yyyyzzz_xxxyyy_0, \
                                         tg_yyyyzzz_xxxyyy_1, tg_yyyyzzz_xxxyyz_0, tg_yyyyzzz_xxxyyz_1, tg_yyyyzzz_xxxyz_1, \
                                         tg_yyyyzzz_xxxyzz_0, tg_yyyyzzz_xxxyzz_1, tg_yyyyzzz_xxxzz_1, tg_yyyyzzz_xxxzzz_0, \
                                         tg_yyyyzzz_xxxzzz_1, tg_yyyyzzz_xxyyy_1, tg_yyyyzzz_xxyyyy_0, tg_yyyyzzz_xxyyyy_1, \
                                         tg_yyyyzzz_xxyyyz_0, tg_yyyyzzz_xxyyyz_1, tg_yyyyzzz_xxyyz_1, tg_yyyyzzz_xxyyzz_0, \
                                         tg_yyyyzzz_xxyyzz_1, tg_yyyyzzz_xxyzz_1, tg_yyyyzzz_xxyzzz_0, tg_yyyyzzz_xxyzzz_1, \
                                         tg_yyyyzzz_xxzzz_1, tg_yyyyzzz_xxzzzz_0, tg_yyyyzzz_xxzzzz_1, tg_yyyyzzz_xyyyy_1, \
                                         tg_yyyyzzz_xyyyyy_0, tg_yyyyzzz_xyyyyy_1, tg_yyyyzzz_xyyyyz_0, tg_yyyyzzz_xyyyyz_1, \
                                         tg_yyyyzzz_xyyyz_1, tg_yyyyzzz_xyyyzz_0, tg_yyyyzzz_xyyyzz_1, tg_yyyyzzz_xyyzz_1, \
                                         tg_yyyyzzz_xyyzzz_0, tg_yyyyzzz_xyyzzz_1, tg_yyyyzzz_xyzzz_1, tg_yyyyzzz_xyzzzz_0, \
                                         tg_yyyyzzz_xyzzzz_1, tg_yyyyzzz_xzzzz_1, tg_yyyyzzz_xzzzzz_0, tg_yyyyzzz_xzzzzz_1, \
                                         tg_yyyyzzz_yyyyy_1, tg_yyyyzzz_yyyyyy_0, tg_yyyyzzz_yyyyyy_1, tg_yyyyzzz_yyyyyz_0, \
                                         tg_yyyyzzz_yyyyyz_1, tg_yyyyzzz_yyyyz_1, tg_yyyyzzz_yyyyzz_0, tg_yyyyzzz_yyyyzz_1, \
                                         tg_yyyyzzz_yyyzz_1, tg_yyyyzzz_yyyzzz_0, tg_yyyyzzz_yyyzzz_1, tg_yyyyzzz_yyzzz_1, \
                                         tg_yyyyzzz_yyzzzz_0, tg_yyyyzzz_yyzzzz_1, tg_yyyyzzz_yzzzz_1, tg_yyyyzzz_yzzzzz_0, \
                                         tg_yyyyzzz_yzzzzz_1, tg_yyyyzzz_zzzzz_1, tg_yyyyzzz_zzzzzz_0, tg_yyyyzzz_zzzzzz_1, \
                                         tg_yyyyzzzz_xxxxxx_0, tg_yyyyzzzz_xxxxxy_0, tg_yyyyzzzz_xxxxxz_0, tg_yyyyzzzz_xxxxyy_0, \
                                         tg_yyyyzzzz_xxxxyz_0, tg_yyyyzzzz_xxxxzz_0, tg_yyyyzzzz_xxxyyy_0, tg_yyyyzzzz_xxxyyz_0, \
                                         tg_yyyyzzzz_xxxyzz_0, tg_yyyyzzzz_xxxzzz_0, tg_yyyyzzzz_xxyyyy_0, tg_yyyyzzzz_xxyyyz_0, \
                                         tg_yyyyzzzz_xxyyzz_0, tg_yyyyzzzz_xxyzzz_0, tg_yyyyzzzz_xxzzzz_0, tg_yyyyzzzz_xyyyyy_0, \
                                         tg_yyyyzzzz_xyyyyz_0, tg_yyyyzzzz_xyyyzz_0, tg_yyyyzzzz_xyyzzz_0, tg_yyyyzzzz_xyzzzz_0, \
                                         tg_yyyyzzzz_xzzzzz_0, tg_yyyyzzzz_yyyyyy_0, tg_yyyyzzzz_yyyyyz_0, tg_yyyyzzzz_yyyyzz_0, \
                                         tg_yyyyzzzz_yyyzzz_0, tg_yyyyzzzz_yyzzzz_0, tg_yyyyzzzz_yzzzzz_0, tg_yyyyzzzz_zzzzzz_0, \
                                         tg_yyyzzz_xxxxxx_0, tg_yyyzzz_xxxxxx_1, tg_yyyzzz_xxxxxy_0, tg_yyyzzz_xxxxxy_1, \
                                         tg_yyyzzz_xxxxxz_0, tg_yyyzzz_xxxxxz_1, tg_yyyzzz_xxxxyy_0, tg_yyyzzz_xxxxyy_1, \
                                         tg_yyyzzz_xxxxyz_0, tg_yyyzzz_xxxxyz_1, tg_yyyzzz_xxxxzz_0, tg_yyyzzz_xxxxzz_1, \
                                         tg_yyyzzz_xxxyyy_0, tg_yyyzzz_xxxyyy_1, tg_yyyzzz_xxxyyz_0, tg_yyyzzz_xxxyyz_1, \
                                         tg_yyyzzz_xxxyzz_0, tg_yyyzzz_xxxyzz_1, tg_yyyzzz_xxxzzz_0, tg_yyyzzz_xxxzzz_1, \
                                         tg_yyyzzz_xxyyyy_0, tg_yyyzzz_xxyyyy_1, tg_yyyzzz_xxyyyz_0, tg_yyyzzz_xxyyyz_1, \
                                         tg_yyyzzz_xxyyzz_0, tg_yyyzzz_xxyyzz_1, tg_yyyzzz_xxyzzz_0, tg_yyyzzz_xxyzzz_1, \
                                         tg_yyyzzz_xxzzzz_0, tg_yyyzzz_xxzzzz_1, tg_yyyzzz_xyyyyy_0, tg_yyyzzz_xyyyyy_1, \
                                         tg_yyyzzz_xyyyyz_0, tg_yyyzzz_xyyyyz_1, tg_yyyzzz_xyyyzz_0, tg_yyyzzz_xyyyzz_1, \
                                         tg_yyyzzz_xyyzzz_0, tg_yyyzzz_xyyzzz_1, tg_yyyzzz_xyzzzz_0, tg_yyyzzz_xyzzzz_1, \
                                         tg_yyyzzz_xzzzzz_0, tg_yyyzzz_xzzzzz_1, tg_yyyzzz_yyyyyy_0, tg_yyyzzz_yyyyyy_1, \
                                         tg_yyyzzz_yyyyyz_0, tg_yyyzzz_yyyyyz_1, tg_yyyzzz_yyyyzz_0, tg_yyyzzz_yyyyzz_1, \
                                         tg_yyyzzz_yyyzzz_0, tg_yyyzzz_yyyzzz_1, tg_yyyzzz_yyzzzz_0, tg_yyyzzz_yyzzzz_1, \
                                         tg_yyyzzz_yzzzzz_0, tg_yyyzzz_yzzzzz_1, tg_yyyzzz_zzzzzz_0, tg_yyyzzz_zzzzzz_1, \
                                         tg_yyyzzzz_xxxxx_1, tg_yyyzzzz_xxxxxx_0, tg_yyyzzzz_xxxxxx_1, tg_yyyzzzz_xxxxxy_0, \
                                         tg_yyyzzzz_xxxxxy_1, tg_yyyzzzz_xxxxxz_0, tg_yyyzzzz_xxxxxz_1, tg_yyyzzzz_xxxxy_1, \
                                         tg_yyyzzzz_xxxxyy_0, tg_yyyzzzz_xxxxyy_1, tg_yyyzzzz_xxxxyz_0, tg_yyyzzzz_xxxxyz_1, \
                                         tg_yyyzzzz_xxxxz_1, tg_yyyzzzz_xxxxzz_0, tg_yyyzzzz_xxxxzz_1, tg_yyyzzzz_xxxyy_1, \
                                         tg_yyyzzzz_xxxyyy_0, tg_yyyzzzz_xxxyyy_1, tg_yyyzzzz_xxxyyz_0, tg_yyyzzzz_xxxyyz_1, \
                                         tg_yyyzzzz_xxxyz_1, tg_yyyzzzz_xxxyzz_0, tg_yyyzzzz_xxxyzz_1, tg_yyyzzzz_xxxzz_1, \
                                         tg_yyyzzzz_xxxzzz_0, tg_yyyzzzz_xxxzzz_1, tg_yyyzzzz_xxyyy_1, tg_yyyzzzz_xxyyyy_0, \
                                         tg_yyyzzzz_xxyyyy_1, tg_yyyzzzz_xxyyyz_0, tg_yyyzzzz_xxyyyz_1, tg_yyyzzzz_xxyyz_1, \
                                         tg_yyyzzzz_xxyyzz_0, tg_yyyzzzz_xxyyzz_1, tg_yyyzzzz_xxyzz_1, tg_yyyzzzz_xxyzzz_0, \
                                         tg_yyyzzzz_xxyzzz_1, tg_yyyzzzz_xxzzz_1, tg_yyyzzzz_xxzzzz_0, tg_yyyzzzz_xxzzzz_1, \
                                         tg_yyyzzzz_xyyyy_1, tg_yyyzzzz_xyyyyy_0, tg_yyyzzzz_xyyyyy_1, tg_yyyzzzz_xyyyyz_0, \
                                         tg_yyyzzzz_xyyyyz_1, tg_yyyzzzz_xyyyz_1, tg_yyyzzzz_xyyyzz_0, tg_yyyzzzz_xyyyzz_1, \
                                         tg_yyyzzzz_xyyzz_1, tg_yyyzzzz_xyyzzz_0, tg_yyyzzzz_xyyzzz_1, tg_yyyzzzz_xyzzz_1, \
                                         tg_yyyzzzz_xyzzzz_0, tg_yyyzzzz_xyzzzz_1, tg_yyyzzzz_xzzzz_1, tg_yyyzzzz_xzzzzz_0, \
                                         tg_yyyzzzz_xzzzzz_1, tg_yyyzzzz_yyyyy_1, tg_yyyzzzz_yyyyyy_0, tg_yyyzzzz_yyyyyy_1, \
                                         tg_yyyzzzz_yyyyyz_0, tg_yyyzzzz_yyyyyz_1, tg_yyyzzzz_yyyyz_1, tg_yyyzzzz_yyyyzz_0, \
                                         tg_yyyzzzz_yyyyzz_1, tg_yyyzzzz_yyyzz_1, tg_yyyzzzz_yyyzzz_0, tg_yyyzzzz_yyyzzz_1, \
                                         tg_yyyzzzz_yyzzz_1, tg_yyyzzzz_yyzzzz_0, tg_yyyzzzz_yyzzzz_1, tg_yyyzzzz_yzzzz_1, \
                                         tg_yyyzzzz_yzzzzz_0, tg_yyyzzzz_yzzzzz_1, tg_yyyzzzz_zzzzz_1, tg_yyyzzzz_zzzzzz_0, \
                                         tg_yyyzzzz_zzzzzz_1, tg_yyyzzzzz_xxxxxx_0, tg_yyyzzzzz_xxxxxy_0, tg_yyyzzzzz_xxxxxz_0, \
                                         tg_yyyzzzzz_xxxxyy_0, tg_yyyzzzzz_xxxxyz_0, tg_yyyzzzzz_xxxxzz_0, tg_yyyzzzzz_xxxyyy_0, \
                                         tg_yyyzzzzz_xxxyyz_0, tg_yyyzzzzz_xxxyzz_0, tg_yyyzzzzz_xxxzzz_0, tg_yyyzzzzz_xxyyyy_0, \
                                         tg_yyyzzzzz_xxyyyz_0, tg_yyyzzzzz_xxyyzz_0, tg_yyyzzzzz_xxyzzz_0, tg_yyyzzzzz_xxzzzz_0, \
                                         tg_yyyzzzzz_xyyyyy_0, tg_yyzzzz_xxxxxx_0, tg_yyzzzz_xxxxxx_1, tg_yyzzzz_xxxxxy_0, \
                                         tg_yyzzzz_xxxxxy_1, tg_yyzzzz_xxxxxz_0, tg_yyzzzz_xxxxxz_1, tg_yyzzzz_xxxxyy_0, \
                                         tg_yyzzzz_xxxxyy_1, tg_yyzzzz_xxxxyz_0, tg_yyzzzz_xxxxyz_1, tg_yyzzzz_xxxxzz_0, \
                                         tg_yyzzzz_xxxxzz_1, tg_yyzzzz_xxxyyy_0, tg_yyzzzz_xxxyyy_1, tg_yyzzzz_xxxyyz_0, \
                                         tg_yyzzzz_xxxyyz_1, tg_yyzzzz_xxxyzz_0, tg_yyzzzz_xxxyzz_1, tg_yyzzzz_xxxzzz_0, \
                                         tg_yyzzzz_xxxzzz_1, tg_yyzzzz_xxyyyy_0, tg_yyzzzz_xxyyyy_1, tg_yyzzzz_xxyyyz_0, \
                                         tg_yyzzzz_xxyyyz_1, tg_yyzzzz_xxyyzz_0, tg_yyzzzz_xxyyzz_1, tg_yyzzzz_xxyzzz_0, \
                                         tg_yyzzzz_xxyzzz_1, tg_yyzzzz_xxzzzz_0, tg_yyzzzz_xxzzzz_1, tg_yyzzzz_xyyyyy_0, \
                                         tg_yyzzzz_xyyyyy_1, tg_yyzzzz_xyyyyz_0, tg_yyzzzz_xyyyyz_1, tg_yyzzzz_xyyyzz_0, \
                                         tg_yyzzzz_xyyyzz_1, tg_yyzzzz_xyyzzz_0, tg_yyzzzz_xyyzzz_1, tg_yyzzzz_xyzzzz_0, \
                                         tg_yyzzzz_xyzzzz_1, tg_yyzzzz_xzzzzz_0, tg_yyzzzz_xzzzzz_1, tg_yyzzzz_yyyyyy_0, \
                                         tg_yyzzzz_yyyyyy_1, tg_yyzzzz_yyyyyz_0, tg_yyzzzz_yyyyyz_1, tg_yyzzzz_yyyyzz_0, \
                                         tg_yyzzzz_yyyyzz_1, tg_yyzzzz_yyyzzz_0, tg_yyzzzz_yyyzzz_1, tg_yyzzzz_yyzzzz_0, \
                                         tg_yyzzzz_yyzzzz_1, tg_yyzzzz_yzzzzz_0, tg_yyzzzz_yzzzzz_1, tg_yyzzzz_zzzzzz_0, \
                                         tg_yyzzzz_zzzzzz_1, tg_yyzzzzz_xxxxx_1, tg_yyzzzzz_xxxxxx_0, tg_yyzzzzz_xxxxxx_1, \
                                         tg_yyzzzzz_xxxxxy_0, tg_yyzzzzz_xxxxxy_1, tg_yyzzzzz_xxxxxz_0, tg_yyzzzzz_xxxxxz_1, \
                                         tg_yyzzzzz_xxxxy_1, tg_yyzzzzz_xxxxyy_0, tg_yyzzzzz_xxxxyy_1, tg_yyzzzzz_xxxxyz_0, \
                                         tg_yyzzzzz_xxxxyz_1, tg_yyzzzzz_xxxxz_1, tg_yyzzzzz_xxxxzz_0, tg_yyzzzzz_xxxxzz_1, \
                                         tg_yyzzzzz_xxxyy_1, tg_yyzzzzz_xxxyyy_0, tg_yyzzzzz_xxxyyy_1, tg_yyzzzzz_xxxyyz_0, \
                                         tg_yyzzzzz_xxxyyz_1, tg_yyzzzzz_xxxyz_1, tg_yyzzzzz_xxxyzz_0, tg_yyzzzzz_xxxyzz_1, \
                                         tg_yyzzzzz_xxxzz_1, tg_yyzzzzz_xxxzzz_0, tg_yyzzzzz_xxxzzz_1, tg_yyzzzzz_xxyyy_1, \
                                         tg_yyzzzzz_xxyyyy_0, tg_yyzzzzz_xxyyyy_1, tg_yyzzzzz_xxyyyz_0, tg_yyzzzzz_xxyyyz_1, \
                                         tg_yyzzzzz_xxyyz_1, tg_yyzzzzz_xxyyzz_0, tg_yyzzzzz_xxyyzz_1, tg_yyzzzzz_xxyzz_1, \
                                         tg_yyzzzzz_xxyzzz_0, tg_yyzzzzz_xxyzzz_1, tg_yyzzzzz_xxzzz_1, tg_yyzzzzz_xxzzzz_0, \
                                         tg_yyzzzzz_xxzzzz_1, tg_yyzzzzz_xyyyy_1, tg_yyzzzzz_xyyyyy_0, tg_yyzzzzz_xyyyyy_1, \
                                         tg_yzzzzz_xxxxxx_0, tg_yzzzzz_xxxxxx_1, tg_yzzzzz_xxxxxy_0, tg_yzzzzz_xxxxxy_1, \
                                         tg_yzzzzz_xxxxxz_0, tg_yzzzzz_xxxxxz_1, tg_yzzzzz_xxxxyy_0, tg_yzzzzz_xxxxyy_1, \
                                         tg_yzzzzz_xxxxyz_0, tg_yzzzzz_xxxxyz_1, tg_yzzzzz_xxxxzz_0, tg_yzzzzz_xxxxzz_1, \
                                         tg_yzzzzz_xxxyyy_0, tg_yzzzzz_xxxyyy_1, tg_yzzzzz_xxxyyz_0, tg_yzzzzz_xxxyyz_1, \
                                         tg_yzzzzz_xxxyzz_0, tg_yzzzzz_xxxyzz_1, tg_yzzzzz_xxxzzz_0, tg_yzzzzz_xxxzzz_1, \
                                         tg_yzzzzz_xxyyyy_0, tg_yzzzzz_xxyyyy_1, tg_yzzzzz_xxyyyz_0, tg_yzzzzz_xxyyyz_1, \
                                         tg_yzzzzz_xxyyzz_0, tg_yzzzzz_xxyyzz_1, tg_yzzzzz_xxyzzz_0, tg_yzzzzz_xxyzzz_1, \
                                         tg_yzzzzz_xxzzzz_0, tg_yzzzzz_xxzzzz_1, tg_yzzzzz_xyyyyy_0, tg_yzzzzz_xyyyyy_1, wp_y: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyyyyyzz_xxxxyy_0[j] = pb_y * tg_yyyyyzz_xxxxyy_0[j] + fr * tg_yyyyyzz_xxxxyy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxyy_0[j] - tg_yyyyzz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_xxxxy_1[j];

                    tg_yyyyyyzz_xxxxyz_0[j] = pb_y * tg_yyyyyzz_xxxxyz_0[j] + fr * tg_yyyyyzz_xxxxyz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxyz_0[j] - tg_yyyyzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_xxxxz_1[j];

                    tg_yyyyyyzz_xxxxzz_0[j] = pb_y * tg_yyyyyzz_xxxxzz_0[j] + fr * tg_yyyyyzz_xxxxzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxxzz_0[j] - tg_yyyyzz_xxxxzz_1[j] * fl1_fza);

                    tg_yyyyyyzz_xxxyyy_0[j] = pb_y * tg_yyyyyzz_xxxyyy_0[j] + fr * tg_yyyyyzz_xxxyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxyyy_0[j] - tg_yyyyzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyzz_xxxyy_1[j];

                    tg_yyyyyyzz_xxxyyz_0[j] = pb_y * tg_yyyyyzz_xxxyyz_0[j] + fr * tg_yyyyyzz_xxxyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxyyz_0[j] - tg_yyyyzz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_xxxyz_1[j];

                    tg_yyyyyyzz_xxxyzz_0[j] = pb_y * tg_yyyyyzz_xxxyzz_0[j] + fr * tg_yyyyyzz_xxxyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxyzz_0[j] - tg_yyyyzz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_xxxzz_1[j];

                    tg_yyyyyyzz_xxxzzz_0[j] = pb_y * tg_yyyyyzz_xxxzzz_0[j] + fr * tg_yyyyyzz_xxxzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxxzzz_0[j] - tg_yyyyzz_xxxzzz_1[j] * fl1_fza);

                    tg_yyyyyyzz_xxyyyy_0[j] = pb_y * tg_yyyyyzz_xxyyyy_0[j] + fr * tg_yyyyyzz_xxyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxyyyy_0[j] - tg_yyyyzz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyzz_xxyyy_1[j];

                    tg_yyyyyyzz_xxyyyz_0[j] = pb_y * tg_yyyyyzz_xxyyyz_0[j] + fr * tg_yyyyyzz_xxyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxyyyz_0[j] - tg_yyyyzz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyzz_xxyyz_1[j];

                    tg_yyyyyyzz_xxyyzz_0[j] = pb_y * tg_yyyyyzz_xxyyzz_0[j] + fr * tg_yyyyyzz_xxyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxyyzz_0[j] - tg_yyyyzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_xxyzz_1[j];

                    tg_yyyyyyzz_xxyzzz_0[j] = pb_y * tg_yyyyyzz_xxyzzz_0[j] + fr * tg_yyyyyzz_xxyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxyzzz_0[j] - tg_yyyyzz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_xxzzz_1[j];

                    tg_yyyyyyzz_xxzzzz_0[j] = pb_y * tg_yyyyyzz_xxzzzz_0[j] + fr * tg_yyyyyzz_xxzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xxzzzz_0[j] - tg_yyyyzz_xxzzzz_1[j] * fl1_fza);

                    tg_yyyyyyzz_xyyyyy_0[j] = pb_y * tg_yyyyyzz_xyyyyy_0[j] + fr * tg_yyyyyzz_xyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xyyyyy_0[j] - tg_yyyyzz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyzz_xyyyy_1[j];

                    tg_yyyyyyzz_xyyyyz_0[j] = pb_y * tg_yyyyyzz_xyyyyz_0[j] + fr * tg_yyyyyzz_xyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xyyyyz_0[j] - tg_yyyyzz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyzz_xyyyz_1[j];

                    tg_yyyyyyzz_xyyyzz_0[j] = pb_y * tg_yyyyyzz_xyyyzz_0[j] + fr * tg_yyyyyzz_xyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xyyyzz_0[j] - tg_yyyyzz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyzz_xyyzz_1[j];

                    tg_yyyyyyzz_xyyzzz_0[j] = pb_y * tg_yyyyyzz_xyyzzz_0[j] + fr * tg_yyyyyzz_xyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xyyzzz_0[j] - tg_yyyyzz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_xyzzz_1[j];

                    tg_yyyyyyzz_xyzzzz_0[j] = pb_y * tg_yyyyyzz_xyzzzz_0[j] + fr * tg_yyyyyzz_xyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xyzzzz_0[j] - tg_yyyyzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_xzzzz_1[j];

                    tg_yyyyyyzz_xzzzzz_0[j] = pb_y * tg_yyyyyzz_xzzzzz_0[j] + fr * tg_yyyyyzz_xzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_xzzzzz_0[j] - tg_yyyyzz_xzzzzz_1[j] * fl1_fza);

                    tg_yyyyyyzz_yyyyyy_0[j] = pb_y * tg_yyyyyzz_yyyyyy_0[j] + fr * tg_yyyyyzz_yyyyyy_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yyyyyy_0[j] - tg_yyyyzz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyyzz_yyyyy_1[j];

                    tg_yyyyyyzz_yyyyyz_0[j] = pb_y * tg_yyyyyzz_yyyyyz_0[j] + fr * tg_yyyyyzz_yyyyyz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yyyyyz_0[j] - tg_yyyyzz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyyzz_yyyyz_1[j];

                    tg_yyyyyyzz_yyyyzz_0[j] = pb_y * tg_yyyyyzz_yyyyzz_0[j] + fr * tg_yyyyyzz_yyyyzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yyyyzz_0[j] - tg_yyyyzz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyyzz_yyyzz_1[j];

                    tg_yyyyyyzz_yyyzzz_0[j] = pb_y * tg_yyyyyzz_yyyzzz_0[j] + fr * tg_yyyyyzz_yyyzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yyyzzz_0[j] - tg_yyyyzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyyzz_yyzzz_1[j];

                    tg_yyyyyyzz_yyzzzz_0[j] = pb_y * tg_yyyyyzz_yyzzzz_0[j] + fr * tg_yyyyyzz_yyzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yyzzzz_0[j] - tg_yyyyzz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyyzz_yzzzz_1[j];

                    tg_yyyyyyzz_yzzzzz_0[j] = pb_y * tg_yyyyyzz_yzzzzz_0[j] + fr * tg_yyyyyzz_yzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_yzzzzz_0[j] - tg_yyyyzz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyyzz_zzzzz_1[j];

                    tg_yyyyyyzz_zzzzzz_0[j] = pb_y * tg_yyyyyzz_zzzzzz_0[j] + fr * tg_yyyyyzz_zzzzzz_1[j] + 2.5 * fl1_fx * (tg_yyyyzz_zzzzzz_0[j] - tg_yyyyzz_zzzzzz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xxxxxx_0[j] = pb_y * tg_yyyyzzz_xxxxxx_0[j] + fr * tg_yyyyzzz_xxxxxx_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxxx_0[j] - tg_yyyzzz_xxxxxx_1[j] * fl1_fza);

                    tg_yyyyyzzz_xxxxxy_0[j] = pb_y * tg_yyyyzzz_xxxxxy_0[j] + fr * tg_yyyyzzz_xxxxxy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxxy_0[j] - tg_yyyzzz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_xxxxx_1[j];

                    tg_yyyyyzzz_xxxxxz_0[j] = pb_y * tg_yyyyzzz_xxxxxz_0[j] + fr * tg_yyyyzzz_xxxxxz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxxz_0[j] - tg_yyyzzz_xxxxxz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xxxxyy_0[j] = pb_y * tg_yyyyzzz_xxxxyy_0[j] + fr * tg_yyyyzzz_xxxxyy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxyy_0[j] - tg_yyyzzz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_xxxxy_1[j];

                    tg_yyyyyzzz_xxxxyz_0[j] = pb_y * tg_yyyyzzz_xxxxyz_0[j] + fr * tg_yyyyzzz_xxxxyz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxyz_0[j] - tg_yyyzzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_xxxxz_1[j];

                    tg_yyyyyzzz_xxxxzz_0[j] = pb_y * tg_yyyyzzz_xxxxzz_0[j] + fr * tg_yyyyzzz_xxxxzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxxzz_0[j] - tg_yyyzzz_xxxxzz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xxxyyy_0[j] = pb_y * tg_yyyyzzz_xxxyyy_0[j] + fr * tg_yyyyzzz_xxxyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxyyy_0[j] - tg_yyyzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzzz_xxxyy_1[j];

                    tg_yyyyyzzz_xxxyyz_0[j] = pb_y * tg_yyyyzzz_xxxyyz_0[j] + fr * tg_yyyyzzz_xxxyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxyyz_0[j] - tg_yyyzzz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_xxxyz_1[j];

                    tg_yyyyyzzz_xxxyzz_0[j] = pb_y * tg_yyyyzzz_xxxyzz_0[j] + fr * tg_yyyyzzz_xxxyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxyzz_0[j] - tg_yyyzzz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_xxxzz_1[j];

                    tg_yyyyyzzz_xxxzzz_0[j] = pb_y * tg_yyyyzzz_xxxzzz_0[j] + fr * tg_yyyyzzz_xxxzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxxzzz_0[j] - tg_yyyzzz_xxxzzz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xxyyyy_0[j] = pb_y * tg_yyyyzzz_xxyyyy_0[j] + fr * tg_yyyyzzz_xxyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxyyyy_0[j] - tg_yyyzzz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzzz_xxyyy_1[j];

                    tg_yyyyyzzz_xxyyyz_0[j] = pb_y * tg_yyyyzzz_xxyyyz_0[j] + fr * tg_yyyyzzz_xxyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxyyyz_0[j] - tg_yyyzzz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzzz_xxyyz_1[j];

                    tg_yyyyyzzz_xxyyzz_0[j] = pb_y * tg_yyyyzzz_xxyyzz_0[j] + fr * tg_yyyyzzz_xxyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxyyzz_0[j] - tg_yyyzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_xxyzz_1[j];

                    tg_yyyyyzzz_xxyzzz_0[j] = pb_y * tg_yyyyzzz_xxyzzz_0[j] + fr * tg_yyyyzzz_xxyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxyzzz_0[j] - tg_yyyzzz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_xxzzz_1[j];

                    tg_yyyyyzzz_xxzzzz_0[j] = pb_y * tg_yyyyzzz_xxzzzz_0[j] + fr * tg_yyyyzzz_xxzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xxzzzz_0[j] - tg_yyyzzz_xxzzzz_1[j] * fl1_fza);

                    tg_yyyyyzzz_xyyyyy_0[j] = pb_y * tg_yyyyzzz_xyyyyy_0[j] + fr * tg_yyyyzzz_xyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xyyyyy_0[j] - tg_yyyzzz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyzzz_xyyyy_1[j];

                    tg_yyyyyzzz_xyyyyz_0[j] = pb_y * tg_yyyyzzz_xyyyyz_0[j] + fr * tg_yyyyzzz_xyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xyyyyz_0[j] - tg_yyyzzz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzzz_xyyyz_1[j];

                    tg_yyyyyzzz_xyyyzz_0[j] = pb_y * tg_yyyyzzz_xyyyzz_0[j] + fr * tg_yyyyzzz_xyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xyyyzz_0[j] - tg_yyyzzz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzzz_xyyzz_1[j];

                    tg_yyyyyzzz_xyyzzz_0[j] = pb_y * tg_yyyyzzz_xyyzzz_0[j] + fr * tg_yyyyzzz_xyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xyyzzz_0[j] - tg_yyyzzz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_xyzzz_1[j];

                    tg_yyyyyzzz_xyzzzz_0[j] = pb_y * tg_yyyyzzz_xyzzzz_0[j] + fr * tg_yyyyzzz_xyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xyzzzz_0[j] - tg_yyyzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_xzzzz_1[j];

                    tg_yyyyyzzz_xzzzzz_0[j] = pb_y * tg_yyyyzzz_xzzzzz_0[j] + fr * tg_yyyyzzz_xzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_xzzzzz_0[j] - tg_yyyzzz_xzzzzz_1[j] * fl1_fza);

                    tg_yyyyyzzz_yyyyyy_0[j] = pb_y * tg_yyyyzzz_yyyyyy_0[j] + fr * tg_yyyyzzz_yyyyyy_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yyyyyy_0[j] - tg_yyyzzz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyyzzz_yyyyy_1[j];

                    tg_yyyyyzzz_yyyyyz_0[j] = pb_y * tg_yyyyzzz_yyyyyz_0[j] + fr * tg_yyyyzzz_yyyyyz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yyyyyz_0[j] - tg_yyyzzz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyyzzz_yyyyz_1[j];

                    tg_yyyyyzzz_yyyyzz_0[j] = pb_y * tg_yyyyzzz_yyyyzz_0[j] + fr * tg_yyyyzzz_yyyyzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yyyyzz_0[j] - tg_yyyzzz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyyzzz_yyyzz_1[j];

                    tg_yyyyyzzz_yyyzzz_0[j] = pb_y * tg_yyyyzzz_yyyzzz_0[j] + fr * tg_yyyyzzz_yyyzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yyyzzz_0[j] - tg_yyyzzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyyzzz_yyzzz_1[j];

                    tg_yyyyyzzz_yyzzzz_0[j] = pb_y * tg_yyyyzzz_yyzzzz_0[j] + fr * tg_yyyyzzz_yyzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yyzzzz_0[j] - tg_yyyzzz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyyzzz_yzzzz_1[j];

                    tg_yyyyyzzz_yzzzzz_0[j] = pb_y * tg_yyyyzzz_yzzzzz_0[j] + fr * tg_yyyyzzz_yzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_yzzzzz_0[j] - tg_yyyzzz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyyzzz_zzzzz_1[j];

                    tg_yyyyyzzz_zzzzzz_0[j] = pb_y * tg_yyyyzzz_zzzzzz_0[j] + fr * tg_yyyyzzz_zzzzzz_1[j] + 2.0 * fl1_fx * (tg_yyyzzz_zzzzzz_0[j] - tg_yyyzzz_zzzzzz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xxxxxx_0[j] = pb_y * tg_yyyzzzz_xxxxxx_0[j] + fr * tg_yyyzzzz_xxxxxx_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxxx_0[j] - tg_yyzzzz_xxxxxx_1[j] * fl1_fza);

                    tg_yyyyzzzz_xxxxxy_0[j] = pb_y * tg_yyyzzzz_xxxxxy_0[j] + fr * tg_yyyzzzz_xxxxxy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxxy_0[j] - tg_yyzzzz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_xxxxx_1[j];

                    tg_yyyyzzzz_xxxxxz_0[j] = pb_y * tg_yyyzzzz_xxxxxz_0[j] + fr * tg_yyyzzzz_xxxxxz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxxz_0[j] - tg_yyzzzz_xxxxxz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xxxxyy_0[j] = pb_y * tg_yyyzzzz_xxxxyy_0[j] + fr * tg_yyyzzzz_xxxxyy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxyy_0[j] - tg_yyzzzz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_xxxxy_1[j];

                    tg_yyyyzzzz_xxxxyz_0[j] = pb_y * tg_yyyzzzz_xxxxyz_0[j] + fr * tg_yyyzzzz_xxxxyz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxyz_0[j] - tg_yyzzzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_xxxxz_1[j];

                    tg_yyyyzzzz_xxxxzz_0[j] = pb_y * tg_yyyzzzz_xxxxzz_0[j] + fr * tg_yyyzzzz_xxxxzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxxzz_0[j] - tg_yyzzzz_xxxxzz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xxxyyy_0[j] = pb_y * tg_yyyzzzz_xxxyyy_0[j] + fr * tg_yyyzzzz_xxxyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxyyy_0[j] - tg_yyzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzzz_xxxyy_1[j];

                    tg_yyyyzzzz_xxxyyz_0[j] = pb_y * tg_yyyzzzz_xxxyyz_0[j] + fr * tg_yyyzzzz_xxxyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxyyz_0[j] - tg_yyzzzz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_xxxyz_1[j];

                    tg_yyyyzzzz_xxxyzz_0[j] = pb_y * tg_yyyzzzz_xxxyzz_0[j] + fr * tg_yyyzzzz_xxxyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxyzz_0[j] - tg_yyzzzz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_xxxzz_1[j];

                    tg_yyyyzzzz_xxxzzz_0[j] = pb_y * tg_yyyzzzz_xxxzzz_0[j] + fr * tg_yyyzzzz_xxxzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxxzzz_0[j] - tg_yyzzzz_xxxzzz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xxyyyy_0[j] = pb_y * tg_yyyzzzz_xxyyyy_0[j] + fr * tg_yyyzzzz_xxyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxyyyy_0[j] - tg_yyzzzz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzzz_xxyyy_1[j];

                    tg_yyyyzzzz_xxyyyz_0[j] = pb_y * tg_yyyzzzz_xxyyyz_0[j] + fr * tg_yyyzzzz_xxyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxyyyz_0[j] - tg_yyzzzz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzzz_xxyyz_1[j];

                    tg_yyyyzzzz_xxyyzz_0[j] = pb_y * tg_yyyzzzz_xxyyzz_0[j] + fr * tg_yyyzzzz_xxyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxyyzz_0[j] - tg_yyzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_xxyzz_1[j];

                    tg_yyyyzzzz_xxyzzz_0[j] = pb_y * tg_yyyzzzz_xxyzzz_0[j] + fr * tg_yyyzzzz_xxyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxyzzz_0[j] - tg_yyzzzz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_xxzzz_1[j];

                    tg_yyyyzzzz_xxzzzz_0[j] = pb_y * tg_yyyzzzz_xxzzzz_0[j] + fr * tg_yyyzzzz_xxzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xxzzzz_0[j] - tg_yyzzzz_xxzzzz_1[j] * fl1_fza);

                    tg_yyyyzzzz_xyyyyy_0[j] = pb_y * tg_yyyzzzz_xyyyyy_0[j] + fr * tg_yyyzzzz_xyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xyyyyy_0[j] - tg_yyzzzz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzzzz_xyyyy_1[j];

                    tg_yyyyzzzz_xyyyyz_0[j] = pb_y * tg_yyyzzzz_xyyyyz_0[j] + fr * tg_yyyzzzz_xyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xyyyyz_0[j] - tg_yyzzzz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzzz_xyyyz_1[j];

                    tg_yyyyzzzz_xyyyzz_0[j] = pb_y * tg_yyyzzzz_xyyyzz_0[j] + fr * tg_yyyzzzz_xyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xyyyzz_0[j] - tg_yyzzzz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzzz_xyyzz_1[j];

                    tg_yyyyzzzz_xyyzzz_0[j] = pb_y * tg_yyyzzzz_xyyzzz_0[j] + fr * tg_yyyzzzz_xyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xyyzzz_0[j] - tg_yyzzzz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_xyzzz_1[j];

                    tg_yyyyzzzz_xyzzzz_0[j] = pb_y * tg_yyyzzzz_xyzzzz_0[j] + fr * tg_yyyzzzz_xyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xyzzzz_0[j] - tg_yyzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_xzzzz_1[j];

                    tg_yyyyzzzz_xzzzzz_0[j] = pb_y * tg_yyyzzzz_xzzzzz_0[j] + fr * tg_yyyzzzz_xzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_xzzzzz_0[j] - tg_yyzzzz_xzzzzz_1[j] * fl1_fza);

                    tg_yyyyzzzz_yyyyyy_0[j] = pb_y * tg_yyyzzzz_yyyyyy_0[j] + fr * tg_yyyzzzz_yyyyyy_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yyyyyy_0[j] - tg_yyzzzz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyyzzzz_yyyyy_1[j];

                    tg_yyyyzzzz_yyyyyz_0[j] = pb_y * tg_yyyzzzz_yyyyyz_0[j] + fr * tg_yyyzzzz_yyyyyz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yyyyyz_0[j] - tg_yyzzzz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyyzzzz_yyyyz_1[j];

                    tg_yyyyzzzz_yyyyzz_0[j] = pb_y * tg_yyyzzzz_yyyyzz_0[j] + fr * tg_yyyzzzz_yyyyzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yyyyzz_0[j] - tg_yyzzzz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyyzzzz_yyyzz_1[j];

                    tg_yyyyzzzz_yyyzzz_0[j] = pb_y * tg_yyyzzzz_yyyzzz_0[j] + fr * tg_yyyzzzz_yyyzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yyyzzz_0[j] - tg_yyzzzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyyzzzz_yyzzz_1[j];

                    tg_yyyyzzzz_yyzzzz_0[j] = pb_y * tg_yyyzzzz_yyzzzz_0[j] + fr * tg_yyyzzzz_yyzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yyzzzz_0[j] - tg_yyzzzz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyyzzzz_yzzzz_1[j];

                    tg_yyyyzzzz_yzzzzz_0[j] = pb_y * tg_yyyzzzz_yzzzzz_0[j] + fr * tg_yyyzzzz_yzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_yzzzzz_0[j] - tg_yyzzzz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyyzzzz_zzzzz_1[j];

                    tg_yyyyzzzz_zzzzzz_0[j] = pb_y * tg_yyyzzzz_zzzzzz_0[j] + fr * tg_yyyzzzz_zzzzzz_1[j] + 1.5 * fl1_fx * (tg_yyzzzz_zzzzzz_0[j] - tg_yyzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xxxxxx_0[j] = pb_y * tg_yyzzzzz_xxxxxx_0[j] + fr * tg_yyzzzzz_xxxxxx_1[j] + fl1_fx * (tg_yzzzzz_xxxxxx_0[j] - tg_yzzzzz_xxxxxx_1[j] * fl1_fza);

                    tg_yyyzzzzz_xxxxxy_0[j] = pb_y * tg_yyzzzzz_xxxxxy_0[j] + fr * tg_yyzzzzz_xxxxxy_1[j] + fl1_fx * (tg_yzzzzz_xxxxxy_0[j] - tg_yzzzzz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_xxxxx_1[j];

                    tg_yyyzzzzz_xxxxxz_0[j] = pb_y * tg_yyzzzzz_xxxxxz_0[j] + fr * tg_yyzzzzz_xxxxxz_1[j] + fl1_fx * (tg_yzzzzz_xxxxxz_0[j] - tg_yzzzzz_xxxxxz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xxxxyy_0[j] = pb_y * tg_yyzzzzz_xxxxyy_0[j] + fr * tg_yyzzzzz_xxxxyy_1[j] + fl1_fx * (tg_yzzzzz_xxxxyy_0[j] - tg_yzzzzz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_xxxxy_1[j];

                    tg_yyyzzzzz_xxxxyz_0[j] = pb_y * tg_yyzzzzz_xxxxyz_0[j] + fr * tg_yyzzzzz_xxxxyz_1[j] + fl1_fx * (tg_yzzzzz_xxxxyz_0[j] - tg_yzzzzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_xxxxz_1[j];

                    tg_yyyzzzzz_xxxxzz_0[j] = pb_y * tg_yyzzzzz_xxxxzz_0[j] + fr * tg_yyzzzzz_xxxxzz_1[j] + fl1_fx * (tg_yzzzzz_xxxxzz_0[j] - tg_yzzzzz_xxxxzz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xxxyyy_0[j] = pb_y * tg_yyzzzzz_xxxyyy_0[j] + fr * tg_yyzzzzz_xxxyyy_1[j] + fl1_fx * (tg_yzzzzz_xxxyyy_0[j] - tg_yzzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzzz_xxxyy_1[j];

                    tg_yyyzzzzz_xxxyyz_0[j] = pb_y * tg_yyzzzzz_xxxyyz_0[j] + fr * tg_yyzzzzz_xxxyyz_1[j] + fl1_fx * (tg_yzzzzz_xxxyyz_0[j] - tg_yzzzzz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_xxxyz_1[j];

                    tg_yyyzzzzz_xxxyzz_0[j] = pb_y * tg_yyzzzzz_xxxyzz_0[j] + fr * tg_yyzzzzz_xxxyzz_1[j] + fl1_fx * (tg_yzzzzz_xxxyzz_0[j] - tg_yzzzzz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_xxxzz_1[j];

                    tg_yyyzzzzz_xxxzzz_0[j] = pb_y * tg_yyzzzzz_xxxzzz_0[j] + fr * tg_yyzzzzz_xxxzzz_1[j] + fl1_fx * (tg_yzzzzz_xxxzzz_0[j] - tg_yzzzzz_xxxzzz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xxyyyy_0[j] = pb_y * tg_yyzzzzz_xxyyyy_0[j] + fr * tg_yyzzzzz_xxyyyy_1[j] + fl1_fx * (tg_yzzzzz_xxyyyy_0[j] - tg_yzzzzz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzzz_xxyyy_1[j];

                    tg_yyyzzzzz_xxyyyz_0[j] = pb_y * tg_yyzzzzz_xxyyyz_0[j] + fr * tg_yyzzzzz_xxyyyz_1[j] + fl1_fx * (tg_yzzzzz_xxyyyz_0[j] - tg_yzzzzz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzzz_xxyyz_1[j];

                    tg_yyyzzzzz_xxyyzz_0[j] = pb_y * tg_yyzzzzz_xxyyzz_0[j] + fr * tg_yyzzzzz_xxyyzz_1[j] + fl1_fx * (tg_yzzzzz_xxyyzz_0[j] - tg_yzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_xxyzz_1[j];

                    tg_yyyzzzzz_xxyzzz_0[j] = pb_y * tg_yyzzzzz_xxyzzz_0[j] + fr * tg_yyzzzzz_xxyzzz_1[j] + fl1_fx * (tg_yzzzzz_xxyzzz_0[j] - tg_yzzzzz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_xxzzz_1[j];

                    tg_yyyzzzzz_xxzzzz_0[j] = pb_y * tg_yyzzzzz_xxzzzz_0[j] + fr * tg_yyzzzzz_xxzzzz_1[j] + fl1_fx * (tg_yzzzzz_xxzzzz_0[j] - tg_yzzzzz_xxzzzz_1[j] * fl1_fza);

                    tg_yyyzzzzz_xyyyyy_0[j] = pb_y * tg_yyzzzzz_xyyyyy_0[j] + fr * tg_yyzzzzz_xyyyyy_1[j] + fl1_fx * (tg_yzzzzz_xyyyyy_0[j] - tg_yzzzzz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzzzz_xyyyy_1[j];
                }

                idx++;
            }
        }
    }

    void
    compElectronRepulsionForSLSI_1164_1260(      CMemBlock2D<double>* primBuffer,
                                           const CRecursionMap&       recursionMap,
                                           const CMemBlock2D<double>& osFactors,
                                           const CMemBlock2D<double>& wpDistances,
                                           const CGtoPairsBlock&      braGtoPairsBlock,
                                           const CGtoPairsBlock&      ketGtoPairsBlock,
                                           const int32_t              nKetPrimPairs,
                                           const int32_t              iContrPair)
    {
        // Batch of Integrals (1164,1260)

        // set up pointers to primitives data on bra side

        auto spos = braGtoPairsBlock.getStartPositions();

        auto epos = braGtoPairsBlock.getEndPositions();

        // set up pointers to tensor of distance R(PB) = P - B

        auto r_pb_y = braGtoPairsBlock.getDistancesPBY();

        auto r_pb_z = braGtoPairsBlock.getDistancesPBZ();

        // set up pointers to common Obara-Saika factors

        auto b_fx = braGtoPairsBlock.getFactorsOneOverXi();

        // set up maximum order of integral

        auto mord = recursionMap.getMaxOrder({"Electron Repulsion"},
                                             {8, -1, -1, -1},
                                             {6, -1, -1, -1},
                                             1, 1);

        for (int32_t iord = 0; iord <= mord; iord++)
        {
            // set up index of integral

            auto pidx_g_8_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {8, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            // check if integral is needed in recursion expansion

            if (pidx_g_8_6_m0 == -1) continue;

            // set up indexes of auxilary integral

            auto pidx_g_7_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_7_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_6_6_m0 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord));

            auto pidx_g_6_6_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {6, -1, -1, -1}, {6, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            auto pidx_g_7_5_m1 = recursionMap.index(CRecursionTerm({"Electron Repulsion"}, 0, true, 
                                                                   {7, -1, -1, -1}, {5, -1, -1, -1}, 
                                                                   1, 1, iord + 1));

            // loop over contracted GTO on bra side

            int32_t idx = 0;

            for (int32_t i = spos[iContrPair]; i < epos[iContrPair]; i++)
            {
                // set up pointers to Obara-Saika factors

                double fx = b_fx[i];

                auto fza = osFactors.data(4 * idx + 2);

                auto fxn = osFactors.data(4 * idx);

                // set up distances R(PB) = P - B

                auto pb_y = r_pb_y[i];

                auto pb_z = r_pb_z[i];

                // set up pointers to tensors product of distances R(WP) = W - P

                auto wp_y = wpDistances.data(3 * idx + 1);

                auto wp_z = wpDistances.data(3 * idx + 2);

                // set up pointers to auxilary integrals

                auto tg_yyzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 940); 

                auto tg_yyzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 941); 

                auto tg_yyzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 942); 

                auto tg_yyzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 943); 

                auto tg_yyzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 944); 

                auto tg_yyzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 945); 

                auto tg_yyzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 946); 

                auto tg_yyzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 947); 

                auto tg_yyzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 948); 

                auto tg_yyzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 949); 

                auto tg_yyzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 950); 

                auto tg_yyzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 951); 

                auto tg_yzzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 952); 

                auto tg_yzzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 953); 

                auto tg_yzzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 954); 

                auto tg_yzzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 955); 

                auto tg_yzzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 956); 

                auto tg_yzzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 957); 

                auto tg_yzzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 958); 

                auto tg_yzzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 959); 

                auto tg_yzzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 960); 

                auto tg_yzzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 961); 

                auto tg_yzzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 962); 

                auto tg_yzzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 963); 

                auto tg_yzzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 964); 

                auto tg_yzzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 965); 

                auto tg_yzzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 966); 

                auto tg_yzzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 967); 

                auto tg_yzzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 968); 

                auto tg_yzzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 969); 

                auto tg_yzzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 970); 

                auto tg_yzzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 971); 

                auto tg_yzzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 972); 

                auto tg_yzzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 973); 

                auto tg_yzzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 974); 

                auto tg_yzzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 975); 

                auto tg_yzzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 976); 

                auto tg_yzzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 977); 

                auto tg_yzzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 978); 

                auto tg_yzzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 979); 

                auto tg_zzzzzzz_xxxxxx_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 980); 

                auto tg_zzzzzzz_xxxxxy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 981); 

                auto tg_zzzzzzz_xxxxxz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 982); 

                auto tg_zzzzzzz_xxxxyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 983); 

                auto tg_zzzzzzz_xxxxyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 984); 

                auto tg_zzzzzzz_xxxxzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 985); 

                auto tg_zzzzzzz_xxxyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 986); 

                auto tg_zzzzzzz_xxxyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 987); 

                auto tg_zzzzzzz_xxxyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 988); 

                auto tg_zzzzzzz_xxxzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 989); 

                auto tg_zzzzzzz_xxyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 990); 

                auto tg_zzzzzzz_xxyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 991); 

                auto tg_zzzzzzz_xxyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 992); 

                auto tg_zzzzzzz_xxyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 993); 

                auto tg_zzzzzzz_xxzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 994); 

                auto tg_zzzzzzz_xyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 995); 

                auto tg_zzzzzzz_xyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 996); 

                auto tg_zzzzzzz_xyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 997); 

                auto tg_zzzzzzz_xyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 998); 

                auto tg_zzzzzzz_xyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 999); 

                auto tg_zzzzzzz_xzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1000); 

                auto tg_zzzzzzz_yyyyyy_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1001); 

                auto tg_zzzzzzz_yyyyyz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1002); 

                auto tg_zzzzzzz_yyyyzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1003); 

                auto tg_zzzzzzz_yyyzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1004); 

                auto tg_zzzzzzz_yyzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1005); 

                auto tg_zzzzzzz_yzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1006); 

                auto tg_zzzzzzz_zzzzzz_0 = primBuffer[pidx_g_7_6_m0].data(1008 * idx + 1007); 

                auto tg_yyzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 940); 

                auto tg_yyzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 941); 

                auto tg_yyzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 942); 

                auto tg_yyzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 943); 

                auto tg_yyzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 944); 

                auto tg_yyzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 945); 

                auto tg_yyzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 946); 

                auto tg_yyzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 947); 

                auto tg_yyzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 948); 

                auto tg_yyzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 949); 

                auto tg_yyzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 950); 

                auto tg_yyzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 951); 

                auto tg_yzzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 952); 

                auto tg_yzzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 953); 

                auto tg_yzzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 954); 

                auto tg_yzzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 955); 

                auto tg_yzzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 956); 

                auto tg_yzzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 957); 

                auto tg_yzzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 958); 

                auto tg_yzzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 959); 

                auto tg_yzzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 960); 

                auto tg_yzzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 961); 

                auto tg_yzzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 962); 

                auto tg_yzzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 963); 

                auto tg_yzzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 964); 

                auto tg_yzzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 965); 

                auto tg_yzzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 966); 

                auto tg_yzzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 967); 

                auto tg_yzzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 968); 

                auto tg_yzzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 969); 

                auto tg_yzzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 970); 

                auto tg_yzzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 971); 

                auto tg_yzzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 972); 

                auto tg_yzzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 973); 

                auto tg_yzzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 974); 

                auto tg_yzzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 975); 

                auto tg_yzzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 976); 

                auto tg_yzzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 977); 

                auto tg_yzzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 978); 

                auto tg_yzzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 979); 

                auto tg_zzzzzzz_xxxxxx_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 980); 

                auto tg_zzzzzzz_xxxxxy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 981); 

                auto tg_zzzzzzz_xxxxxz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 982); 

                auto tg_zzzzzzz_xxxxyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 983); 

                auto tg_zzzzzzz_xxxxyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 984); 

                auto tg_zzzzzzz_xxxxzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 985); 

                auto tg_zzzzzzz_xxxyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 986); 

                auto tg_zzzzzzz_xxxyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 987); 

                auto tg_zzzzzzz_xxxyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 988); 

                auto tg_zzzzzzz_xxxzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 989); 

                auto tg_zzzzzzz_xxyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 990); 

                auto tg_zzzzzzz_xxyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 991); 

                auto tg_zzzzzzz_xxyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 992); 

                auto tg_zzzzzzz_xxyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 993); 

                auto tg_zzzzzzz_xxzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 994); 

                auto tg_zzzzzzz_xyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 995); 

                auto tg_zzzzzzz_xyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 996); 

                auto tg_zzzzzzz_xyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 997); 

                auto tg_zzzzzzz_xyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 998); 

                auto tg_zzzzzzz_xyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 999); 

                auto tg_zzzzzzz_xzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1000); 

                auto tg_zzzzzzz_yyyyyy_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1001); 

                auto tg_zzzzzzz_yyyyyz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1002); 

                auto tg_zzzzzzz_yyyyzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1003); 

                auto tg_zzzzzzz_yyyzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1004); 

                auto tg_zzzzzzz_yyzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1005); 

                auto tg_zzzzzzz_yzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1006); 

                auto tg_zzzzzzz_zzzzzz_1 = primBuffer[pidx_g_7_6_m1].data(1008 * idx + 1007); 

                auto tg_yzzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 775); 

                auto tg_zzzzzz_xzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 782); 

                auto tg_zzzzzz_zzzzzz_0 = primBuffer[pidx_g_6_6_m0].data(784 * idx + 783); 

                auto tg_yzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 744); 

                auto tg_yzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 745); 

                auto tg_yzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 746); 

                auto tg_yzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 747); 

                auto tg_yzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 748); 

                auto tg_yzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 749); 

                auto tg_yzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 750); 

                auto tg_yzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 751); 

                auto tg_yzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 752); 

                auto tg_yzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 753); 

                auto tg_yzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 754); 

                auto tg_yzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 755); 

                auto tg_zzzzzz_xxxxxx_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 756); 

                auto tg_zzzzzz_xxxxxy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 757); 

                auto tg_zzzzzz_xxxxxz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 758); 

                auto tg_zzzzzz_xxxxyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 759); 

                auto tg_zzzzzz_xxxxyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 760); 

                auto tg_zzzzzz_xxxxzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 761); 

                auto tg_zzzzzz_xxxyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 762); 

                auto tg_zzzzzz_xxxyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 763); 

                auto tg_zzzzzz_xxxyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 764); 

                auto tg_zzzzzz_xxxzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 765); 

                auto tg_zzzzzz_xxyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 766); 

                auto tg_zzzzzz_xxyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 767); 

                auto tg_zzzzzz_xxyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 768); 

                auto tg_zzzzzz_xxyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 769); 

                auto tg_zzzzzz_xxzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 770); 

                auto tg_zzzzzz_xyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 771); 

                auto tg_zzzzzz_xyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 772); 

                auto tg_zzzzzz_xyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 773); 

                auto tg_zzzzzz_xyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 774); 

                auto tg_zzzzzz_xyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 775); 

                auto tg_zzzzzz_xzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 776); 

                auto tg_zzzzzz_yyyyyy_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 777); 

                auto tg_zzzzzz_yyyyyz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 778); 

                auto tg_zzzzzz_yyyyzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 779); 

                auto tg_zzzzzz_yyyzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 780); 

                auto tg_zzzzzz_yyzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 781); 

                auto tg_zzzzzz_yzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 782); 

                auto tg_zzzzzz_zzzzzz_1 = primBuffer[pidx_g_6_6_m1].data(784 * idx + 783); 

                auto tg_yyzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 704); 

                auto tg_yyzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 705); 

                auto tg_yyzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 706); 

                auto tg_yyzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 707); 

                auto tg_yyzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 708); 

                auto tg_yyzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 709); 

                auto tg_yyzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 710); 

                auto tg_yyzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 711); 

                auto tg_yyzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 712); 

                auto tg_yyzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 713); 

                auto tg_yzzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 714); 

                auto tg_yzzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 715); 

                auto tg_yzzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 716); 

                auto tg_yzzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 717); 

                auto tg_yzzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 718); 

                auto tg_yzzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 719); 

                auto tg_yzzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 720); 

                auto tg_yzzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 721); 

                auto tg_yzzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 722); 

                auto tg_yzzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 723); 

                auto tg_yzzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 724); 

                auto tg_yzzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 725); 

                auto tg_yzzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 726); 

                auto tg_yzzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 727); 

                auto tg_yzzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 728); 

                auto tg_yzzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 729); 

                auto tg_yzzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 730); 

                auto tg_yzzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 731); 

                auto tg_yzzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 732); 

                auto tg_yzzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 733); 

                auto tg_yzzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 734); 

                auto tg_zzzzzzz_xxxxx_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 735); 

                auto tg_zzzzzzz_xxxxy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 736); 

                auto tg_zzzzzzz_xxxxz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 737); 

                auto tg_zzzzzzz_xxxyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 738); 

                auto tg_zzzzzzz_xxxyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 739); 

                auto tg_zzzzzzz_xxxzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 740); 

                auto tg_zzzzzzz_xxyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 741); 

                auto tg_zzzzzzz_xxyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 742); 

                auto tg_zzzzzzz_xxyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 743); 

                auto tg_zzzzzzz_xxzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 744); 

                auto tg_zzzzzzz_xyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 745); 

                auto tg_zzzzzzz_xyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 746); 

                auto tg_zzzzzzz_xyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 747); 

                auto tg_zzzzzzz_xyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 748); 

                auto tg_zzzzzzz_xzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 749); 

                auto tg_zzzzzzz_yyyyy_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 750); 

                auto tg_zzzzzzz_yyyyz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 751); 

                auto tg_zzzzzzz_yyyzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 752); 

                auto tg_zzzzzzz_yyzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 753); 

                auto tg_zzzzzzz_yzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 754); 

                auto tg_zzzzzzz_zzzzz_1 = primBuffer[pidx_g_7_5_m1].data(756 * idx + 755); 

                // set up pointers to integrals

                auto tg_yyyzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1164); 

                auto tg_yyyzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1165); 

                auto tg_yyyzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1166); 

                auto tg_yyyzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1167); 

                auto tg_yyyzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1168); 

                auto tg_yyyzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1169); 

                auto tg_yyyzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1170); 

                auto tg_yyyzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1171); 

                auto tg_yyyzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1172); 

                auto tg_yyyzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1173); 

                auto tg_yyyzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1174); 

                auto tg_yyyzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1175); 

                auto tg_yyzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1176); 

                auto tg_yyzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1177); 

                auto tg_yyzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1178); 

                auto tg_yyzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1179); 

                auto tg_yyzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1180); 

                auto tg_yyzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1181); 

                auto tg_yyzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1182); 

                auto tg_yyzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1183); 

                auto tg_yyzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1184); 

                auto tg_yyzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1185); 

                auto tg_yyzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1186); 

                auto tg_yyzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1187); 

                auto tg_yyzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1188); 

                auto tg_yyzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1189); 

                auto tg_yyzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1190); 

                auto tg_yyzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1191); 

                auto tg_yyzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1192); 

                auto tg_yyzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1193); 

                auto tg_yyzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1194); 

                auto tg_yyzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1195); 

                auto tg_yyzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1196); 

                auto tg_yyzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1197); 

                auto tg_yyzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1198); 

                auto tg_yyzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1199); 

                auto tg_yyzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1200); 

                auto tg_yyzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1201); 

                auto tg_yyzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1202); 

                auto tg_yyzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1203); 

                auto tg_yzzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1204); 

                auto tg_yzzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1205); 

                auto tg_yzzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1206); 

                auto tg_yzzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1207); 

                auto tg_yzzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1208); 

                auto tg_yzzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1209); 

                auto tg_yzzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1210); 

                auto tg_yzzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1211); 

                auto tg_yzzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1212); 

                auto tg_yzzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1213); 

                auto tg_yzzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1214); 

                auto tg_yzzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1215); 

                auto tg_yzzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1216); 

                auto tg_yzzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1217); 

                auto tg_yzzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1218); 

                auto tg_yzzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1219); 

                auto tg_yzzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1220); 

                auto tg_yzzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1221); 

                auto tg_yzzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1222); 

                auto tg_yzzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1223); 

                auto tg_yzzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1224); 

                auto tg_yzzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1225); 

                auto tg_yzzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1226); 

                auto tg_yzzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1227); 

                auto tg_yzzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1228); 

                auto tg_yzzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1229); 

                auto tg_yzzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1230); 

                auto tg_yzzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1231); 

                auto tg_zzzzzzzz_xxxxxx_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1232); 

                auto tg_zzzzzzzz_xxxxxy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1233); 

                auto tg_zzzzzzzz_xxxxxz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1234); 

                auto tg_zzzzzzzz_xxxxyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1235); 

                auto tg_zzzzzzzz_xxxxyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1236); 

                auto tg_zzzzzzzz_xxxxzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1237); 

                auto tg_zzzzzzzz_xxxyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1238); 

                auto tg_zzzzzzzz_xxxyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1239); 

                auto tg_zzzzzzzz_xxxyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1240); 

                auto tg_zzzzzzzz_xxxzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1241); 

                auto tg_zzzzzzzz_xxyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1242); 

                auto tg_zzzzzzzz_xxyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1243); 

                auto tg_zzzzzzzz_xxyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1244); 

                auto tg_zzzzzzzz_xxyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1245); 

                auto tg_zzzzzzzz_xxzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1246); 

                auto tg_zzzzzzzz_xyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1247); 

                auto tg_zzzzzzzz_xyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1248); 

                auto tg_zzzzzzzz_xyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1249); 

                auto tg_zzzzzzzz_xyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1250); 

                auto tg_zzzzzzzz_xyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1251); 

                auto tg_zzzzzzzz_xzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1252); 

                auto tg_zzzzzzzz_yyyyyy_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1253); 

                auto tg_zzzzzzzz_yyyyyz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1254); 

                auto tg_zzzzzzzz_yyyyzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1255); 

                auto tg_zzzzzzzz_yyyzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1256); 

                auto tg_zzzzzzzz_yyzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1257); 

                auto tg_zzzzzzzz_yzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1258); 

                auto tg_zzzzzzzz_zzzzzz_0 = primBuffer[pidx_g_8_6_m0].data(1260 * idx + 1259); 

                // Batch of Integrals (1164,1260)

                #pragma omp simd aligned(fxn, fza, tg_yyyzzzzz_xyyyyz_0, tg_yyyzzzzz_xyyyzz_0, \
                                         tg_yyyzzzzz_xyyzzz_0, tg_yyyzzzzz_xyzzzz_0, tg_yyyzzzzz_xzzzzz_0, tg_yyyzzzzz_yyyyyy_0, \
                                         tg_yyyzzzzz_yyyyyz_0, tg_yyyzzzzz_yyyyzz_0, tg_yyyzzzzz_yyyzzz_0, tg_yyyzzzzz_yyzzzz_0, \
                                         tg_yyyzzzzz_yzzzzz_0, tg_yyyzzzzz_zzzzzz_0, tg_yyzzzzz_xyyyyz_0, tg_yyzzzzz_xyyyyz_1, \
                                         tg_yyzzzzz_xyyyz_1, tg_yyzzzzz_xyyyzz_0, tg_yyzzzzz_xyyyzz_1, tg_yyzzzzz_xyyzz_1, \
                                         tg_yyzzzzz_xyyzzz_0, tg_yyzzzzz_xyyzzz_1, tg_yyzzzzz_xyzzz_1, tg_yyzzzzz_xyzzzz_0, \
                                         tg_yyzzzzz_xyzzzz_1, tg_yyzzzzz_xzzzz_1, tg_yyzzzzz_xzzzzz_0, tg_yyzzzzz_xzzzzz_1, \
                                         tg_yyzzzzz_yyyyy_1, tg_yyzzzzz_yyyyyy_0, tg_yyzzzzz_yyyyyy_1, tg_yyzzzzz_yyyyyz_0, \
                                         tg_yyzzzzz_yyyyyz_1, tg_yyzzzzz_yyyyz_1, tg_yyzzzzz_yyyyzz_0, tg_yyzzzzz_yyyyzz_1, \
                                         tg_yyzzzzz_yyyzz_1, tg_yyzzzzz_yyyzzz_0, tg_yyzzzzz_yyyzzz_1, tg_yyzzzzz_yyzzz_1, \
                                         tg_yyzzzzz_yyzzzz_0, tg_yyzzzzz_yyzzzz_1, tg_yyzzzzz_yzzzz_1, tg_yyzzzzz_yzzzzz_0, \
                                         tg_yyzzzzz_yzzzzz_1, tg_yyzzzzz_zzzzz_1, tg_yyzzzzz_zzzzzz_0, tg_yyzzzzz_zzzzzz_1, \
                                         tg_yyzzzzzz_xxxxxx_0, tg_yyzzzzzz_xxxxxy_0, tg_yyzzzzzz_xxxxxz_0, tg_yyzzzzzz_xxxxyy_0, \
                                         tg_yyzzzzzz_xxxxyz_0, tg_yyzzzzzz_xxxxzz_0, tg_yyzzzzzz_xxxyyy_0, tg_yyzzzzzz_xxxyyz_0, \
                                         tg_yyzzzzzz_xxxyzz_0, tg_yyzzzzzz_xxxzzz_0, tg_yyzzzzzz_xxyyyy_0, tg_yyzzzzzz_xxyyyz_0, \
                                         tg_yyzzzzzz_xxyyzz_0, tg_yyzzzzzz_xxyzzz_0, tg_yyzzzzzz_xxzzzz_0, tg_yyzzzzzz_xyyyyy_0, \
                                         tg_yyzzzzzz_xyyyyz_0, tg_yyzzzzzz_xyyyzz_0, tg_yyzzzzzz_xyyzzz_0, tg_yyzzzzzz_xyzzzz_0, \
                                         tg_yyzzzzzz_xzzzzz_0, tg_yyzzzzzz_yyyyyy_0, tg_yyzzzzzz_yyyyyz_0, tg_yyzzzzzz_yyyyzz_0, \
                                         tg_yyzzzzzz_yyyzzz_0, tg_yyzzzzzz_yyzzzz_0, tg_yyzzzzzz_yzzzzz_0, tg_yyzzzzzz_zzzzzz_0, \
                                         tg_yzzzzz_xyyyyz_0, tg_yzzzzz_xyyyyz_1, tg_yzzzzz_xyyyzz_0, tg_yzzzzz_xyyyzz_1, \
                                         tg_yzzzzz_xyyzzz_0, tg_yzzzzz_xyyzzz_1, tg_yzzzzz_xyzzzz_0, tg_yzzzzz_xyzzzz_1, \
                                         tg_yzzzzz_xzzzzz_0, tg_yzzzzz_xzzzzz_1, tg_yzzzzz_yyyyyy_0, tg_yzzzzz_yyyyyy_1, \
                                         tg_yzzzzz_yyyyyz_0, tg_yzzzzz_yyyyyz_1, tg_yzzzzz_yyyyzz_0, tg_yzzzzz_yyyyzz_1, \
                                         tg_yzzzzz_yyyzzz_0, tg_yzzzzz_yyyzzz_1, tg_yzzzzz_yyzzzz_0, tg_yzzzzz_yyzzzz_1, \
                                         tg_yzzzzz_yzzzzz_0, tg_yzzzzz_yzzzzz_1, tg_yzzzzz_zzzzzz_0, tg_yzzzzz_zzzzzz_1, \
                                         tg_yzzzzzz_xxxxx_1, tg_yzzzzzz_xxxxxx_0, tg_yzzzzzz_xxxxxx_1, tg_yzzzzzz_xxxxxy_0, \
                                         tg_yzzzzzz_xxxxxy_1, tg_yzzzzzz_xxxxxz_0, tg_yzzzzzz_xxxxxz_1, tg_yzzzzzz_xxxxy_1, \
                                         tg_yzzzzzz_xxxxyy_0, tg_yzzzzzz_xxxxyy_1, tg_yzzzzzz_xxxxyz_0, tg_yzzzzzz_xxxxyz_1, \
                                         tg_yzzzzzz_xxxxz_1, tg_yzzzzzz_xxxxzz_0, tg_yzzzzzz_xxxxzz_1, tg_yzzzzzz_xxxyy_1, \
                                         tg_yzzzzzz_xxxyyy_0, tg_yzzzzzz_xxxyyy_1, tg_yzzzzzz_xxxyyz_0, tg_yzzzzzz_xxxyyz_1, \
                                         tg_yzzzzzz_xxxyz_1, tg_yzzzzzz_xxxyzz_0, tg_yzzzzzz_xxxyzz_1, tg_yzzzzzz_xxxzz_1, \
                                         tg_yzzzzzz_xxxzzz_0, tg_yzzzzzz_xxxzzz_1, tg_yzzzzzz_xxyyy_1, tg_yzzzzzz_xxyyyy_0, \
                                         tg_yzzzzzz_xxyyyy_1, tg_yzzzzzz_xxyyyz_0, tg_yzzzzzz_xxyyyz_1, tg_yzzzzzz_xxyyz_1, \
                                         tg_yzzzzzz_xxyyzz_0, tg_yzzzzzz_xxyyzz_1, tg_yzzzzzz_xxyzz_1, tg_yzzzzzz_xxyzzz_0, \
                                         tg_yzzzzzz_xxyzzz_1, tg_yzzzzzz_xxzzz_1, tg_yzzzzzz_xxzzzz_0, tg_yzzzzzz_xxzzzz_1, \
                                         tg_yzzzzzz_xyyyy_1, tg_yzzzzzz_xyyyyy_0, tg_yzzzzzz_xyyyyy_1, tg_yzzzzzz_xyyyyz_0, \
                                         tg_yzzzzzz_xyyyyz_1, tg_yzzzzzz_xyyyz_1, tg_yzzzzzz_xyyyzz_0, tg_yzzzzzz_xyyyzz_1, \
                                         tg_yzzzzzz_xyyzz_1, tg_yzzzzzz_xyyzzz_0, tg_yzzzzzz_xyyzzz_1, tg_yzzzzzz_xyzzz_1, \
                                         tg_yzzzzzz_xyzzzz_0, tg_yzzzzzz_xyzzzz_1, tg_yzzzzzz_xzzzz_1, tg_yzzzzzz_xzzzzz_0, \
                                         tg_yzzzzzz_xzzzzz_1, tg_yzzzzzz_yyyyy_1, tg_yzzzzzz_yyyyyy_0, tg_yzzzzzz_yyyyyy_1, \
                                         tg_yzzzzzz_yyyyyz_0, tg_yzzzzzz_yyyyyz_1, tg_yzzzzzz_yyyyz_1, tg_yzzzzzz_yyyyzz_0, \
                                         tg_yzzzzzz_yyyyzz_1, tg_yzzzzzz_yyyzz_1, tg_yzzzzzz_yyyzzz_0, tg_yzzzzzz_yyyzzz_1, \
                                         tg_yzzzzzz_yyzzz_1, tg_yzzzzzz_yyzzzz_0, tg_yzzzzzz_yyzzzz_1, tg_yzzzzzz_yzzzz_1, \
                                         tg_yzzzzzz_yzzzzz_0, tg_yzzzzzz_yzzzzz_1, tg_yzzzzzz_zzzzz_1, tg_yzzzzzz_zzzzzz_0, \
                                         tg_yzzzzzz_zzzzzz_1, tg_yzzzzzzz_xxxxxx_0, tg_yzzzzzzz_xxxxxy_0, tg_yzzzzzzz_xxxxxz_0, \
                                         tg_yzzzzzzz_xxxxyy_0, tg_yzzzzzzz_xxxxyz_0, tg_yzzzzzzz_xxxxzz_0, tg_yzzzzzzz_xxxyyy_0, \
                                         tg_yzzzzzzz_xxxyyz_0, tg_yzzzzzzz_xxxyzz_0, tg_yzzzzzzz_xxxzzz_0, tg_yzzzzzzz_xxyyyy_0, \
                                         tg_yzzzzzzz_xxyyyz_0, tg_yzzzzzzz_xxyyzz_0, tg_yzzzzzzz_xxyzzz_0, tg_yzzzzzzz_xxzzzz_0, \
                                         tg_yzzzzzzz_xyyyyy_0, tg_yzzzzzzz_xyyyyz_0, tg_yzzzzzzz_xyyyzz_0, tg_yzzzzzzz_xyyzzz_0, \
                                         tg_yzzzzzzz_xyzzzz_0, tg_yzzzzzzz_xzzzzz_0, tg_yzzzzzzz_yyyyyy_0, tg_yzzzzzzz_yyyyyz_0, \
                                         tg_yzzzzzzz_yyyyzz_0, tg_yzzzzzzz_yyyzzz_0, tg_yzzzzzzz_yyzzzz_0, tg_yzzzzzzz_yzzzzz_0, \
                                         tg_yzzzzzzz_zzzzzz_0, tg_zzzzzz_xxxxxx_0, tg_zzzzzz_xxxxxx_1, tg_zzzzzz_xxxxxy_0, \
                                         tg_zzzzzz_xxxxxy_1, tg_zzzzzz_xxxxxz_0, tg_zzzzzz_xxxxxz_1, tg_zzzzzz_xxxxyy_0, \
                                         tg_zzzzzz_xxxxyy_1, tg_zzzzzz_xxxxyz_0, tg_zzzzzz_xxxxyz_1, tg_zzzzzz_xxxxzz_0, \
                                         tg_zzzzzz_xxxxzz_1, tg_zzzzzz_xxxyyy_0, tg_zzzzzz_xxxyyy_1, tg_zzzzzz_xxxyyz_0, \
                                         tg_zzzzzz_xxxyyz_1, tg_zzzzzz_xxxyzz_0, tg_zzzzzz_xxxyzz_1, tg_zzzzzz_xxxzzz_0, \
                                         tg_zzzzzz_xxxzzz_1, tg_zzzzzz_xxyyyy_0, tg_zzzzzz_xxyyyy_1, tg_zzzzzz_xxyyyz_0, \
                                         tg_zzzzzz_xxyyyz_1, tg_zzzzzz_xxyyzz_0, tg_zzzzzz_xxyyzz_1, tg_zzzzzz_xxyzzz_0, \
                                         tg_zzzzzz_xxyzzz_1, tg_zzzzzz_xxzzzz_0, tg_zzzzzz_xxzzzz_1, tg_zzzzzz_xyyyyy_0, \
                                         tg_zzzzzz_xyyyyy_1, tg_zzzzzz_xyyyyz_0, tg_zzzzzz_xyyyyz_1, tg_zzzzzz_xyyyzz_0, \
                                         tg_zzzzzz_xyyyzz_1, tg_zzzzzz_xyyzzz_0, tg_zzzzzz_xyyzzz_1, tg_zzzzzz_xyzzzz_0, \
                                         tg_zzzzzz_xyzzzz_1, tg_zzzzzz_xzzzzz_0, tg_zzzzzz_xzzzzz_1, tg_zzzzzz_yyyyyy_0, \
                                         tg_zzzzzz_yyyyyy_1, tg_zzzzzz_yyyyyz_0, tg_zzzzzz_yyyyyz_1, tg_zzzzzz_yyyyzz_0, \
                                         tg_zzzzzz_yyyyzz_1, tg_zzzzzz_yyyzzz_0, tg_zzzzzz_yyyzzz_1, tg_zzzzzz_yyzzzz_0, \
                                         tg_zzzzzz_yyzzzz_1, tg_zzzzzz_yzzzzz_0, tg_zzzzzz_yzzzzz_1, tg_zzzzzz_zzzzzz_0, \
                                         tg_zzzzzz_zzzzzz_1, tg_zzzzzzz_xxxxx_1, tg_zzzzzzz_xxxxxx_0, tg_zzzzzzz_xxxxxx_1, \
                                         tg_zzzzzzz_xxxxxy_0, tg_zzzzzzz_xxxxxy_1, tg_zzzzzzz_xxxxxz_0, tg_zzzzzzz_xxxxxz_1, \
                                         tg_zzzzzzz_xxxxy_1, tg_zzzzzzz_xxxxyy_0, tg_zzzzzzz_xxxxyy_1, tg_zzzzzzz_xxxxyz_0, \
                                         tg_zzzzzzz_xxxxyz_1, tg_zzzzzzz_xxxxz_1, tg_zzzzzzz_xxxxzz_0, tg_zzzzzzz_xxxxzz_1, \
                                         tg_zzzzzzz_xxxyy_1, tg_zzzzzzz_xxxyyy_0, tg_zzzzzzz_xxxyyy_1, tg_zzzzzzz_xxxyyz_0, \
                                         tg_zzzzzzz_xxxyyz_1, tg_zzzzzzz_xxxyz_1, tg_zzzzzzz_xxxyzz_0, tg_zzzzzzz_xxxyzz_1, \
                                         tg_zzzzzzz_xxxzz_1, tg_zzzzzzz_xxxzzz_0, tg_zzzzzzz_xxxzzz_1, tg_zzzzzzz_xxyyy_1, \
                                         tg_zzzzzzz_xxyyyy_0, tg_zzzzzzz_xxyyyy_1, tg_zzzzzzz_xxyyyz_0, tg_zzzzzzz_xxyyyz_1, \
                                         tg_zzzzzzz_xxyyz_1, tg_zzzzzzz_xxyyzz_0, tg_zzzzzzz_xxyyzz_1, tg_zzzzzzz_xxyzz_1, \
                                         tg_zzzzzzz_xxyzzz_0, tg_zzzzzzz_xxyzzz_1, tg_zzzzzzz_xxzzz_1, tg_zzzzzzz_xxzzzz_0, \
                                         tg_zzzzzzz_xxzzzz_1, tg_zzzzzzz_xyyyy_1, tg_zzzzzzz_xyyyyy_0, tg_zzzzzzz_xyyyyy_1, \
                                         tg_zzzzzzz_xyyyyz_0, tg_zzzzzzz_xyyyyz_1, tg_zzzzzzz_xyyyz_1, tg_zzzzzzz_xyyyzz_0, \
                                         tg_zzzzzzz_xyyyzz_1, tg_zzzzzzz_xyyzz_1, tg_zzzzzzz_xyyzzz_0, tg_zzzzzzz_xyyzzz_1, \
                                         tg_zzzzzzz_xyzzz_1, tg_zzzzzzz_xyzzzz_0, tg_zzzzzzz_xyzzzz_1, tg_zzzzzzz_xzzzz_1, \
                                         tg_zzzzzzz_xzzzzz_0, tg_zzzzzzz_xzzzzz_1, tg_zzzzzzz_yyyyy_1, tg_zzzzzzz_yyyyyy_0, \
                                         tg_zzzzzzz_yyyyyy_1, tg_zzzzzzz_yyyyyz_0, tg_zzzzzzz_yyyyyz_1, tg_zzzzzzz_yyyyz_1, \
                                         tg_zzzzzzz_yyyyzz_0, tg_zzzzzzz_yyyyzz_1, tg_zzzzzzz_yyyzz_1, tg_zzzzzzz_yyyzzz_0, \
                                         tg_zzzzzzz_yyyzzz_1, tg_zzzzzzz_yyzzz_1, tg_zzzzzzz_yyzzzz_0, tg_zzzzzzz_yyzzzz_1, \
                                         tg_zzzzzzz_yzzzz_1, tg_zzzzzzz_yzzzzz_0, tg_zzzzzzz_yzzzzz_1, tg_zzzzzzz_zzzzz_1, \
                                         tg_zzzzzzz_zzzzzz_0, tg_zzzzzzz_zzzzzz_1, tg_zzzzzzzz_xxxxxx_0, tg_zzzzzzzz_xxxxxy_0, \
                                         tg_zzzzzzzz_xxxxxz_0, tg_zzzzzzzz_xxxxyy_0, tg_zzzzzzzz_xxxxyz_0, tg_zzzzzzzz_xxxxzz_0, \
                                         tg_zzzzzzzz_xxxyyy_0, tg_zzzzzzzz_xxxyyz_0, tg_zzzzzzzz_xxxyzz_0, tg_zzzzzzzz_xxxzzz_0, \
                                         tg_zzzzzzzz_xxyyyy_0, tg_zzzzzzzz_xxyyyz_0, tg_zzzzzzzz_xxyyzz_0, tg_zzzzzzzz_xxyzzz_0, \
                                         tg_zzzzzzzz_xxzzzz_0, tg_zzzzzzzz_xyyyyy_0, tg_zzzzzzzz_xyyyyz_0, tg_zzzzzzzz_xyyyzz_0, \
                                         tg_zzzzzzzz_xyyzzz_0, tg_zzzzzzzz_xyzzzz_0, tg_zzzzzzzz_xzzzzz_0, tg_zzzzzzzz_yyyyyy_0, \
                                         tg_zzzzzzzz_yyyyyz_0, tg_zzzzzzzz_yyyyzz_0, tg_zzzzzzzz_yyyzzz_0, tg_zzzzzzzz_yyzzzz_0, \
                                         tg_zzzzzzzz_yzzzzz_0, tg_zzzzzzzz_zzzzzz_0, wp_y, wp_z: VLX_ALIGN)
                for (int32_t j = 0; j < nKetPrimPairs; j++)
                {
                    double fl1_fx = fx;

                    double fl1_fxn = fxn[j];

                    double fl1_fza = fza[j];

                    double fr = wp_y[j]; 

                    tg_yyyzzzzz_xyyyyz_0[j] = pb_y * tg_yyzzzzz_xyyyyz_0[j] + fr * tg_yyzzzzz_xyyyyz_1[j] + fl1_fx * (tg_yzzzzz_xyyyyz_0[j] - tg_yzzzzz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzzz_xyyyz_1[j];

                    tg_yyyzzzzz_xyyyzz_0[j] = pb_y * tg_yyzzzzz_xyyyzz_0[j] + fr * tg_yyzzzzz_xyyyzz_1[j] + fl1_fx * (tg_yzzzzz_xyyyzz_0[j] - tg_yzzzzz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzzz_xyyzz_1[j];

                    tg_yyyzzzzz_xyyzzz_0[j] = pb_y * tg_yyzzzzz_xyyzzz_0[j] + fr * tg_yyzzzzz_xyyzzz_1[j] + fl1_fx * (tg_yzzzzz_xyyzzz_0[j] - tg_yzzzzz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_xyzzz_1[j];

                    tg_yyyzzzzz_xyzzzz_0[j] = pb_y * tg_yyzzzzz_xyzzzz_0[j] + fr * tg_yyzzzzz_xyzzzz_1[j] + fl1_fx * (tg_yzzzzz_xyzzzz_0[j] - tg_yzzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_xzzzz_1[j];

                    tg_yyyzzzzz_xzzzzz_0[j] = pb_y * tg_yyzzzzz_xzzzzz_0[j] + fr * tg_yyzzzzz_xzzzzz_1[j] + fl1_fx * (tg_yzzzzz_xzzzzz_0[j] - tg_yzzzzz_xzzzzz_1[j] * fl1_fza);

                    tg_yyyzzzzz_yyyyyy_0[j] = pb_y * tg_yyzzzzz_yyyyyy_0[j] + fr * tg_yyzzzzz_yyyyyy_1[j] + fl1_fx * (tg_yzzzzz_yyyyyy_0[j] - tg_yzzzzz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yyzzzzz_yyyyy_1[j];

                    tg_yyyzzzzz_yyyyyz_0[j] = pb_y * tg_yyzzzzz_yyyyyz_0[j] + fr * tg_yyzzzzz_yyyyyz_1[j] + fl1_fx * (tg_yzzzzz_yyyyyz_0[j] - tg_yzzzzz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yyzzzzz_yyyyz_1[j];

                    tg_yyyzzzzz_yyyyzz_0[j] = pb_y * tg_yyzzzzz_yyyyzz_0[j] + fr * tg_yyzzzzz_yyyyzz_1[j] + fl1_fx * (tg_yzzzzz_yyyyzz_0[j] - tg_yzzzzz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yyzzzzz_yyyzz_1[j];

                    tg_yyyzzzzz_yyyzzz_0[j] = pb_y * tg_yyzzzzz_yyyzzz_0[j] + fr * tg_yyzzzzz_yyyzzz_1[j] + fl1_fx * (tg_yzzzzz_yyyzzz_0[j] - tg_yzzzzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yyzzzzz_yyzzz_1[j];

                    tg_yyyzzzzz_yyzzzz_0[j] = pb_y * tg_yyzzzzz_yyzzzz_0[j] + fr * tg_yyzzzzz_yyzzzz_1[j] + fl1_fx * (tg_yzzzzz_yyzzzz_0[j] - tg_yzzzzz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yyzzzzz_yzzzz_1[j];

                    tg_yyyzzzzz_yzzzzz_0[j] = pb_y * tg_yyzzzzz_yzzzzz_0[j] + fr * tg_yyzzzzz_yzzzzz_1[j] + fl1_fx * (tg_yzzzzz_yzzzzz_0[j] - tg_yzzzzz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yyzzzzz_zzzzz_1[j];

                    tg_yyyzzzzz_zzzzzz_0[j] = pb_y * tg_yyzzzzz_zzzzzz_0[j] + fr * tg_yyzzzzz_zzzzzz_1[j] + fl1_fx * (tg_yzzzzz_zzzzzz_0[j] - tg_yzzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xxxxxx_0[j] = pb_y * tg_yzzzzzz_xxxxxx_0[j] + fr * tg_yzzzzzz_xxxxxx_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxx_0[j] - tg_zzzzzz_xxxxxx_1[j] * fl1_fza);

                    tg_yyzzzzzz_xxxxxy_0[j] = pb_y * tg_yzzzzzz_xxxxxy_0[j] + fr * tg_yzzzzzz_xxxxxy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxy_0[j] - tg_zzzzzz_xxxxxy_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_xxxxx_1[j];

                    tg_yyzzzzzz_xxxxxz_0[j] = pb_y * tg_yzzzzzz_xxxxxz_0[j] + fr * tg_yzzzzzz_xxxxxz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxxz_0[j] - tg_zzzzzz_xxxxxz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xxxxyy_0[j] = pb_y * tg_yzzzzzz_xxxxyy_0[j] + fr * tg_yzzzzzz_xxxxyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxyy_0[j] - tg_zzzzzz_xxxxyy_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_xxxxy_1[j];

                    tg_yyzzzzzz_xxxxyz_0[j] = pb_y * tg_yzzzzzz_xxxxyz_0[j] + fr * tg_yzzzzzz_xxxxyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxyz_0[j] - tg_zzzzzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_xxxxz_1[j];

                    tg_yyzzzzzz_xxxxzz_0[j] = pb_y * tg_yzzzzzz_xxxxzz_0[j] + fr * tg_yzzzzzz_xxxxzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxxzz_0[j] - tg_zzzzzz_xxxxzz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xxxyyy_0[j] = pb_y * tg_yzzzzzz_xxxyyy_0[j] + fr * tg_yzzzzzz_xxxyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyyy_0[j] - tg_zzzzzz_xxxyyy_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzzz_xxxyy_1[j];

                    tg_yyzzzzzz_xxxyyz_0[j] = pb_y * tg_yzzzzzz_xxxyyz_0[j] + fr * tg_yzzzzzz_xxxyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyyz_0[j] - tg_zzzzzz_xxxyyz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_xxxyz_1[j];

                    tg_yyzzzzzz_xxxyzz_0[j] = pb_y * tg_yzzzzzz_xxxyzz_0[j] + fr * tg_yzzzzzz_xxxyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxyzz_0[j] - tg_zzzzzz_xxxyzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_xxxzz_1[j];

                    tg_yyzzzzzz_xxxzzz_0[j] = pb_y * tg_yzzzzzz_xxxzzz_0[j] + fr * tg_yzzzzzz_xxxzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxxzzz_0[j] - tg_zzzzzz_xxxzzz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xxyyyy_0[j] = pb_y * tg_yzzzzzz_xxyyyy_0[j] + fr * tg_yzzzzzz_xxyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyyy_0[j] - tg_zzzzzz_xxyyyy_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzzz_xxyyy_1[j];

                    tg_yyzzzzzz_xxyyyz_0[j] = pb_y * tg_yzzzzzz_xxyyyz_0[j] + fr * tg_yzzzzzz_xxyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyyz_0[j] - tg_zzzzzz_xxyyyz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzzz_xxyyz_1[j];

                    tg_yyzzzzzz_xxyyzz_0[j] = pb_y * tg_yzzzzzz_xxyyzz_0[j] + fr * tg_yzzzzzz_xxyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyyzz_0[j] - tg_zzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_xxyzz_1[j];

                    tg_yyzzzzzz_xxyzzz_0[j] = pb_y * tg_yzzzzzz_xxyzzz_0[j] + fr * tg_yzzzzzz_xxyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxyzzz_0[j] - tg_zzzzzz_xxyzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_xxzzz_1[j];

                    tg_yyzzzzzz_xxzzzz_0[j] = pb_y * tg_yzzzzzz_xxzzzz_0[j] + fr * tg_yzzzzzz_xxzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xxzzzz_0[j] - tg_zzzzzz_xxzzzz_1[j] * fl1_fza);

                    tg_yyzzzzzz_xyyyyy_0[j] = pb_y * tg_yzzzzzz_xyyyyy_0[j] + fr * tg_yzzzzzz_xyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyyy_0[j] - tg_zzzzzz_xyyyyy_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzzzz_xyyyy_1[j];

                    tg_yyzzzzzz_xyyyyz_0[j] = pb_y * tg_yzzzzzz_xyyyyz_0[j] + fr * tg_yzzzzzz_xyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyyz_0[j] - tg_zzzzzz_xyyyyz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzzz_xyyyz_1[j];

                    tg_yyzzzzzz_xyyyzz_0[j] = pb_y * tg_yzzzzzz_xyyyzz_0[j] + fr * tg_yzzzzzz_xyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyyzz_0[j] - tg_zzzzzz_xyyyzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzzz_xyyzz_1[j];

                    tg_yyzzzzzz_xyyzzz_0[j] = pb_y * tg_yzzzzzz_xyyzzz_0[j] + fr * tg_yzzzzzz_xyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyyzzz_0[j] - tg_zzzzzz_xyyzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_xyzzz_1[j];

                    tg_yyzzzzzz_xyzzzz_0[j] = pb_y * tg_yzzzzzz_xyzzzz_0[j] + fr * tg_yzzzzzz_xyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xyzzzz_0[j] - tg_zzzzzz_xyzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_xzzzz_1[j];

                    tg_yyzzzzzz_xzzzzz_0[j] = pb_y * tg_yzzzzzz_xzzzzz_0[j] + fr * tg_yzzzzzz_xzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_xzzzzz_0[j] - tg_zzzzzz_xzzzzz_1[j] * fl1_fza);

                    tg_yyzzzzzz_yyyyyy_0[j] = pb_y * tg_yzzzzzz_yyyyyy_0[j] + fr * tg_yzzzzzz_yyyyyy_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyyy_0[j] - tg_zzzzzz_yyyyyy_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_yzzzzzz_yyyyy_1[j];

                    tg_yyzzzzzz_yyyyyz_0[j] = pb_y * tg_yzzzzzz_yyyyyz_0[j] + fr * tg_yzzzzzz_yyyyyz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyyz_0[j] - tg_zzzzzz_yyyyyz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_yzzzzzz_yyyyz_1[j];

                    tg_yyzzzzzz_yyyyzz_0[j] = pb_y * tg_yzzzzzz_yyyyzz_0[j] + fr * tg_yzzzzzz_yyyyzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyyzz_0[j] - tg_zzzzzz_yyyyzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_yzzzzzz_yyyzz_1[j];

                    tg_yyzzzzzz_yyyzzz_0[j] = pb_y * tg_yzzzzzz_yyyzzz_0[j] + fr * tg_yzzzzzz_yyyzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyyzzz_0[j] - tg_zzzzzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_yzzzzzz_yyzzz_1[j];

                    tg_yyzzzzzz_yyzzzz_0[j] = pb_y * tg_yzzzzzz_yyzzzz_0[j] + fr * tg_yzzzzzz_yyzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yyzzzz_0[j] - tg_zzzzzz_yyzzzz_1[j] * fl1_fza) + fl1_fxn * tg_yzzzzzz_yzzzz_1[j];

                    tg_yyzzzzzz_yzzzzz_0[j] = pb_y * tg_yzzzzzz_yzzzzz_0[j] + fr * tg_yzzzzzz_yzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_yzzzzz_0[j] - tg_zzzzzz_yzzzzz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_yzzzzzz_zzzzz_1[j];

                    tg_yyzzzzzz_zzzzzz_0[j] = pb_y * tg_yzzzzzz_zzzzzz_0[j] + fr * tg_yzzzzzz_zzzzzz_1[j] + 0.5 * fl1_fx * (tg_zzzzzz_zzzzzz_0[j] - tg_zzzzzz_zzzzzz_1[j] * fl1_fza);

                    tg_yzzzzzzz_xxxxxx_0[j] = pb_y * tg_zzzzzzz_xxxxxx_0[j] + fr * tg_zzzzzzz_xxxxxx_1[j];

                    tg_yzzzzzzz_xxxxxy_0[j] = pb_y * tg_zzzzzzz_xxxxxy_0[j] + fr * tg_zzzzzzz_xxxxxy_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_xxxxx_1[j];

                    tg_yzzzzzzz_xxxxxz_0[j] = pb_y * tg_zzzzzzz_xxxxxz_0[j] + fr * tg_zzzzzzz_xxxxxz_1[j];

                    tg_yzzzzzzz_xxxxyy_0[j] = pb_y * tg_zzzzzzz_xxxxyy_0[j] + fr * tg_zzzzzzz_xxxxyy_1[j] + fl1_fxn * tg_zzzzzzz_xxxxy_1[j];

                    tg_yzzzzzzz_xxxxyz_0[j] = pb_y * tg_zzzzzzz_xxxxyz_0[j] + fr * tg_zzzzzzz_xxxxyz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_xxxxz_1[j];

                    tg_yzzzzzzz_xxxxzz_0[j] = pb_y * tg_zzzzzzz_xxxxzz_0[j] + fr * tg_zzzzzzz_xxxxzz_1[j];

                    tg_yzzzzzzz_xxxyyy_0[j] = pb_y * tg_zzzzzzz_xxxyyy_0[j] + fr * tg_zzzzzzz_xxxyyy_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxxyy_1[j];

                    tg_yzzzzzzz_xxxyyz_0[j] = pb_y * tg_zzzzzzz_xxxyyz_0[j] + fr * tg_zzzzzzz_xxxyyz_1[j] + fl1_fxn * tg_zzzzzzz_xxxyz_1[j];

                    tg_yzzzzzzz_xxxyzz_0[j] = pb_y * tg_zzzzzzz_xxxyzz_0[j] + fr * tg_zzzzzzz_xxxyzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_xxxzz_1[j];

                    tg_yzzzzzzz_xxxzzz_0[j] = pb_y * tg_zzzzzzz_xxxzzz_0[j] + fr * tg_zzzzzzz_xxxzzz_1[j];

                    tg_yzzzzzzz_xxyyyy_0[j] = pb_y * tg_zzzzzzz_xxyyyy_0[j] + fr * tg_zzzzzzz_xxyyyy_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_xxyyy_1[j];

                    tg_yzzzzzzz_xxyyyz_0[j] = pb_y * tg_zzzzzzz_xxyyyz_0[j] + fr * tg_zzzzzzz_xxyyyz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xxyyz_1[j];

                    tg_yzzzzzzz_xxyyzz_0[j] = pb_y * tg_zzzzzzz_xxyyzz_0[j] + fr * tg_zzzzzzz_xxyyzz_1[j] + fl1_fxn * tg_zzzzzzz_xxyzz_1[j];

                    tg_yzzzzzzz_xxyzzz_0[j] = pb_y * tg_zzzzzzz_xxyzzz_0[j] + fr * tg_zzzzzzz_xxyzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_xxzzz_1[j];

                    tg_yzzzzzzz_xxzzzz_0[j] = pb_y * tg_zzzzzzz_xxzzzz_0[j] + fr * tg_zzzzzzz_xxzzzz_1[j];

                    tg_yzzzzzzz_xyyyyy_0[j] = pb_y * tg_zzzzzzz_xyyyyy_0[j] + fr * tg_zzzzzzz_xyyyyy_1[j] + 2.5 * fl1_fxn * tg_zzzzzzz_xyyyy_1[j];

                    tg_yzzzzzzz_xyyyyz_0[j] = pb_y * tg_zzzzzzz_xyyyyz_0[j] + fr * tg_zzzzzzz_xyyyyz_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_xyyyz_1[j];

                    tg_yzzzzzzz_xyyyzz_0[j] = pb_y * tg_zzzzzzz_xyyyzz_0[j] + fr * tg_zzzzzzz_xyyyzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_xyyzz_1[j];

                    tg_yzzzzzzz_xyyzzz_0[j] = pb_y * tg_zzzzzzz_xyyzzz_0[j] + fr * tg_zzzzzzz_xyyzzz_1[j] + fl1_fxn * tg_zzzzzzz_xyzzz_1[j];

                    tg_yzzzzzzz_xyzzzz_0[j] = pb_y * tg_zzzzzzz_xyzzzz_0[j] + fr * tg_zzzzzzz_xyzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_xzzzz_1[j];

                    tg_yzzzzzzz_xzzzzz_0[j] = pb_y * tg_zzzzzzz_xzzzzz_0[j] + fr * tg_zzzzzzz_xzzzzz_1[j];

                    tg_yzzzzzzz_yyyyyy_0[j] = pb_y * tg_zzzzzzz_yyyyyy_0[j] + fr * tg_zzzzzzz_yyyyyy_1[j] + 3.0 * fl1_fxn * tg_zzzzzzz_yyyyy_1[j];

                    tg_yzzzzzzz_yyyyyz_0[j] = pb_y * tg_zzzzzzz_yyyyyz_0[j] + fr * tg_zzzzzzz_yyyyyz_1[j] + 2.5 * fl1_fxn * tg_zzzzzzz_yyyyz_1[j];

                    tg_yzzzzzzz_yyyyzz_0[j] = pb_y * tg_zzzzzzz_yyyyzz_0[j] + fr * tg_zzzzzzz_yyyyzz_1[j] + 2.0 * fl1_fxn * tg_zzzzzzz_yyyzz_1[j];

                    tg_yzzzzzzz_yyyzzz_0[j] = pb_y * tg_zzzzzzz_yyyzzz_0[j] + fr * tg_zzzzzzz_yyyzzz_1[j] + 1.5 * fl1_fxn * tg_zzzzzzz_yyzzz_1[j];

                    tg_yzzzzzzz_yyzzzz_0[j] = pb_y * tg_zzzzzzz_yyzzzz_0[j] + fr * tg_zzzzzzz_yyzzzz_1[j] + fl1_fxn * tg_zzzzzzz_yzzzz_1[j];

                    tg_yzzzzzzz_yzzzzz_0[j] = pb_y * tg_zzzzzzz_yzzzzz_0[j] + fr * tg_zzzzzzz_yzzzzz_1[j] + 0.5 * fl1_fxn * tg_zzzzzzz_zzzzz_1[j];

                    tg_yzzzzzzz_zzzzzz_0[j] = pb_y * tg_zzzzzzz_zzzzzz_0[j] + fr * tg_zzzzzzz_zzzzzz_1[j];

                    fr = wp_z[j]; 

                    tg_zzzzzzzz_xxxxxx_0[j] = pb_z * tg_zzzzzzz_xxxxxx_0[j] + fr * tg_zzzzzzz_xxxxxx_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxxx_0[j] - tg_zzzzzz_xxxxxx_1[j] * fl1_fza);

                    tg_zzzzzzzz_xxxxxy_0[j] = pb_z * tg_zzzzzzz_xxxxxy_0[j] + fr * tg_zzzzzzz_xxxxxy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxxy_0[j] - tg_zzzzzz_xxxxxy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xxxxxz_0[j] = pb_z * tg_zzzzzzz_xxxxxz_0[j] + fr * tg_zzzzzzz_xxxxxz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxxz_0[j] - tg_zzzzzz_xxxxxz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_xxxxx_1[j];

                    tg_zzzzzzzz_xxxxyy_0[j] = pb_z * tg_zzzzzzz_xxxxyy_0[j] + fr * tg_zzzzzzz_xxxxyy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxyy_0[j] - tg_zzzzzz_xxxxyy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xxxxyz_0[j] = pb_z * tg_zzzzzzz_xxxxyz_0[j] + fr * tg_zzzzzzz_xxxxyz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxyz_0[j] - tg_zzzzzz_xxxxyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_xxxxy_1[j];

                    tg_zzzzzzzz_xxxxzz_0[j] = pb_z * tg_zzzzzzz_xxxxzz_0[j] + fr * tg_zzzzzzz_xxxxzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxxzz_0[j] - tg_zzzzzz_xxxxzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_xxxxz_1[j];

                    tg_zzzzzzzz_xxxyyy_0[j] = pb_z * tg_zzzzzzz_xxxyyy_0[j] + fr * tg_zzzzzzz_xxxyyy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxyyy_0[j] - tg_zzzzzz_xxxyyy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xxxyyz_0[j] = pb_z * tg_zzzzzzz_xxxyyz_0[j] + fr * tg_zzzzzzz_xxxyyz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxyyz_0[j] - tg_zzzzzz_xxxyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_xxxyy_1[j];

                    tg_zzzzzzzz_xxxyzz_0[j] = pb_z * tg_zzzzzzz_xxxyzz_0[j] + fr * tg_zzzzzzz_xxxyzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxyzz_0[j] - tg_zzzzzz_xxxyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_xxxyz_1[j];

                    tg_zzzzzzzz_xxxzzz_0[j] = pb_z * tg_zzzzzzz_xxxzzz_0[j] + fr * tg_zzzzzzz_xxxzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxxzzz_0[j] - tg_zzzzzz_xxxzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzzz_xxxzz_1[j];

                    tg_zzzzzzzz_xxyyyy_0[j] = pb_z * tg_zzzzzzz_xxyyyy_0[j] + fr * tg_zzzzzzz_xxyyyy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxyyyy_0[j] - tg_zzzzzz_xxyyyy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xxyyyz_0[j] = pb_z * tg_zzzzzzz_xxyyyz_0[j] + fr * tg_zzzzzzz_xxyyyz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxyyyz_0[j] - tg_zzzzzz_xxyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_xxyyy_1[j];

                    tg_zzzzzzzz_xxyyzz_0[j] = pb_z * tg_zzzzzzz_xxyyzz_0[j] + fr * tg_zzzzzzz_xxyyzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxyyzz_0[j] - tg_zzzzzz_xxyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_xxyyz_1[j];

                    tg_zzzzzzzz_xxyzzz_0[j] = pb_z * tg_zzzzzzz_xxyzzz_0[j] + fr * tg_zzzzzzz_xxyzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxyzzz_0[j] - tg_zzzzzz_xxyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzzz_xxyzz_1[j];

                    tg_zzzzzzzz_xxzzzz_0[j] = pb_z * tg_zzzzzzz_xxzzzz_0[j] + fr * tg_zzzzzzz_xxzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xxzzzz_0[j] - tg_zzzzzz_xxzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzzz_xxzzz_1[j];

                    tg_zzzzzzzz_xyyyyy_0[j] = pb_z * tg_zzzzzzz_xyyyyy_0[j] + fr * tg_zzzzzzz_xyyyyy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xyyyyy_0[j] - tg_zzzzzz_xyyyyy_1[j] * fl1_fza);

                    tg_zzzzzzzz_xyyyyz_0[j] = pb_z * tg_zzzzzzz_xyyyyz_0[j] + fr * tg_zzzzzzz_xyyyyz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xyyyyz_0[j] - tg_zzzzzz_xyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_xyyyy_1[j];

                    tg_zzzzzzzz_xyyyzz_0[j] = pb_z * tg_zzzzzzz_xyyyzz_0[j] + fr * tg_zzzzzzz_xyyyzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xyyyzz_0[j] - tg_zzzzzz_xyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_xyyyz_1[j];

                    tg_zzzzzzzz_xyyzzz_0[j] = pb_z * tg_zzzzzzz_xyyzzz_0[j] + fr * tg_zzzzzzz_xyyzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xyyzzz_0[j] - tg_zzzzzz_xyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzzz_xyyzz_1[j];

                    tg_zzzzzzzz_xyzzzz_0[j] = pb_z * tg_zzzzzzz_xyzzzz_0[j] + fr * tg_zzzzzzz_xyzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xyzzzz_0[j] - tg_zzzzzz_xyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzzz_xyzzz_1[j];

                    tg_zzzzzzzz_xzzzzz_0[j] = pb_z * tg_zzzzzzz_xzzzzz_0[j] + fr * tg_zzzzzzz_xzzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_xzzzzz_0[j] - tg_zzzzzz_xzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzzzz_xzzzz_1[j];

                    tg_zzzzzzzz_yyyyyy_0[j] = pb_z * tg_zzzzzzz_yyyyyy_0[j] + fr * tg_zzzzzzz_yyyyyy_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yyyyyy_0[j] - tg_zzzzzz_yyyyyy_1[j] * fl1_fza);

                    tg_zzzzzzzz_yyyyyz_0[j] = pb_z * tg_zzzzzzz_yyyyyz_0[j] + fr * tg_zzzzzzz_yyyyyz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yyyyyz_0[j] - tg_zzzzzz_yyyyyz_1[j] * fl1_fza) + 0.5 * fl1_fxn * tg_zzzzzzz_yyyyy_1[j];

                    tg_zzzzzzzz_yyyyzz_0[j] = pb_z * tg_zzzzzzz_yyyyzz_0[j] + fr * tg_zzzzzzz_yyyyzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yyyyzz_0[j] - tg_zzzzzz_yyyyzz_1[j] * fl1_fza) + fl1_fxn * tg_zzzzzzz_yyyyz_1[j];

                    tg_zzzzzzzz_yyyzzz_0[j] = pb_z * tg_zzzzzzz_yyyzzz_0[j] + fr * tg_zzzzzzz_yyyzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yyyzzz_0[j] - tg_zzzzzz_yyyzzz_1[j] * fl1_fza) + 1.5 * fl1_fxn * tg_zzzzzzz_yyyzz_1[j];

                    tg_zzzzzzzz_yyzzzz_0[j] = pb_z * tg_zzzzzzz_yyzzzz_0[j] + fr * tg_zzzzzzz_yyzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yyzzzz_0[j] - tg_zzzzzz_yyzzzz_1[j] * fl1_fza) + 2.0 * fl1_fxn * tg_zzzzzzz_yyzzz_1[j];

                    tg_zzzzzzzz_yzzzzz_0[j] = pb_z * tg_zzzzzzz_yzzzzz_0[j] + fr * tg_zzzzzzz_yzzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_yzzzzz_0[j] - tg_zzzzzz_yzzzzz_1[j] * fl1_fza) + 2.5 * fl1_fxn * tg_zzzzzzz_yzzzz_1[j];

                    tg_zzzzzzzz_zzzzzz_0[j] = pb_z * tg_zzzzzzz_zzzzzz_0[j] + fr * tg_zzzzzzz_zzzzzz_1[j] + 3.5 * fl1_fx * (tg_zzzzzz_zzzzzz_0[j] - tg_zzzzzz_zzzzzz_1[j] * fl1_fza) + 3.0 * fl1_fxn * tg_zzzzzzz_zzzzz_1[j];
                }

                idx++;
            }
        }
    }


} // erirecfunc namespace

